@@ -114,19 +114,6 @@
 
 //---------------------------------------------------------------------------
 
-    // Borland C++ and C++ Builder
-#if defined (__BORLANDC__)
-    // by default, if runtime is linked as a DLL, then so is Metakit
-#if defined (_RTLDLL) && !defined (q4_KITDLL)
-#define q4_KITDLL 1
-#endif
-
-    // Borland 5.0 supports the bool datatype
-#if __BORLANDC__ >= 0x500
-#define q4_BOOL 1
-#endif
-#endif // __BORLANDC__
-
     // IRIX supports the bool datatype
     // define before gcc to cover both the gcc and MipsPRO compiler
 #if defined (sgi)
@@ -151,17 +138,6 @@
 #ifndef HAVE_LONG_LONG
 #define HAVE_LONG_LONG 1
 #endif
-#endif
-
-    // Metrowerks CodeWarrior
-#if defined (__MWERKS__)
-#if __option(bool)
-#define q4_BOOL 1       // bool datatype is optionally supported
-    // undef, these conflict with c4_Storage::c4_Storage overloading
-#undef bool
-#undef true
-#undef false
-#endif
 #endif
 
     // Microsoft Visual C++
