@@ -30,7 +30,7 @@ class TQBoxLayout;
 class KArtsWidget;
 
 class KLevelMeter_Private : public TQObject {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
 	Arts::KLevelMeter_impl* _impl;
