@@ -88,7 +88,7 @@ public:
 		TQPainter p( this );
 		TQStyle::SFlags flags = TQStyle::Style_Default;
 		if( width() < height() ) flags |= TQStyle::Style_Horizontal;
-		style().tqdrawPrimitive( TQStyle::PE_DockWindowHandle, &p, rect(), colorGroup(), flags );
+		style().drawPrimitive( TQStyle::PE_DockWindowHandle, &p, rect(), colorGroup(), flags );
 	}
 signals:
 	void clicked();
@@ -118,7 +118,7 @@ private:
 public:
 	ShowButton( TQWidget *parent, const char* name=0 ) : TQPushButton( parent,name ), _dir( TQBoxLayout::LeftToRight )
 	{
-		connect( this, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( owntoggle( bool ) ) );
+		connect( this, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( owntoggle( bool ) ) );
 		setToggleButton( true );
 		_pmleft = TQPixmap( const_cast<const char**>( left_xpm ) );
 		_pmright = TQPixmap( const_cast<const char**>( right_xpm ) );
@@ -174,7 +174,7 @@ private:
 public:
 	OwnButton( TQWidget *parent, const char* name=0 ) : TQPushButton( parent,name )
 	{
-		connect( this, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( toggle( bool ) ) );
+		connect( this, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( toggle( bool ) ) );
 		setToggleButton( true );
 		_pmown = TQPixmap( const_cast<const char**>( own_xpm ) );
 		_pminside = TQPixmap( const_cast<const char**>( inside_xpm ) );
