@@ -67,12 +67,12 @@
 LogTextEdit::LogTextEdit( TQWidget *parent, const char *name ) : TQTextEdit( parent, name )
 {
 #ifdef KDE_3_2_FEATURES
-	m_clear = KStdAction::clear( TQT_TQOBJECT(this), TQT_SLOT( clear() ), 0 );
+	m_clear = KStdAction::clear( this, TQ_SLOT( clear() ), 0 );
 #else
-	m_clear = new TDEAction( i18n("Clear"), "clear", NULL, TQT_TQOBJECT(this), TQT_SLOT( clear() ), static_cast<TDEActionCollection *>(0), "clear" );
+	m_clear = new TDEAction( i18n("Clear"), "clear", NULL, this, TQ_SLOT( clear() ), static_cast<TDEActionCollection *>(0), "clear" );
 #endif
-	m_selectAll = KStdAction::selectAll( TQT_TQOBJECT(this), TQT_SLOT( selectAll() ), 0 );
-	m_copy = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( copy() ), 0 );
+	m_selectAll = KStdAction::selectAll( this, TQ_SLOT( selectAll() ), 0 );
+	m_copy = KStdAction::copy( this, TQ_SLOT( copy() ), 0 );
 }
 
 LogTextEdit::~LogTextEdit()
@@ -102,13 +102,13 @@ Atlantik::Atlantik ()
 	readConfig();
 
 	// Toolbar: Game
-//	KStdGameAction::gameNew(this, TQT_SLOT(slotNewGame()), actionCollection(), "game_new");
-        m_showEventLog = new TDEAction(i18n("Show Event &Log")/*, "atlantik_showeventlog"*/, CTRL+Key_L, TQT_TQOBJECT(this), TQT_SLOT(showEventLog()), actionCollection(), "showeventlog");
-	KStdGameAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(closeAllWindows()), actionCollection(), "game_quit");
+//	KStdGameAction::gameNew(this, TQ_SLOT(slotNewGame()), actionCollection(), "game_new");
+        m_showEventLog = new TDEAction(i18n("Show Event &Log")/*, "atlantik_showeventlog"*/, CTRL+Key_L, this, TQ_SLOT(showEventLog()), actionCollection(), "showeventlog");
+	KStdGameAction::quit(kapp, TQ_SLOT(closeAllWindows()), actionCollection(), "game_quit");
 
 	// Toolbar: Settings
-	KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotConfigure()), actionCollection());
-	KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(configureNotifications()), actionCollection());
+	KStdAction::preferences(this, TQ_SLOT(slotConfigure()), actionCollection());
+	KStdAction::configureNotifications(this, TQ_SLOT(configureNotifications()), actionCollection());
 
 	// Initialize pointers to 0L
 	m_configDialog = 0;
@@ -120,29 +120,29 @@ Atlantik::Atlantik ()
 	m_atlantikNetwork = 0;
 
 	// Game and network core
-	m_atlanticCore = new AtlanticCore(TQT_TQOBJECT(this), "atlanticCore");
-	connect(m_atlanticCore, TQT_SIGNAL(createGUI(Player *)), TQT_TQOBJECT(this), TQT_SLOT(newPlayer(Player *)));
-	connect(m_atlanticCore, TQT_SIGNAL(removeGUI(Player *)), TQT_TQOBJECT(this), TQT_SLOT(removeGUI(Player *)));
-	connect(m_atlanticCore, TQT_SIGNAL(createGUI(Trade *)), TQT_TQOBJECT(this), TQT_SLOT(newTrade(Trade *)));
-	connect(m_atlanticCore, TQT_SIGNAL(removeGUI(Trade *)), TQT_TQOBJECT(this), TQT_SLOT(removeGUI(Trade *)));
+	m_atlanticCore = new AtlanticCore(this, "atlanticCore");
+	connect(m_atlanticCore, TQ_SIGNAL(createGUI(Player *)), this, TQ_SLOT(newPlayer(Player *)));
+	connect(m_atlanticCore, TQ_SIGNAL(removeGUI(Player *)), this, TQ_SLOT(removeGUI(Player *)));
+	connect(m_atlanticCore, TQ_SIGNAL(createGUI(Trade *)), this, TQ_SLOT(newTrade(Trade *)));
+	connect(m_atlanticCore, TQ_SIGNAL(removeGUI(Trade *)), this, TQ_SLOT(removeGUI(Trade *)));
 
 	initEventLog();
 	initNetworkObject();
 
 	// Menu,toolbar: Move
-	m_roll = KStdGameAction::roll(TQT_TQOBJECT(this), TQT_SIGNAL(rollDice()), actionCollection());
+	m_roll = KStdGameAction::roll(this, TQ_SIGNAL(rollDice()), actionCollection());
 	m_roll->setEnabled(false);
-	m_buyEstate = new TDEAction(i18n("&Buy"), "atlantik_buy_estate", CTRL+Key_B, TQT_TQOBJECT(this), TQT_SIGNAL(buyEstate()), actionCollection(), "buy_estate");
+	m_buyEstate = new TDEAction(i18n("&Buy"), "atlantik_buy_estate", CTRL+Key_B, this, TQ_SIGNAL(buyEstate()), actionCollection(), "buy_estate");
 	m_buyEstate->setEnabled(false);
-	m_auctionEstate = new TDEAction(i18n("&Auction"), "auction", CTRL+Key_A, TQT_TQOBJECT(this), TQT_SIGNAL(auctionEstate()), actionCollection(), "auction");
+	m_auctionEstate = new TDEAction(i18n("&Auction"), "auction", CTRL+Key_A, this, TQ_SIGNAL(auctionEstate()), actionCollection(), "auction");
 	m_auctionEstate->setEnabled(false);
-	m_endTurn = KStdGameAction::endTurn(TQT_TQOBJECT(this), TQT_SIGNAL(endTurn()), actionCollection());
+	m_endTurn = KStdGameAction::endTurn(this, TQ_SIGNAL(endTurn()), actionCollection());
 	m_endTurn->setEnabled(false);
-        m_jailCard = new TDEAction(i18n("Use Card to Leave Jail")/*, "atlantik_move_jail_card"*/, 0, TQT_TQOBJECT(this), TQT_SIGNAL(jailCard()), actionCollection(), "move_jailcard");
+        m_jailCard = new TDEAction(i18n("Use Card to Leave Jail")/*, "atlantik_move_jail_card"*/, 0, this, TQ_SIGNAL(jailCard()), actionCollection(), "move_jailcard");
 	m_jailCard->setEnabled(false);
-	m_jailPay = new TDEAction(i18n("&Pay to Leave Jail"), "jail_pay", CTRL+Key_P, TQT_TQOBJECT(this), TQT_SIGNAL(jailPay()), actionCollection(), "move_jailpay");
+	m_jailPay = new TDEAction(i18n("&Pay to Leave Jail"), "jail_pay", CTRL+Key_P, this, TQ_SIGNAL(jailPay()), actionCollection(), "move_jailpay");
 	m_jailPay->setEnabled(false);
-        m_jailRoll = new TDEAction(i18n("Roll to Leave &Jail")/*, "atlantik_move_jail_roll"*/, CTRL+Key_J, TQT_TQOBJECT(this), TQT_SIGNAL(jailRoll()), actionCollection(), "move_jailroll");
+        m_jailRoll = new TDEAction(i18n("Roll to Leave &Jail")/*, "atlantik_move_jail_roll"*/, CTRL+Key_J, this, TQ_SIGNAL(jailRoll()), actionCollection(), "move_jailroll");
 	m_jailRoll->setEnabled(false);
 
 	// Mix code and XML into GUI
@@ -150,7 +150,7 @@ Atlantik::Atlantik ()
 	applyMainWindowSettings( TDEGlobal::config(), "AtlantikMainWindow" );
 	TDEMainWindow::statusBar()->insertItem("Atlantik " ATLANTIK_VERSION_STRING, 0);
 	TDEMainWindow::statusBar()->insertItem(TQString(), 1);
-	connect(statusBar(), TQT_SIGNAL(released(int)), TQT_TQOBJECT(this), TQT_SLOT(statusBarClick(int)));
+	connect(statusBar(), TQ_SIGNAL(released(int)), this, TQ_SLOT(statusBarClick(int)));
 
 	// Main widget, containing all others
  	m_mainWidget = new TQWidget(this, "main");
@@ -192,7 +192,7 @@ Atlantik::Atlantik ()
 
 	m_serverMsgs->setFocusProxy(m_input);
 
-	connect(m_input, TQT_SIGNAL(returnPressed()), TQT_TQOBJECT(this), TQT_SLOT(slotSendMsg()));
+	connect(m_input, TQ_SIGNAL(returnPressed()), this, TQ_SLOT(slotSendMsg()));
 
 	// Set stretching where we want it.
 	m_mainLayout->setRowStretch(1, 1); // make m_board+m_serverMsgs stretch vertically, not the rest
@@ -253,9 +253,9 @@ void Atlantik::newPlayer(Player *player)
 	// we'd better force an update.
 	playerChanged(player);
 
-	connect(player, TQT_SIGNAL(changed(Player *)), TQT_TQOBJECT(this), TQT_SLOT(playerChanged(Player *)));
-	connect(player, TQT_SIGNAL(gainedTurn()), TQT_TQOBJECT(this), TQT_SLOT(gainedTurn()));
-	connect(player, TQT_SIGNAL(changed(Player *)), m_board, TQT_SLOT(playerChanged(Player *)));
+	connect(player, TQ_SIGNAL(changed(Player *)), this, TQ_SLOT(playerChanged(Player *)));
+	connect(player, TQ_SIGNAL(gainedTurn()), this, TQ_SLOT(gainedTurn()));
+	connect(player, TQ_SIGNAL(changed(Player *)), m_board, TQ_SLOT(playerChanged(Player *)));
 
 	KNotifyClient::event(winId(), "newplayer");
 }
@@ -314,8 +314,8 @@ void Atlantik::showSelectServer()
 	m_atlanticCore->reset(true);
 	initNetworkObject();
 
-	connect(m_selectServer, TQT_SIGNAL(serverConnect(const TQString, int)), m_atlantikNetwork, TQT_SLOT(serverConnect(const TQString, int)));
-	connect(m_selectServer, TQT_SIGNAL(msgStatus(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotMsgStatus(const TQString &)));
+	connect(m_selectServer, TQ_SIGNAL(serverConnect(const TQString, int)), m_atlantikNetwork, TQ_SLOT(serverConnect(const TQString, int)));
+	connect(m_selectServer, TQ_SIGNAL(msgStatus(const TQString &)), this, TQ_SLOT(slotMsgStatus(const TQString &)));
 
 	m_selectServer->slotRefresh( m_config.connectOnStart );
 }
@@ -354,10 +354,10 @@ void Atlantik::showSelectGame()
 		m_selectConfiguration = 0;
 	}
 
-	connect(m_selectGame, TQT_SIGNAL(joinGame(int)), m_atlantikNetwork, TQT_SLOT(joinGame(int)));
-	connect(m_selectGame, TQT_SIGNAL(newGame(const TQString &)), m_atlantikNetwork, TQT_SLOT(newGame(const TQString &)));
-	connect(m_selectGame, TQT_SIGNAL(leaveServer()), TQT_TQOBJECT(this), TQT_SLOT(showSelectServer()));
-	connect(m_selectGame, TQT_SIGNAL(msgStatus(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotMsgStatus(const TQString &)));
+	connect(m_selectGame, TQ_SIGNAL(joinGame(int)), m_atlantikNetwork, TQ_SLOT(joinGame(int)));
+	connect(m_selectGame, TQ_SIGNAL(newGame(const TQString &)), m_atlantikNetwork, TQ_SLOT(newGame(const TQString &)));
+	connect(m_selectGame, TQ_SIGNAL(leaveServer()), this, TQ_SLOT(showSelectServer()));
+	connect(m_selectGame, TQ_SIGNAL(msgStatus(const TQString &)), this, TQ_SLOT(slotMsgStatus(const TQString &)));
 }
 
 void Atlantik::showSelectConfiguration()
@@ -375,15 +375,15 @@ void Atlantik::showSelectConfiguration()
 	m_mainLayout->addMultiCellWidget(m_selectConfiguration, 0, 2, 1, 1);
 	m_selectConfiguration->show();
 
-	connect(m_atlanticCore, TQT_SIGNAL(createGUI(ConfigOption *)), m_selectConfiguration, TQT_SLOT(addConfigOption(ConfigOption *)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(gameOption(TQString, TQString, TQString, TQString, TQString)), m_selectConfiguration, TQT_SLOT(gameOption(TQString, TQString, TQString, TQString, TQString)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(gameInit()), m_selectConfiguration, TQT_SLOT(initGame()));
-	connect(m_selectConfiguration, TQT_SIGNAL(startGame()), m_atlantikNetwork, TQT_SLOT(startGame()));
-	connect(m_selectConfiguration, TQT_SIGNAL(leaveGame()), m_atlantikNetwork, TQT_SLOT(leaveGame()));
-	connect(m_selectConfiguration, TQT_SIGNAL(changeOption(int, const TQString &)), m_atlantikNetwork, TQT_SLOT(changeOption(int, const TQString &)));
-	connect(m_selectConfiguration, TQT_SIGNAL(buttonCommand(TQString)), m_atlantikNetwork, TQT_SLOT(writeData(TQString)));
-	connect(m_selectConfiguration, TQT_SIGNAL(iconSelected(const TQString &)), m_atlantikNetwork, TQT_SLOT(setImage(const TQString &)));
-	connect(m_selectConfiguration, TQT_SIGNAL(statusMessage(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotMsgStatus(const TQString &)));
+	connect(m_atlanticCore, TQ_SIGNAL(createGUI(ConfigOption *)), m_selectConfiguration, TQ_SLOT(addConfigOption(ConfigOption *)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(gameOption(TQString, TQString, TQString, TQString, TQString)), m_selectConfiguration, TQ_SLOT(gameOption(TQString, TQString, TQString, TQString, TQString)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(gameInit()), m_selectConfiguration, TQ_SLOT(initGame()));
+	connect(m_selectConfiguration, TQ_SIGNAL(startGame()), m_atlantikNetwork, TQ_SLOT(startGame()));
+	connect(m_selectConfiguration, TQ_SIGNAL(leaveGame()), m_atlantikNetwork, TQ_SLOT(leaveGame()));
+	connect(m_selectConfiguration, TQ_SIGNAL(changeOption(int, const TQString &)), m_atlantikNetwork, TQ_SLOT(changeOption(int, const TQString &)));
+	connect(m_selectConfiguration, TQ_SIGNAL(buttonCommand(TQString)), m_atlantikNetwork, TQ_SLOT(writeData(TQString)));
+	connect(m_selectConfiguration, TQ_SIGNAL(iconSelected(const TQString &)), m_atlantikNetwork, TQ_SLOT(setImage(const TQString &)));
+	connect(m_selectConfiguration, TQ_SIGNAL(statusMessage(const TQString &)), this, TQ_SLOT(slotMsgStatus(const TQString &)));
 }
 
 void Atlantik::initBoard()
@@ -394,11 +394,11 @@ void Atlantik::initBoard()
 	m_board = new AtlantikBoard(m_atlanticCore, 40, AtlantikBoard::Play, m_mainWidget, "board");
 	m_board->setViewProperties(m_config.indicateUnowned, m_config.highliteUnowned, m_config.darkenMortgaged, m_config.quartzEffects, m_config.animateTokens);
 
-	connect(m_atlantikNetwork, TQT_SIGNAL(displayDetails(TQString, bool, bool, Estate *)), m_board, TQT_SLOT(insertDetails(TQString, bool, bool, Estate *)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(addCommandButton(TQString, TQString, bool)), m_board, TQT_SLOT(displayButton(TQString, TQString, bool)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(addCloseButton()), m_board, TQT_SLOT(addCloseButton()));
-	connect(m_board, TQT_SIGNAL(tokenConfirmation(Estate *)), m_atlantikNetwork, TQT_SLOT(tokenConfirmation(Estate *)));
-	connect(m_board, TQT_SIGNAL(buttonCommand(TQString)), m_atlantikNetwork, TQT_SLOT(writeData(TQString)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(displayDetails(TQString, bool, bool, Estate *)), m_board, TQ_SLOT(insertDetails(TQString, bool, bool, Estate *)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(addCommandButton(TQString, TQString, bool)), m_board, TQ_SLOT(displayButton(TQString, TQString, bool)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(addCloseButton()), m_board, TQ_SLOT(addCloseButton()));
+	connect(m_board, TQ_SIGNAL(tokenConfirmation(Estate *)), m_atlantikNetwork, TQ_SLOT(tokenConfirmation(Estate *)));
+	connect(m_board, TQ_SIGNAL(buttonCommand(TQString)), m_atlantikNetwork, TQ_SLOT(writeData(TQString)));
 }
 
 void Atlantik::showBoard()
@@ -491,7 +491,7 @@ void Atlantik::slotConfigure()
 		m_configDialog = new ConfigDialog(this);
 	m_configDialog->show();
 
-	connect(m_configDialog, TQT_SIGNAL(okClicked()), TQT_TQOBJECT(this), TQT_SLOT(slotUpdateConfig()));
+	connect(m_configDialog, TQ_SIGNAL(okClicked()), this, TQ_SLOT(slotUpdateConfig()));
 }
 
 void Atlantik::showEventLog()
@@ -728,35 +728,35 @@ void Atlantik::initNetworkObject()
 	}
 
 	m_atlantikNetwork = new AtlantikNetwork(m_atlanticCore);
-	connect(m_atlantikNetwork, TQT_SIGNAL(msgInfo(TQString)), TQT_TQOBJECT(this), TQT_SLOT(slotMsgInfo(TQString)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(msgError(TQString)), TQT_TQOBJECT(this), TQT_SLOT(slotMsgError(TQString)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(msgStatus(const TQString &, const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(slotMsgStatus(const TQString &, const TQString &)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(msgChat(TQString, TQString)), TQT_TQOBJECT(this), TQT_SLOT(slotMsgChat(TQString, TQString)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(msgInfo(TQString)), this, TQ_SLOT(slotMsgInfo(TQString)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(msgError(TQString)), this, TQ_SLOT(slotMsgError(TQString)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(msgStatus(const TQString &, const TQString &)), this, TQ_SLOT(slotMsgStatus(const TQString &, const TQString &)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(msgChat(TQString, TQString)), this, TQ_SLOT(slotMsgChat(TQString, TQString)));
 
-	connect(m_atlantikNetwork, TQT_SIGNAL(connectionSuccess()), TQT_TQOBJECT(this), TQT_SLOT(slotNetworkConnected()));
-	connect(m_atlantikNetwork, TQT_SIGNAL(connectionFailed(int)), TQT_TQOBJECT(this), TQT_SLOT(slotNetworkError(int)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(closed(int)), TQT_TQOBJECT(this), TQT_SLOT(networkClosed(int)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(connectionSuccess()), this, TQ_SLOT(slotNetworkConnected()));
+	connect(m_atlantikNetwork, TQ_SIGNAL(connectionFailed(int)), this, TQ_SLOT(slotNetworkError(int)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(closed(int)), this, TQ_SLOT(networkClosed(int)));
 
-	connect(m_atlantikNetwork, TQT_SIGNAL(receivedHandshake()), TQT_TQOBJECT(this), TQT_SLOT(sendHandshake()));
+	connect(m_atlantikNetwork, TQ_SIGNAL(receivedHandshake()), this, TQ_SLOT(sendHandshake()));
 
-	connect(m_atlantikNetwork, TQT_SIGNAL(gameConfig()), TQT_TQOBJECT(this), TQT_SLOT(showSelectConfiguration()));
-	connect(m_atlantikNetwork, TQT_SIGNAL(gameInit()), TQT_TQOBJECT(this), TQT_SLOT(initBoard()));
-	connect(m_atlantikNetwork, TQT_SIGNAL(gameRun()), TQT_TQOBJECT(this), TQT_SLOT(showBoard()));
-	connect(m_atlantikNetwork, TQT_SIGNAL(gameEnd()), TQT_TQOBJECT(this), TQT_SLOT(freezeBoard()));
+	connect(m_atlantikNetwork, TQ_SIGNAL(gameConfig()), this, TQ_SLOT(showSelectConfiguration()));
+	connect(m_atlantikNetwork, TQ_SIGNAL(gameInit()), this, TQ_SLOT(initBoard()));
+	connect(m_atlantikNetwork, TQ_SIGNAL(gameRun()), this, TQ_SLOT(showBoard()));
+	connect(m_atlantikNetwork, TQ_SIGNAL(gameEnd()), this, TQ_SLOT(freezeBoard()));
 
-	connect(m_atlantikNetwork, TQT_SIGNAL(newEstate(Estate *)), TQT_TQOBJECT(this), TQT_SLOT(newEstate(Estate *)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(newAuction(Auction *)), TQT_TQOBJECT(this), TQT_SLOT(newAuction(Auction *)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(newEstate(Estate *)), this, TQ_SLOT(newEstate(Estate *)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(newAuction(Auction *)), this, TQ_SLOT(newAuction(Auction *)));
 
-	connect(m_atlantikNetwork, TQT_SIGNAL(clientCookie(TQString)), TQT_TQOBJECT(this), TQT_SLOT(clientCookie(TQString)));
-	connect(m_atlantikNetwork, TQT_SIGNAL(networkEvent(const TQString &, const TQString &)), m_eventLog, TQT_SLOT(addEvent(const TQString &, const TQString &)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(clientCookie(TQString)), this, TQ_SLOT(clientCookie(TQString)));
+	connect(m_atlantikNetwork, TQ_SIGNAL(networkEvent(const TQString &, const TQString &)), m_eventLog, TQ_SLOT(addEvent(const TQString &, const TQString &)));
 
-	connect(this, TQT_SIGNAL(rollDice()), m_atlantikNetwork, TQT_SLOT(rollDice()));
-	connect(this, TQT_SIGNAL(buyEstate()), m_atlantikNetwork, TQT_SLOT(buyEstate()));
-	connect(this, TQT_SIGNAL(auctionEstate()), m_atlantikNetwork, TQT_SLOT(auctionEstate()));
-	connect(this, TQT_SIGNAL(endTurn()), m_atlantikNetwork, TQT_SLOT(endTurn()));
-	connect(this, TQT_SIGNAL(jailCard()), m_atlantikNetwork, TQT_SLOT(jailCard()));
-	connect(this, TQT_SIGNAL(jailPay()), m_atlantikNetwork, TQT_SLOT(jailPay()));
-	connect(this, TQT_SIGNAL(jailRoll()), m_atlantikNetwork, TQT_SLOT(jailRoll()));
+	connect(this, TQ_SIGNAL(rollDice()), m_atlantikNetwork, TQ_SLOT(rollDice()));
+	connect(this, TQ_SIGNAL(buyEstate()), m_atlantikNetwork, TQ_SLOT(buyEstate()));
+	connect(this, TQ_SIGNAL(auctionEstate()), m_atlantikNetwork, TQ_SLOT(auctionEstate()));
+	connect(this, TQ_SIGNAL(endTurn()), m_atlantikNetwork, TQ_SLOT(endTurn()));
+	connect(this, TQ_SIGNAL(jailCard()), m_atlantikNetwork, TQ_SLOT(jailCard()));
+	connect(this, TQ_SIGNAL(jailPay()), m_atlantikNetwork, TQ_SLOT(jailPay()));
+	connect(this, TQ_SIGNAL(jailRoll()), m_atlantikNetwork, TQ_SLOT(jailRoll()));
 }
 
 void Atlantik::clientCookie(TQString cookie)
@@ -812,10 +812,10 @@ PortfolioView *Atlantik::addPortfolioView(Player *player)
 	if ( m_portfolioViews.count() > 0 && m_portfolioScroll->isHidden() )
 		m_portfolioScroll->show();
 
-	connect(player, TQT_SIGNAL(changed(Player *)), portfolioView, TQT_SLOT(playerChanged()));
-	connect(portfolioView, TQT_SIGNAL(newTrade(Player *)), m_atlantikNetwork, TQT_SLOT(newTrade(Player *)));
-	connect(portfolioView, TQT_SIGNAL(kickPlayer(Player *)), m_atlantikNetwork, TQT_SLOT(kickPlayer(Player *)));
-	connect(portfolioView, TQT_SIGNAL(estateClicked(Estate *)), m_board, TQT_SLOT(prependEstateDetails(Estate *)));
+	connect(player, TQ_SIGNAL(changed(Player *)), portfolioView, TQ_SLOT(playerChanged()));
+	connect(portfolioView, TQ_SIGNAL(newTrade(Player *)), m_atlantikNetwork, TQ_SLOT(newTrade(Player *)));
+	connect(portfolioView, TQ_SIGNAL(kickPlayer(Player *)), m_atlantikNetwork, TQ_SLOT(kickPlayer(Player *)));
+	connect(portfolioView, TQ_SIGNAL(estateClicked(Estate *)), m_board, TQ_SLOT(prependEstateDetails(Estate *)));
 
 	m_portfolioLayout->addWidget(portfolioView);
 	portfolioView->show();
