@@ -23,7 +23,7 @@
 
 class LIBATLANTIC_EXPORT EstateGroup : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
