@@ -47,7 +47,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "marshall.cpp"
 
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #endif
@@ -429,7 +429,7 @@ TQStringList dcopSessionList( const TQString &user, const TQString &home )
 
 void sendUserTime( const char* app )
 {
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
     static unsigned long time = 0;
     if( time == 0 )
     {
