@@ -9,7 +9,7 @@
 class DCOPRSSIface : public TQObject, public DCOPObject
 {
 	K_DCOP
-	Q_OBJECT
+	TQ_OBJECT
 //	
 	public:
 		DCOPRSSIface( TQObject *parent, const char *name = 0 );
@@ -26,7 +26,7 @@ class DCOPRSSIface : public TQObject, public DCOPObject
 
 class CategoryItem : public TQObject, public TDEListViewItem
 {
-	Q_OBJECT
+	TQ_OBJECT
 //	
 	public:
 		CategoryItem( TDEListView *parent, const TQString &category );
@@ -48,7 +48,7 @@ class CategoryItem : public TQObject, public TDEListViewItem
 
 class FeedBrowserDlg : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 //	
 	friend class CategoryItem;
 	public:
