@@ -202,8 +202,8 @@ KcmSambaConf::~KcmSambaConf() {
 
 void KcmSambaConf::createSmbConfigWidget() {
   m_smbConfConfigWidget = new SmbConfConfigWidget(this);
-  connect( m_smbConfConfigWidget, TQT_SIGNAL(smbConfChoosed(const TQString &)),
-           this, TQT_SLOT(slotSpecifySmbConf(const TQString &)));
+  connect( m_smbConfConfigWidget, TQ_SIGNAL(smbConfChoosed(const TQString &)),
+           this, TQ_SLOT(slotSpecifySmbConf(const TQString &)));
 }
 
 void KcmSambaConf::slotSpecifySmbConf(const TQString & smbConf) {
@@ -231,45 +231,45 @@ void KcmSambaConf::init() {
   _interface = new KcmInterface(this);
 
 
-  connect ( _interface->sambaUserPasswordBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(sambaUserPasswordBtnClicked()));
+  connect ( _interface->sambaUserPasswordBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(sambaUserPasswordBtnClicked()));
 
-  connect ( _interface->editShareBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(editShare()));
-  connect ( _interface->addShareBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(addShare()));
-  connect ( _interface->removeShareBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(removeShare()));
+  connect ( _interface->editShareBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(editShare()));
+  connect ( _interface->addShareBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(addShare()));
+  connect ( _interface->removeShareBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(removeShare()));
 
-  connect ( _interface->editPrinterBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(editPrinter()));
-  connect ( _interface->addPrinterBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(addPrinter()));
-  connect ( _interface->removePrinterBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(removePrinter()));
+  connect ( _interface->editPrinterBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(editPrinter()));
+  connect ( _interface->addPrinterBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(addPrinter()));
+  connect ( _interface->removePrinterBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(removePrinter()));
 
-  connect ( _interface->editDefaultPrinterBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(editPrinterDefaults()));
-  connect ( _interface->editDefaultShareBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(editShareDefaults()));
+  connect ( _interface->editDefaultPrinterBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(editPrinterDefaults()));
+  connect ( _interface->editDefaultShareBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(editShareDefaults()));
 
-  connect( _interface->domainRadio, TQT_SIGNAL(toggled(bool)),
-          _interface->joinADomainBtn, TQT_SLOT( setEnabled(bool) ));
+  connect( _interface->domainRadio, TQ_SIGNAL(toggled(bool)),
+          _interface->joinADomainBtn, TQ_SLOT( setEnabled(bool) ));
 
-  connect(_interface->nullPasswordsChk,TQT_SIGNAL(toggled(bool)),
-          this, TQT_SLOT(nullPasswordsEnabled(bool)));
+  connect(_interface->nullPasswordsChk,TQ_SIGNAL(toggled(bool)),
+          this, TQ_SLOT(nullPasswordsEnabled(bool)));
 
-  connect( _interface->addSambaUserBtn, TQT_SIGNAL(clicked()),
-          this, TQT_SLOT( addSambaUserBtnClicked() ));
+  connect( _interface->addSambaUserBtn, TQ_SIGNAL(clicked()),
+          this, TQ_SLOT( addSambaUserBtnClicked() ));
 
-  connect( _interface->removeSambaUserBtn, TQT_SIGNAL(clicked()),
-          this, TQT_SLOT( removeSambaUserBtnClicked() ));
+  connect( _interface->removeSambaUserBtn, TQ_SIGNAL(clicked()),
+          this, TQ_SLOT( removeSambaUserBtnClicked() ));
 
   _interface->removeSambaUserBtn->setIconSet(SmallIconSet("1rightarrow"));
   _interface->addSambaUserBtn->setIconSet(SmallIconSet("1leftarrow"));
 
 
-  connect( _interface->sambaUsersListView, TQT_SIGNAL(mouseButtonPressed(int,TQListViewItem*,const TQPoint &,int)),
-          this, TQT_SLOT(slotMouseButtonPressed(int,TQListViewItem*,const TQPoint &,int)));
+  connect( _interface->sambaUsersListView, TQ_SIGNAL(mouseButtonPressed(int,TQListViewItem*,const TQPoint &,int)),
+          this, TQ_SLOT(slotMouseButtonPressed(int,TQListViewItem*,const TQPoint &,int)));
 
-  connect( _interface->joinADomainBtn, TQT_SIGNAL(clicked()),
-          this, TQT_SLOT( joinADomainBtnClicked() ));
+  connect( _interface->joinADomainBtn, TQ_SIGNAL(clicked()),
+          this, TQ_SLOT( joinADomainBtnClicked() ));
 
-  connect( _interface->loadBtn, TQT_SIGNAL(clicked()),
-          this, TQT_SLOT( loadBtnClicked() ));
+  connect( _interface->loadBtn, TQ_SIGNAL(clicked()),
+          this, TQ_SLOT( loadBtnClicked() ));
 
-  connect( _interface, TQT_SIGNAL(changed()), this, TQT_SLOT(configChanged()));
+  connect( _interface, TQ_SIGNAL(changed()), this, TQ_SLOT(configChanged()));
 }
 
 
@@ -366,11 +366,11 @@ void KcmSambaConf::editShare()
     return;
 
   ShareDlgImpl* dlg = new ShareDlgImpl(_interface,item->getShare());
-  connect(dlg, TQT_SIGNAL(changed()), this, TQT_SLOT(configChanged()));
+  connect(dlg, TQ_SIGNAL(changed()), this, TQ_SLOT(configChanged()));
   dlg->exec();
   item->updateShare();
 
-  disconnect(dlg, TQT_SIGNAL(changed()), this, TQT_SLOT(configChanged()));
+  disconnect(dlg, TQ_SIGNAL(changed()), this, TQ_SLOT(configChanged()));
 
   delete dlg;
 
@@ -504,8 +504,8 @@ void KcmSambaConf::load(const TQString & smbFile)
 
   _sambaFile = new SambaFile(_smbconf,false);
 
-  connect( _sambaFile, TQT_SIGNAL(completed()), this, TQT_SLOT(fillFields()));
-  connect( _sambaFile, TQT_SIGNAL(canceled(const TQString &)), this, TQT_SLOT(loadCanceled(const TQString &)));
+  connect( _sambaFile, TQ_SIGNAL(completed()), this, TQ_SLOT(fillFields()));
+  connect( _sambaFile, TQ_SIGNAL(canceled(const TQString &)), this, TQ_SLOT(loadCanceled(const TQString &)));
 
   _sambaFile->load();
 
@@ -579,7 +579,7 @@ void KcmSambaConf::fillFields()
 
   loadUserTab();
 
-  connect(_dictMngr, TQT_SIGNAL(changed()), this, TQT_SLOT(configChanged()));
+  connect(_dictMngr, TQ_SIGNAL(changed()), this, TQ_SLOT(configChanged()));
 
 }
 
@@ -1446,7 +1446,7 @@ TQString KcmSambaConf::handbookSection() const
 
 extern "C"
 {
-  KDE_EXPORT TDECModule *create_KcmSambaConf(TQWidget *parent, const char *name)
+  TDE_EXPORT TDECModule *create_KcmSambaConf(TQWidget *parent, const char *name)
   {
     TDEGlobal::locale()->insertCatalogue("tdefileshare");
     return new KcmSambaConf(parent, name);
