@@ -158,7 +158,7 @@ TQStringList PlaylistCollection::playlists() const
     TQObjectList *childList = m_playlistStack->queryList("Playlist");
     TQObject *obj;
     for(obj = childList->first(); obj; obj = childList->next()) {
-        Playlist *p = static_cast<Playlist *>(TQT_TQWIDGET(obj));
+        Playlist *p = static_cast<Playlist *>(obj);
         l.append(p->name());
     }
 
@@ -670,8 +670,8 @@ void PlaylistCollection::setupPlaylist(Playlist *playlist, const TQString &)
     if(!playlist->name().isNull())
         m_playlistNames.insert(playlist->name());
 
-    TQObject::connect(playlist, TQT_SIGNAL(selectionChanged()),
-                     object(), TQT_SIGNAL(signalSelectedItemsChanged()));
+    TQObject::connect(playlist, TQ_SIGNAL(selectionChanged()),
+                     object(), TQ_SIGNAL(signalSelectedItemsChanged()));
 }
 
 bool PlaylistCollection::importPlaylists() const
@@ -706,16 +706,16 @@ void PlaylistCollection::clearShowMore(bool raisePlaylist)
 
 void PlaylistCollection::enableDirWatch(bool enable)
 {
-    TQObject *collection = TQT_TQOBJECT(CollectionList::instance());
+    TQObject *collection = CollectionList::instance();
 
     m_dirLister.disconnect(object());
     if(enable) {
-        TQObject::connect(&m_dirLister, TQT_SIGNAL(newItems(const KFileItemList &)),
-                object(), TQT_SLOT(slotNewItems(const KFileItemList &)));
-        TQObject::connect(&m_dirLister, TQT_SIGNAL(refreshItems(const KFileItemList &)),
-                collection, TQT_SLOT(slotRefreshItems(const KFileItemList &)));
-        TQObject::connect(&m_dirLister, TQT_SIGNAL(deleteItem(KFileItem *)),
-                collection, TQT_SLOT(slotDeleteItem(KFileItem *)));
+        TQObject::connect(&m_dirLister, TQ_SIGNAL(newItems(const KFileItemList &)),
+                object(), TQ_SLOT(slotNewItems(const KFileItemList &)));
+        TQObject::connect(&m_dirLister, TQ_SIGNAL(refreshItems(const KFileItemList &)),
+                collection, TQ_SLOT(slotRefreshItems(const KFileItemList &)));
+        TQObject::connect(&m_dirLister, TQ_SIGNAL(deleteItem(KFileItem *)),
+                collection, TQ_SLOT(slotDeleteItem(KFileItem *)));
     }
 }
 
@@ -789,7 +789,7 @@ Playlist *PlaylistCollection::playlistByName(const TQString &name) const
     TQObject *obj;
 
     for(obj = l->first(); obj; obj = l->next()) {
-        Playlist *p = static_cast<Playlist*>(TQT_TQWIDGET(obj));
+        Playlist *p = static_cast<Playlist*>(obj);
         if(p->name() == name) {
             list = p;
             break;
@@ -842,11 +842,11 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
 
     menu = new TDEActionMenu(i18n("&New"), "document-new", actions(), "file_new");
 
-    menu->insert(createAction(i18n("&Empty Playlist..."), TQT_SLOT(slotCreatePlaylist()),
+    menu->insert(createAction(i18n("&Empty Playlist..."), TQ_SLOT(slotCreatePlaylist()),
                               "newPlaylist", "window-new", "CTRL+n"));
-    menu->insert(createAction(i18n("&Search Playlist..."), TQT_SLOT(slotCreateSearchPlaylist()),
+    menu->insert(createAction(i18n("&Search Playlist..."), TQ_SLOT(slotCreateSearchPlaylist()),
                               "newSearchPlaylist", "edit-find", "CTRL+f"));
-    menu->insert(createAction(i18n("Playlist From &Folder..."), TQT_SLOT(slotCreateFolderPlaylist()),
+    menu->insert(createAction(i18n("Playlist From &Folder..."), TQ_SLOT(slotCreateFolderPlaylist()),
                               "newDirectoryPlaylist", "document-open", "CTRL+d"));
 
     // Guess tag info menu
@@ -855,47 +855,47 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
     menu = new TDEActionMenu(i18n("&Guess Tag Information"), TQString(), actions(), "guessTag");
     menu->setIconSet(SmallIconSet("wizard"));
 
-    menu->insert(createAction(i18n("From &File Name"), TQT_SLOT(slotGuessTagFromFile()),
+    menu->insert(createAction(i18n("From &File Name"), TQ_SLOT(slotGuessTagFromFile()),
                               "guessTagFile", "fileimport", "CTRL+g"));
-    menu->insert(createAction(i18n("From &Internet"), TQT_SLOT(slotGuessTagFromInternet()),
+    menu->insert(createAction(i18n("From &Internet"), TQ_SLOT(slotGuessTagFromInternet()),
                               "guessTagInternet", "connect_established", "CTRL+i"));
 #else
-    createAction(i18n("Guess Tag Information From &File Name"), TQT_SLOT(slotGuessTagFromFile()),
+    createAction(i18n("Guess Tag Information From &File Name"), TQ_SLOT(slotGuessTagFromFile()),
                  "guessTag", "fileimport", "CTRL+f");
 #endif
 
 
-    createAction(i18n("Play First Track"),TQT_SLOT(slotPlayFirst()),     "playFirst");
-    createAction(i18n("Play Next Album"), TQT_SLOT(slotPlayNextAlbum()), "forwardAlbum", "next");
+    createAction(i18n("Play First Track"),TQ_SLOT(slotPlayFirst()),     "playFirst");
+    createAction(i18n("Play Next Album"), TQ_SLOT(slotPlayNextAlbum()), "forwardAlbum", "next");
 
-    createAction(i18n("Open..."),         TQT_SLOT(slotOpen()),         "file_open", "document-open", "CTRL+o");
-    createAction(i18n("Add &Folder..."),  TQT_SLOT(slotAddFolder()),    "openDirectory", "document-open");
-    createAction(i18n("&Rename..."),      TQT_SLOT(slotRename()),       "renamePlaylist", "lineedit");
-    createAction(i18n("D&uplicate..."),   TQT_SLOT(slotDuplicate()),    "duplicatePlaylist", "edit-copy");
-    createAction(i18n("Save"),            TQT_SLOT(slotSave()),         "file_save", "document-save", "CTRL+s");
-    createAction(i18n("Save As..."),      TQT_SLOT(slotSaveAs()),       "file_save_as", "document-save-as");
-    createAction(i18n("R&emove"),         TQT_SLOT(slotRemove()),       "deleteItemPlaylist", "edittrash");
-    createAction(i18n("Reload"),          TQT_SLOT(slotReload()),       "reloadPlaylist", "reload");
-    createAction(i18n("Edit Search..."),  TQT_SLOT(slotEditSearch()),   "editSearch", "edit-clear");
+    createAction(i18n("Open..."),         TQ_SLOT(slotOpen()),         "file_open", "document-open", "CTRL+o");
+    createAction(i18n("Add &Folder..."),  TQ_SLOT(slotAddFolder()),    "openDirectory", "document-open");
+    createAction(i18n("&Rename..."),      TQ_SLOT(slotRename()),       "renamePlaylist", "lineedit");
+    createAction(i18n("D&uplicate..."),   TQ_SLOT(slotDuplicate()),    "duplicatePlaylist", "edit-copy");
+    createAction(i18n("Save"),            TQ_SLOT(slotSave()),         "file_save", "document-save", "CTRL+s");
+    createAction(i18n("Save As..."),      TQ_SLOT(slotSaveAs()),       "file_save_as", "document-save-as");
+    createAction(i18n("R&emove"),         TQ_SLOT(slotRemove()),       "deleteItemPlaylist", "edittrash");
+    createAction(i18n("Reload"),          TQ_SLOT(slotReload()),       "reloadPlaylist", "reload");
+    createAction(i18n("Edit Search..."),  TQ_SLOT(slotEditSearch()),   "editSearch", "edit-clear");
 
-    createAction(i18n("&Delete"),         TQT_SLOT(slotRemoveItems()),  "removeItem", "edit-delete");
-    createAction(i18n("Refresh"),         TQT_SLOT(slotRefreshItems()), "refresh", "reload");
-    createAction(i18n("&Rename File"),    TQT_SLOT(slotRenameItems()),  "renameFile", "document-save-as", "CTRL+r");
+    createAction(i18n("&Delete"),         TQ_SLOT(slotRemoveItems()),  "removeItem", "edit-delete");
+    createAction(i18n("Refresh"),         TQ_SLOT(slotRefreshItems()), "refresh", "reload");
+    createAction(i18n("&Rename File"),    TQ_SLOT(slotRenameItems()),  "renameFile", "document-save-as", "CTRL+r");
 
     menu = new TDEActionMenu(i18n("Cover Manager"), TQString(), actions(), "coverManager");
     menu->setIconSet(SmallIconSet("image-x-generic"));
     menu->insert(createAction(i18n("&View Cover"),
-        TQT_SLOT(slotViewCovers()), "viewCover", "viewmag"));
+        TQ_SLOT(slotViewCovers()), "viewCover", "viewmag"));
     menu->insert(createAction(i18n("Get Cover From &File..."),
-        TQT_SLOT(slotAddLocalCover()), "addCover", "fileimport", "CTRL+SHIFT+f"));
+        TQ_SLOT(slotAddLocalCover()), "addCover", "fileimport", "CTRL+SHIFT+f"));
 
     // Do not rename googleCover for backward compatibility
     menu->insert(createAction(i18n("Get Cover From &Internet..."),
-        TQT_SLOT(slotAddInternetCover()), "googleCover", "connect_established", "CTRL+SHIFT+g"));
+        TQ_SLOT(slotAddInternetCover()), "googleCover", "connect_established", "CTRL+SHIFT+g"));
     menu->insert(createAction(i18n("&Delete Cover"),
-        TQT_SLOT(slotRemoveCovers()), "removeCover", "edit-delete"));
+        TQ_SLOT(slotRemoveCovers()), "removeCover", "edit-delete"));
     menu->insert(createAction(i18n("Show Cover &Manager"),
-        TQT_SLOT(slotShowCoverManager()), "showCoverManager"));
+        TQ_SLOT(slotShowCoverManager()), "showCoverManager"));
 
     TDEToggleAction *historyAction =
         new TDEToggleAction(i18n("Show &History"), "history",  0, actions(), "showHistory");
@@ -905,10 +905,10 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
         new TDEToggleAction(i18n("Show &Play Queue"), "today", 0, actions(), "showUpcoming");
     upcomingAction->setCheckedState(i18n("Hide &Play Queue"));
 
-    connect(action<TDEToggleAction>("showHistory"), TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotSetHistoryPlaylistEnabled(bool)));
-    connect(action<TDEToggleAction>("showUpcoming"), TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotSetUpcomingPlaylistEnabled(bool)));
+    connect(action<TDEToggleAction>("showHistory"), TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotSetHistoryPlaylistEnabled(bool)));
+    connect(action<TDEToggleAction>("showUpcoming"), TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotSetUpcomingPlaylistEnabled(bool)));
 }
 
 TDEAction *PlaylistCollection::ActionHandler::createAction(const TQString &text,
