@@ -135,8 +135,8 @@ void AddresseeEditorWidget::initGUI()
   setupAdditionalTabs();
   setupCustomFieldsTabs();
 
-  connect( mTabWidget, TQT_SIGNAL( currentChanged(TQWidget*) ),
-           TQT_SLOT( pageChanged(TQWidget*) ) );
+  connect( mTabWidget, TQ_SIGNAL( currentChanged(TQWidget*) ),
+           TQ_SLOT( pageChanged(TQWidget*) ) );
 }
 
 void AddresseeEditorWidget::setupTab1()
@@ -165,9 +165,9 @@ void AddresseeEditorWidget::setupTab1()
   button = new TQPushButton( i18n( "Edit Name..." ), tab1 );
   TQToolTip::add( button, i18n( "Edit the contact's name" ) );
   mNameEdit = new KLineEdit( tab1, "mNameEdit" );
-  connect( mNameEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( nameTextChanged( const TQString& ) ) );
-  connect( button, TQT_SIGNAL( clicked() ), TQT_SLOT( nameButtonClicked() ) );
+  connect( mNameEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( nameTextChanged( const TQString& ) ) );
+  connect( button, TQ_SIGNAL( clicked() ), TQ_SLOT( nameButtonClicked() ) );
   mNameLabel = new KSqueezedTextLabel( tab1 );
 
   if ( KABPrefs::instance()->automaticNameParsing() ) {
@@ -183,8 +183,8 @@ void AddresseeEditorWidget::setupTab1()
   layout->addWidget( mNameLabel, 0, 2 );
   label = new TQLabel( i18n( "<roleLabel>:", "%1:" ).arg( TDEABC::Addressee::roleLabel() ), tab1 );
   mRoleEdit = new KLineEdit( tab1 );
-  connect( mRoleEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mRoleEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mRoleEdit );
   layout->addWidget( label, 1, 1 );
   layout->addWidget( mRoleEdit, 1, 2 );
@@ -193,8 +193,8 @@ void AddresseeEditorWidget::setupTab1()
   label = new TQLabel( i18n( "<organizationLabel>:", "%1:" ).arg( TDEABC::Addressee::organizationLabel() ), tab1 );
   mOrgEdit = new KLineEdit( tab1 );
   label->setBuddy( mOrgEdit );
-  connect( mOrgEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( organizationTextChanged( const TQString& ) ) );
+  connect( mOrgEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( organizationTextChanged( const TQString& ) ) );
   layout->addWidget( label, 2, 1 );
   layout->addWidget( mOrgEdit, 2, 2 );
 
@@ -217,7 +217,7 @@ void AddresseeEditorWidget::setupTab1()
   layout->addMultiCellWidget( label, 0, 1, 3, 3 );
 
   mPhoneEditWidget = new PhoneEditWidget( tab1 );
-  connect( mPhoneEditWidget, TQT_SIGNAL( modified() ), TQT_SLOT( emitModified() ) );
+  connect( mPhoneEditWidget, TQ_SIGNAL( modified() ), TQ_SLOT( emitModified() ) );
   layout->addMultiCellWidget( mPhoneEditWidget, 0, 3, 4, 6 );
 
   bar = new KSeparator( KSeparator::HLine, tab1 );
@@ -231,7 +231,7 @@ void AddresseeEditorWidget::setupTab1()
   layout->addMultiCellWidget( label, 5, 6, 0, 0 );
 
   mAddressEditWidget = new AddressEditWidget( tab1 );
-  connect( mAddressEditWidget, TQT_SIGNAL( modified() ), TQT_SLOT( emitModified() ) );
+  connect( mAddressEditWidget, TQ_SIGNAL( modified() ), TQ_SLOT( emitModified() ) );
   layout->addMultiCellWidget( mAddressEditWidget, 5, 10, 1, 2 );
 
   //////////////////////////////////////
@@ -242,7 +242,7 @@ void AddresseeEditorWidget::setupTab1()
   layout->addMultiCellWidget( label, 5, 6, 3, 3 );
 
   mEmailWidget = new EmailEditWidget( tab1 );
-  connect( mEmailWidget, TQT_SIGNAL( modified() ), TQT_SLOT( emitModified() ) );
+  connect( mEmailWidget, TQ_SIGNAL( modified() ), TQ_SLOT( emitModified() ) );
   layout->addMultiCellWidget( mEmailWidget, 5, 6, 4, 6 );
 
   // add the separator
@@ -258,8 +258,8 @@ void AddresseeEditorWidget::setupTab1()
 
   label = new TQLabel( i18n( "<urlLabel>:", "%1:" ).arg( TDEABC::Addressee::urlLabel() ), tab1 );
   mURLEdit = new KLineEdit( tab1 );
-  connect( mURLEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mURLEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mURLEdit );
   homePageLayout->addWidget( label );
   homePageLayout->addWidget( mURLEdit );
@@ -270,13 +270,13 @@ void AddresseeEditorWidget::setupTab1()
   blogLayout->addWidget( label );
   mBlogEdit = new KLineEdit( tab1 );
   blogLayout->addWidget( mBlogEdit );
-  connect( mBlogEdit, TQT_SIGNAL( textChanged( const TQString & ) ),
-           TQT_SLOT( textChanged( const TQString & ) ) );
+  connect( mBlogEdit, TQ_SIGNAL( textChanged( const TQString & ) ),
+           TQ_SLOT( textChanged( const TQString & ) ) );
   label->setBuddy( mBlogEdit );
   layout->addMultiCellLayout( blogLayout, 9, 9, 4, 6 );
 
   mIMWidget = new IMEditWidget( tab1, mAddressee );
-  connect( mIMWidget, TQT_SIGNAL( modified() ), TQT_SLOT( emitModified() ) );
+  connect( mIMWidget, TQ_SIGNAL( modified() ), TQ_SLOT( emitModified() ) );
   layout->addMultiCellWidget( mIMWidget, 10, 10, 4, 6 );
 
   layout->addColSpacing( 6, 50 );
@@ -290,15 +290,15 @@ void AddresseeEditorWidget::setupTab1()
 
   // Categories
   mCategoryButton = new TQPushButton( i18n( "Select Categories..." ), categoryBox );
-  connect( mCategoryButton, TQT_SIGNAL( clicked() ), TQT_SLOT( selectCategories() ) );
+  connect( mCategoryButton, TQ_SIGNAL( clicked() ), TQ_SLOT( selectCategories() ) );
 
   mCategoryEdit = new KLineEdit( categoryBox );
   mCategoryEdit->setReadOnly( true );
-  connect( mCategoryEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mCategoryEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
 
   mSecrecyWidget = new SecrecyWidget( categoryBox );
-  connect( mSecrecyWidget, TQT_SIGNAL( changed() ), TQT_SLOT( emitModified() ) );
+  connect( mSecrecyWidget, TQ_SIGNAL( changed() ), TQ_SLOT( emitModified() ) );
 
   layout->addMultiCellWidget( categoryBox, 12, 12, 0, 6 );
 
@@ -332,48 +332,48 @@ void AddresseeEditorWidget::setupTab2()
   label = new TQLabel( i18n( "Department:" ), tab2 );
   layout->addWidget( label, 0, 1 );
   mDepartmentEdit = new KLineEdit( tab2 );
-  connect( mDepartmentEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mDepartmentEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mDepartmentEdit );
   layout->addWidget( mDepartmentEdit, 0, 2 );
 
   label = new TQLabel( i18n( "Office:" ), tab2 );
   layout->addWidget( label, 1, 1 );
   mOfficeEdit = new KLineEdit( tab2 );
-  connect( mOfficeEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mOfficeEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mOfficeEdit );
   layout->addWidget( mOfficeEdit, 1, 2 );
 
   label = new TQLabel( i18n( "Profession:" ), tab2 );
   layout->addWidget( label, 2, 1 );
   mProfessionEdit = new KLineEdit( tab2 );
-  connect( mProfessionEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mProfessionEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mProfessionEdit );
   layout->addWidget( mProfessionEdit, 2, 2 );
 
   label = new TQLabel( i18n( "Manager\'s name:" ), tab2 );
   layout->addWidget( label, 0, 3 );
   mManagerEdit = new KPIM::AddresseeLineEdit( tab2 );
-  connect( mManagerEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mManagerEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mManagerEdit );
   layout->addMultiCellWidget( mManagerEdit, 0, 0, 4, 5 );
 
   label = new TQLabel( i18n( "Assistant's name:" ), tab2 );
   layout->addWidget( label, 1, 3 );
   mAssistantEdit = new KPIM::AddresseeLineEdit( tab2 );
-  connect( mAssistantEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mAssistantEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mAssistantEdit );
   layout->addMultiCellWidget( mAssistantEdit, 1, 1, 4, 5 );
 
   label = new TQLabel( i18n( "<titleLabel>:", "%1:" ).arg( TDEABC::Addressee::titleLabel() ), tab2 );
   layout->addWidget( label, 2, 3 );
   mTitleEdit = new KLineEdit( tab2 );
-  connect( mTitleEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mTitleEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mTitleEdit );
   layout->addMultiCellWidget( mTitleEdit, 2, 2, 4, 5 );
 
@@ -391,36 +391,36 @@ void AddresseeEditorWidget::setupTab2()
   label = new TQLabel( i18n( "Nickname:" ), tab2 );
   layout->addWidget( label, 4, 1 );
   mNicknameEdit = new KLineEdit( tab2 );
-  connect( mNicknameEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mNicknameEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mNicknameEdit );
   layout->addWidget( mNicknameEdit, 4, 2 );
 
   label = new TQLabel( i18n( "Partner's name:" ), tab2 );
   layout->addWidget( label, 5, 1 );
   mSpouseEdit = new KPIM::AddresseeLineEdit( tab2 );
-  connect( mSpouseEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( textChanged( const TQString& ) ) );
+  connect( mSpouseEdit, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( textChanged( const TQString& ) ) );
   label->setBuddy( mSpouseEdit );
   layout->addWidget( mSpouseEdit, 5, 2 );
 
   label = new TQLabel( i18n( "Birthdate:" ), tab2 );
   layout->addWidget( label, 4, 3 );
   mBirthdayPicker = new KDateEdit( tab2 );
-  connect( mBirthdayPicker, TQT_SIGNAL( dateChanged( const TQDate& ) ),
-           TQT_SLOT( dateChanged( const TQDate& ) ) );
-  connect( mBirthdayPicker, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( emitModified() ) );
+  connect( mBirthdayPicker, TQ_SIGNAL( dateChanged( const TQDate& ) ),
+           TQ_SLOT( dateChanged( const TQDate& ) ) );
+  connect( mBirthdayPicker, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( emitModified() ) );
   label->setBuddy( mBirthdayPicker );
   layout->addWidget( mBirthdayPicker, 4, 4 );
 
   label = new TQLabel( i18n( "Anniversary:" ), tab2 );
   layout->addWidget( label, 5, 3 );
   mAnniversaryPicker = new KDateEdit( tab2 );
-  connect( mAnniversaryPicker, TQT_SIGNAL( dateChanged( const TQDate& ) ),
-           TQT_SLOT( dateChanged( const TQDate& ) ) );
-  connect( mAnniversaryPicker, TQT_SIGNAL( textChanged( const TQString& ) ),
-           TQT_SLOT( emitModified() ) );
+  connect( mAnniversaryPicker, TQ_SIGNAL( dateChanged( const TQDate& ) ),
+           TQ_SLOT( dateChanged( const TQDate& ) ) );
+  connect( mAnniversaryPicker, TQ_SIGNAL( textChanged( const TQString& ) ),
+           TQ_SLOT( emitModified() ) );
   label->setBuddy( mAnniversaryPicker );
   layout->addWidget( mAnniversaryPicker, 5, 4 );
 
@@ -435,7 +435,7 @@ void AddresseeEditorWidget::setupTab2()
   mNoteEdit = new TQTextEdit( tab2 );
   mNoteEdit->setWordWrap( TQTextEdit::WidgetWidth );
   mNoteEdit->setMinimumSize( mNoteEdit->sizeHint() );
-  connect( mNoteEdit, TQT_SIGNAL( textChanged() ), TQT_SLOT( emitModified() ) );
+  connect( mNoteEdit, TQ_SIGNAL( textChanged() ), TQ_SLOT( emitModified() ) );
   label->setBuddy( mNoteEdit );
   layout->addMultiCellWidget( mNoteEdit, 7, 7, 1, 5 );
 
@@ -464,7 +464,7 @@ void AddresseeEditorWidget::setupAdditionalTabs()
 
       mTabWidget->addTab( page, pageTitle );
 
-      connect( page, TQT_SIGNAL( changed() ), TQT_SLOT( emitModified() ) );
+      connect( page, TQ_SIGNAL( changed() ), TQ_SLOT( emitModified() ) );
     }
 
     KAB::ContactEditorWidget *widget
@@ -498,7 +498,7 @@ void AddresseeEditorWidget::setupCustomFieldsTabs()
       page->addWidget( wdg );
       page->updateLayout();
 
-      connect( page, TQT_SIGNAL( changed() ), TQT_SLOT( emitModified() ) );
+      connect( page, TQ_SIGNAL( changed() ), TQ_SLOT( emitModified() ) );
     } else
       delete page;
   }
@@ -558,7 +558,7 @@ void AddresseeEditorWidget::load()
   mBirthdayPicker->setDate( mAddressee.birthday().date() );
 
   TQString anniversaryStr = mAddressee.custom( "KADDRESSBOOK", "X-Anniversary" );
-  TQDate anniversary = (anniversaryStr.isEmpty() ? TQDate() : TQDate::fromString( anniversaryStr, Qt::ISODate ));
+  TQDate anniversary = (anniversaryStr.isEmpty() ? TQDate() : TQDate::fromString( anniversaryStr, TQt::ISODate ));
   mAnniversaryPicker->setDate( anniversary );
   mNicknameEdit->setText( mAddressee.nickName() );
   mCategoryEdit->setText( mAddressee.categories().join( "," ) );
@@ -652,7 +652,7 @@ void AddresseeEditorWidget::save()
 
   if ( mAnniversaryPicker->date().isValid() )
     mAddressee.insertCustom( "KADDRESSBOOK", "X-Anniversary",
-                             mAnniversaryPicker->date().toString( Qt::ISODate ) );
+                             mAnniversaryPicker->date().toString( TQt::ISODate ) );
   else
     mAddressee.removeCustom( "KADDRESSBOOK", "X-Anniversary" );
 
@@ -798,10 +798,10 @@ void AddresseeEditorWidget::selectCategories()
   // Show the category dialog
   if ( mCategorySelectDialog == 0 ) {
     mCategorySelectDialog = new KPIM::CategorySelectDialog( KABPrefs::instance(), this );
-    connect( mCategorySelectDialog, TQT_SIGNAL( categoriesSelected( const TQStringList& ) ),
-             this, TQT_SLOT( categoriesSelected( const TQStringList& ) ) );
-    connect( mCategorySelectDialog, TQT_SIGNAL( editCategories() ),
-             this, TQT_SLOT( editCategories() ) );
+    connect( mCategorySelectDialog, TQ_SIGNAL( categoriesSelected( const TQStringList& ) ),
+             this, TQ_SLOT( categoriesSelected( const TQStringList& ) ) );
+    connect( mCategorySelectDialog, TQ_SIGNAL( editCategories() ),
+             this, TQ_SLOT( editCategories() ) );
   }
 
   mCategorySelectDialog->setSelected( TQStringList::split( ",", mCategoryEdit->text() ) );
@@ -817,8 +817,8 @@ void AddresseeEditorWidget::editCategories()
 {
   if ( mCategoryEditDialog == 0 ) {
     mCategoryEditDialog = new KPIM::CategoryEditDialog( KABPrefs::instance(), this );
-    connect( mCategoryEditDialog, TQT_SIGNAL( categoryConfigChanged() ),
-             mCategorySelectDialog, TQT_SLOT( updateCategoryConfig() ) );
+    connect( mCategoryEditDialog, TQ_SIGNAL( categoryConfigChanged() ),
+             mCategorySelectDialog, TQ_SLOT( updateCategoryConfig() ) );
   }
 
   mCategoryEditDialog->exec();
