@@ -99,7 +99,7 @@ bool KEduVocDocument::open(const KURL& url, bool /*append*/)
   if (!url.isEmpty())
     doc_url = url;
 
-  // TODO EPT  connect( this, TQT_SIGNAL(progressChanged(KEduVocDocument*,int)), parent, TQT_SLOT(slotProgress(KEduVocDocument*,int)) );
+  // TODO EPT  connect( this, TQ_SIGNAL(progressChanged(KEduVocDocument*,int)), parent, TQ_SLOT(slotProgress(KEduVocDocument*,int)) );
 
   TQString tmpfile;
   if (TDEIO::NetAccess::download( url, tmpfile, 0 ))
@@ -182,7 +182,7 @@ bool KEduVocDocument::open(const KURL& url, bool /*append*/)
 
 bool KEduVocDocument::saveAs(TQObject * /*parent*/, const KURL & url, FileType ft, const TQString & generator)
 {
-//  connect( this, TQT_SIGNAL(progressChanged(KEduVocDocument*,int)), parent, TQT_SLOT(slotProgress(KEduVocDocument*,int)) );
+//  connect( this, TQ_SIGNAL(progressChanged(KEduVocDocument*,int)), parent, TQ_SLOT(slotProgress(KEduVocDocument*,int)) );
 
   KURL tmp (url);
 
@@ -463,7 +463,7 @@ void KEduVocDocument::setSizeHint (int idx, const int width)
 }
 
 
-class eraseTrans : public unary_function<KEduVocExpression, void>
+class eraseTrans : public function<void(KEduVocExpression)>
 {
 
 public:
@@ -507,7 +507,7 @@ void KEduVocDocument::setOriginalIdent (const TQString &id)
 }
 
 
-class sortByOrg : public binary_function<KEduVocExpression, KEduVocExpression, bool>
+class sortByOrg : public function<bool(KEduVocExpression, KEduVocExpression)>
 {
 
 public:
@@ -531,7 +531,7 @@ public:
 
 
 class sortByLessonAndOrg_alpha
-  : public binary_function<KEduVocExpression, KEduVocExpression, bool>
+  : public function<bool(KEduVocExpression, KEduVocExpression)>
 {
 
 public:
@@ -564,7 +564,7 @@ public:
 
 
 class sortByLessonAndOrg_index
-  : public binary_function<KEduVocExpression, KEduVocExpression, bool>
+  : public function<bool(KEduVocExpression, KEduVocExpression)>
 {
 
 public:
@@ -594,7 +594,7 @@ public:
 };
 
 
-class sortByTrans : public binary_function<KEduVocExpression, KEduVocExpression, bool>
+class sortByTrans : public function<bool(KEduVocExpression, KEduVocExpression)>
 {
 
 public:
@@ -727,7 +727,7 @@ LeitnerSystem* KEduVocDocument::getLeitnerSystem()
 }
 
 
-class resetAll : public unary_function<KEduVocExpression, void>
+class resetAll : public function<void(KEduVocExpression)>
 {
 
 public:
@@ -755,7 +755,7 @@ public:
 };
 
 
-class resetOne : public unary_function<KEduVocExpression, void>
+class resetOne : public function<void(KEduVocExpression)>
 {
 
 public:
