@@ -25,7 +25,7 @@ karmPart::karmPart( TQWidget *parentWidget, const char *widgetName,
                                   TQObject *parent, const char *name )
     : DCOPObject ( "KarmDCOPIface" ), KParts::ReadWritePart(parent, name), 
     _accel     ( new TDEAccel( parentWidget ) ),
-    _watcher   ( new TDEAccelMenuWatch( _accel, TQT_TQOBJECT(parentWidget) ) )
+    _watcher   ( new TDEAccelMenuWatch( _accel, parentWidget ) )
 {
     // we need an instance
     setInstance( karmPartFactory::instance() );
@@ -40,9 +40,9 @@ karmPart::karmPart( TQWidget *parentWidget, const char *widgetName,
     setWidget(_taskView);
 
     // create our actions
-    KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
-    KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
-    KStdAction::save(this, TQT_SLOT(save()), actionCollection());
+    KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());
+    KStdAction::saveAs(this, TQ_SLOT(fileSaveAs()), actionCollection());
+    KStdAction::save(this, TQ_SLOT(save()), actionCollection());
 
     makeMenus();
 
@@ -50,29 +50,29 @@ karmPart::karmPart( TQWidget *parentWidget, const char *widgetName,
 
   // connections
 
-  connect( _taskView, TQT_SIGNAL( totalTimesChanged( long, long ) ),
-           this, TQT_SLOT( updateTime( long, long ) ) );
-  connect( _taskView, TQT_SIGNAL( selectionChanged ( TQListViewItem * )),
-           this, TQT_SLOT(slotSelectionChanged()));
-  connect( _taskView, TQT_SIGNAL( updateButtons() ),
-           this, TQT_SLOT(slotSelectionChanged()));
+  connect( _taskView, TQ_SIGNAL( totalTimesChanged( long, long ) ),
+           this, TQ_SLOT( updateTime( long, long ) ) );
+  connect( _taskView, TQ_SIGNAL( selectionChanged ( TQListViewItem * )),
+           this, TQ_SLOT(slotSelectionChanged()));
+  connect( _taskView, TQ_SIGNAL( updateButtons() ),
+           this, TQ_SLOT(slotSelectionChanged()));
 
   // Setup context menu request handling
   connect( _taskView,
-           TQT_SIGNAL( contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
+           TQ_SIGNAL( contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
            this,
-           TQT_SLOT( contextMenuRequest( TQListViewItem*, const TQPoint&, int )));
+           TQ_SLOT( contextMenuRequest( TQListViewItem*, const TQPoint&, int )));
 
   _tray = new KarmTray( this );
 
-  connect( _tray, TQT_SIGNAL( quitSelected() ), TQT_SLOT( quit() ) );
+  connect( _tray, TQ_SIGNAL( quitSelected() ), TQ_SLOT( quit() ) );
 
-  connect( _taskView, TQT_SIGNAL( timersActive() ), _tray, TQT_SLOT( startClock() ) );
-  connect( _taskView, TQT_SIGNAL( timersActive() ), this,  TQT_SLOT( enableStopAll() ));
-  connect( _taskView, TQT_SIGNAL( timersInactive() ), _tray, TQT_SLOT( stopClock() ) );
-  connect( _taskView, TQT_SIGNAL( timersInactive() ),  this,  TQT_SLOT( disableStopAll()));
-  connect( _taskView, TQT_SIGNAL( tasksChanged( TQPtrList<Task> ) ),
-                      _tray, TQT_SLOT( updateToolTip( TQPtrList<Task> ) ));
+  connect( _taskView, TQ_SIGNAL( timersActive() ), _tray, TQ_SLOT( startClock() ) );
+  connect( _taskView, TQ_SIGNAL( timersActive() ), this,  TQ_SLOT( enableStopAll() ));
+  connect( _taskView, TQ_SIGNAL( timersInactive() ), _tray, TQ_SLOT( stopClock() ) );
+  connect( _taskView, TQ_SIGNAL( timersInactive() ),  this,  TQ_SLOT( disableStopAll()));
+  connect( _taskView, TQ_SIGNAL( tasksChanged( TQPtrList<Task> ) ),
+                      _tray, TQ_SLOT( updateToolTip( TQPtrList<Task> ) ));
 
   _taskView->load();
 
@@ -113,119 +113,119 @@ void karmPart::makeMenus()
     *actionNew,
     *actionNewSub;
 
-  (void) KStdAction::quit(  this, TQT_SLOT( quit() ),  actionCollection());
-  (void) KStdAction::print( this, TQT_SLOT( print() ), actionCollection());
-  actionKeyBindings = KStdAction::keyBindings( this, TQT_SLOT( keyBindings() ),
+  (void) KStdAction::quit(  this, TQ_SLOT( quit() ),  actionCollection());
+  (void) KStdAction::print( this, TQ_SLOT( print() ), actionCollection());
+  actionKeyBindings = KStdAction::keyBindings( this, TQ_SLOT( keyBindings() ),
       actionCollection() );
-  actionPreferences = KStdAction::preferences(TQT_TQOBJECT(_preferences),
-      TQT_SLOT(showDialog()),
+  actionPreferences = KStdAction::preferences(_preferences,
+      TQ_SLOT(showDialog()),
       actionCollection() );
-  (void) KStdAction::save( this, TQT_SLOT( save() ), actionCollection() );
+  (void) KStdAction::save( this, TQ_SLOT( save() ), actionCollection() );
   TDEAction* actionStartNewSession = new TDEAction( i18n("Start &New Session"),
       0,
-      TQT_TQOBJECT(this),
-      TQT_SLOT( startNewSession() ),
+      this,
+      TQ_SLOT( startNewSession() ),
       actionCollection(),
       "start_new_session");
   TDEAction* actionResetAll = new TDEAction( i18n("&Reset All Times"),
       0,
-      TQT_TQOBJECT(this),
-      TQT_SLOT( resetAllTimes() ),
+      this,
+      TQ_SLOT( resetAllTimes() ),
       actionCollection(),
       "reset_all_times");
   actionStart = new TDEAction( i18n("&Start"),
       TQString::fromLatin1("1rightarrow"), Key_S,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( startCurrentTimer() ), actionCollection(),
+      _taskView,
+      TQ_SLOT( startCurrentTimer() ), actionCollection(),
       "start");
   actionStop = new TDEAction( i18n("S&top"),
       TQString::fromLatin1("process-stop"), 0,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( stopCurrentTimer() ), actionCollection(),
+      _taskView,
+      TQ_SLOT( stopCurrentTimer() ), actionCollection(),
       "stop");
   actionStopAll = new TDEAction( i18n("Stop &All Timers"),
       Key_Escape,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( stopAllTimers() ), actionCollection(),
+      _taskView,
+      TQ_SLOT( stopAllTimers() ), actionCollection(),
       "stopAll");
   actionStopAll->setEnabled(false);
 
   actionNew = new TDEAction( i18n("&New..."),
       TQString::fromLatin1("document-new"), CTRL+Key_N,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( newTask() ), actionCollection(),
+      _taskView,
+      TQ_SLOT( newTask() ), actionCollection(),
       "new_task");
   actionNewSub = new TDEAction( i18n("New &Subtask..."),
       TQString::fromLatin1("application-vnd.tde.tdemultiple"), CTRL+ALT+Key_N,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( newSubTask() ), actionCollection(),
+      _taskView,
+      TQ_SLOT( newSubTask() ), actionCollection(),
       "new_sub_task");
   actionDelete = new TDEAction( i18n("&Delete"),
       TQString::fromLatin1("edit-delete"), Key_Delete,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( deleteTask() ), actionCollection(),
+      _taskView,
+      TQ_SLOT( deleteTask() ), actionCollection(),
       "delete_task");
   actionEdit = new TDEAction( i18n("&Edit..."),
       TQString::fromLatin1("edit"), CTRL + Key_E,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( editTask() ), actionCollection(),
+      _taskView,
+      TQ_SLOT( editTask() ), actionCollection(),
       "edit_task");
 //  actionAddComment = new TDEAction( i18n("&Add Comment..."),
 //      TQString::fromLatin1("text-x-generic"),
 //      CTRL+ALT+Key_E,
-//      TQT_TQOBJECT(_taskView),
-//      TQT_SLOT( addCommentToTask() ),
+//      _taskView,
+//      TQ_SLOT( addCommentToTask() ),
 //      actionCollection(),
 //      "add_comment_to_task");
   actionMarkAsComplete = new TDEAction( i18n("&Mark as Complete"),
       TQString::fromLatin1("text-x-generic"),
       CTRL+Key_M,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( markTaskAsComplete() ),
+      _taskView,
+      TQ_SLOT( markTaskAsComplete() ),
       actionCollection(),
       "mark_as_complete");
   actionMarkAsIncomplete = new TDEAction( i18n("&Mark as Incomplete"),
       TQString::fromLatin1("text-x-generic"),
       CTRL+Key_M,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( markTaskAsIncomplete() ),
+      _taskView,
+      TQ_SLOT( markTaskAsIncomplete() ),
       actionCollection(),
       "mark_as_incomplete");
   actionClipTotals = new TDEAction( i18n("&Copy Totals to Clipboard"),
       TQString::fromLatin1("klipper"),
       CTRL+Key_C,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( clipTotals() ),
+      _taskView,
+      TQ_SLOT( clipTotals() ),
       actionCollection(),
       "clip_totals");
   actionClipHistory = new TDEAction( i18n("Copy &History to Clipboard"),
       TQString::fromLatin1("klipper"),
       CTRL+ALT+Key_C,
-      TQT_TQOBJECT(_taskView),
-      TQT_SLOT( clipHistory() ),
+      _taskView,
+      TQ_SLOT( clipHistory() ),
       actionCollection(),
       "clip_history");
 
   new TDEAction( i18n("Import &Legacy Flat File..."), 0,
-      TQT_TQOBJECT(_taskView), TQT_SLOT(loadFromFlatFile()), actionCollection(),
+      _taskView, TQ_SLOT(loadFromFlatFile()), actionCollection(),
       "import_flatfile");
   new TDEAction( i18n("&Export to CSV File..."), 0,
-      TQT_TQOBJECT(_taskView), TQT_SLOT(exportcsvFile()), actionCollection(),
+      _taskView, TQ_SLOT(exportcsvFile()), actionCollection(),
       "export_csvfile");
   new TDEAction( i18n("Export &History to CSV File..."), 0,
-      TQT_TQOBJECT(this), TQT_SLOT(exportcsvHistory()), actionCollection(),
+      this, TQ_SLOT(exportcsvHistory()), actionCollection(),
       "export_csvhistory");
   new TDEAction( i18n("Import Tasks From &Planner..."), 0,
-      TQT_TQOBJECT(_taskView), TQT_SLOT(importPlanner()), actionCollection(),
+      _taskView, TQ_SLOT(importPlanner()), actionCollection(),
       "import_planner");  
   new TDEAction( i18n("Configure KArm..."), 0,
-      TQT_TQOBJECT(_preferences), TQT_SLOT(showDialog()), actionCollection(),
+      _preferences, TQ_SLOT(showDialog()), actionCollection(),
       "configure_karm");  
 
 /*
   new TDEAction( i18n("Import E&vents"), 0,
                             _taskView,
-                            TQT_SLOT( loadFromKOrgEvents() ), actionCollection(),
+                            TQ_SLOT( loadFromKOrgEvents() ), actionCollection(),
                             "import_korg_events");
   */
 
@@ -287,12 +287,12 @@ void karmPart::setReadWrite(bool rw)
 {
     // notify your internal widget of the read-write state
     if (rw)
-        connect(_taskView, TQT_SIGNAL(textChanged()),
-                this,     TQT_SLOT(setModified()));
+        connect(_taskView, TQ_SIGNAL(textChanged()),
+                this,     TQ_SLOT(setModified()));
     else
     {
-        disconnect(_taskView, TQT_SIGNAL(textChanged()),
-                   this,     TQT_SLOT(setModified()));
+        disconnect(_taskView, TQ_SIGNAL(textChanged()),
+                   this,     TQ_SLOT(setModified()));
     }
 
     ReadWritePart::setReadWrite(rw);
@@ -414,7 +414,7 @@ TDEInstance* karmPartFactory::instance()
 
 extern "C"
 {
-    KDE_EXPORT void* init_libkarmpart()
+    TDE_EXPORT void* init_libkarmpart()
     {
 	TDEGlobal::locale()->insertCatalogue("karm");
         return new karmPartFactory;
@@ -544,10 +544,10 @@ int karmPart::bookTime
   // Parse datetime
   if ( !rval ) 
   {
-    startDate = TQDate::fromString( datetime, Qt::ISODate );
+    startDate = TQDate::fromString( datetime, TQt::ISODate );
     if ( datetime.length() > 10 )  // "YYYY-MM-DD".length() = 10
     {
-      startTime = TQTime::fromString( datetime, Qt::ISODate );
+      startTime = TQTime::fromString( datetime, TQt::ISODate );
     }
     else startTime = TQTime( 12, 0 );
     if ( startDate.isValid() && startTime.isValid() )
