@@ -57,7 +57,7 @@
 //BEGIN KatePrinter
 bool KatePrinter::print (KateDocument *doc)
 {
-#ifndef Q_WS_WIN //TODO: reenable
+#ifndef TQ_WS_WIN //TODO: reenable
   KPrinter printer;
 
   // docname is now always there, including the right Untitled name
@@ -228,9 +228,9 @@ bool KatePrinter::print (KateDocument *doc)
            headerTagList = TQStringList::split('|', headerTags, true);
 
            if (!headerBgColor.isValid())
-             headerBgColor = Qt::lightGray;
+             headerBgColor = TQt::lightGray;
            if (!headerFgColor.isValid())
-             headerFgColor = Qt::black;
+             headerFgColor = TQt::black;
          }
 
          if (useFooter)
@@ -255,9 +255,9 @@ bool KatePrinter::print (KateDocument *doc)
 
            footerTagList = TQStringList::split('|', footerTags, true);
            if (!footerBgColor.isValid())
-             footerBgColor = Qt::lightGray;
+             footerBgColor = TQt::lightGray;
            if (!footerFgColor.isValid())
-             footerFgColor = Qt::black;
+             footerFgColor = TQt::black;
            // adjust maxheight, so we can know when/where to print footer
            maxHeight -= footerHeight;
          }
@@ -275,7 +275,7 @@ bool KatePrinter::print (KateDocument *doc)
        if ( useBox )
        {
          if (!boxColor.isValid())
-           boxColor = Qt::black;
+           boxColor = TQt::black;
          if (boxWidth < 1) // shouldn't be pssible no more!
            boxWidth = 1;
          // set maxwidth to something sensible
@@ -307,7 +307,7 @@ bool KatePrinter::print (KateDocument *doc)
 
          // get a title and add the height required to draw it
          TQString _title = i18n("Typographical Conventions for %1").arg(doc->highlight()->name());
-         guideHeight += paint.boundingRect( 0, 0, _w, 1000, Qt::AlignTop|Qt::AlignHCenter, _title ).height();
+         guideHeight += paint.boundingRect( 0, 0, _w, 1000, TQt::AlignTop|TQt::AlignHCenter, _title ).height();
 
          // see how many columns we can fit in
          int _widest( 0 );
@@ -417,8 +417,8 @@ bool KatePrinter::print (KateDocument *doc)
              if (headerTagList.count() == 3)
              {
                int valign = ( (useBox||headerDrawBg||useBackground) ?
-                              Qt::AlignVCenter : Qt::AlignTop );
-               int align = valign|Qt::AlignLeft;
+                              TQt::AlignVCenter : TQt::AlignTop );
+               int align = valign|TQt::AlignLeft;
                int marg = ( useBox || headerDrawBg ) ? innerMargin : 0;
                if ( useBox ) marg += boxWidth;
                TQString s;
@@ -427,7 +427,7 @@ bool KatePrinter::print (KateDocument *doc)
                  s = headerTagList[i];
                  if (s.find("%p") != -1) s.replace("%p", TQString::number(currentPage));
                  paint.drawText(marg, 0, headerWidth-(marg*2), headerHeight, align, s);
-                 align = valign|(i == 0 ? Qt::AlignHCenter : Qt::AlignRight);
+                 align = valign|(i == 0 ? TQt::AlignHCenter : TQt::AlignRight);
                }
              }
              if ( ! ( headerDrawBg || useBox || useBackground ) ) // draw a 1 px (!?) line to separate header from contents
@@ -446,7 +446,7 @@ bool KatePrinter::print (KateDocument *doc)
                 paint.fillRect(0, maxHeight+innerMargin+boxWidth, headerWidth, footerHeight, footerBgColor);
              if (footerTagList.count() == 3)
              {
-               int align = Qt::AlignVCenter|Qt::AlignLeft;
+               int align = TQt::AlignVCenter|TQt::AlignLeft;
                int marg = ( useBox || footerDrawBg ) ? innerMargin : 0;
                if ( useBox ) marg += boxWidth;
                TQString s;
@@ -455,7 +455,7 @@ bool KatePrinter::print (KateDocument *doc)
                  s = footerTagList[i];
                  if (s.find("%p") != -1) s.replace("%p", TQString::number(currentPage));
                  paint.drawText(marg, maxHeight+innerMargin, headerWidth-(marg*2), footerHeight, align, s);
-                 align = Qt::AlignVCenter|(i == 0 ? Qt::AlignHCenter : Qt::AlignRight);
+                 align = TQt::AlignVCenter|(i == 0 ? TQt::AlignHCenter : TQt::AlignRight);
                }
              }
            } // done footer
@@ -524,7 +524,7 @@ bool KatePrinter::print (KateDocument *doc)
              paint.setFont( renderer.config()->fontStruct()->myFontBold );
              TQRect _r;
              paint.drawText( _marg, y, pdmWidth-(2*_marg), maxHeight - y,
-                Qt::AlignTop|Qt::AlignHCenter,
+                TQt::AlignTop|TQt::AlignHCenter,
                 i18n("Typographical Conventions for %1").arg(doc->highlight()->name()), -1, &_r );
              int _w = pdmWidth - (_marg*2) - (innerMargin*2);
              int _x = _marg + innerMargin;
@@ -543,7 +543,7 @@ bool KatePrinter::print (KateDocument *doc)
                paint.setPen( renderer.attribute(_i)->textColor() );
                paint.setFont( renderer.attribute(_i)->font( *renderer.currentFont() ) );
                paint.drawText(( _x + ((_i%guideCols)*_cw)), y, _cw, renderer.fontHeight(),
-                        Qt::AlignVCenter|Qt::AlignLeft, _d->name, -1, &_r );
+                        TQt::AlignVCenter|TQt::AlignLeft, _d->name, -1, &_r );
                _i++;
                if ( _i && ! ( _i%guideCols ) ) y += renderer.fontHeight();
                ++_it;
@@ -561,7 +561,7 @@ bool KatePrinter::print (KateDocument *doc)
            paint.setPen( renderer.config()->lineNumberColor() );
            paint.drawText( (( useBox || useBackground ) ? innerMargin : 0), y,
                         lineNumberWidth, renderer.fontHeight(),
-                        Qt::AlignRight, TQString("%1").arg( lineCount + 1 ) );
+                        TQt::AlignRight, TQString("%1").arg( lineCount + 1 ) );
          }
          endCol = renderer.textWidth(doc->kateTextLine(lineCount), startCol, maxWidth, &needWrap);
 
@@ -626,12 +626,12 @@ bool KatePrinter::print (KateDocument *doc)
      return true;
   }
 
-#endif //!Q_WS_WIN
+#endif //!TQ_WS_WIN
   return false;
 }
 //END KatePrinter
 
-#ifndef Q_WS_WIN //TODO: reenable
+#ifndef TQ_WS_WIN //TODO: reenable
 //BEGIN KatePrintTextSettings
 KatePrintTextSettings::KatePrintTextSettings( KPrinter * /*printer*/, TQWidget *parent, const char *name )
   : KPrintDialogPage( parent, name )
@@ -719,9 +719,9 @@ KatePrintHeaderFooter::KatePrintHeaderFooter( KPrinter * /*printer*/, TQWidget *
   lo2->setStretchFactor( lFontPreview, 1 );
   TQPushButton *btnChooseFont = new TQPushButton( i18n("Choo&se Font..."), this );
   lo2->addWidget( btnChooseFont );
-  connect( btnChooseFont, TQT_SIGNAL(clicked()), this, TQT_SLOT(setHFFont()) );
+  connect( btnChooseFont, TQ_SIGNAL(clicked()), this, TQ_SLOT(setHFFont()) );
   // header
-  gbHeader = new TQGroupBox( 2, Qt::Horizontal, i18n("Header Properties"), this );
+  gbHeader = new TQGroupBox( 2, TQt::Horizontal, i18n("Header Properties"), this );
   lo->addWidget( gbHeader );
 
   TQLabel *lHeaderFormat = new TQLabel( i18n("&Format:"), gbHeader );
@@ -740,7 +740,7 @@ KatePrintHeaderFooter::KatePrintHeaderFooter( KPrinter * /*printer*/, TQWidget *
   cbHeaderEnableBgColor = new TQCheckBox( i18n("Bac&kground"), hbHeaderColors );
   kcbtnHeaderBg = new KColorButton( hbHeaderColors );
 
-  gbFooter = new TQGroupBox( 2, Qt::Horizontal, i18n("Footer Properties"), this );
+  gbFooter = new TQGroupBox( 2, TQt::Horizontal, i18n("Footer Properties"), this );
   lo->addWidget( gbFooter );
 
   // footer
@@ -764,10 +764,10 @@ KatePrintHeaderFooter::KatePrintHeaderFooter( KPrinter * /*printer*/, TQWidget *
   lo->addStretch( 1 );
 
   // user friendly
-  connect( cbEnableHeader, TQT_SIGNAL(toggled(bool)), gbHeader, TQT_SLOT(setEnabled(bool)) );
-  connect( cbEnableFooter, TQT_SIGNAL(toggled(bool)), gbFooter, TQT_SLOT(setEnabled(bool)) );
-  connect( cbHeaderEnableBgColor, TQT_SIGNAL(toggled(bool)), kcbtnHeaderBg, TQT_SLOT(setEnabled(bool)) );
-  connect( cbFooterEnableBgColor, TQT_SIGNAL(toggled(bool)), kcbtnFooterBg, TQT_SLOT(setEnabled(bool)) );
+  connect( cbEnableHeader, TQ_SIGNAL(toggled(bool)), gbHeader, TQ_SLOT(setEnabled(bool)) );
+  connect( cbEnableFooter, TQ_SIGNAL(toggled(bool)), gbFooter, TQ_SLOT(setEnabled(bool)) );
+  connect( cbHeaderEnableBgColor, TQ_SIGNAL(toggled(bool)), kcbtnHeaderBg, TQ_SLOT(setEnabled(bool)) );
+  connect( cbFooterEnableBgColor, TQ_SIGNAL(toggled(bool)), kcbtnFooterBg, TQ_SLOT(setEnabled(bool)) );
 
   // set defaults
   cbEnableHeader->setChecked( true );
@@ -922,7 +922,7 @@ KatePrintLayout::KatePrintLayout( KPrinter * /*printer*/, TQWidget *parent, cons
   cbEnableBox = new TQCheckBox( i18n("Draw &boxes"), this );
   lo->addWidget( cbEnableBox );
 
-  gbBoxProps = new TQGroupBox( 2, Qt::Horizontal, i18n("Box Properties"), this );
+  gbBoxProps = new TQGroupBox( 2, TQt::Horizontal, i18n("Box Properties"), this );
   lo->addWidget( gbBoxProps );
 
   TQLabel *lBoxWidth = new TQLabel( i18n("W&idth:"), gbBoxProps );
@@ -937,7 +937,7 @@ KatePrintLayout::KatePrintLayout( KPrinter * /*printer*/, TQWidget *parent, cons
   kcbtnBoxColor = new KColorButton( gbBoxProps );
   lBoxColor->setBuddy( kcbtnBoxColor );
 
-  connect( cbEnableBox, TQT_SIGNAL(toggled(bool)), gbBoxProps, TQT_SLOT(setEnabled(bool)) );
+  connect( cbEnableBox, TQ_SIGNAL(toggled(bool)), gbBoxProps, TQ_SLOT(setEnabled(bool)) );
 
   lo->addStretch( 1 );
   // set defaults:
@@ -1000,4 +1000,4 @@ void KatePrintLayout::setOptions( const TQMap<TQString,TQString>& opts )
 //END KatePrintLayout
 
 #include "kateprinter.moc"
-#endif //!Q_WS_WIN
+#endif //!TQ_WS_WIN
