@@ -66,11 +66,11 @@ ISearchPluginView::ISearchPluginView( KTextEditor::View *view )
 
 	m_searchForwardAction = new TDEAction(
 		i18n("Search Incrementally"), CTRL+ALT+Key_F,
-		this, TQT_SLOT(slotSearchForwardAction()),
+		this, TQ_SLOT(slotSearchForwardAction()),
 		actionCollection(), "edit_isearch" );
 	m_searchBackwardAction = new TDEAction(
 		i18n("Search Incrementally Backwards"), CTRL+ALT+SHIFT+Key_F,
-		this, TQT_SLOT(slotSearchBackwardAction()),
+		this, TQ_SLOT(slotSearchBackwardAction()),
 		actionCollection(), "edit_isearch_reverse" );
 
 	m_label = new TQLabel( i18n("I-Search:"), 0L, "tde toolbar widget" );
@@ -84,12 +84,12 @@ ISearchPluginView::ISearchPluginView( KTextEditor::View *view )
 	m_combo->setDuplicatesEnabled( false );
 	m_combo->setMaximumWidth( 300 );
 	m_combo->lineEdit()->installEventFilter( this );
-	connect( m_combo, TQT_SIGNAL(textChanged(const TQString&)),
-	         this, TQT_SLOT(slotTextChanged(const TQString&)) );
-	connect( m_combo, TQT_SIGNAL(returnPressed(const TQString&)),
-	         this, TQT_SLOT(slotReturnPressed(const TQString&)) );
-	connect( m_combo, TQT_SIGNAL(aboutToShowContextMenu(TQPopupMenu*)),
-		 this, TQT_SLOT(slotAddContextMenuItems(TQPopupMenu*)) );
+	connect( m_combo, TQ_SIGNAL(textChanged(const TQString&)),
+	         this, TQ_SLOT(slotTextChanged(const TQString&)) );
+	connect( m_combo, TQ_SIGNAL(returnPressed(const TQString&)),
+	         this, TQ_SLOT(slotReturnPressed(const TQString&)) );
+	connect( m_combo, TQ_SIGNAL(aboutToShowContextMenu(TQPopupMenu*)),
+		 this, TQ_SLOT(slotAddContextMenuItems(TQPopupMenu*)) );
 	m_comboAction = new KWidgetAction(
 		m_combo,
 		i18n("Search"), 0, 0, 0,
@@ -106,8 +106,8 @@ ISearchPluginView::ISearchPluginView( KTextEditor::View *view )
 		i18n("Case Sensitive"), TDEShortcut(),
 		actionCollection(), "isearch_case_sensitive" );
 	action->setShortcutConfigurable( false );
-	connect( action, TQT_SIGNAL(toggled(bool)),
-	         this, TQT_SLOT(setCaseSensitive(bool)) );
+	connect( action, TQ_SIGNAL(toggled(bool)),
+	         this, TQ_SLOT(setCaseSensitive(bool)) );
 	action->setChecked( m_caseSensitive );
 	optionMenu->insert( action );
 
@@ -115,8 +115,8 @@ ISearchPluginView::ISearchPluginView( KTextEditor::View *view )
 		i18n("From Beginning"), TDEShortcut(),
 		actionCollection(), "isearch_from_beginning" );
 	action->setShortcutConfigurable( false );
-	connect( action, TQT_SIGNAL(toggled(bool)),
-	         this, TQT_SLOT(setFromBeginning(bool)) );
+	connect( action, TQ_SIGNAL(toggled(bool)),
+	         this, TQ_SLOT(setFromBeginning(bool)) );
 	action->setChecked( m_fromBeginning );
 	optionMenu->insert( action );
 
@@ -124,8 +124,8 @@ ISearchPluginView::ISearchPluginView( KTextEditor::View *view )
 		i18n("Regular Expression"), TDEShortcut(),
 		actionCollection(), "isearch_reg_exp" );
 	action->setShortcutConfigurable( false );
-	connect( action, TQT_SIGNAL(toggled(bool)),
-	         this, TQT_SLOT(setRegExp(bool)) );
+	connect( action, TQ_SIGNAL(toggled(bool)),
+	         this, TQ_SLOT(setRegExp(bool)) );
 	action->setChecked( m_regExp );
 	optionMenu->insert( action );
 
@@ -134,8 +134,8 @@ ISearchPluginView::ISearchPluginView( KTextEditor::View *view )
 // 	action = new TDEToggleAction(
 // 		i18n("Auto-Wrap Search"), TDEShortcut(),
 // 		actionCollection(), "isearch_auto_wrap" );
-// 	connect( action, TQT_SIGNAL(toggled(bool)),
-// 	         this, TQT_SLOT(setAutoWrap(bool)) );
+// 	connect( action, TQ_SIGNAL(toggled(bool)),
+// 	         this, TQ_SLOT(setAutoWrap(bool)) );
 // 	action->setChecked( m_autoWrap );
 // 	optionMenu->insert( action );
 
@@ -225,7 +225,7 @@ bool ISearchPluginView::eventFilter( TQObject* o, TQEvent* e )
 
 	if( e->type() == TQEvent::KeyPress ) {
 		TQKeyEvent *keyEvent = (TQKeyEvent*)e;
-		if( keyEvent->key() == Qt::Key_Escape )
+		if( keyEvent->key() == TQt::Key_Escape )
 			quitToView( TQString::null );
 	}
 
@@ -410,13 +410,13 @@ void ISearchPluginView::slotAddContextMenuItems( TQPopupMenu *menu )
 	if( menu ) {
 		menu->insertSeparator();
 		menu->insertItem( i18n("Case Sensitive"), this,
-				  TQT_SLOT(setCaseSensitive(bool)));
+				  TQ_SLOT(setCaseSensitive(bool)));
 		menu->insertItem( i18n("From Beginning"), this,
-				  TQT_SLOT(setFromBeginning(bool)));
+				  TQ_SLOT(setFromBeginning(bool)));
 		menu->insertItem( i18n("Regular Expression"), this,
-				  TQT_SLOT(setRegExp(bool)));
+				  TQ_SLOT(setRegExp(bool)));
 		//menu->insertItem( i18n("Auto-Wrap Search"), this,
-		//		  TQT_SLOT(setAutoWrap(bool)));
+		//		  TQ_SLOT(setAutoWrap(bool)));
 	}
 }
 
