@@ -20,7 +20,7 @@
 */
 
 class CSnippet : public TQObject {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   CSnippet(TQString sKey, TQString sValue, TQListViewItem *lvi, TQObject *parent = 0, const char *name = 0);
