@@ -55,7 +55,7 @@ class PluginView : public KXMLGUIClient
 
 extern "C"
 {
-	KDE_EXPORT void* init_libkatetabbarextensionplugin()
+	TDE_EXPORT void* init_libkatetabbarextensionplugin()
 	{
 		TDEGlobal::locale()->insertCatalogue("katetabbarextension");
 		return new KatePluginFactory;
