@@ -25,9 +25,9 @@ Kate::MessageView::MessageView( TQWidget *parent, const char *name )
   : Kate::DockViewBase( parent, name )
 {
   m_view = new TQTextBrowser( this );
-  // m_view->setFormat( Qt::richText ); // should be!!
-  connect( m_view, TQT_SIGNAL( linkClicked( const TQString & ) ), 
-           TQT_SIGNAL( linkClicked( const TQString & ) ) );
+  // m_view->setFormat( TQt::richText ); // should be!!
+  connect( m_view, TQ_SIGNAL( linkClicked( const TQString & ) ), 
+           TQ_SIGNAL( linkClicked( const TQString & ) ) );
 }
 
 Kate::MessageView::~MessageView()
