@@ -89,12 +89,12 @@ KBBGame::KBBGame()
 
   initTDEAction();
 
-  connect( gr, TQT_SIGNAL(inputAt(int,int,int)),
-	  this, TQT_SLOT(gotInputAt(int,int,int)) );
-  connect( this, TQT_SIGNAL(gameRuns(bool)),
-	  gr, TQT_SLOT(setInputAccepted(bool)) );
-  connect( gr, TQT_SIGNAL(endMouseClicked()),
-	  this, TQT_SLOT(gameFinished()) );
+  connect( gr, TQ_SIGNAL(inputAt(int,int,int)),
+	  this, TQ_SLOT(gotInputAt(int,int,int)) );
+  connect( this, TQ_SIGNAL(gameRuns(bool)),
+	  gr, TQ_SLOT(setInputAccepted(bool)) );
+  connect( gr, TQ_SIGNAL(endMouseClicked()),
+	  this, TQ_SLOT(gameFinished()) );
 
   /*
   TQToolTip::add( doneButton, i18n(
@@ -104,7 +104,7 @@ KBBGame::KBBGame()
   /*
      Game initializations
   */
-  running = FALSE;
+  running = false;
   gameBoard = NULL;
 
   TDEConfig *kConf;
@@ -141,7 +141,7 @@ KBBGame::KBBGame()
   }
   if (kConf->hasKey( "tutorial" )) {
     tutorial = (bool) kConf->readNumEntry( "tutorial" );
-  } else tutorial = FALSE;
+  } else tutorial = false;
   tutorialAction->setChecked(tutorial);
 
   setCentralWidget( gr );
@@ -298,11 +298,11 @@ void KBBGame::newGame()
 
   randomBalls( balls );
   remap( gameBoard, gr->getGraphicBoard() );
-  gr->repaint( TRUE );
+  gr->repaint( true );
   setScore( 0 );
   detourCounter = -1;
   ballsPlaced = 0;
-  running = TRUE;
+  running = true;
   updateStats();
   emit gameRuns( running );
 }
@@ -370,7 +370,7 @@ void KBBGame::getResults()
 void KBBGame::abortGame()
 {
   if (running) {
-    running = FALSE;
+    running = false;
     ballsPlaced = 0;
     updateStats();
     gr->clearFocus();
@@ -437,7 +437,7 @@ void KBBGame::setScore( int n )
 
 bool KBBGame::setSize( int w, int h )
 {
-  bool ok = FALSE;
+  bool ok = false;
   if (((w+4) != gr->numC()) || ((h+4) != gr->numR())) {
     if (running) {
       ok = KMessageBox::warningContinueCancel(0,
@@ -445,7 +445,7 @@ bool KBBGame::setSize( int w, int h )
 			      "This will be the end of the current game!"),TQString(),i18n("End Game"))
 	== KMessageBox::Continue;
 
-    } else ok = TRUE;
+    } else ok = true;
     if (ok) {
       gr->setSize( w+4, h+4 ); // +4 is the space for "lasers" and an edge...
       setMinSize();
@@ -454,7 +454,7 @@ bool KBBGame::setSize( int w, int h )
       gameBoard = new RectOnArray( gr->numC(), gr->numR() );
       if (running) abortGame();
       newGame();
-      //      gr->repaint( TRUE );
+      //      gr->repaint( true );
     }
   }
   return ok;
@@ -466,13 +466,13 @@ bool KBBGame::setSize( int w, int h )
 
 bool KBBGame::setBalls( int n )
 {
-  bool ok = FALSE;
+  bool ok = false;
   if (balls != n) {
     if (running) {
       ok = KMessageBox::warningContinueCancel(0,
 			 i18n("This will be the end of the current game!"),TQString(),i18n("End Game"))
 	== KMessageBox::Continue;
-    } else ok = TRUE;
+    } else ok = true;
     if (ok) {
       balls = n;
       if (running) abortGame();
@@ -551,7 +551,7 @@ int KBBGame::traceRay( int startX, int startY, int *endX, int *endY )
       sly = 1; scy = 0; sry = -1;
       break;
     }
-    directionChanged = FALSE;
+    directionChanged = false;
     if (gameBoard->get( x+scx, y+scy ) == LASERBBT) {
       type = DETOUR;
       *endX = x+scx;
@@ -566,13 +566,13 @@ int KBBGame::traceRay( int startX, int startY, int *endX, int *endY )
     if (gameBoard->get( x+slx, y+sly ) == BALLBBT) {
       type = REFLECTION;
       if (gameBoard->get( x, y ) == LASERBBT) break;
-      directionChanged = TRUE;
+      directionChanged = true;
       refl += 1;
     }
     if (gameBoard->get( x+srx, y+sry ) == BALLBBT) {
       type = REFLECTION;
       if (gameBoard->get( x, y ) == LASERBBT) break;
-      directionChanged = TRUE;
+      directionChanged = true;
       refl +=2;
     }
     // turn to the right
@@ -622,7 +622,7 @@ void KBBGame::gotInputAt( int col, int row, int state )
   int w = gameBoard->width() - 2;
   int h = gameBoard->height() - 2;
 
-  if (state & Qt::LeftButton) {
+  if (state & TQt::LeftButton) {
     switch (type) {
     case WBALLBBG: // because of the tutorial mode
     case INNERBBG:
@@ -681,7 +681,7 @@ void KBBGame::gotInputAt( int col, int row, int state )
       }
       break;
     }
-  } else if (state & Qt::RightButton) {
+  } else if (state & TQt::RightButton) {
     switch (type) {
     case INNERBBG:
       r->set( col, row, MARK1BBG );
@@ -698,37 +698,37 @@ void KBBGame::gotInputAt( int col, int row, int state )
 void KBBGame::initTDEAction()
 {
 // game
-  KStdGameAction::gameNew(TQT_TQOBJECT(this), TQT_SLOT(newGame()), actionCollection());
-  (void)new TDEAction( i18n("&Give Up"), SmallIcon("giveup"), 0, TQT_TQOBJECT(this), TQT_SLOT(giveUp()), actionCollection(), "game_giveup" );
-  (void)new TDEAction( i18n("&Done"), SmallIcon("done"), 0, TQT_TQOBJECT(this), TQT_SLOT(gameFinished()), actionCollection(), "game_done" );
-  (void)new TDEAction( i18n("&Resize"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotResize()), actionCollection(), "game_resize" );
-  KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
+  KStdGameAction::gameNew(this, TQ_SLOT(newGame()), actionCollection());
+  (void)new TDEAction( i18n("&Give Up"), SmallIcon("giveup"), 0, this, TQ_SLOT(giveUp()), actionCollection(), "game_giveup" );
+  (void)new TDEAction( i18n("&Done"), SmallIcon("done"), 0, this, TQ_SLOT(gameFinished()), actionCollection(), "game_done" );
+  (void)new TDEAction( i18n("&Resize"), 0, this, TQ_SLOT(slotResize()), actionCollection(), "game_resize" );
+  KStdGameAction::quit(this, TQ_SLOT(close()), actionCollection());
 
 
 // settings
-  sizeAction = new TDESelectAction( i18n("&Size"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotSize()), actionCollection(), "options_size");
+  sizeAction = new TDESelectAction( i18n("&Size"), 0, this, TQ_SLOT(slotSize()), actionCollection(), "options_size");
   TQStringList list;
   list.append(i18n("  8 x  8 "));
   list.append(i18n(" 10 x 10 "));
   list.append(i18n(" 12 x 12 "));
   sizeAction->setItems(list);
 
-  ballsAction = new TDESelectAction( i18n("&Balls"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotBalls()), actionCollection(), "options_balls");
+  ballsAction = new TDESelectAction( i18n("&Balls"), 0, this, TQ_SLOT(slotBalls()), actionCollection(), "options_balls");
   list.clear();
   list.append(i18n(" 4 "));
   list.append(i18n(" 6 "));
   list.append(i18n(" 8 "));
   ballsAction->setItems(list);
-  tutorialAction = new TDEToggleAction( i18n("&Tutorial"), 0, TQT_TQOBJECT(this), TQT_SLOT(tutorialSwitch()), actionCollection(), "options_tutorial" );
-//  KStdAction::keyBindings(guiFactory(), TQT_SLOT(configureShortcuts()), 
+  tutorialAction = new TDEToggleAction( i18n("&Tutorial"), 0, this, TQ_SLOT(tutorialSwitch()), actionCollection(), "options_tutorial" );
+//  KStdAction::keyBindings(guiFactory(), TQ_SLOT(configureShortcuts()), 
 //actionCollection());
 
 // keyboard only
-  (void)new TDEAction( i18n("Move Down"), TQt::Key_Down, TQT_TQOBJECT(gr), TQT_SLOT(slotDown()), actionCollection(), "move_down" );
-  (void)new TDEAction( i18n("Move Up"), TQt::Key_Up, TQT_TQOBJECT(gr), TQT_SLOT(slotUp()), actionCollection(), "move_up" );
-  (void)new TDEAction( i18n("Move Left"), TQt::Key_Left, TQT_TQOBJECT(gr), TQT_SLOT(slotLeft()), actionCollection(), "move_left" );
-  (void)new TDEAction( i18n("Move Right"), TQt::Key_Right, TQT_TQOBJECT(gr), TQT_SLOT(slotRight()), actionCollection(), "move_right" );
-  (void)new TDEAction( i18n("Trigger Action"), TQt::Key_Return, TQT_TQOBJECT(gr), TQT_SLOT(slotInput()), actionCollection(), "move_trigger" );
+  (void)new TDEAction( i18n("Move Down"), TQt::Key_Down, gr, TQ_SLOT(slotDown()), actionCollection(), "move_down" );
+  (void)new TDEAction( i18n("Move Up"), TQt::Key_Up, gr, TQ_SLOT(slotUp()), actionCollection(), "move_up" );
+  (void)new TDEAction( i18n("Move Left"), TQt::Key_Left, gr, TQ_SLOT(slotLeft()), actionCollection(), "move_left" );
+  (void)new TDEAction( i18n("Move Right"), TQt::Key_Right, gr, TQ_SLOT(slotRight()), actionCollection(), "move_right" );
+  (void)new TDEAction( i18n("Trigger Action"), TQt::Key_Return, gr, TQ_SLOT(slotInput()), actionCollection(), "move_trigger" );
 }
 
 void KBBGame::slotResize()
