@@ -398,7 +398,7 @@ typedef bool (*KForEvery)
 class KTreeView : public TQGridView
 {
     friend class KTreeViewItem;
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
