@@ -71,7 +71,7 @@ public:
 		new TQLabel(caption + ": ", l);
 		KLineEdit* e = new KLineEdit( l );
 		m_widgets.insert(key, e ) ;
-        	e->setValidator( new TQIntValidator( TQT_TQOBJECT(e) ) );
+        	e->setValidator( new TQIntValidator( e ) );
 	}
 	int field(int key)
 	{
@@ -133,7 +133,7 @@ DCOPBrowserApplicationItem::DCOPBrowserApplicationItem
 	TQString mainWindowName= rx.cap(1) + "-mainwindow#1" ;
 
 	TQByteArray data;
-	int callId=kapp->dcopClient()->callAsync( app_, mainWindowName.utf8(), "icon()", data, this, TQT_SLOT(retreiveIcon(int, const TQCString&, const TQByteArray&)));
+	int callId=kapp->dcopClient()->callAsync( app_, mainWindowName.utf8(), "icon()", data, this, TQ_SLOT(retreiveIcon(int, const TQCString&, const TQByteArray&)));
 
 	if(!callId)
 	{
@@ -142,7 +142,7 @@ DCOPBrowserApplicationItem::DCOPBrowserApplicationItem
 		TQDataStream arg(data, IO_WriteOnly);
 		arg << TQCString( "MainWindow" );
 
-		kapp->dcopClient()->callAsync( app_, "qt", "find(TQCString)", data, this, TQT_SLOT(slotGotWindowName(int, const TQCString&, const TQByteArray& )));
+		kapp->dcopClient()->callAsync( app_, "qt", "find(TQCString)", data, this, TQ_SLOT(slotGotWindowName(int, const TQCString&, const TQByteArray& )));
 	}
 }
 
@@ -158,7 +158,7 @@ DCOPBrowserApplicationItem::setOpen(bool o)
   void
 DCOPBrowserApplicationItem::populate()
 {
-  TDEApplication::setOverrideCursor(tqwaitCursor);
+  TDEApplication::setOverrideCursor(TQt::waitCursor);
 
   bool ok = false;
   bool isDefault = false;
@@ -192,7 +192,7 @@ void DCOPBrowserApplicationItem::slotGotWindowName(int /*callId*/, const TQCStri
 		{
 			TQByteArray data;
 			kapp->dcopClient()->callAsync( app_, mainWindowName.utf8(), "icon()", data,
-				this, TQT_SLOT(retreiveIcon(int, const TQCString&, const TQByteArray&)));
+				this, TQ_SLOT(retreiveIcon(int, const TQCString&, const TQByteArray&)));
 		}
 	}
 }
@@ -241,7 +241,7 @@ DCOPBrowserInterfaceItem::setOpen(bool o)
   void
 DCOPBrowserInterfaceItem::populate()
 {
-  TDEApplication::setOverrideCursor(tqwaitCursor);
+  TDEApplication::setOverrideCursor(TQt::waitCursor);
 
   bool ok = false;
 
@@ -297,18 +297,18 @@ KDCOPWindow::KDCOPWindow(TQWidget *parent, const char * name)
 //	mainView->lv->addColumn(i18n("Function"));
 	mainView->lv->setDragAutoScroll( FALSE );
 	mainView->lv->setRootIsDecorated( TRUE );
-  connect(mainView->lv, TQT_SIGNAL(doubleClicked(TQListViewItem *)), TQT_SLOT(slotCallFunction(TQListViewItem *)));
-  connect(mainView->lv, TQT_SIGNAL(currentChanged(TQListViewItem *)), TQT_SLOT(slotCurrentChanged(TQListViewItem *)));
-  connect(mainView->lb_replyData, TQT_SIGNAL(contextMenuRequested(TQListBoxItem*, const TQPoint&)),
-          TQT_SLOT(slotResultListContextMenu(TQListBoxItem*, const TQPoint&)));
+  connect(mainView->lv, TQ_SIGNAL(doubleClicked(TQListViewItem *)), TQ_SLOT(slotCallFunction(TQListViewItem *)));
+  connect(mainView->lv, TQ_SIGNAL(currentChanged(TQListViewItem *)), TQ_SLOT(slotCurrentChanged(TQListViewItem *)));
+  connect(mainView->lb_replyData, TQ_SIGNAL(contextMenuRequested(TQListBoxItem*, const TQPoint&)),
+          TQ_SLOT(slotResultListContextMenu(TQListBoxItem*, const TQPoint&)));
 
   // set up the actions
-  KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection() );
-  KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( slotCopy()), actionCollection() );
-  KStdAction::keyBindings( guiFactory(), TQT_SLOT( configureShortcuts() ), actionCollection() );
+  KStdAction::quit( this, TQ_SLOT( close() ), actionCollection() );
+  KStdAction::copy( this, TQ_SLOT( slotCopy()), actionCollection() );
+  KStdAction::keyBindings( guiFactory(), TQ_SLOT( configureShortcuts() ), actionCollection() );
 
 
-  (void) new TDEAction( i18n( "&Reload" ), "reload", TDEStdAccel::shortcut(TDEStdAccel::Reload), TQT_TQOBJECT(this), TQT_SLOT( slotReload() ), actionCollection(), "reload" );
+  (void) new TDEAction( i18n( "&Reload" ), "reload", TDEStdAccel::shortcut(TDEStdAccel::Reload), this, TQ_SLOT( slotReload() ), actionCollection(), "reload" );
 
   exeaction =
     new TDEAction
@@ -316,8 +316,8 @@ KDCOPWindow::KDCOPWindow(TQWidget *parent, const char * name)
      i18n("&Execute"),
       "application-x-executable",
      CTRL + Key_E,
-     TQT_TQOBJECT(this),
-     TQT_SLOT(slotItemExecuted()),
+     this,
+     TQ_SLOT(slotItemExecuted()),
      actionCollection(),
      "execute"
     );
@@ -327,8 +327,8 @@ KDCOPWindow::KDCOPWindow(TQWidget *parent, const char * name)
 
   langmode = new TDESelectAction ( i18n("Language Mode"),
   		CTRL + Key_M,
-		TQT_TQOBJECT(this),
-		TQT_SLOT(slotMode()),
+		this,
+		TQ_SLOT(slotMode()),
 		actionCollection(),
 		"langmode");
   langmode->setEditable(false);
@@ -339,22 +339,22 @@ KDCOPWindow::KDCOPWindow(TQWidget *parent, const char * name)
   connect
     (
      dcopClient,
-     TQT_SIGNAL(applicationRegistered(const TQCString &)),
-     TQT_SLOT(slotApplicationRegistered(const TQCString &))
+     TQ_SIGNAL(applicationRegistered(const TQCString &)),
+     TQ_SLOT(slotApplicationRegistered(const TQCString &))
     );
 
   connect
     (
      dcopClient,
-     TQT_SIGNAL(applicationRemoved(const TQCString &)),
-     TQT_SLOT(slotApplicationUnregistered(const TQCString &))
+     TQ_SIGNAL(applicationRemoved(const TQCString &)),
+     TQ_SLOT(slotApplicationUnregistered(const TQCString &))
     );
 
   dcopClient->setNotifications(true);
   createGUI();
   setCaption(i18n("DCOP Browser"));
 	mainView->lb_replyData->hide();
-  TQTimer::singleShot(0, this, TQT_SLOT(slotFillApplications()));
+  TQTimer::singleShot(0, this, TQ_SLOT(slotFillApplications()));
 }
 
 
@@ -458,7 +458,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         KLineEdit* e = new KLineEdit( frame );
         grid->addWidget( e, i, 2 );
         wl.append( e );
-        e->setValidator( new TQIntValidator( TQT_TQOBJECT(e) ) );
+        e->setValidator( new TQIntValidator( e ) );
       }
       else if ( type == "unsigned"  || type == "uint" || type == "unsigned int"
              || type == "TQ_UINT32" )
@@ -471,7 +471,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         grid->addWidget( e, i, 2 );
         wl.append( e );
 
-        TQIntValidator* iv = new TQIntValidator( TQT_TQOBJECT(e) );
+        TQIntValidator* iv = new TQIntValidator( e );
         iv->setBottom( 0 );
         e->setValidator( iv );
       }
@@ -484,7 +484,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         KLineEdit* e = new KLineEdit( frame );
         grid->addWidget( e, i, 2 );
         wl.append( e );
-        e->setValidator( new TQIntValidator( TQT_TQOBJECT(e) ) );
+        e->setValidator( new TQIntValidator( e ) );
       }
       else if ( type == "ulong" || type == "unsigned long" || type == "unsigned long int"
              || type == "TQ_UINT64" )
@@ -496,7 +496,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         KLineEdit* e = new KLineEdit( frame );
         grid->addWidget( e, i, 2 );
         wl.append( e );
-        e->setValidator( new TQIntValidator( TQT_TQOBJECT(e) ) );
+        e->setValidator( new TQIntValidator( e ) );
       }
       else if ( type == "short" || type == "short int" )
       {
@@ -507,7 +507,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         KLineEdit* e = new KLineEdit( frame );
         grid->addWidget( e, i, 2 );
         wl.append( e );
-        e->setValidator( new TQIntValidator( TQT_TQOBJECT(e) ) );
+        e->setValidator( new TQIntValidator( e ) );
       }
       else if ( type == "ushort" || type == "unsigned short" || type == "unsigned short int"  )
       {
@@ -518,7 +518,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         KLineEdit* e = new KLineEdit( frame );
         grid->addWidget( e, i, 2 );
         wl.append( e );
-        e->setValidator( new TQIntValidator( TQT_TQOBJECT(e) ) );
+        e->setValidator( new TQIntValidator( e ) );
       }
       else if ( type == "float" )
       {
@@ -529,7 +529,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         KLineEdit* e = new KLineEdit( frame );
         grid->addWidget( e, i, 2 );
         wl.append( e );
-        e->setValidator( new TQDoubleValidator( TQT_TQOBJECT(e) ) );
+        e->setValidator( new TQDoubleValidator( e ) );
       }
       else if ( type == "double" )
       {
@@ -540,7 +540,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
         KLineEdit* e = new KLineEdit( frame );
         grid->addWidget( e, i, 2 );
         wl.append( e );
-        e->setValidator( new TQDoubleValidator( TQT_TQOBJECT(e) ) );
+        e->setValidator( new TQDoubleValidator( e ) );
       }
       else if ( type == "bool" )
       {
@@ -892,7 +892,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
 
 void KDCOPWindow::slotFillApplications()
 {
-  TDEApplication::setOverrideCursor(tqwaitCursor);
+  TDEApplication::setOverrideCursor(TQt::waitCursor);
 
   QCStringList apps = dcopClient->registeredApplications();
   TQCString appId = dcopClient->appId();
@@ -1233,7 +1233,7 @@ void KDCOPWindow::slotMode()
 void KDCOPWindow::slotResultListContextMenu(TQListBoxItem *item, const TQPoint &point)
 {
 	TQPopupMenu* contextMenu = new TQPopupMenu(this);
-	contextMenu->insertItem(i18n("&Copy"), this, TQT_SLOT(slotCopy()));
+	contextMenu->insertItem(i18n("&Copy"), this, TQ_SLOT(slotCopy()));
 	contextMenu->exec(point);
 }
 
