@@ -25,7 +25,7 @@
 
 class TDEListBoxDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
 
 public:
 
