@@ -120,7 +120,7 @@ DictHTMLPart::~DictHTMLPart()
 
 void DictHTMLPart::tdehtmlMouseReleaseEvent(tdehtml::MouseReleaseEvent *event)
 {
-  if (event->qmouseEvent()->button()==Qt::MidButton)
+  if (event->qmouseEvent()->button()==TQt::MidButton)
     emit(middleButtonClicked());
   else
     TDEHTMLPart::tdehtmlMouseReleaseEvent(event);
@@ -141,15 +141,15 @@ QueryView::QueryView(TQWidget *_parent)
   part->setJavaEnabled(false);
   part->setURLCursor(KCursor::handCursor());
   setFocusPolicy(TQWidget::NoFocus);
-  connect(part, TQT_SIGNAL(completed()), TQT_SLOT(partCompleted()));
-  connect(part, TQT_SIGNAL(middleButtonClicked()), TQT_SLOT(middleButtonClicked()));
+  connect(part, TQ_SIGNAL(completed()), TQ_SLOT(partCompleted()));
+  connect(part, TQ_SIGNAL(middleButtonClicked()), TQ_SLOT(middleButtonClicked()));
   rightBtnMenu = new TDEPopupMenu(this);
-  connect(part,TQT_SIGNAL(popupMenu(const TQString &, const TQPoint &)),this,TQT_SLOT(buildPopupMenu(const TQString &, const TQPoint &)));
-  connect(part->browserExtension(),TQT_SIGNAL(openURLRequest(const KURL &,const KParts::URLArgs &)),
-          this,TQT_SLOT(slotURLRequest(const KURL &,const KParts::URLArgs &)));
-  connect(part->browserExtension(),TQT_SIGNAL(enableAction(const char *,bool)),this,TQT_SLOT(enableAction(const char *,bool)));
-  TQTimer::singleShot( 0, this, TQT_SLOT(optionsChanged()) );
-  connect(interface,TQT_SIGNAL(resultReady(const TQString &, const TQString &)), TQT_SLOT(resultReady(const TQString &, const TQString &)));
+  connect(part,TQ_SIGNAL(popupMenu(const TQString &, const TQPoint &)),this,TQ_SLOT(buildPopupMenu(const TQString &, const TQPoint &)));
+  connect(part->browserExtension(),TQ_SIGNAL(openURLRequest(const KURL &,const KParts::URLArgs &)),
+          this,TQ_SLOT(slotURLRequest(const KURL &,const KParts::URLArgs &)));
+  connect(part->browserExtension(),TQ_SIGNAL(enableAction(const char *,bool)),this,TQ_SLOT(enableAction(const char *,bool)));
+  TQTimer::singleShot( 0, this, TQ_SLOT(optionsChanged()) );
+  connect(interface,TQ_SIGNAL(resultReady(const TQString &, const TQString &)), TQ_SLOT(resultReady(const TQString &, const TQString &)));
 }
 
 
@@ -160,9 +160,9 @@ QueryView::~QueryView()
 void QueryView::setActions(TDEToolBarPopupAction* NactBack, TDEToolBarPopupAction* NactForward, DictComboAction* NactQueryCombo)
 {
   actBack = NactBack;
-  connect(actBack->popupMenu(),TQT_SIGNAL(activated(int)),TQT_SLOT(browseBack(int)));
+  connect(actBack->popupMenu(),TQ_SIGNAL(activated(int)),TQ_SLOT(browseBack(int)));
   actForward = NactForward;
-  connect(actForward->popupMenu(),TQT_SIGNAL(activated(int)),TQT_SLOT(browseForward(int)));
+  connect(actForward->popupMenu(),TQ_SIGNAL(activated(int)),TQ_SLOT(browseForward(int)));
   actQueryCombo = NactQueryCombo;
 }
 
@@ -407,27 +407,27 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
     if (type.length()) {             // valid url
       if(type=="define") {
         rightBtnMenu->insertItem(i18n("Define &Synonym"),
-                                 this,TQT_SLOT(popupDefineLink()));
+                                 this,TQ_SLOT(popupDefineLink()));
         rightBtnMenu->insertItem(i18n("M&atch Synonym"),
-                                 this,TQT_SLOT(popupMatchLink()));
+                                 this,TQ_SLOT(popupMatchLink()));
         rightBtnMenu->insertSeparator();
       }
       if(type=="dbinfo") {
-        rightBtnMenu->insertItem(i18n("D&atabase Information"),this,TQT_SLOT(popupDbInfo()));
+        rightBtnMenu->insertItem(i18n("D&atabase Information"),this,TQ_SLOT(popupDbInfo()));
         rightBtnMenu->insertSeparator();
       }
       if(type=="realhttp") {
         popupLink.prepend("http://");
         rightBtnMenu->insertItem(SmallIcon("document-open"),
                                  i18n("&Open Link"),
-                                 this,TQT_SLOT(popupOpenLink()));
+                                 this,TQ_SLOT(popupOpenLink()));
         rightBtnMenu->insertSeparator();
       }
       if(type=="realftp") {
         popupLink.prepend("ftp://");
         rightBtnMenu->insertItem(SmallIcon("document-open"),
                                  i18n("&Open Link"),
-                                 this,TQT_SLOT(popupOpenLink()));
+                                 this,TQ_SLOT(popupOpenLink()));
         rightBtnMenu->insertSeparator();
       }
     }
@@ -436,9 +436,9 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
   if (part->hasSelection()) {
     popupSelect = part->selectedText();
     rightBtnMenu->insertItem(i18n("&Define Selection"),
-                             this,TQT_SLOT(popupDefineSelect()));
+                             this,TQ_SLOT(popupDefineSelect()));
     rightBtnMenu->insertItem(i18n("&Match Selection"),
-                             this,TQT_SLOT(popupMatchSelect()));
+                             this,TQ_SLOT(popupMatchSelect()));
     rightBtnMenu->insertSeparator();
   } else {
     kapp->clipboard()->setSelectionMode(false);
@@ -451,9 +451,9 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
       popupSelect = TQApplication::clipboard()->text();
       rightBtnMenu->insertItem(SmallIcon("define_clip"),
                                i18n("&Define Clipboard Content"),
-                               this,TQT_SLOT(popupDefineSelect()));
+                               this,TQ_SLOT(popupDefineSelect()));
       rightBtnMenu->insertItem(i18n("&Match Clipboard Content"),
-                               this,TQT_SLOT(popupMatchSelect()));
+                               this,TQ_SLOT(popupMatchSelect()));
       rightBtnMenu->insertSeparator();
     }
   }
@@ -464,13 +464,13 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
     if (browseList.at(browsePos-1)->queryText.isEmpty())
       rightBtnMenu->insertItem(SmallIcon("back"),
                                i18n("&Back: Information"),
-                               this,TQT_SLOT(browseBack()));
+                               this,TQ_SLOT(browseBack()));
     else
       rightBtnMenu->insertItem(SmallIcon("back"),
                                i18n("&Back: '%1'").arg(getShortString(browseList.at(browsePos-1)->queryText,25)),
-                               this,TQT_SLOT(browseBack()));
+                               this,TQ_SLOT(browseBack()));
   } else {
-    ID = rightBtnMenu->insertItem(SmallIcon("back"), i18n("&Back"), this, TQT_SLOT(browseBack()));
+    ID = rightBtnMenu->insertItem(SmallIcon("back"), i18n("&Back"), this, TQ_SLOT(browseBack()));
     rightBtnMenu->setItemEnabled(ID,false);
   }
 
@@ -478,13 +478,13 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
     if (browseList.at(browsePos+1)->queryText.isEmpty())
       rightBtnMenu->insertItem(SmallIcon("forward"),
                                i18n("&Forward: Information"),
-                               this,TQT_SLOT(browseForward()));
+                               this,TQ_SLOT(browseForward()));
     else
       rightBtnMenu->insertItem(SmallIcon("forward"),
                                i18n("&Forward: '%1'").arg(getShortString(browseList.at(browsePos+1)->queryText,25)),
-                               this,TQT_SLOT(browseForward()));
+                               this,TQ_SLOT(browseForward()));
   } else {
-    ID = rightBtnMenu->insertItem(SmallIcon("forward"),i18n("&Forward"),this,TQT_SLOT(browseForward()));
+    ID = rightBtnMenu->insertItem(SmallIcon("forward"),i18n("&Forward"),this,TQ_SLOT(browseForward()));
     rightBtnMenu->setItemEnabled(ID,false);
   }
 
@@ -544,7 +544,7 @@ void QueryView::browseBack(int index)
     browsePos = x;
     actQueryCombo->setEditText(browseList.at(browsePos)->queryText);
     showResult();
-    TQTimer::singleShot(0, this, TQT_SLOT(updateBrowseActions()));  // don't clear the menu in this slot
+    TQTimer::singleShot(0, this, TQ_SLOT(updateBrowseActions()));  // don't clear the menu in this slot
   }
 }
 
@@ -557,7 +557,7 @@ void QueryView::browseForward(int index)
     browsePos = x;
     actQueryCombo->setEditText(browseList.at(browsePos)->queryText);
     showResult();
-    TQTimer::singleShot(0, this, TQT_SLOT(updateBrowseActions()));  // don't clear the menu in this slot
+    TQTimer::singleShot(0, this, TQ_SLOT(updateBrowseActions()));  // don't clear the menu in this slot
   }
 }
 
