@@ -17,6 +17,7 @@
  */
 
 #include <algorithm>
+#include <functional>
 #include <memory>
 
 #include <tqfileinfo.h>
@@ -63,8 +64,8 @@ KGVDocument::KGVDocument( KGVPart* part, const char* name ) :
     readSettings();
 
     _pdf2dsc = new Pdf2dsc( _interpreterPath, this );
-    connect( _pdf2dsc, TQT_SIGNAL( finished( bool ) ),
-             TQT_SLOT( openPDFFileContinue( bool ) ) );
+    connect( _pdf2dsc, TQ_SIGNAL( finished( bool ) ),
+             TQ_SLOT( openPDFFileContinue( bool ) ) );
 }
 
 KGVDocument::~KGVDocument()
@@ -87,7 +88,7 @@ void KGVDocument::openFile( const TQString& name, const TQString& mimetype )
     _fileName = name;
     _mimetype = mimetype;
 
-    TQTimer::singleShot( 0, this, TQT_SLOT( doOpenFile() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( doOpenFile() ) );
 }
 
 void KGVDocument::doOpenFile()
@@ -171,7 +172,7 @@ bool KGVDocument::uncompressFile()
     // If the file is gzipped, gunzip it to the temporary file _tmpUnzipped.
     kdDebug(4500) << "KGVDocument::uncompressFile()" << endl;
 
-    auto_ptr<TQIODevice> filterDev( KFilterDev::deviceForFile( _fileName, _mimetype, true ) );
+    unique_ptr<TQIODevice> filterDev( KFilterDev::deviceForFile( _fileName, _mimetype, true ) );
     if ( !filterDev.get() ) {
         KMimeType::Ptr mt = KMimeType::mimeType(_mimetype);
 	if ( (_fileName.right( 3 ) == ".gz") || mt->is("application/x-gzip") ) {
@@ -565,9 +566,7 @@ void KGVDocument::saveAs()
                           TQString(), 
                           _part->widget(), 
                           TQString() );
-    if( !TDEIO::NetAccess::upload( _fileName,
-				 saveURL,
-				 static_cast<TQWidget*>( 0 ) ) ) {
+    if( !TDEIO::NetAccess::upload( _fileName, saveURL, 0 ) ) {
 	// TODO: Proper error dialog
     }
 }
@@ -620,7 +619,7 @@ bool KGVDocument::savePages( const TQString& saveFileName,
 	PageList normedPageList;
 	transform( pageList.begin(), pageList.end(),
 	           back_inserter( normedPageList ),
-	           bind2nd( minus<int>(), minPage - 1 ) );
+	           bind( minus<int>(), std::placeholders::_1, minPage - 1 ) );
 	
 	// Finally select the desired pages from the converted file.
 	psCopyDoc( psSaveFile.name(), saveFileName, normedPageList );
@@ -786,8 +785,8 @@ e=%1" ).arg( dscName )
 	    << "-c"
 	    << "quit";
 
-    connect( &process, TQT_SIGNAL( processExited( TDEProcess* ) ),
-	     this, TQT_SLOT( pdf2psExited( TDEProcess* ) ) );
+    connect( &process, TQ_SIGNAL( processExited( TDEProcess* ) ),
+	     this, TQ_SLOT( pdf2psExited( TDEProcess* ) ) );
 
     kdDebug(4500) << "KGVDocument: pdf2ps started" << endl;
     process.start( TDEProcess::NotifyOnExit );
@@ -832,8 +831,8 @@ void Pdf2dsc::run( const TQString& pdfName, const TQString& dscName )
               << "-c"
               << "quit";
 
-    connect( _process, TQT_SIGNAL( processExited( TDEProcess* ) ),
-	     this, TQT_SLOT( processExited() ) );
+    connect( _process, TQ_SIGNAL( processExited( TDEProcess* ) ),
+	     this, TQ_SLOT( processExited() ) );
 
     kdDebug(4500) << "Pdf2dsc: started" << endl;
     _process->start( TDEProcess::NotifyOnExit );
