@@ -25,7 +25,7 @@ class KURL;
 
 class KGVMainWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
@@ -42,5 +42,3 @@ protected:
 };
 
 #endif
-
-// vim:sw=4:sts=4:ts=8:noet
