@@ -50,35 +50,35 @@ ViewControl::ViewControl( TQWidget *parent, const char *name )
 	grid->setColStretch(1,10);
 
 
-	magComboBox = new TQComboBox( FALSE, vcGroupBox );
+	magComboBox = new TQComboBox( false, vcGroupBox );
 	magComboBox->setFixedHeight( magComboBox->sizeHint().height() );
 
 
 	//magComboBox->hide();
 
-	connect ( magComboBox, TQT_SIGNAL (activated (int)),
-		  this, TQT_SLOT (slotMagSelection (int)) );
+	connect ( magComboBox, TQ_SIGNAL (activated (int)),
+		  this, TQ_SLOT (slotMagSelection (int)) );
 	grid->addWidget( magComboBox, 0, 1 );
 
 
 
-	mediaComboBox = new TQComboBox( FALSE, vcGroupBox );
+	mediaComboBox = new TQComboBox( false, vcGroupBox );
 	mediaComboBox->setFixedHeight( magComboBox->sizeHint().height() );
 
-	connect ( mediaComboBox, TQT_SIGNAL (activated (int)),
-		  this, TQT_SLOT (slotMediaSelection (int)) );
+	connect ( mediaComboBox, TQ_SIGNAL (activated (int)),
+		  this, TQ_SLOT (slotMediaSelection (int)) );
 
 	grid->addWidget( mediaComboBox, 1, 1 );
 
-	orientComboBox = new TQComboBox( FALSE, vcGroupBox );
+	orientComboBox = new TQComboBox( false, vcGroupBox );
 	orientComboBox->insertItem(i18n("Portrait"));
 	orientComboBox->insertItem(i18n("Landscape"));
 	orientComboBox->insertItem(i18n("Seascape"));
 	orientComboBox->insertItem(i18n("Upside Down"));
 	orientComboBox->setFixedHeight( magComboBox->sizeHint().height() );
 
-	connect ( orientComboBox, TQT_SIGNAL (activated (int)),
-		  this, TQT_SLOT (slotOrientSelection (int)) );
+	connect ( orientComboBox, TQ_SIGNAL (activated (int)),
+		  this, TQ_SLOT (slotOrientSelection (int)) );
 	grid->addWidget( orientComboBox, 2, 1 );
 
 	int labelWidth = 0;
@@ -124,10 +124,10 @@ ViewControl::ViewControl( TQWidget *parent, const char *name )
 	bbox->addStretch( 10 );
 
 	apply = bbox->addButton( KStdGuiItem::apply() );
-	connect( apply, TQT_SIGNAL(clicked()), TQT_SLOT(slotApplyClicked()) );
+	connect( apply, TQ_SIGNAL(clicked()), TQ_SLOT(slotApplyClicked()) );
 
 	TQPushButton *closebtn = bbox->addButton( KStdGuiItem::close() );
-	connect( closebtn, TQT_SIGNAL(clicked()), TQT_SLOT(reject()) );
+	connect( closebtn, TQ_SIGNAL(clicked()), TQ_SLOT(reject()) );
 
 
 	bbox->layout();
