@@ -77,10 +77,10 @@ KHangManView::KHangManView(KHangMan*parent, const char *name)
     m_accentedLetters  = true;
     m_hintExists       = true;	// Assume hint exists
 
-    connect( m_letterInput, TQT_SIGNAL( returnPressed() ),
-	     this,          TQT_SLOT( slotTry() ) );
-    connect( m_guessButton, TQT_SIGNAL( clicked() ),
-	     this,          TQT_SLOT( slotTry() ));
+    connect( m_letterInput, TQ_SIGNAL( returnPressed() ),
+	     this,          TQ_SLOT( slotTry() ) );
+    connect( m_guessButton, TQ_SIGNAL( clicked() ),
+	     this,          TQ_SLOT( slotTry() ));
 }
 
 
@@ -190,7 +190,7 @@ bool KHangManView::containsChar(const TQString &sChar)
 
 void KHangManView::mousePressEvent(TQMouseEvent *mouse)
 {
-    if (mouse->button() == Qt::RightButton && m_hintExists && Prefs::hint()) {
+    if (mouse->button() == TQt::RightButton && m_hintExists && Prefs::hint()) {
 
         KPassivePopup *myPopup = new KPassivePopup( m_letterInput);
         myPopup->setView(i18n("Hint"), m_hint );
@@ -429,7 +429,7 @@ void KHangManView::slotTry()
 		    y = abspos.y() + height()*20/535;
 		    point = TQPoint(x, y);
 		    popup->show(mapToGlobal(point));
-		    TQTimer::singleShot( 4*1000, this, TQT_SLOT(slotNewGame()) );
+		    TQTimer::singleShot( 4*1000, this, TQ_SLOT(slotNewGame()) );
 		}
 		else if (KMessageBox::questionYesNo(this, i18n("Congratulations! You won! Do you want to play again?"),TQString(),i18n("Play Again"), i18n("Do Not Play")) == 3)
 		    slotNewGame();
@@ -475,7 +475,7 @@ void KHangManView::slotTry()
 		    int  y = abspos.y() + height() * 20 / 535;
 		    popup->show(mapToGlobal(TQPoint(x, y)));
 
-		    TQTimer::singleShot( 4 * 1000, this, TQT_SLOT(slotNewGame()) );
+		    TQTimer::singleShot( 4 * 1000, this, TQ_SLOT(slotNewGame()) );
 		}
 		else if (KMessageBox::questionYesNo(this, newGameString, TQString(), i18n("Play Again"), i18n("Do Not Play")) == 3)
 		    slotNewGame();
@@ -507,7 +507,7 @@ void KHangManView::slotTry()
 	    // Create a 1 second single-shot timer, and reenable user
 	    // input after this time.
 	    TQTimer::singleShot( Prefs::missedTimer() * 1000, 
-				this, TQT_SLOT(enableUserInput()) );
+				this, TQ_SLOT(enableUserInput()) );
 
 	    // Disable any possible entry
 	    m_letterInput->setEnabled(false);
@@ -528,7 +528,7 @@ void KHangManView::slotTry()
 	    point = TQPoint(x, y);
 
 	    TQTimer::singleShot( Prefs::missedTimer() * 1000,
-				this, TQT_SLOT(enableUserInput()) );
+				this, TQ_SLOT(enableUserInput()) );
 
 	    // Disable any possible entry
 	    m_letterInput->setEnabled(false);	
