@@ -10,9 +10,9 @@ namespace KHC {
 
 class DocEntry;
 
-class HTMLSearch : public QObject
+class HTMLSearch : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   public:
     HTMLSearch();
     ~HTMLSearch();
