@@ -92,24 +92,24 @@ TaskBar::TaskBar( TaskBarSettings* settingsObject, TaskBarSettings* globalSettin
     // configure
     configure();
 
-    connect(&m_relayoutTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(reLayout()));
+    connect(&m_relayoutTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(reLayout()));
 
-		connect(this, TQT_SIGNAL(contentsMoving(int, int)), TQT_SLOT(setBackground()));
+		connect(this, TQ_SIGNAL(contentsMoving(int, int)), TQ_SLOT(setBackground()));
 
     // connect manager
-    connect(TaskManager::the(), TQT_SIGNAL(taskAdded(Task::Ptr)),
-            this, TQT_SLOT(add(Task::Ptr)));
-    connect(TaskManager::the(), TQT_SIGNAL(taskRemoved(Task::Ptr)),
-            this, TQT_SLOT(remove(Task::Ptr)));
-    connect(TaskManager::the(), TQT_SIGNAL(startupAdded(Startup::Ptr)),
-            this, TQT_SLOT(add(Startup::Ptr)));
-    connect(TaskManager::the(), TQT_SIGNAL(startupRemoved(Startup::Ptr)),
-            this, TQT_SLOT(remove(Startup::Ptr)));
-    connect(TaskManager::the(), TQT_SIGNAL(desktopChanged(int)),
-            this, TQT_SLOT(desktopChanged(int)));
-    connect(TaskManager::the(), TQT_SIGNAL(windowChanged(Task::Ptr)),
-            this, TQT_SLOT(windowChanged(Task::Ptr)));
+    connect(TaskManager::the(), TQ_SIGNAL(taskAdded(Task::Ptr)),
+            this, TQ_SLOT(add(Task::Ptr)));
+    connect(TaskManager::the(), TQ_SIGNAL(taskRemoved(Task::Ptr)),
+            this, TQ_SLOT(remove(Task::Ptr)));
+    connect(TaskManager::the(), TQ_SIGNAL(startupAdded(Startup::Ptr)),
+            this, TQ_SLOT(add(Startup::Ptr)));
+    connect(TaskManager::the(), TQ_SIGNAL(startupRemoved(Startup::Ptr)),
+            this, TQ_SLOT(remove(Startup::Ptr)));
+    connect(TaskManager::the(), TQ_SIGNAL(desktopChanged(int)),
+            this, TQ_SLOT(desktopChanged(int)));
+    connect(TaskManager::the(), TQ_SIGNAL(windowChanged(Task::Ptr)),
+            this, TQ_SLOT(windowChanged(Task::Ptr)));
 
     isGrouping = shouldGroup();
 
@@ -131,8 +131,8 @@ TaskBar::TaskBar( TaskBarSettings* settingsObject, TaskBarSettings* globalSettin
 
     blocklayout = false;
 
-    connect(kapp, TQT_SIGNAL(settingsChanged(int)), TQT_SLOT(slotSettingsChanged(int)));
-    keys = new TDEGlobalAccel( TQT_TQOBJECT(this) );
+    connect(kapp, TQ_SIGNAL(settingsChanged(int)), TQ_SLOT(slotSettingsChanged(int)));
+    keys = new TDEGlobalAccel( this );
 #include "taskbarbindings.cpp"
     keys->readSettings();
     keys->updateConnections();
@@ -261,12 +261,12 @@ void TaskBar::configure()
     // are paying attention to the current Xinerama screen
     // disconnect first in case we've been here before
     // to avoid multiple connections
-    disconnect(TaskManager::the(), TQT_SIGNAL(windowChangedGeometry(Task::Ptr)),
-                this, TQT_SLOT(windowChangedGeometry(Task::Ptr)));
+    disconnect(TaskManager::the(), TQ_SIGNAL(windowChangedGeometry(Task::Ptr)),
+                this, TQ_SLOT(windowChangedGeometry(Task::Ptr)));
     if (m_showOnlyCurrentScreen)
     {
-        connect(TaskManager::the(), TQT_SIGNAL(windowChangedGeometry(Task::Ptr)),
-                 this, TQT_SLOT(windowChangedGeometry(Task::Ptr)));
+        connect(TaskManager::the(), TQ_SIGNAL(windowChangedGeometry(Task::Ptr)),
+                 this, TQ_SLOT(windowChangedGeometry(Task::Ptr)));
     }
     TaskManager::the()->trackGeometry(m_showOnlyCurrentScreen);
 
@@ -386,7 +386,7 @@ void TaskBar::add(Startup::Ptr startup)
     // create new container
     TaskContainer *container = new TaskContainer(startup, frames, this, m_settingsObject, m_globalSettingsObject, viewport());
     m_hiddenContainers.append(container);
-    connect(container, TQT_SIGNAL(showMe(TaskContainer*)), this, TQT_SLOT(showTaskContainer(TaskContainer*)));
+    connect(container, TQ_SIGNAL(showMe(TaskContainer*)), this, TQ_SLOT(showTaskContainer(TaskContainer*)));
 }
 
 void TaskBar::reSort()
@@ -746,7 +746,7 @@ void TaskBar::reLayout()
     int minButtonHeight = buttonHeight();
 
     // horizontal layout
-    if (orientation() == Qt::Horizontal)
+    if (orientation() == TQt::Horizontal)
     {
         int bwidth=buttonWidth();
         int rows = contentsRect().height() / minButtonHeight;
@@ -854,7 +854,7 @@ void TaskBar::reLayout()
         }
     }
     
-    TQTimer::singleShot(100, this, TQT_SLOT(publishIconGeometry()));
+    TQTimer::singleShot(100, this, TQ_SLOT(publishIconGeometry()));
 }
 
 void TaskBar::setViewportBackground()
@@ -1005,7 +1005,7 @@ int TaskBar::maximumButtonsWithoutShrinking() const
         rows = 1;
     }
 
-    if ( orientation() == Qt::Horizontal ) {
+    if ( orientation() == TQt::Horizontal ) {
         // maxWidth of 0 means no max width, drop back to default
         int maxWidth = READ_MERGED_TASKBAR_SETTING(maximumButtonWidth);
         if (maxWidth == 0)
@@ -1254,7 +1254,7 @@ TQImage* TaskBar::blendGradient(const TQSize& size)
 
 void TaskBar::sortContainersByDesktop(TaskContainer::List& list)
 {
-    typedef TQValueVector<QPair<int, QPair<int, TaskContainer*> > > SortVector;
+    typedef TQValueVector<TQPair<int, TQPair<int, TaskContainer*> > > SortVector;
     SortVector sorted;
     sorted.resize(list.count());
     int i = 0;
