@@ -24,6 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <assert.h>
 
+#include <tdeglobal.h>
 #include <kiconloader.h>
 #include <tdelocale.h>
 
@@ -44,6 +45,8 @@ TaskRMBMenu::TaskRMBMenu(const Task::List& theTasks, bool show, TQPopupMenu* mov
 	, showAll( show )
 	, taskMoveMenu( moveMenu )
 {
+    TDEGlobal::iconLoader()->addAppDir("twin");
+
     assert(tasks.count() > 0);
     if (tasks.count() == 1)
     {
@@ -68,9 +71,14 @@ void TaskRMBMenu::fillMenu(Task::Ptr t)
     int id;
     setCheckable(true);
 
-    insertItem(i18n("Ad&vanced"), makeAdvancedMenu(t));
     bool checkActions = KWin::allowedActionsSupported();
 
+    insertItem(i18n("Ad&vanced"), makeAdvancedMenu(t));
+
+    id = insertItem(i18n("T&ile"), makeTileMenu(t));
+    setItemEnabled(id, !checkActions ||
+            (t->info().actionSupported(NET::ActionMove) && t->info().actionSupported(NET::ActionResize)));
+
     if (TaskManager::the()->numberOfDesktops() > 1)
     {
         id = insertItem(i18n("To &Desktop"), makeDesktopsMenu(t));
@@ -280,6 +288,33 @@ TQPopupMenu* TaskRMBMenu::makeDesktopsMenu()
 	return m;
 }
 
+TQPopupMenu* TaskRMBMenu::makeTileMenu(Task::Ptr t)
+{
+    TQPopupMenu *m = new TQPopupMenu( this );
+
+    // Tile to side (the menu id matched the ActiveBorder index used for tiling)
+    int id = m->insertItem( UserIconSet("tile_left"), i18n("&Left"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 6 );
+    id = m->insertItem( UserIconSet("tile_right"), i18n("&Right"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 2 );
+    id = m->insertItem( UserIconSet("tile_top"), i18n("&Top"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 0 );
+    id = m->insertItem( UserIconSet("tile_bottom"), i18n("&Bottom"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 4 );
+
+    // Tile to corner (the menu id matched the ActiveBorder index used for tiling)
+    id = m->insertItem( UserIconSet("tile_topleft"), i18n("Top &Left"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 7 );
+    id = m->insertItem( UserIconSet("tile_topright"), i18n("Top &Right"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 1 );
+    id = m->insertItem( UserIconSet("tile_bottomleft"), i18n("Bottom L&eft"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 5 );
+    id = m->insertItem( UserIconSet("tile_bottomright"), i18n("&Bottom R&ight"), t, TQ_SLOT( tileTo(int) ) );
+    m->setItemParameter( id, 3 );
+
+    return m;
+}
+
 void TaskRMBMenu::slotMinimizeAll()
 {
     Task::List::iterator itEnd = tasks.end();
