@@ -193,7 +193,7 @@ KigPart::KigPart( TQWidget *parentWidget, const char *,
   // construct our command history
   mhistory = new KCommandHistory(actionCollection());
   mhistory->documentSaved();
-  connect( mhistory, TQT_SIGNAL( documentRestored() ), this, TQT_SLOT( setUnmodified() ) );
+  connect( mhistory, TQ_SIGNAL( documentRestored() ), this, TQ_SLOT( setUnmodified() ) );
 
   // we are read-write by default
   setReadWrite(true);
@@ -206,21 +206,21 @@ KigPart::KigPart( TQWidget *parentWidget, const char *,
 void KigPart::setupActions()
 {
   // save actions..
-  (void) KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
-  (void) KStdAction::save(this, TQT_SLOT(fileSave()), actionCollection());
+  (void) KStdAction::saveAs(this, TQ_SLOT(fileSaveAs()), actionCollection());
+  (void) KStdAction::save(this, TQ_SLOT(fileSave()), actionCollection());
 
   // print actions
-  (void) KStdAction::print( this, TQT_SLOT( filePrint() ), actionCollection() );
-  (void) KStdAction::printPreview( this, TQT_SLOT( filePrintPreview() ), actionCollection() );
+  (void) KStdAction::print( this, TQ_SLOT( filePrint() ), actionCollection() );
+  (void) KStdAction::printPreview( this, TQ_SLOT( filePrintPreview() ), actionCollection() );
 
   // selection actions
   aSelectAll = KStdAction::selectAll(
-    this, TQT_SLOT( slotSelectAll() ), actionCollection() );
+    this, TQ_SLOT( slotSelectAll() ), actionCollection() );
   aDeselectAll = KStdAction::deselect(
-    this, TQT_SLOT( slotDeselectAll() ), actionCollection() );
+    this, TQ_SLOT( slotDeselectAll() ), actionCollection() );
   aInvertSelection = new TDEAction(
     i18n( "Invert Selection" ), "", 0, this,
-    TQT_SLOT( slotInvertSelection() ), actionCollection(),
+    TQ_SLOT( slotInvertSelection() ), actionCollection(),
     "edit_invert_selection" );
 
   // we need icons...
@@ -229,46 +229,46 @@ void KigPart::setupActions()
 
   aDeleteObjects = new TDEAction(
       i18n("&Delete Objects"), "edit-delete", Key_Delete, this,
-      TQT_SLOT(deleteObjects()), actionCollection(), "delete_objects");
+      TQ_SLOT(deleteObjects()), actionCollection(), "delete_objects");
   aDeleteObjects->setToolTip(i18n("Delete the selected objects"));
 
   aCancelConstruction = new TDEAction(
       i18n("Cancel Construction"), "process-stop", Key_Escape, this,
-      TQT_SLOT(cancelConstruction()), actionCollection(), "cancel_construction");
+      TQ_SLOT(cancelConstruction()), actionCollection(), "cancel_construction");
   aCancelConstruction->setToolTip(
       i18n("Cancel the construction of the object being constructed"));
   aCancelConstruction->setEnabled(false);
 
   aShowHidden = new TDEAction(
-    i18n("U&nhide All"), 0, this, TQT_SLOT( showHidden() ),
+    i18n("U&nhide All"), 0, this, TQ_SLOT( showHidden() ),
     actionCollection(), "edit_unhide_all");
   aShowHidden->setToolTip(i18n("Show all hidden objects"));
   aShowHidden->setEnabled( true );
 
   aNewMacro = new TDEAction(
-    i18n("&New Macro..."), "gear", 0, this, TQT_SLOT(newMacro()),
+    i18n("&New Macro..."), "gear", 0, this, TQ_SLOT(newMacro()),
     actionCollection(), "macro_action");
   aNewMacro->setToolTip(i18n("Define a new macro"));
 
   aConfigureTypes = new TDEAction(
-    i18n("Manage &Types..."), 0, this, TQT_SLOT(editTypes()),
+    i18n("Manage &Types..."), 0, this, TQ_SLOT(editTypes()),
     actionCollection(), "types_edit");
   aConfigureTypes->setToolTip(i18n("Manage macro types."));
 
   KigExportManager::instance()->addMenuAction( this, m_widget->realWidget(),
                                                actionCollection() );
 
-  TDEAction* a = KStdAction::zoomIn( TQT_TQOBJECT(m_widget), TQT_SLOT( slotZoomIn() ),
+  TDEAction* a = KStdAction::zoomIn( m_widget, TQ_SLOT( slotZoomIn() ),
                                    actionCollection() );
   a->setToolTip( i18n( "Zoom in on the document" ) );
   a->setWhatsThis( i18n( "Zoom in on the document" ) );
 
-  a = KStdAction::zoomOut( TQT_TQOBJECT(m_widget), TQT_SLOT( slotZoomOut() ),
+  a = KStdAction::zoomOut( m_widget, TQ_SLOT( slotZoomOut() ),
                            actionCollection() );
   a->setToolTip( i18n( "Zoom out of the document" ) );
   a->setWhatsThis( i18n( "Zoom out of the document" ) );
 
-  a = KStdAction::fitToPage( TQT_TQOBJECT(m_widget), TQT_SLOT( slotRecenterScreen() ),
+  a = KStdAction::fitToPage( m_widget, TQ_SLOT( slotRecenterScreen() ),
                              actionCollection() );
   // grr.. why isn't there an icon for this..
   a->setIconSet( TQIconSet( l->loadIcon( "view_fit_to_page", TDEIcon::Toolbar ) ) );
@@ -281,12 +281,12 @@ void KigPart::setupActions()
 #endif
 #endif
 #ifdef KIG_PART_CPP_STD_FULLSCREEN_ACTION
-  a = KStdAction::fullScreen( TQT_TQOBJECT(m_widget), TQT_SLOT( toggleFullScreen() ), actionCollection(), (TQWidget*)(widget()->parent()),"fullscreen" );
+  a = KStdAction::fullScreen( m_widget, TQ_SLOT( toggleFullScreen() ), actionCollection(), (TQWidget*)(widget()->parent()),"fullscreen" );
 #else
   tmp = l->loadIcon( "view-fullscreen", TDEIcon::Toolbar );
   a = new TDEAction(
     i18n( "Full Screen" ), tmp, CTRL+SHIFT+Key_F,
-    m_widget, TQT_SLOT( toggleFullScreen() ),
+    m_widget, TQ_SLOT( toggleFullScreen() ),
     actionCollection(), "fullscreen" );
 #endif
   a->setToolTip( i18n( "View this document full-screen." ) );
@@ -294,31 +294,31 @@ void KigPart::setupActions()
 
   // TODO: an icon for this..
   a = new TDEAction(
-    i18n( "&Select Shown Area" ), "zoom-fit-best", 0, TQT_TQOBJECT(m_widget), TQT_SLOT( zoomRect() ),
+    i18n( "&Select Shown Area" ), "zoom-fit-best", 0, m_widget, TQ_SLOT( zoomRect() ),
     actionCollection(), "view_select_shown_rect" );
   a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
   a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
 
   a = new TDEAction(
-    i18n( "S&elect Zoom Area" ), "viewmag", 0, TQT_TQOBJECT(m_widget), TQT_SLOT( zoomArea() ),
+    i18n( "S&elect Zoom Area" ), "viewmag", 0, m_widget, TQ_SLOT( zoomArea() ),
     actionCollection(), "view_zoom_area" );
 //  a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
 //  a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
 
   aToggleGrid = new TDEToggleAction(
-    i18n( "Show &Grid" ), 0, this, TQT_SLOT( toggleGrid() ),
+    i18n( "Show &Grid" ), 0, this, TQ_SLOT( toggleGrid() ),
     actionCollection(), "settings_show_grid" );
   aToggleGrid->setToolTip( i18n( "Show or hide the grid." ) );
   aToggleGrid->setChecked( true );
 
   aToggleAxes = new TDEToggleAction(
-    i18n( "Show &Axes" ), 0, this, TQT_SLOT( toggleAxes() ),
+    i18n( "Show &Axes" ), 0, this, TQ_SLOT( toggleAxes() ),
     actionCollection(), "settings_show_axes" );
   aToggleAxes->setToolTip( i18n( "Show or hide the axes." ) );
   aToggleAxes->setChecked( true );
 
   aToggleNightVision = new TDEToggleAction(
-    i18n( "Wear Infrared Glasses" ), 0, this, TQT_SLOT( toggleNightVision() ),
+    i18n( "Wear Infrared Glasses" ), 0, this, TQ_SLOT( toggleNightVision() ),
     actionCollection(), "settings_toggle_nightvision" );
   aToggleNightVision->setToolTip( i18n( "Enable/Disable hidden objects visibility." ) );
   aToggleNightVision->setChecked( false );
@@ -563,8 +563,8 @@ void KigPart::delObjects( const std::vector<ObjectHolder*>& os )
 void KigPart::enableConstructActions( bool enabled )
 {
   for_each( aActions.begin(), aActions.end(),
-            bind2nd( mem_fun( &TDEAction::setEnabled ),
-                     enabled ) );
+            std::bind( mem_fn( &TDEAction::setEnabled ),
+                       std::placeholders::_1, enabled ) );
 }
 
 void KigPart::unplugActionLists()
@@ -716,7 +716,7 @@ void KigPart::setupMacroTypes()
   };
   // hack: we need to plug the action lists _after_ the gui is
   // built.. i can't find a better solution than this...
-  TQTimer::singleShot( 0, this, TQT_SLOT( plugActionLists() ) );
+  TQTimer::singleShot( 0, this, TQ_SLOT( plugActionLists() ) );
 }
 
 void KigPart::setupBuiltinMacros()
