@@ -54,43 +54,43 @@ TopLevel::TopLevel(TQWidget *parent, const char *name) : TDEMainWindow(parent, n
 
 	config = Config::self();
 	config->readConfig();
-	Accel = new TDEGlobalAccel(TQT_TQOBJECT(this));
-	(void) Accel->insert("Lookup Kanji (Kanjidic)", i18n("Lookup Kanji (Kanjidic)"), i18n("Gives detailed information about Kanji currently on clipboard."), CTRL + ALT + Key_K, CTRL + ALT + Key_K, TQT_TQOBJECT(this), TQT_SLOT(kanjiSearchAccel()));
-	(void) Accel->insert("Lookup English/Japanese word", i18n("Lookup English/Japanese Word"), i18n("Looks up current text on clipboard in the same way as if you used Kiten's regular search."), CTRL + ALT + Key_S, CTRL + ALT + Key_S, TQT_TQOBJECT(this), TQT_SLOT(searchAccel()));
+	Accel = new TDEGlobalAccel(this);
+	(void) Accel->insert("Lookup Kanji (Kanjidic)", i18n("Lookup Kanji (Kanjidic)"), i18n("Gives detailed information about Kanji currently on clipboard."), CTRL + ALT + Key_K, CTRL + ALT + Key_K, this, TQ_SLOT(kanjiSearchAccel()));
+	(void) Accel->insert("Lookup English/Japanese word", i18n("Lookup English/Japanese Word"), i18n("Looks up current text on clipboard in the same way as if you used Kiten's regular search."), CTRL + ALT + Key_S, CTRL + ALT + Key_S, this, TQ_SLOT(searchAccel()));
 	Accel->readSettings(TDEGlobal::config());
 	Accel->updateConnections();
 
 	_ResultView = new ResultView(true, this, "_ResultView");
 	setCentralWidget(_ResultView);
 
-	(void) KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
-	(void) KStdAction::print(TQT_TQOBJECT(this), TQT_SLOT(print()), actionCollection());
-	(void) KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotConfigure()), actionCollection());
-	KStdAction::keyBindings(guiFactory(), TQT_SLOT(configureShortcuts()), actionCollection());
-	(void) new TDEAction(i18n("&Learn"), "pencil", CTRL+Key_L, TQT_TQOBJECT(this), TQT_SLOT(createLearn()), actionCollection(), "file_learn");
-	(void) new TDEAction(i18n("&Dictionary Editor..."), "edit", 0, TQT_TQOBJECT(this), TQT_SLOT(createEEdit()), actionCollection(), "dict_editor");
-	(void) new TDEAction(i18n("Ra&dical Search..."), "gear", CTRL+Key_R, TQT_TQOBJECT(this), TQT_SLOT(radicalSearch()), actionCollection(), "search_radical");
-	Edit = new EditAction(i18n("Search Edit"), 0, TQT_TQOBJECT(this), TQT_SLOT(search()), actionCollection(), "search_edit");
-	(void) new TDEAction(i18n("&Clear Search Bar"), BarIcon("locationbar_erase", 16), CTRL+Key_N, Edit, TQT_SLOT(clear()), actionCollection(), "clear_search");
-	(void) new TDEAction(i18n("S&earch"), "key_enter", 0, TQT_TQOBJECT(this), TQT_SLOT(search()), actionCollection(), "search");
-	(void) new TDEAction(i18n("Search with &Beginning of Word"), 0, TQT_TQOBJECT(this), TQT_SLOT(searchBeginning()), actionCollection(), "search_beginning");
-	(void) new TDEAction(i18n("Search &Anywhere"), 0, TQT_TQOBJECT(this), TQT_SLOT(searchAnywhere()), actionCollection(), "search_anywhere");
-	(void) new TDEAction(i18n("Stro&kes"), "paintbrush", CTRL+Key_S, TQT_TQOBJECT(this), TQT_SLOT(strokeSearch()), actionCollection(), "search_stroke");
-	(void) new TDEAction(i18n("&Grade"), "format-justify-left", CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT(gradeSearch()), actionCollection(), "search_grade");
-	kanjiCB = new TDEToggleAction(i18n("&Kanjidic"), "kanjidic", CTRL+Key_K, TQT_TQOBJECT(this), TQT_SLOT(kanjiDictChange()), actionCollection(), "kanji_toggle");
-	deinfCB = new TDEToggleAction(i18n("&Deinflect Verbs in Regular Search"), 0, TQT_TQOBJECT(this), TQT_SLOT(kanjiDictChange()), actionCollection(), "deinf_toggle");
-	comCB = new TDEToggleAction(i18n("&Filter Rare"), "filter", CTRL+Key_F, TQT_TQOBJECT(this), TQT_SLOT(toggleCom()), actionCollection(), "common");
-	autoSearchToggle = new TDEToggleAction(i18n("&Automatically Search Clipboard Selections"), "edit-find", 0, TQT_TQOBJECT(this), TQT_SLOT(kanjiDictChange()), actionCollection(), "autosearch_toggle");
-	irAction =  new TDEAction(i18n("Search &in Results"), "edit-find", CTRL+Key_I, TQT_TQOBJECT(this), TQT_SLOT(resultSearch()), actionCollection(), "search_in_results");
-	(void) KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(configureToolBars()), actionCollection());
-	addAction = new TDEAction(i18n("Add &Kanji to Learning List"), 0, TQT_TQOBJECT(this), TQT_SLOT(addToList()), actionCollection(), "add");
+	(void) KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
+	(void) KStdAction::print(this, TQ_SLOT(print()), actionCollection());
+	(void) KStdAction::preferences(this, TQ_SLOT(slotConfigure()), actionCollection());
+	KStdAction::keyBindings(guiFactory(), TQ_SLOT(configureShortcuts()), actionCollection());
+	(void) new TDEAction(i18n("&Learn"), "pencil", CTRL+Key_L, this, TQ_SLOT(createLearn()), actionCollection(), "file_learn");
+	(void) new TDEAction(i18n("&Dictionary Editor..."), "edit", 0, this, TQ_SLOT(createEEdit()), actionCollection(), "dict_editor");
+	(void) new TDEAction(i18n("Ra&dical Search..."), "gear", CTRL+Key_R, this, TQ_SLOT(radicalSearch()), actionCollection(), "search_radical");
+	Edit = new EditAction(i18n("Search Edit"), 0, this, TQ_SLOT(search()), actionCollection(), "search_edit");
+	(void) new TDEAction(i18n("&Clear Search Bar"), BarIcon("locationbar_erase", 16), CTRL+Key_N, Edit, TQ_SLOT(clear()), actionCollection(), "clear_search");
+	(void) new TDEAction(i18n("S&earch"), "key_enter", 0, this, TQ_SLOT(search()), actionCollection(), "search");
+	(void) new TDEAction(i18n("Search with &Beginning of Word"), 0, this, TQ_SLOT(searchBeginning()), actionCollection(), "search_beginning");
+	(void) new TDEAction(i18n("Search &Anywhere"), 0, this, TQ_SLOT(searchAnywhere()), actionCollection(), "search_anywhere");
+	(void) new TDEAction(i18n("Stro&kes"), "paintbrush", CTRL+Key_S, this, TQ_SLOT(strokeSearch()), actionCollection(), "search_stroke");
+	(void) new TDEAction(i18n("&Grade"), "format-justify-left", CTRL+Key_G, this, TQ_SLOT(gradeSearch()), actionCollection(), "search_grade");
+	kanjiCB = new TDEToggleAction(i18n("&Kanjidic"), "kanjidic", CTRL+Key_K, this, TQ_SLOT(kanjiDictChange()), actionCollection(), "kanji_toggle");
+	deinfCB = new TDEToggleAction(i18n("&Deinflect Verbs in Regular Search"), 0, this, TQ_SLOT(kanjiDictChange()), actionCollection(), "deinf_toggle");
+	comCB = new TDEToggleAction(i18n("&Filter Rare"), "filter", CTRL+Key_F, this, TQ_SLOT(toggleCom()), actionCollection(), "common");
+	autoSearchToggle = new TDEToggleAction(i18n("&Automatically Search Clipboard Selections"), "edit-find", 0, this, TQ_SLOT(kanjiDictChange()), actionCollection(), "autosearch_toggle");
+	irAction =  new TDEAction(i18n("Search &in Results"), "edit-find", CTRL+Key_I, this, TQ_SLOT(resultSearch()), actionCollection(), "search_in_results");
+	(void) KStdAction::configureToolbars(this, TQ_SLOT(configureToolBars()), actionCollection());
+	addAction = new TDEAction(i18n("Add &Kanji to Learning List"), 0, this, TQ_SLOT(addToList()), actionCollection(), "add");
 	addAction->setEnabled(false);
-	(void) new TDEAction(i18n("Configure &Global Shortcuts..."), "configure_shortcuts", 0, TQT_TQOBJECT(this), TQT_SLOT(configureGlobalKeys()), actionCollection(), "options_configure_keybinding");
+	(void) new TDEAction(i18n("Configure &Global Shortcuts..."), "configure_shortcuts", 0, this, TQ_SLOT(configureGlobalKeys()), actionCollection(), "options_configure_keybinding");
 
 	historyAction = new TDEListAction(i18n("&History"), 0, 0, 0, actionCollection(), "history");
-	connect(historyAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(goInHistory(int)));
-	backAction = KStdAction::back(TQT_TQOBJECT(this), TQT_SLOT(back()), actionCollection());
-	forwardAction = KStdAction::forward(TQT_TQOBJECT(this), TQT_SLOT(forward()), actionCollection());
+	connect(historyAction, TQ_SIGNAL(activated(int)), this, TQ_SLOT(goInHistory(int)));
+	backAction = KStdAction::back(this, TQ_SLOT(back()), actionCollection());
+	forwardAction = KStdAction::forward(this, TQ_SLOT(forward()), actionCollection());
 	backAction->setEnabled(false);
 	forwardAction->setEnabled(false);
 	currentResult = resultHistory.end();
@@ -114,10 +114,10 @@ TopLevel::TopLevel(TQWidget *parent, const char *name) : TDEMainWindow(parent, n
 	resize(600, 400);
 	applyMainWindowSettings(TDEGlobal::config(), "TopLevelWindow");
 
-	connect(_ResultView, TQT_SIGNAL(linkClicked(const TQString &)), TQT_SLOT(ressearch(const TQString &)));
-	connect(kapp->clipboard(), TQT_SIGNAL(selectionChanged()), TQT_TQOBJECT(this), TQT_SLOT(autoSearch()));
+	connect(_ResultView, TQ_SIGNAL(linkClicked(const TQString &)), TQ_SLOT(ressearch(const TQString &)));
+	connect(kapp->clipboard(), TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(autoSearch()));
 
-	TQTimer::singleShot(10, TQT_TQOBJECT(this), TQT_SLOT(finishInit()));
+	TQTimer::singleShot(10, this, TQ_SLOT(finishInit()));
 }
 
 TopLevel::~TopLevel()
@@ -609,9 +609,9 @@ void TopLevel::slotConfigure()
 	
 	//ConfigureDialog didn't find an instance of this dialog, so lets create it :
 	optionDialog = new ConfigureDialog(this, "settings");
-	connect(optionDialog, TQT_SIGNAL(hidden()),this,TQT_SLOT(slotConfigureHide()));
-	connect(optionDialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(slotConfigurationChanged()));
-	connect(optionDialog, TQT_SIGNAL(valueChanged()), TQT_TQOBJECT(this), TQT_SIGNAL(quizConfChanged()));
+	connect(optionDialog, TQ_SIGNAL(hidden()),this,TQ_SLOT(slotConfigureHide()));
+	connect(optionDialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(slotConfigurationChanged()));
+	connect(optionDialog, TQ_SIGNAL(valueChanged()), this, TQ_SIGNAL(quizConfChanged()));
 	optionDialog->show();
 
 	return;
@@ -625,7 +625,7 @@ void TopLevel::slotLearnConfigure()
 
 void TopLevel::slotConfigureHide()
 {
-	TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigureDestroy()));
+	TQTimer::singleShot(0, this, TQ_SLOT(slotConfigureDestroy()));
 }
 
 void TopLevel::slotConfigureDestroy()
@@ -641,11 +641,11 @@ void TopLevel::createLearn()
 {
 	Learn *_Learn = new Learn(_Asyndeta.retrieveIndex(), 0);
 
-	connect(_Learn, TQT_SIGNAL(destroyed(Learn *)), TQT_TQOBJECT(this), TQT_SLOT(learnDestroyed(Learn *)));
-	connect(_Learn, TQT_SIGNAL(linkClicked(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(ressearch(const TQString &)));
-	connect(_Learn, TQT_SIGNAL(configureLearn()), TQT_TQOBJECT(this), TQT_SLOT(slotLearnConfigure()));
-	connect(this, TQT_SIGNAL(quizConfChanged()), _Learn, TQT_SLOT(updateQuizConfiguration()));
-	connect(this, TQT_SIGNAL(add(Dict::Entry)), _Learn, TQT_SLOT(add(Dict::Entry)));
+	connect(_Learn, TQ_SIGNAL(destroyed(Learn *)), this, TQ_SLOT(learnDestroyed(Learn *)));
+	connect(_Learn, TQ_SIGNAL(linkClicked(const TQString &)), this, TQ_SLOT(ressearch(const TQString &)));
+	connect(_Learn, TQ_SIGNAL(configureLearn()), this, TQ_SLOT(slotLearnConfigure()));
+	connect(this, TQ_SIGNAL(quizConfChanged()), _Learn, TQ_SLOT(updateQuizConfiguration()));
+	connect(this, TQ_SIGNAL(add(Dict::Entry)), _Learn, TQ_SLOT(add(Dict::Entry)));
 
 	learnList.append(_Learn);
 
@@ -730,7 +730,7 @@ void TopLevel::configureToolBars()
 {
 	saveMainWindowSettings(TDEGlobal::config(), "TopLevelWindow");
 	KEditToolbar dlg(actionCollection(), "kitenui.rc");
-	connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_SLOT(newToolBarConfig()));
+	connect(&dlg, TQ_SIGNAL(newToolbarConfig()), TQ_SLOT(newToolBarConfig()));
 	dlg.exec();
 }
 
@@ -743,7 +743,7 @@ void TopLevel::newToolBarConfig()
 RadWidget *TopLevel::radicalSearch()
 {
 	RadWidget *rw = new RadWidget(&_Rad, 0, "rw");
-	connect(rw, TQT_SIGNAL(set(const TQStringList &, unsigned int, unsigned int)), TQT_TQOBJECT(this), TQT_SLOT(radSearch(const TQStringList &, unsigned int, unsigned int)));
+	connect(rw, TQ_SIGNAL(set(const TQStringList &, unsigned int, unsigned int)), this, TQ_SLOT(radSearch(const TQStringList &, unsigned int, unsigned int)));
 	rw->show();
 	return rw;
 }
