@@ -30,7 +30,7 @@
 #include <tdelocale.h>
 #include <kinputdialog.h>
 #include <tdemessagebox.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include "ksimpleprocess.h"
 
 #else
