@@ -54,12 +54,12 @@ LinesBoard::LinesBoard( BallPainter * abPainter, TQWidget* parent, const char* n
   setFocusPolicy( TQWidget::NoFocus );
   setBackgroundColor( gray );
 
-  setMouseTracking( FALSE );
+  setMouseTracking( false );
   setFixedSize(wHint(), hHint());
 
   timer = new TQTimer(this);
   connect( timer, TQ_SIGNAL(timeout()), TQ_SLOT(timerSlot()) );
-  timer->start( TIMERCLOCK, FALSE );
+  timer->start( TIMERCLOCK, false );
 
 }
 
@@ -163,7 +163,7 @@ void LinesBoard::placeBall(  )
 
 /*id LinesBoard::doAfterBalls() {
   erase5Balls();
-  repaint(FALSE);
+  repaint(false);
 }
 */
 /*
@@ -306,7 +306,7 @@ void LinesBoard::moveFocus(int dx, int dy)
     focusX = (focusX + dx + NUMCELLSW) % NUMCELLSW;
     focusY = (focusY + dy + NUMCELLSH) % NUMCELLSH;
   }
-  repaint(FALSE);
+  repaint(false);
 } 
 
 void LinesBoard::moveLeft()
@@ -401,7 +401,7 @@ int LinesBoard::AnimEnd( )
   else if ( oldanim == ANIM_BURN )
   {
     emit eraseLine( deleteAnimatedBalls() );
-    repaint(FALSE);
+    repaint(false);
     if ( nextBallToPlace < BALLSDROP )
     {
       placeBall();
@@ -455,7 +455,7 @@ void LinesBoard::AnimNext() {
       if ( (direction > 0 && animstep == animmax) || ( direction < 0 && animstep == 0))
         direction = -direction;
       animstep += direction;
-      repaint(FALSE);
+      repaint(false);
     } else {
       if ( animstep >= animmax )
         AnimEnd();
@@ -466,7 +466,7 @@ void LinesBoard::AnimNext() {
             moveBall(way[animstep].x,way[animstep].y,way[animstep+1].x,way[animstep+1].y);
           animstep++;
           animdelaycount = animdelaystart;
-          repaint( FALSE );
+          repaint( false );
         }
       }
     }
@@ -698,7 +698,7 @@ void LinesBoard::undo()
   AnimEnd();
   restoreUndo();
   restoreRandomState();
-  repaint( FALSE );
+  repaint( false );
 }
 
 void LinesBoard::showDemoText(const TQString &text)
@@ -708,7 +708,7 @@ void LinesBoard::showDemoText(const TQString &text)
      demoLabel = new TQLabel(0, "demoTip", WStyle_StaysOnTop | WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WX11BypassWM );
      demoLabel->setMargin(1);
      demoLabel->setIndent(0);
-     demoLabel->setAutoMask( FALSE );
+     demoLabel->setAutoMask( false );
      demoLabel->setFrameStyle( TQFrame::Plain | TQFrame::Box );
      demoLabel->setLineWidth( 1 );
      demoLabel->setAlignment( AlignHCenter | AlignTop );
