@@ -20,8 +20,8 @@ BoardWidget::BoardWidget( TQWidget* parent, const char *name )
     setBackgroundColor( TQColor( 0,0,0 ) );
 
     timer = new TQTimer(this);
-    connect( timer, TQT_SIGNAL(timeout()),
-             this, TQT_SLOT(helpMoveTimeout()) );
+    connect( timer, TQ_SIGNAL(timeout()),
+             this, TQ_SLOT(helpMoveTimeout()) );
 
     TimerState = Stop;
     gamePaused = false;
@@ -440,7 +440,7 @@ void BoardWidget::stackTiles(unsigned char t, unsigned short h, unsigned short x
     int ss = theTiles.shadowSize();
     TQPainter p(&backBuffer);
     TQPen line;
-    p.setBackgroundMode(Qt::OpaqueMode);
+    p.setBackgroundMode(TQt::OpaqueMode);
     p.setBackgroundColor(black);
 
 
@@ -633,7 +633,7 @@ void BoardWidget::demoMoveTimeout()
                 break;
         }
         // restart timer
-        TQTimer::singleShot( ANIMSPEED, this, TQT_SLOT( demoMoveTimeout() ) );
+        TQTimer::singleShot( ANIMSPEED, this, TQ_SLOT( demoMoveTimeout() ) );
     }
 }
 
@@ -667,7 +667,7 @@ void BoardWidget::matchAnimationTimeout()
         }
     }
     if( TimerState == Match )
-        TQTimer::singleShot( ANIMSPEED, this, TQT_SLOT( matchAnimationTimeout() ) );
+        TQTimer::singleShot( ANIMSPEED, this, TQ_SLOT( matchAnimationTimeout() ) );
 }
 // ---------------------------------------------------------
 void BoardWidget::stopMatchAnimation()
@@ -1623,7 +1623,7 @@ void BoardWidget::mousePressEvent ( TQMouseEvent* event )
     if (gamePaused)
         return;
 
-    if( event->button() == Qt::LeftButton )
+    if( event->button() == TQt::LeftButton )
     {
         if( TimerState == Demo )
         {
