@@ -80,20 +80,20 @@ FolderStorage::FolderStorage( KMFolder* folder, const char* aName )
   mNoChildren     = false;
   mRDict = 0;
   mDirtyTimer = new TQTimer(this, "mDirtyTimer");
-  connect(mDirtyTimer, TQT_SIGNAL(timeout()),
-	  this, TQT_SLOT(updateIndex()));
+  connect(mDirtyTimer, TQ_SIGNAL(timeout()),
+	  this, TQ_SLOT(updateIndex()));
 
   mHasChildren = HasNoChildren;
   mContentsType = KMail::ContentsTypeMail;
 
-  connect(this, TQT_SIGNAL(closed(KMFolder*)), mFolder, TQT_SIGNAL(closed()));
+  connect(this, TQ_SIGNAL(closed(KMFolder*)), mFolder, TQ_SIGNAL(closed()));
 }
 
 //-----------------------------------------------------------------------------
 FolderStorage::~FolderStorage()
 {
   mJobList.setAutoDelete( true );
-  TQObject::disconnect( TQT_SIGNAL(destroyed(TQObject*)), this, 0 );
+  TQObject::disconnect( TQ_SIGNAL(destroyed(TQObject*)), this, 0 );
   mJobList.clear();
   KMMsgDict::deleteRentry(mRDict);
 }
@@ -118,8 +118,8 @@ TQString FolderStorage::dotEscape(const TQString& aStr)
 
 void FolderStorage::addJob( FolderJob* job ) const
 {
-  TQObject::connect( job, TQT_SIGNAL(destroyed(TQObject*)),
-                    TQT_SLOT(removeJob(TQObject*)) );
+  TQObject::connect( job, TQ_SIGNAL(destroyed(TQObject*)),
+                    TQ_SLOT(removeJob(TQObject*)) );
   mJobList.append( job );
 }
 
@@ -212,8 +212,8 @@ void FolderStorage::quiet(bool beQuiet)
      */
     if ( !mEmitChangedTimer) {
       mEmitChangedTimer= new TQTimer( this, "mEmitChangedTimer" );
-      connect( mEmitChangedTimer, TQT_SIGNAL( timeout() ),
-      this, TQT_SLOT( slotEmitChangedTimer() ) );
+      connect( mEmitChangedTimer, TQ_SIGNAL( timeout() ),
+      this, TQ_SLOT( slotEmitChangedTimer() ) );
     }
     mQuiet++;
   } else {
@@ -309,8 +309,8 @@ bool FolderStorage::canAddMsgNow(KMMessage* aMsg, int* aIndex_ret)
   if (!aMsg->isComplete() && msgParent && msgParent->folderType() == KMFolderTypeImap)
   {
     FolderJob *job = msgParent->createJob(aMsg);
-    connect(job, TQT_SIGNAL(messageRetrieved(KMMessage*)),
-            TQT_SLOT(reallyAddMsg(KMMessage*)));
+    connect(job, TQ_SIGNAL(messageRetrieved(KMMessage*)),
+            TQ_SLOT(reallyAddMsg(KMMessage*)));
     job->start();
     aMsg->setTransferInProgress( true );
     return false;
@@ -1147,7 +1147,7 @@ void FolderStorage::slotProcessNextSearchBatch()
   bool complete = ( end >= count() );
   emit searchResult( folder(), matchingSerNums, mSearchPattern, complete );
   if ( !complete )
-    TQTimer::singleShot( 0, this, TQT_SLOT(slotProcessNextSearchBatch()) );
+    TQTimer::singleShot( 0, this, TQ_SLOT(slotProcessNextSearchBatch()) );
 }
 
 //-----------------------------------------------------------------------------
