@@ -7,11 +7,11 @@
 #include <weaver.h>
 #include <weaverlogger.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <tdeconfig.h>
 #include <tdeversion.h>
 #include <tdeimproxy.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #ifdef __TDE_HAVE_TDEHWLIB
 # include <tdenetworkconnections.h>
@@ -88,7 +88,7 @@ class ConfigureDialog;
  * (singleton) objects such as the UndoStack, the folder managers and filter
  * manager, etc.
  */
-class KDE_EXPORT KMKernel : public TQObject, virtual public KMailIface
+class TDE_EXPORT KMKernel : public TQObject, virtual public KMailIface
 {
   TQ_OBJECT
   
