@@ -71,7 +71,7 @@ KMSystemTray::KMSystemTray(TQWidget *parent, const char *name)
 
   mLastUpdate = time( 0 );
   mUpdateTimer = new TQTimer( this, "systraytimer" );
-  connect( mUpdateTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( updateNewMessages() ) );
+  connect( mUpdateTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( updateNewMessages() ) );
 
   mDefaultIcon = loadIcon( "kmail" );
   mLightIconImage = loadIcon( "kmaillight" ).convertToImage();
@@ -94,15 +94,15 @@ KMSystemTray::KMSystemTray(TQWidget *parent, const char *name)
   /** Initiate connections between folders and this object */
   foldersChanged();
 
-  connect( kmkernel->folderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(foldersChanged()));
-  connect( kmkernel->imapFolderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(foldersChanged()));
-  connect( kmkernel->dimapFolderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(foldersChanged()));
-  connect( kmkernel->searchFolderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(foldersChanged()));
+  connect( kmkernel->folderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(foldersChanged()));
+  connect( kmkernel->imapFolderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(foldersChanged()));
+  connect( kmkernel->dimapFolderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(foldersChanged()));
+  connect( kmkernel->searchFolderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(foldersChanged()));
 
-  connect( kmkernel->acctMgr(), TQT_SIGNAL( checkedMail( bool, bool, const TQMap<TQString, int> & ) ),
-           TQT_SLOT( updateNewMessages() ) );
+  connect( kmkernel->acctMgr(), TQ_SIGNAL( checkedMail( bool, bool, const TQMap<TQString, int> & ) ),
+           TQ_SLOT( updateNewMessages() ) );
 
-  connect( this, TQT_SIGNAL( quitSelected() ), TQT_SLOT( tray_quit() ) );
+  connect( this, TQ_SIGNAL( quitSelected() ), TQ_SLOT( tray_quit() ) );
 }
 
 void KMSystemTray::buildPopupMenu()
@@ -132,7 +132,7 @@ void KMSystemTray::buildPopupMenu()
     action->plug( mPopupMenu );
   mPopupMenu->insertSeparator();
 
-  mPopupMenu->insertItem( SmallIcon("system-log-out"), i18n("&Quit"), this, TQT_SLOT(maybeQuit()) );
+  mPopupMenu->insertItem( SmallIcon("system-log-out"), i18n("&Quit"), this, TQ_SLOT(maybeQuit()) );
 }
 
 void KMSystemTray::tray_quit()
@@ -275,7 +275,7 @@ void KMSystemTray::foldersChanged()
   }
 
   /** Disconnect all previous connections */
-  disconnect(this, TQT_SLOT(updateNewMessageNotification(KMFolder *)));
+  disconnect(this, TQ_SLOT(updateNewMessageNotification(KMFolder *)));
 
   TQStringList folderNames;
   TQValueList<TQGuardedPtr<KMFolder> > folderList;
@@ -297,14 +297,14 @@ void KMSystemTray::foldersChanged()
          !currentFolder->ignoreNewMail() )
     {
       /** If this is a new folder, start listening for messages */
-      connect(currentFolder, TQT_SIGNAL(numUnreadMsgsChanged(KMFolder *)),
-              this, TQT_SLOT(updateNewMessageNotification(KMFolder *)));
+      connect(currentFolder, TQ_SIGNAL(numUnreadMsgsChanged(KMFolder *)),
+              this, TQ_SLOT(updateNewMessageNotification(KMFolder *)));
 
       /** Check all new folders to see if we started with any new messages */
       updateNewMessageNotification(currentFolder);
     }
     else {
-        disconnect(currentFolder, TQT_SIGNAL(numUnreadMsgsChanged(KMFolder *)), this, TQT_SLOT(updateNewMessageNotification(KMFolder *)) );
+        disconnect(currentFolder, TQ_SIGNAL(numUnreadMsgsChanged(KMFolder *)), this, TQ_SLOT(updateNewMessageNotification(KMFolder *)) );
     }
   }
 }
@@ -316,7 +316,7 @@ void KMSystemTray::foldersChanged()
 void KMSystemTray::mousePressEvent(TQMouseEvent *e)
 {
   // switch to kmail on left mouse button
-  if( e->button() == Qt::LeftButton )
+  if( e->button() == TQt::LeftButton )
   {
     if( mParentVisible && mainWindowIsOnCurrentDesktop() )
       hideKMail();
@@ -325,7 +325,7 @@ void KMSystemTray::mousePressEvent(TQMouseEvent *e)
   }
 
   // open popup menu on right mouse button
-  if( e->button() == Qt::RightButton )
+  if( e->button() == TQt::RightButton )
   {
     mPopupFolders.clear();
     mPopupFolders.reserve( mFoldersWithUnread.count() );
@@ -349,7 +349,7 @@ void KMSystemTray::mousePressEvent(TQMouseEvent *e)
         kdDebug(5006) << "Adding folder" << endl;
         mPopupFolders.append( it.key() );
         TQString item = prettyName(it.key()) + " (" + TQString::number(it.data()) + ")";
-        newMessagesPopup->insertItem(item, this, TQT_SLOT(selectedAccount(int)), 0, i);
+        newMessagesPopup->insertItem(item, this, TQ_SLOT(selectedAccount(int)), 0, i);
         ++it;
       }
 
@@ -545,7 +545,7 @@ void KMSystemTray::updateNewMessages()
       if(mFoldersWithUnread.count() == 0)
       {
         mPopupFolders.clear();
-        disconnect(this, TQT_SLOT(selectedAccount(int)));
+        disconnect(this, TQ_SLOT(selectedAccount(int)));
 
         mCount = 0;
 
