@@ -364,10 +364,10 @@ RecipientsPicker::RecipientsPicker( TQWidget *parent )
   resLayout->addWidget( mCollectionCombo );
   resLayout->addItem(new TQSpacerItem(1, 1, TQSizePolicy::Expanding));
 
-//  connect( mCollectionCombo, TQT_SIGNAL( highlighted( int ) ),
-//    TQT_SLOT( updateList() ) );
-  connect( mCollectionCombo, TQT_SIGNAL( activated( int ) ),
-    TQT_SLOT( updateList() ) );
+//  connect( mCollectionCombo, TQ_SIGNAL( highlighted( int ) ),
+//    TQ_SLOT( updateList() ) );
+  connect( mCollectionCombo, TQ_SIGNAL( activated( int ) ),
+    TQ_SLOT( updateList() ) );
 
   TQBoxLayout *searchLayout = new TQHBoxLayout( topLayout );
 
@@ -375,7 +375,7 @@ RecipientsPicker::RecipientsPicker( TQWidget *parent )
   button->setIconSet( TDEGlobal::iconLoader()->loadIconSet(
               TDEApplication::reverseLayout() ? "clear_left":"locationbar_erase", TDEIcon::Small, 0 ) );
   searchLayout->addWidget( button );
-  connect( button, TQT_SIGNAL( clicked() ), TQT_SLOT( resetSearch() ) );
+  connect( button, TQ_SIGNAL( clicked() ), TQ_SLOT( resetSearch() ) );
 
   label = new TQLabel( i18n("&Search:"), this );
   searchLayout->addWidget( label );
@@ -388,21 +388,21 @@ RecipientsPicker::RecipientsPicker( TQWidget *parent )
   mRecipientList->addColumn( i18n("->") );
   mRecipientList->addColumn( i18n("Name") );
   mRecipientList->addColumn( i18n("Email") );
-  connect( mRecipientList, TQT_SIGNAL( doubleClicked( TQListViewItem *,
-    const TQPoint &, int ) ), TQT_SLOT( slotPicked() ) );
-  connect( mRecipientList, TQT_SIGNAL( returnPressed( TQListViewItem * ) ),
-    TQT_SLOT( slotPicked() ) );
+  connect( mRecipientList, TQ_SIGNAL( doubleClicked( TQListViewItem *,
+    const TQPoint &, int ) ), TQ_SLOT( slotPicked() ) );
+  connect( mRecipientList, TQ_SIGNAL( returnPressed( TQListViewItem * ) ),
+    TQ_SLOT( slotPicked() ) );
 
   new RecipientsListToolTip( mRecipientList->viewport(), mRecipientList );
 
   mSearchLine = new SearchLine( this, mRecipientList );
   searchLayout->addWidget( mSearchLine );
   label->setBuddy( label );
-  connect( mSearchLine, TQT_SIGNAL( downPressed() ), TQT_SLOT( setFocusList() ) );
+  connect( mSearchLine, TQ_SIGNAL( downPressed() ), TQ_SLOT( setFocusList() ) );
 
   mSearchLDAPButton = new TQPushButton( i18n("Search &Directory Service"), this );
   searchLayout->addWidget( mSearchLDAPButton );
-  connect( mSearchLDAPButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotSearchLDAP() ) );
+  connect( mSearchLDAPButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotSearchLDAP() ) );
 
   TQBoxLayout *buttonLayout = new TQHBoxLayout( topLayout );
 
@@ -410,27 +410,27 @@ RecipientsPicker::RecipientsPicker( TQWidget *parent )
 
   mToButton = new TQPushButton( i18n("Add as To"), this );
   buttonLayout->addWidget( mToButton );
-  connect( mToButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotToClicked() ) );
+  connect( mToButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotToClicked() ) );
 
   mCcButton = new TQPushButton( i18n("Add as CC"), this );
   buttonLayout->addWidget( mCcButton );
-  connect( mCcButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotCcClicked() ) );
+  connect( mCcButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotCcClicked() ) );
 
   mBccButton = new TQPushButton( i18n("Add as BCC"), this );
   buttonLayout->addWidget( mBccButton );
-  connect( mBccButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotBccClicked() ) );
+  connect( mBccButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotBccClicked() ) );
   // BCC isn't commonly used, so hide it for now
   //mBccButton->hide();
 
   TQPushButton *closeButton = new TQPushButton( i18n("&Cancel"), this );
   buttonLayout->addWidget( closeButton );
-  connect( closeButton, TQT_SIGNAL( clicked() ), TQT_SLOT( close() ) );
+  connect( closeButton, TQ_SIGNAL( clicked() ), TQ_SLOT( close() ) );
 
   {
     using namespace TDEABC;
     mAddressBook = TDEABC::StdAddressBook::self( true );
-    connect( mAddressBook, TQT_SIGNAL( addressBookChanged( AddressBook * ) ),
-             this, TQT_SLOT( insertAddressBook( AddressBook * ) ) );
+    connect( mAddressBook, TQ_SIGNAL( addressBookChanged( AddressBook * ) ),
+             this, TQ_SLOT( insertAddressBook( AddressBook * ) ) );
   }
 
   initCollections();
@@ -845,8 +845,8 @@ void RecipientsPicker::slotSearchLDAP()
 {
     if ( !mLdapSearchDialog ) {
         mLdapSearchDialog = new KPIM::LDAPSearchDialog( this );
-        connect( mLdapSearchDialog, TQT_SIGNAL( addresseesAdded() ),
-                 TQT_SLOT(ldapSearchResult() ) );
+        connect( mLdapSearchDialog, TQ_SIGNAL( addresseesAdded() ),
+                 TQ_SLOT(ldapSearchResult() ) );
     }
     mLdapSearchDialog->setSearchText( mSearchLine->text() );
     mLdapSearchDialog->show();
