@@ -436,8 +436,8 @@ namespace KMail {
     if ( mUrl.isEmpty() ) // nothing to do...
       return;
     mSieveJob = SieveJob::get( mUrl, !checkOnly );
-    connect( mSieveJob, TQT_SIGNAL(gotScript(KMail::SieveJob*,bool,const TQString&,bool)),
-	     TQT_SLOT(slotGetResult(KMail::SieveJob*,bool,const TQString&,bool)) );
+    connect( mSieveJob, TQ_SIGNAL(gotScript(KMail::SieveJob*,bool,const TQString&,bool)),
+	     TQ_SLOT(slotGetResult(KMail::SieveJob*,bool,const TQString&,bool)) );
   }
 
   Vacation::~Vacation() {
@@ -645,9 +645,9 @@ namespace KMail {
       mDialog->setDomainName( domainName );
       mDialog->enableDomainAndSendForSpam( !GlobalSettings::allowOutOfOfficeUploadButNoSettings() );
 
-      connect( mDialog, TQT_SIGNAL(okClicked()), TQT_SLOT(slotDialogOk()) );
-      connect( mDialog, TQT_SIGNAL(cancelClicked()), TQT_SLOT(slotDialogCancel()) );
-      connect( mDialog, TQT_SIGNAL(defaultClicked()), TQT_SLOT(slotDialogDefaults()) );
+      connect( mDialog, TQ_SIGNAL(okClicked()), TQ_SLOT(slotDialogOk()) );
+      connect( mDialog, TQ_SIGNAL(cancelClicked()), TQ_SLOT(slotDialogCancel()) );
+      connect( mDialog, TQ_SIGNAL(defaultClicked()), TQ_SLOT(slotDialogDefaults()) );
 
       mDialog->show();
     }
@@ -690,10 +690,10 @@ namespace KMail {
 
     // and commit the dialog's settings to the server:
     mSieveJob = SieveJob::put( mUrl, script, active, mWasActive );
-    connect( mSieveJob, TQT_SIGNAL(gotScript(KMail::SieveJob*,bool,const TQString&,bool)),
+    connect( mSieveJob, TQ_SIGNAL(gotScript(KMail::SieveJob*,bool,const TQString&,bool)),
 	     active
-	     ? TQT_SLOT(slotPutActiveResult(KMail::SieveJob*,bool))
-	     : TQT_SLOT(slotPutInactiveResult(KMail::SieveJob*,bool)) );
+	     ? TQ_SLOT(slotPutActiveResult(KMail::SieveJob*,bool))
+	     : TQ_SLOT(slotPutInactiveResult(KMail::SieveJob*,bool)) );
 
     // destroy the dialog:
     mDialog->delayedDestruct();
