@@ -20,12 +20,12 @@
 #define HIGHSCORES_H
 
 #include <highscore/kexthighscore.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace KExtHighscore
 {
 
-class KDE_EXPORT ExtManager : public Manager
+class TDE_EXPORT ExtManager : public Manager
 {
  public:
     ExtManager();
