@@ -66,7 +66,7 @@
 
 extern "C"
 {
-  KDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
+  TDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
   {
      TDEGlobal::locale()->insertCatalogue("kmix");
      return new KMixApplet(configFile, KPanelApplet::Normal,
