@@ -24,7 +24,7 @@
 #include <tqstringlist.h>
 #include <tqmutex.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <klibloader.h>
 
 #include <tdeabc/addressee.h>
@@ -62,7 +62,7 @@ class TDEConfig;
  * @author Helge Deller <deller@kde.org>
  */
 
-class KDE_EXPORT KMobileDevice : public KLibFactory
+class TDE_EXPORT KMobileDevice : public KLibFactory
 {
     TQ_OBJECT
 
