@@ -109,31 +109,31 @@ KNewsTickerConfig::KNewsTickerConfig(ConfigAccess *cfg, TQWidget *parent,  const
 	m_child->lvNewsSources->viewport()->installEventFilter(this);
 	m_child->lvNewsSources->installEventFilter(this);
 
-	connect(m_newsIconMgr, TQT_SIGNAL(gotIcon(const KURL &, const TQPixmap &)), TQT_SLOT(slotGotNewsIcon(const KURL &, const TQPixmap &)));
-	connect(m_child->bChooseFont, TQT_SIGNAL(clicked()), TQT_SLOT(slotChooseFont()));
+	connect(m_newsIconMgr, TQ_SIGNAL(gotIcon(const KURL &, const TQPixmap &)), TQ_SLOT(slotGotNewsIcon(const KURL &, const TQPixmap &)));
+	connect(m_child->bChooseFont, TQ_SIGNAL(clicked()), TQ_SLOT(slotChooseFont()));
 
-	connect(m_child->lvNewsSources, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
-			TQT_SLOT(slotNewsSourceContextMenu(TDEListView *, TQListViewItem *, const TQPoint &)));
-	connect(m_child->lvNewsSources, TQT_SIGNAL(selectionChanged()),
-			TQT_SLOT(slotNewsSourceSelectionChanged()));
-	connect(m_child->lvNewsSources, TQT_SIGNAL(doubleClicked(TQListViewItem *, const TQPoint &, int)),
-			TQT_SLOT(slotModifyNewsSource(TQListViewItem *, const TQPoint &, int)));
-	connect(m_child->bAddNewsSource, TQT_SIGNAL(clicked()), TQT_SLOT(slotAddNewsSource()));
-	connect(m_child->bRemoveNewsSource, TQT_SIGNAL(clicked()), TQT_SLOT(slotRemoveNewsSource()));
-	connect(m_child->bModifyNewsSource, TQT_SIGNAL(clicked()), TQT_SLOT(slotModifyNewsSource()));
+	connect(m_child->lvNewsSources, TQ_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+			TQ_SLOT(slotNewsSourceContextMenu(TDEListView *, TQListViewItem *, const TQPoint &)));
+	connect(m_child->lvNewsSources, TQ_SIGNAL(selectionChanged()),
+			TQ_SLOT(slotNewsSourceSelectionChanged()));
+	connect(m_child->lvNewsSources, TQ_SIGNAL(doubleClicked(TQListViewItem *, const TQPoint &, int)),
+			TQ_SLOT(slotModifyNewsSource(TQListViewItem *, const TQPoint &, int)));
+	connect(m_child->bAddNewsSource, TQ_SIGNAL(clicked()), TQ_SLOT(slotAddNewsSource()));
+	connect(m_child->bRemoveNewsSource, TQ_SIGNAL(clicked()), TQ_SLOT(slotRemoveNewsSource()));
+	connect(m_child->bModifyNewsSource, TQ_SIGNAL(clicked()), TQ_SLOT(slotModifyNewsSource()));
 
-	connect(m_child->lvFilters, TQT_SIGNAL(selectionChanged(TQListViewItem *)),
-			TQT_SLOT(slotFilterSelectionChanged(TQListViewItem *)));
-	connect(m_child->comboFilterAction, TQT_SIGNAL(activated(const TQString &)),
-			TQT_SLOT(slotFilterActionChanged(const TQString &)));
-	connect(m_child->comboFilterNewsSource, TQT_SIGNAL(activated(const TQString &)),
-			TQT_SLOT(slotFilterNewsSourceChanged(const TQString &)));
-	connect(m_child->comboFilterCondition, TQT_SIGNAL(activated(const TQString &)),
-			TQT_SLOT(slotFilterConditionChanged(const TQString &)));
-	connect(m_child->leFilterExpression, TQT_SIGNAL(textChanged(const TQString &)),
-			TQT_SLOT(slotFilterExpressionChanged(const TQString &)));
-	connect(m_child->bAddFilter, TQT_SIGNAL(clicked()), TQT_SLOT(slotAddFilter()));
-	connect(m_child->bRemoveFilter, TQT_SIGNAL(clicked()), TQT_SLOT(slotRemoveFilter()));
+	connect(m_child->lvFilters, TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+			TQ_SLOT(slotFilterSelectionChanged(TQListViewItem *)));
+	connect(m_child->comboFilterAction, TQ_SIGNAL(activated(const TQString &)),
+			TQ_SLOT(slotFilterActionChanged(const TQString &)));
+	connect(m_child->comboFilterNewsSource, TQ_SIGNAL(activated(const TQString &)),
+			TQ_SLOT(slotFilterNewsSourceChanged(const TQString &)));
+	connect(m_child->comboFilterCondition, TQ_SIGNAL(activated(const TQString &)),
+			TQ_SLOT(slotFilterConditionChanged(const TQString &)));
+	connect(m_child->leFilterExpression, TQ_SIGNAL(textChanged(const TQString &)),
+			TQ_SLOT(slotFilterExpressionChanged(const TQString &)));
+	connect(m_child->bAddFilter, TQ_SIGNAL(clicked()), TQ_SLOT(slotAddFilter()));
+	connect(m_child->bRemoveFilter, TQ_SIGNAL(clicked()), TQ_SLOT(slotRemoveFilter()));
 
 	load();
 
@@ -265,8 +265,8 @@ bool KNewsTickerConfig::eventFilter(TQObject *o, TQEvent *e)
 
 			NewsSourceBase::Data nsd(name, newSourceUrl, "" , NewsSourceBase::Computers , 10, true, false);
 			NewsSourceDlgImpl nsDlg(this, 0L, true);
-			connect(&nsDlg, TQT_SIGNAL(newsSource(const NewsSourceBase::Data &)),
-			TQT_SLOT(slotAddNewsSource(const NewsSourceBase::Data &)));
+			connect(&nsDlg, TQ_SIGNAL(newsSource(const NewsSourceBase::Data &)),
+			TQ_SLOT(slotAddNewsSource(const NewsSourceBase::Data &)));
 			nsDlg.setup(nsd, false);
 			nsDlg.exec();
 		}
@@ -402,8 +402,8 @@ void KNewsTickerConfig::slotChooseFont()
 void KNewsTickerConfig::slotAddNewsSource()
 {
 	NewsSourceDlgImpl nsDlg(this, 0L, true);
-	connect(&nsDlg, TQT_SIGNAL(newsSource(const NewsSourceBase::Data &)),
-			TQT_SLOT(slotAddNewsSource(const NewsSourceBase::Data &)));
+	connect(&nsDlg, TQ_SIGNAL(newsSource(const NewsSourceBase::Data &)),
+			TQ_SLOT(slotAddNewsSource(const NewsSourceBase::Data &)));
 	nsDlg.exec();
 }
 
@@ -460,8 +460,8 @@ void KNewsTickerConfig::modifyNewsSource(TQListViewItem *item)
 void KNewsTickerConfig::openModifyDialog()
 {
 	NewsSourceDlgImpl nsDlg(this, 0L, true);
-	connect(&nsDlg, TQT_SIGNAL(newsSource(const NewsSourceBase::Data &)),
-			TQT_SLOT(slotModifyNewsSource(const NewsSourceBase::Data &)));
+	connect(&nsDlg, TQ_SIGNAL(newsSource(const NewsSourceBase::Data &)),
+			TQ_SLOT(slotModifyNewsSource(const NewsSourceBase::Data &)));
 	nsDlg.setup(m_modifyItem->data(), true);
 	nsDlg.exec();
 }
