@@ -30,17 +30,17 @@ using RSS::Status;
 
 class KntSrcFilePropsFactory : public KLibFactory
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
 		virtual TQObject *createObject(TQObject * = 0, const char * = 0,
-				const char * = TQOBJECT_OBJECT_NAME_STRING, const TQStringList & = TQStringList());
+				const char * = "TQObject", const TQStringList & = TQStringList());
 };
 
 class KntSrcFilePropsDlg : public KPropsDlgPlugin
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
