@@ -106,9 +106,9 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
   //setView(a_rtDock);
   setMainDockWidget(a_rtDock);
 
-  connect(a_rtDock, TQT_SIGNAL(iMBeingClosed()), TQT_SLOT(slotArticleDockHidden()));
-  connect(a_rtDock, TQT_SIGNAL(hasUndocked()), TQT_SLOT(slotArticleDockHidden()));
-  connect( mArticleViewer, TQT_SIGNAL(focusChangeRequest(TQWidget*)), TQT_SLOT(slotDockWidgetFocusChangeRequest(TQWidget*)) );
+  connect(a_rtDock, TQ_SIGNAL(iMBeingClosed()), TQ_SLOT(slotArticleDockHidden()));
+  connect(a_rtDock, TQ_SIGNAL(hasUndocked()), TQ_SLOT(slotArticleDockHidden()));
+  connect( mArticleViewer, TQ_SIGNAL(focusChangeRequest(TQWidget*)), TQ_SLOT(slotDockWidgetFocusChangeRequest(TQWidget*)) );
 
   //collection view
   c_olDock = createDockWidget("group_view", UserIcon("group"), 0,
@@ -123,22 +123,22 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
   c_olDock->setWidget(c_olView);
   c_olDock->manualDock(a_rtDock, KDockWidget::DockLeft, 3000);
 
-  connect(c_olDock, TQT_SIGNAL(iMBeingClosed()), TQT_SLOT(slotGroupDockHidden()));
-  connect(c_olDock, TQT_SIGNAL(hasUndocked()), TQT_SLOT(slotGroupDockHidden()));
-  connect(c_olView, TQT_SIGNAL(focusChangeRequest(TQWidget *)), TQT_SLOT(slotDockWidgetFocusChangeRequest(TQWidget *)));
-  connect(c_olView, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-          TQT_SLOT(slotCollectionSelected(TQListViewItem*)));
-  connect(c_olView, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-          TQT_SLOT(slotCollectionRMB(TDEListView*, TQListViewItem*, const TQPoint&)));
-  connect(c_olView, TQT_SIGNAL(folderDrop(TQDropEvent*, KNCollectionViewItem*)),
-          TQT_SLOT(slotCollectionViewDrop(TQDropEvent*, KNCollectionViewItem*)));
-  connect(c_olView, TQT_SIGNAL(itemRenamed(TQListViewItem*)),
-          TQT_SLOT(slotCollectionRenamed(TQListViewItem*)));
+  connect(c_olDock, TQ_SIGNAL(iMBeingClosed()), TQ_SLOT(slotGroupDockHidden()));
+  connect(c_olDock, TQ_SIGNAL(hasUndocked()), TQ_SLOT(slotGroupDockHidden()));
+  connect(c_olView, TQ_SIGNAL(focusChangeRequest(TQWidget *)), TQ_SLOT(slotDockWidgetFocusChangeRequest(TQWidget *)));
+  connect(c_olView, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+          TQ_SLOT(slotCollectionSelected(TQListViewItem*)));
+  connect(c_olView, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+          TQ_SLOT(slotCollectionRMB(TDEListView*, TQListViewItem*, const TQPoint&)));
+  connect(c_olView, TQ_SIGNAL(folderDrop(TQDropEvent*, KNCollectionViewItem*)),
+          TQ_SLOT(slotCollectionViewDrop(TQDropEvent*, KNCollectionViewItem*)));
+  connect(c_olView, TQ_SIGNAL(itemRenamed(TQListViewItem*)),
+          TQ_SLOT(slotCollectionRenamed(TQListViewItem*)));
 
-  accel->connectItem( accel->insertItem(Key_Up), mArticleViewer, TQT_SLOT(scrollUp()) );
-  accel->connectItem( accel->insertItem(Key_Down), mArticleViewer, TQT_SLOT(scrollDown()) );
-  accel->connectItem( accel->insertItem(Key_Prior), mArticleViewer, TQT_SLOT(scrollPrior()) );
-  accel->connectItem( accel->insertItem(Key_Next), mArticleViewer, TQT_SLOT(scrollNext()) );
+  accel->connectItem( accel->insertItem(Key_Up), mArticleViewer, TQ_SLOT(scrollUp()) );
+  accel->connectItem( accel->insertItem(Key_Down), mArticleViewer, TQ_SLOT(scrollDown()) );
+  accel->connectItem( accel->insertItem(Key_Prior), mArticleViewer, TQ_SLOT(scrollPrior()) );
+  accel->connectItem( accel->insertItem(Key_Next), mArticleViewer, TQ_SLOT(scrollNext()) );
 
   //header view
   h_drDock = createDockWidget("header_view", SmallIcon("text_block"), 0,
@@ -171,25 +171,25 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
   s_earchLineEdit = new TDEListViewSearchLine(q_uicksearch, h_drView, "TDEListViewSearchLine");
   q_uicksearch->setStretchableWidget(s_earchLineEdit);
   lbl->setBuddy(s_earchLineEdit);
-  connect( resetQuickSearch, TQT_SIGNAL( activated() ), s_earchLineEdit, TQT_SLOT( clear() ));
+  connect( resetQuickSearch, TQ_SIGNAL( activated() ), s_earchLineEdit, TQ_SLOT( clear() ));
 
   vlay->addWidget(q_uicksearch);
   vlay->addWidget(h_drView);
 
-  connect(h_drDock, TQT_SIGNAL(iMBeingClosed()), TQT_SLOT(slotHeaderDockHidden()));
-  connect(h_drDock, TQT_SIGNAL(hasUndocked()), TQT_SLOT(slotHeaderDockHidden()));
-  connect(h_drView, TQT_SIGNAL(focusChangeRequest(TQWidget *)),
-          TQT_SLOT(slotDockWidgetFocusChangeRequest(TQWidget *)));
-  connect(h_drView, TQT_SIGNAL(itemSelected(TQListViewItem*)),
-          TQT_SLOT(slotArticleSelected(TQListViewItem*)));
-  connect(h_drView, TQT_SIGNAL(selectionChanged()),
-          TQT_SLOT(slotArticleSelectionChanged()));
-  connect(h_drView, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-          TQT_SLOT(slotArticleRMB(TDEListView*, TQListViewItem*, const TQPoint&)));
-  connect(h_drView, TQT_SIGNAL(doubleClick(TQListViewItem *)),
-          TQT_SLOT(slotOpenArticle(TQListViewItem *)));
-  connect(h_drView, TQT_SIGNAL(sortingChanged(int)),
-          TQT_SLOT(slotHdrViewSortingChanged(int)));
+  connect(h_drDock, TQ_SIGNAL(iMBeingClosed()), TQ_SLOT(slotHeaderDockHidden()));
+  connect(h_drDock, TQ_SIGNAL(hasUndocked()), TQ_SLOT(slotHeaderDockHidden()));
+  connect(h_drView, TQ_SIGNAL(focusChangeRequest(TQWidget *)),
+          TQ_SLOT(slotDockWidgetFocusChangeRequest(TQWidget *)));
+  connect(h_drView, TQ_SIGNAL(itemSelected(TQListViewItem*)),
+          TQ_SLOT(slotArticleSelected(TQListViewItem*)));
+  connect(h_drView, TQ_SIGNAL(selectionChanged()),
+          TQ_SLOT(slotArticleSelectionChanged()));
+  connect(h_drView, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+          TQ_SLOT(slotArticleRMB(TDEListView*, TQListViewItem*, const TQPoint&)));
+  connect(h_drView, TQ_SIGNAL(doubleClick(TQListViewItem *)),
+          TQ_SLOT(slotOpenArticle(TQListViewItem *)));
+  connect(h_drView, TQ_SIGNAL(sortingChanged(int)),
+          TQ_SLOT(slotHdrViewSortingChanged(int)));
 
   //actions
   initActions();
@@ -200,7 +200,7 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
 
   //Network
   n_etAccess = knGlobals.netAccess();
-  connect(n_etAccess, TQT_SIGNAL(netActive(bool)), this, TQT_SLOT(slotNetworkActive(bool)));
+  connect(n_etAccess, TQ_SIGNAL(netActive(bool)), this, TQ_SLOT(slotNetworkActive(bool)));
 
   //Filter Manager
   f_ilManager = knGlobals.filterManager();
@@ -225,8 +225,8 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
 
   // Score Manager
   s_coreManager = knGlobals.scoringManager();
-  //connect(s_coreManager, TQT_SIGNAL(changedRules()), TQT_SLOT(slotReScore()));
-  connect(s_coreManager, TQT_SIGNAL(finishedEditing()), TQT_SLOT(slotReScore()));
+  //connect(s_coreManager, TQ_SIGNAL(changedRules()), TQ_SLOT(slotReScore()));
+  connect(s_coreManager, TQ_SIGNAL(finishedEditing()), TQ_SLOT(slotReScore()));
 
   // Memory Manager
   m_emManager = knGlobals.memoryManager();
@@ -550,114 +550,114 @@ void KNMainWidget::initActions()
 
   //navigation
   a_ctNavNextArt            = new TDEAction( KGuiItem(i18n("&Next Article"), "go-next",
-                              i18n("Go to next article")), "N;Right", TQT_TQOBJECT(h_drView),
-                              TQT_SLOT(nextArticle()), actionCollection(), "go_nextArticle" );
+                              i18n("Go to next article")), "N;Right", h_drView,
+                              TQ_SLOT(nextArticle()), actionCollection(), "go_nextArticle" );
   a_ctNavPrevArt            = new TDEAction( KGuiItem(i18n("&Previous Article"), "go-previous",
-                              i18n("Go to previous article")), "P;Left" , TQT_TQOBJECT(h_drView),
-                              TQT_SLOT(prevArticle()), actionCollection(), "go_prevArticle" );
-  a_ctNavNextUnreadArt      = new TDEAction(i18n("Next Unread &Article"), "1rightarrow", ALT+SHIFT+Key_Space , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotNavNextUnreadArt()), actionCollection(), "go_nextUnreadArticle");
-  a_ctNavNextUnreadThread   = new TDEAction(i18n("Next Unread &Thread"),"2rightarrow", SHIFT+Key_Space , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotNavNextUnreadThread()), actionCollection(), "go_nextUnreadThread");
-  a_ctNavNextGroup          = new TDEAction(i18n("Ne&xt Group"), "go-down", Key_Plus , TQT_TQOBJECT(c_olView),
-                              TQT_SLOT(nextGroup()), actionCollection(), "go_nextGroup");
-  a_ctNavPrevGroup          = new TDEAction(i18n("Pre&vious Group"), "go-up", Key_Minus , TQT_TQOBJECT(c_olView),
-                              TQT_SLOT(prevGroup()), actionCollection(), "go_prevGroup");
-  a_ctNavReadThrough        = new TDEAction(i18n("Read &Through Articles"), Key_Space , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotNavReadThrough()), actionCollection(), "go_readThrough");
+                              i18n("Go to previous article")), "P;Left" , h_drView,
+                              TQ_SLOT(prevArticle()), actionCollection(), "go_prevArticle" );
+  a_ctNavNextUnreadArt      = new TDEAction(i18n("Next Unread &Article"), "1rightarrow", ALT+SHIFT+Key_Space , this,
+                              TQ_SLOT(slotNavNextUnreadArt()), actionCollection(), "go_nextUnreadArticle");
+  a_ctNavNextUnreadThread   = new TDEAction(i18n("Next Unread &Thread"),"2rightarrow", SHIFT+Key_Space , this,
+                              TQ_SLOT(slotNavNextUnreadThread()), actionCollection(), "go_nextUnreadThread");
+  a_ctNavNextGroup          = new TDEAction(i18n("Ne&xt Group"), "go-down", Key_Plus , c_olView,
+                              TQ_SLOT(nextGroup()), actionCollection(), "go_nextGroup");
+  a_ctNavPrevGroup          = new TDEAction(i18n("Pre&vious Group"), "go-up", Key_Minus , c_olView,
+                              TQ_SLOT(prevGroup()), actionCollection(), "go_prevGroup");
+  a_ctNavReadThrough        = new TDEAction(i18n("Read &Through Articles"), Key_Space , this,
+                              TQ_SLOT(slotNavReadThrough()), actionCollection(), "go_readThrough");
   a_ctNavReadThrough->plugAccel(a_ccel);
 
   TQAccel *accel = new TQAccel( this );
-  new TDEAction( i18n("Focus on Next Folder"), CTRL+Key_Right, TQT_TQOBJECT(c_olView),
-    TQT_SLOT(incCurrentFolder()), actionCollection(), "inc_current_folder" );
+  new TDEAction( i18n("Focus on Next Folder"), CTRL+Key_Right, c_olView,
+    TQ_SLOT(incCurrentFolder()), actionCollection(), "inc_current_folder" );
   accel->connectItem(accel->insertItem(CTRL+Key_Right),
-    c_olView, TQT_SLOT(incCurrentFolder()));
-  new TDEAction( i18n("Focus on Previous Folder"), CTRL+Key_Left, TQT_TQOBJECT(c_olView),
-    TQT_SLOT(decCurrentFolder()), actionCollection(), "dec_current_folder" );
+    c_olView, TQ_SLOT(incCurrentFolder()));
+  new TDEAction( i18n("Focus on Previous Folder"), CTRL+Key_Left, c_olView,
+    TQ_SLOT(decCurrentFolder()), actionCollection(), "dec_current_folder" );
   accel->connectItem(accel->insertItem(CTRL+Key_Left),
-    c_olView, TQT_SLOT(decCurrentFolder()));
-  new TDEAction( i18n("Select Folder with Focus"), CTRL+Key_Space, TQT_TQOBJECT(c_olView),
-    TQT_SLOT(selectCurrentFolder()), actionCollection(), "select_current_folder" );
+    c_olView, TQ_SLOT(decCurrentFolder()));
+  new TDEAction( i18n("Select Folder with Focus"), CTRL+Key_Space, c_olView,
+    TQ_SLOT(selectCurrentFolder()), actionCollection(), "select_current_folder" );
   accel->connectItem(accel->insertItem(CTRL+Key_Space),
-    c_olView, TQT_SLOT(selectCurrentFolder()));
+    c_olView, TQ_SLOT(selectCurrentFolder()));
 
-  new TDEAction( i18n("Focus on Next Article"), ALT+Key_Right, TQT_TQOBJECT(h_drView),
-               TQT_SLOT(incCurrentArticle()), actionCollection(), "inc_current_article" );
+  new TDEAction( i18n("Focus on Next Article"), ALT+Key_Right, h_drView,
+               TQ_SLOT(incCurrentArticle()), actionCollection(), "inc_current_article" );
   accel->connectItem( accel->insertItem(ALT+Key_Right),
-                      TQT_TQOBJECT(h_drView), TQT_SLOT(incCurrentArticle()) );
-  new TDEAction( i18n("Focus on Previous Article"), ALT+Key_Left, TQT_TQOBJECT(h_drView),
-               TQT_SLOT(decCurrentArticle()), actionCollection(), "dec_current_article" );
+                      h_drView, TQ_SLOT(incCurrentArticle()) );
+  new TDEAction( i18n("Focus on Previous Article"), ALT+Key_Left, h_drView,
+               TQ_SLOT(decCurrentArticle()), actionCollection(), "dec_current_article" );
   accel->connectItem( accel->insertItem(ALT+Key_Left),
-                      TQT_TQOBJECT(h_drView), TQT_SLOT(decCurrentArticle()) );
-  new TDEAction( i18n("Select Article with Focus"), ALT+Key_Space, TQT_TQOBJECT(h_drView),
-               TQT_SLOT(selectCurrentArticle()), actionCollection(), "select_current_article" );
+                      h_drView, TQ_SLOT(decCurrentArticle()) );
+  new TDEAction( i18n("Select Article with Focus"), ALT+Key_Space, h_drView,
+               TQ_SLOT(selectCurrentArticle()), actionCollection(), "select_current_article" );
   accel->connectItem( accel->insertItem(ALT+Key_Space),
-                      TQT_TQOBJECT(h_drView), TQT_SLOT(selectCurrentArticle()) );
+                      h_drView, TQ_SLOT(selectCurrentArticle()) );
 
   //collection-view - accounts
-  a_ctAccProperties         = new TDEAction(i18n("Account &Properties"), "configure", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotAccProperties()), actionCollection(), "account_properties");
-  a_ctAccRename             = new TDEAction(i18n("&Rename Account"), "text", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotAccRename()), actionCollection(), "account_rename");
-  a_ctAccSubscribe          = new TDEAction(i18n("&Subscribe to Newsgroups..."), "news_subscribe", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotAccSubscribe()), actionCollection(), "account_subscribe");
-  a_ctAccExpireAll          = new TDEAction(i18n("&Expire All Groups"), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotAccExpireAll()), actionCollection(), "account_expire_all");
-  a_ctAccGetNewHdrs         = new TDEAction(i18n("&Get New Articles in All Groups"), "mail_get", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotAccGetNewHdrs()), actionCollection(), "account_dnlHeaders");
-  a_ctAccGetNewHdrsAll      = new TDEAction(i18n("&Get New Articles in All Accounts"), "mail_get_all", 0, TQT_TQOBJECT(this),
-                                          TQT_SLOT(slotAccGetNewHdrsAll()), actionCollection(), "account_dnlAllHeaders");
-  a_ctAccDelete             = new TDEAction(i18n("&Delete Account"), "edit-delete", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotAccDelete()), actionCollection(), "account_delete");
-  a_ctAccPostNewArticle     = new TDEAction(i18n("&Post to Newsgroup..."), "mail-message-new", CTRL+Key_N, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotAccPostNewArticle()), actionCollection(), "article_postNew");
+  a_ctAccProperties         = new TDEAction(i18n("Account &Properties"), "configure", 0, this,
+                              TQ_SLOT(slotAccProperties()), actionCollection(), "account_properties");
+  a_ctAccRename             = new TDEAction(i18n("&Rename Account"), "text", 0, this,
+                              TQ_SLOT(slotAccRename()), actionCollection(), "account_rename");
+  a_ctAccSubscribe          = new TDEAction(i18n("&Subscribe to Newsgroups..."), "news_subscribe", 0, this,
+                              TQ_SLOT(slotAccSubscribe()), actionCollection(), "account_subscribe");
+  a_ctAccExpireAll          = new TDEAction(i18n("&Expire All Groups"), 0, this,
+                              TQ_SLOT(slotAccExpireAll()), actionCollection(), "account_expire_all");
+  a_ctAccGetNewHdrs         = new TDEAction(i18n("&Get New Articles in All Groups"), "mail_get", 0, this,
+                              TQ_SLOT(slotAccGetNewHdrs()), actionCollection(), "account_dnlHeaders");
+  a_ctAccGetNewHdrsAll      = new TDEAction(i18n("&Get New Articles in All Accounts"), "mail_get_all", 0, this,
+                                          TQ_SLOT(slotAccGetNewHdrsAll()), actionCollection(), "account_dnlAllHeaders");
+  a_ctAccDelete             = new TDEAction(i18n("&Delete Account"), "edit-delete", 0, this,
+                              TQ_SLOT(slotAccDelete()), actionCollection(), "account_delete");
+  a_ctAccPostNewArticle     = new TDEAction(i18n("&Post to Newsgroup..."), "mail-message-new", CTRL+Key_N, this,
+                              TQ_SLOT(slotAccPostNewArticle()), actionCollection(), "article_postNew");
 
   //collection-view - groups
-  a_ctGrpProperties         = new TDEAction(i18n("Group &Properties"), "configure", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpProperties()), actionCollection(), "group_properties");
-  a_ctGrpRename             = new TDEAction(i18n("Rename &Group"), "text", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpRename()), actionCollection(), "group_rename");
-  a_ctGrpGetNewHdrs         = new TDEAction(i18n("&Get New Articles"), "mail_get" , 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpGetNewHdrs()), actionCollection(), "group_dnlHeaders");
-  a_ctGrpExpire             = new TDEAction(i18n("E&xpire Group"), "wizard", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpExpire()), actionCollection(), "group_expire");
-  a_ctGrpReorganize         = new TDEAction(i18n("Re&organize Group"), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpReorganize()), actionCollection(), "group_reorg");
-  a_ctGrpUnsubscribe        = new TDEAction(i18n("&Unsubscribe From Group"), "news_unsubscribe", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpUnsubscribe()), actionCollection(), "group_unsubscribe");
-  a_ctGrpSetAllRead         = new TDEAction(i18n("Mark All as &Read"), "goto", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpSetAllRead()), actionCollection(), "group_allRead");
-  a_ctGrpSetAllUnread       = new TDEAction(i18n("Mark All as U&nread"), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpSetAllUnread()), actionCollection(), "group_allUnread");
-  a_ctGrpSetUnread          = new TDEAction(i18n("Mark Last as Unr&ead..."), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotGrpSetUnread()), actionCollection(), "group_unread");
+  a_ctGrpProperties         = new TDEAction(i18n("Group &Properties"), "configure", 0, this,
+                              TQ_SLOT(slotGrpProperties()), actionCollection(), "group_properties");
+  a_ctGrpRename             = new TDEAction(i18n("Rename &Group"), "text", 0, this,
+                              TQ_SLOT(slotGrpRename()), actionCollection(), "group_rename");
+  a_ctGrpGetNewHdrs         = new TDEAction(i18n("&Get New Articles"), "mail_get" , 0, this,
+                              TQ_SLOT(slotGrpGetNewHdrs()), actionCollection(), "group_dnlHeaders");
+  a_ctGrpExpire             = new TDEAction(i18n("E&xpire Group"), "wizard", 0, this,
+                              TQ_SLOT(slotGrpExpire()), actionCollection(), "group_expire");
+  a_ctGrpReorganize         = new TDEAction(i18n("Re&organize Group"), 0, this,
+                              TQ_SLOT(slotGrpReorganize()), actionCollection(), "group_reorg");
+  a_ctGrpUnsubscribe        = new TDEAction(i18n("&Unsubscribe From Group"), "news_unsubscribe", 0, this,
+                              TQ_SLOT(slotGrpUnsubscribe()), actionCollection(), "group_unsubscribe");
+  a_ctGrpSetAllRead         = new TDEAction(i18n("Mark All as &Read"), "goto", 0, this,
+                              TQ_SLOT(slotGrpSetAllRead()), actionCollection(), "group_allRead");
+  a_ctGrpSetAllUnread       = new TDEAction(i18n("Mark All as U&nread"), 0, this,
+                              TQ_SLOT(slotGrpSetAllUnread()), actionCollection(), "group_allUnread");
+  a_ctGrpSetUnread          = new TDEAction(i18n("Mark Last as Unr&ead..."), 0, this,
+                              TQ_SLOT(slotGrpSetUnread()), actionCollection(), "group_unread");
 
 
 
    (void) new TDEAction( i18n("&Configure KNode..."),
-                       "configure", 0, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotSettings()), actionCollection(),
+                       "configure", 0, this,
+                       TQ_SLOT(slotSettings()), actionCollection(),
                        "knode_configure_knode" );
 
   //collection-view - folder
-  a_ctFolNew                = new TDEAction(i18n("&New Folder"), "folder-new", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolNew()), actionCollection(), "folder-new");
-  a_ctFolNewChild           = new TDEAction(i18n("New &Subfolder"), "folder-new", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolNewChild()), actionCollection(), "folder_newChild");
-  a_ctFolDelete             = new TDEAction(i18n("&Delete Folder"), "edit-delete", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolDelete()), actionCollection(), "folder_delete");
-  a_ctFolRename             = new TDEAction(i18n("&Rename Folder"), "text", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolRename()), actionCollection(), "folder_rename");
-  a_ctFolCompact            = new TDEAction(i18n("C&ompact Folder"), "wizard", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolCompact()), actionCollection(), "folder_compact");
-  a_ctFolCompactAll         = new TDEAction(i18n("Co&mpact All Folders"), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolCompactAll()), actionCollection(), "folder_compact_all");
-  a_ctFolEmpty              = new TDEAction(i18n("&Empty Folder"), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolEmpty()), actionCollection(), "folder_empty");
-  a_ctFolMboxImport         = new TDEAction(i18n("&Import MBox Folder..."), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolMBoxImport()), actionCollection(), "folder_MboxImport");
-  a_ctFolMboxExport         = new TDEAction(i18n("E&xport as MBox Folder..."), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFolMBoxExport()), actionCollection(), "folder_MboxExport");
+  a_ctFolNew                = new TDEAction(i18n("&New Folder"), "folder-new", 0, this,
+                              TQ_SLOT(slotFolNew()), actionCollection(), "folder-new");
+  a_ctFolNewChild           = new TDEAction(i18n("New &Subfolder"), "folder-new", 0, this,
+                              TQ_SLOT(slotFolNewChild()), actionCollection(), "folder_newChild");
+  a_ctFolDelete             = new TDEAction(i18n("&Delete Folder"), "edit-delete", 0, this,
+                              TQ_SLOT(slotFolDelete()), actionCollection(), "folder_delete");
+  a_ctFolRename             = new TDEAction(i18n("&Rename Folder"), "text", 0, this,
+                              TQ_SLOT(slotFolRename()), actionCollection(), "folder_rename");
+  a_ctFolCompact            = new TDEAction(i18n("C&ompact Folder"), "wizard", 0, this,
+                              TQ_SLOT(slotFolCompact()), actionCollection(), "folder_compact");
+  a_ctFolCompactAll         = new TDEAction(i18n("Co&mpact All Folders"), 0, this,
+                              TQ_SLOT(slotFolCompactAll()), actionCollection(), "folder_compact_all");
+  a_ctFolEmpty              = new TDEAction(i18n("&Empty Folder"), 0, this,
+                              TQ_SLOT(slotFolEmpty()), actionCollection(), "folder_empty");
+  a_ctFolMboxImport         = new TDEAction(i18n("&Import MBox Folder..."), 0, this,
+                              TQ_SLOT(slotFolMBoxImport()), actionCollection(), "folder_MboxImport");
+  a_ctFolMboxExport         = new TDEAction(i18n("E&xport as MBox Folder..."), 0, this,
+                              TQ_SLOT(slotFolMBoxExport()), actionCollection(), "folder_MboxExport");
 
   //header-view - list-handling
   a_ctArtSortHeaders        = new TDESelectAction(i18n("S&ort"), 0, actionCollection(), "view_Sort");
@@ -669,96 +669,96 @@ void KNMainWidget::initActions()
   items += i18n("By &Date");
   a_ctArtSortHeaders->setItems(items);
   a_ctArtSortHeaders->setShortcutConfigurable(false);
-  connect(a_ctArtSortHeaders, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotArtSortHeaders(int)));
-  a_ctArtSortHeadersKeyb   = new TDEAction(i18n("Sort"), TQString(), Key_F7 , TQT_TQOBJECT(this),
-                             TQT_SLOT(slotArtSortHeadersKeyb()), actionCollection(), "view_Sort_Keyb");
+  connect(a_ctArtSortHeaders, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotArtSortHeaders(int)));
+  a_ctArtSortHeadersKeyb   = new TDEAction(i18n("Sort"), TQString(), Key_F7 , this,
+                             TQ_SLOT(slotArtSortHeadersKeyb()), actionCollection(), "view_Sort_Keyb");
   a_ctArtSortHeadersKeyb->plugAccel(a_ccel);
   a_ctArtFilter             = new KNFilterSelectAction(i18n("&Filter"), "filter",
                               actionCollection(), "view_Filter");
   a_ctArtFilter->setShortcutConfigurable(false);
   a_ctArtFilterKeyb         = new TDEAction(i18n("Filter"), Key_F6, actionCollection(), "view_Filter_Keyb");
   a_ctArtFilterKeyb->plugAccel(a_ccel);
-  a_ctArtSearch             = new TDEAction(i18n("&Search Articles..."),"mail_find" , Key_F4 , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtSearch()), actionCollection(), "article_search");
-  a_ctArtRefreshList        = new TDEAction(i18n("&Refresh List"),"reload", TDEStdAccel::shortcut(TDEStdAccel::Reload), TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtRefreshList()), actionCollection(), "view_Refresh");
-  a_ctArtCollapseAll        = new TDEAction(i18n("&Collapse All Threads"), 0 , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtCollapseAll()), actionCollection(), "view_CollapseAll");
-  a_ctArtExpandAll          = new TDEAction(i18n("E&xpand All Threads"), 0 , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtExpandAll()), actionCollection(), "view_ExpandAll");
-  a_ctArtToggleThread       = new TDEAction(i18n("&Toggle Subthread"), Key_T, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtToggleThread()), actionCollection(), "thread_toggle");
-  a_ctArtToggleShowThreads  = new TDEToggleAction(i18n("Show T&hreads"), 0 , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtToggleShowThreads()), actionCollection(), "view_showThreads");
+  a_ctArtSearch             = new TDEAction(i18n("&Search Articles..."),"mail_find" , Key_F4 , this,
+                              TQ_SLOT(slotArtSearch()), actionCollection(), "article_search");
+  a_ctArtRefreshList        = new TDEAction(i18n("&Refresh List"),"reload", TDEStdAccel::shortcut(TDEStdAccel::Reload), this,
+                              TQ_SLOT(slotArtRefreshList()), actionCollection(), "view_Refresh");
+  a_ctArtCollapseAll        = new TDEAction(i18n("&Collapse All Threads"), 0 , this,
+                              TQ_SLOT(slotArtCollapseAll()), actionCollection(), "view_CollapseAll");
+  a_ctArtExpandAll          = new TDEAction(i18n("E&xpand All Threads"), 0 , this,
+                              TQ_SLOT(slotArtExpandAll()), actionCollection(), "view_ExpandAll");
+  a_ctArtToggleThread       = new TDEAction(i18n("&Toggle Subthread"), Key_T, this,
+                              TQ_SLOT(slotArtToggleThread()), actionCollection(), "thread_toggle");
+  a_ctArtToggleShowThreads  = new TDEToggleAction(i18n("Show T&hreads"), 0 , this,
+                              TQ_SLOT(slotArtToggleShowThreads()), actionCollection(), "view_showThreads");
   a_ctArtToggleShowThreads->setCheckedState(i18n("Hide T&hreads"));
 
   a_ctArtToggleShowThreads->setChecked(c_fgManager->readNewsGeneral()->showThreads());
 
   //header-view - remote articles
-  a_ctArtSetArtRead         = new TDEAction(i18n("Mark as &Read"), Key_D , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtSetArtRead()), actionCollection(), "article_read");
-  a_ctArtSetArtUnread       = new TDEAction(i18n("Mar&k as Unread"), Key_U , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtSetArtUnread()), actionCollection(), "article_unread");
-  a_ctArtSetThreadRead      = new TDEAction(i18n("Mark &Thread as Read"), CTRL+Key_D , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtSetThreadRead()), actionCollection(), "thread_read");
-  a_ctArtSetThreadUnread    = new TDEAction(i18n("Mark T&hread as Unread"), CTRL+Key_U , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtSetThreadUnread()), actionCollection(), "thread_unread");
-  a_ctArtOpenNewWindow      = new TDEAction(i18n("Open in Own &Window"), "window-new", Key_O , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtOpenNewWindow()), actionCollection(), "article_ownWindow");
+  a_ctArtSetArtRead         = new TDEAction(i18n("Mark as &Read"), Key_D , this,
+                              TQ_SLOT(slotArtSetArtRead()), actionCollection(), "article_read");
+  a_ctArtSetArtUnread       = new TDEAction(i18n("Mar&k as Unread"), Key_U , this,
+                              TQ_SLOT(slotArtSetArtUnread()), actionCollection(), "article_unread");
+  a_ctArtSetThreadRead      = new TDEAction(i18n("Mark &Thread as Read"), CTRL+Key_D , this,
+                              TQ_SLOT(slotArtSetThreadRead()), actionCollection(), "thread_read");
+  a_ctArtSetThreadUnread    = new TDEAction(i18n("Mark T&hread as Unread"), CTRL+Key_U , this,
+                              TQ_SLOT(slotArtSetThreadUnread()), actionCollection(), "thread_unread");
+  a_ctArtOpenNewWindow      = new TDEAction(i18n("Open in Own &Window"), "window-new", Key_O , this,
+                              TQ_SLOT(slotArtOpenNewWindow()), actionCollection(), "article_ownWindow");
 
   // scoring
-  a_ctScoresEdit            = new TDEAction(i18n("&Edit Scoring Rules..."), "edit", CTRL+Key_E, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotScoreEdit()), actionCollection(), "scoreedit");
-  a_ctReScore               = new TDEAction(i18n("Recalculate &Scores"), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotReScore()),actionCollection(),"rescore");
-  a_ctScoreLower            = new TDEAction(i18n("&Lower Score for Author..."), CTRL+Key_L, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotScoreLower()), actionCollection(), "scorelower");
-  a_ctScoreRaise            = new TDEAction(i18n("&Raise Score for Author..."), CTRL+Key_I, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotScoreRaise()),actionCollection(),"scoreraise");
-  a_ctArtToggleIgnored      = new TDEAction(i18n("&Ignore Thread"), "go-bottom", Key_I , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtToggleIgnored()), actionCollection(), "thread_ignore");
-  a_ctArtToggleWatched      = new TDEAction(i18n("&Watch Thread"), "go-top", Key_W , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtToggleWatched()), actionCollection(), "thread_watch");
+  a_ctScoresEdit            = new TDEAction(i18n("&Edit Scoring Rules..."), "edit", CTRL+Key_E, this,
+                              TQ_SLOT(slotScoreEdit()), actionCollection(), "scoreedit");
+  a_ctReScore               = new TDEAction(i18n("Recalculate &Scores"), 0, this,
+                              TQ_SLOT(slotReScore()),actionCollection(),"rescore");
+  a_ctScoreLower            = new TDEAction(i18n("&Lower Score for Author..."), CTRL+Key_L, this,
+                              TQ_SLOT(slotScoreLower()), actionCollection(), "scorelower");
+  a_ctScoreRaise            = new TDEAction(i18n("&Raise Score for Author..."), CTRL+Key_I, this,
+                              TQ_SLOT(slotScoreRaise()),actionCollection(),"scoreraise");
+  a_ctArtToggleIgnored      = new TDEAction(i18n("&Ignore Thread"), "go-bottom", Key_I , this,
+                              TQ_SLOT(slotArtToggleIgnored()), actionCollection(), "thread_ignore");
+  a_ctArtToggleWatched      = new TDEAction(i18n("&Watch Thread"), "go-top", Key_W , this,
+                              TQ_SLOT(slotArtToggleWatched()), actionCollection(), "thread_watch");
 
   //header-view local articles
-  a_ctArtSendOutbox         = new TDEAction(i18n("Sen&d Pending Messages"), "mail-send", 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtSendOutbox()), actionCollection(), "net_sendPending");
-  a_ctArtDelete             = new TDEAction(i18n("&Delete Article"), "edit-delete", Key_Delete, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtDelete()), actionCollection(), "article_delete");
-  a_ctArtSendNow            = new TDEAction(i18n("Send &Now"),"mail-send", 0 , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtSendNow()), actionCollection(), "article_sendNow");
-  a_ctArtEdit               = new TDEAction(i18n("edit article","&Edit Article..."), "edit", Key_E , TQT_TQOBJECT(this),
-                              TQT_SLOT(slotArtEdit()), actionCollection(), "article_edit");
+  a_ctArtSendOutbox         = new TDEAction(i18n("Sen&d Pending Messages"), "mail-send", 0, this,
+                              TQ_SLOT(slotArtSendOutbox()), actionCollection(), "net_sendPending");
+  a_ctArtDelete             = new TDEAction(i18n("&Delete Article"), "edit-delete", Key_Delete, this,
+                              TQ_SLOT(slotArtDelete()), actionCollection(), "article_delete");
+  a_ctArtSendNow            = new TDEAction(i18n("Send &Now"),"mail-send", 0 , this,
+                              TQ_SLOT(slotArtSendNow()), actionCollection(), "article_sendNow");
+  a_ctArtEdit               = new TDEAction(i18n("edit article","&Edit Article..."), "edit", Key_E , this,
+                              TQ_SLOT(slotArtEdit()), actionCollection(), "article_edit");
 
   //network
-  a_ctNetCancel             = new TDEAction(i18n("Stop &Network"),"process-stop",0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotNetCancel()), actionCollection(), "net_stop");
+  a_ctNetCancel             = new TDEAction(i18n("Stop &Network"),"process-stop",0, this,
+                              TQ_SLOT(slotNetCancel()), actionCollection(), "net_stop");
   a_ctNetCancel->setEnabled(false);
 
-  a_ctFetchArticleWithID    = new TDEAction(i18n("&Fetch Article with ID..."), 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotFetchArticleWithID()), actionCollection(), "fetch_article_with_id");
+  a_ctFetchArticleWithID    = new TDEAction(i18n("&Fetch Article with ID..."), 0, this,
+                              TQ_SLOT(slotFetchArticleWithID()), actionCollection(), "fetch_article_with_id");
   a_ctFetchArticleWithID->setEnabled(false);
 
-  a_ctToggleGroupView        = new TDEToggleAction(i18n("Show &Group View"), CTRL+Key_G, TQT_TQOBJECT(this),
-                               TQT_SLOT(slotToggleGroupView()), actionCollection(), "settings_show_groupView");
+  a_ctToggleGroupView        = new TDEToggleAction(i18n("Show &Group View"), CTRL+Key_G, this,
+                               TQ_SLOT(slotToggleGroupView()), actionCollection(), "settings_show_groupView");
   a_ctToggleGroupView->setCheckedState(i18n("Hide &Group View"));
-  a_ctToggleHeaderView       = new TDEToggleAction(i18n("Show &Header View"), CTRL+Key_H, TQT_TQOBJECT(this),
-                               TQT_SLOT(slotToggleHeaderView()), actionCollection(), "settings_show_headerView");
+  a_ctToggleHeaderView       = new TDEToggleAction(i18n("Show &Header View"), CTRL+Key_H, this,
+                               TQ_SLOT(slotToggleHeaderView()), actionCollection(), "settings_show_headerView");
   a_ctToggleHeaderView->setCheckedState(i18n("Hide &Header View"));
-  a_ctToggleArticleViewer    = new TDEToggleAction(i18n("Show &Article Viewer"), CTRL+Key_J, TQT_TQOBJECT(this),
-                               TQT_SLOT(slotToggleArticleViewer()), actionCollection(), "settings_show_articleViewer");
+  a_ctToggleArticleViewer    = new TDEToggleAction(i18n("Show &Article Viewer"), CTRL+Key_J, this,
+                               TQ_SLOT(slotToggleArticleViewer()), actionCollection(), "settings_show_articleViewer");
   a_ctToggleArticleViewer->setCheckedState(i18n("Hide &Article Viewer"));
-  a_ctToggleQuickSearch      = new TDEToggleAction(i18n("Show Quick Search"), TQString(), TQT_TQOBJECT(this),
-                               TQT_SLOT(slotToggleQuickSearch()), actionCollection(), "settings_show_quickSearch");
+  a_ctToggleQuickSearch      = new TDEToggleAction(i18n("Show Quick Search"), TQString(), this,
+                               TQ_SLOT(slotToggleQuickSearch()), actionCollection(), "settings_show_quickSearch");
   a_ctToggleQuickSearch->setCheckedState(i18n("Hide Quick Search"));
-  a_ctSwitchToGroupView      = new TDEAction(i18n("Switch to Group View"), Key_G , TQT_TQOBJECT(this),
-                               TQT_SLOT(slotSwitchToGroupView()), actionCollection(), "switch_to_group_view");
+  a_ctSwitchToGroupView      = new TDEAction(i18n("Switch to Group View"), Key_G , this,
+                               TQ_SLOT(slotSwitchToGroupView()), actionCollection(), "switch_to_group_view");
   a_ctSwitchToGroupView->plugAccel(a_ccel);
-  a_ctSwitchToHeaderView     = new TDEAction(i18n("Switch to Header View"), Key_H , TQT_TQOBJECT(this),
-                               TQT_SLOT(slotSwitchToHeaderView()), actionCollection(), "switch_to_header_view");
+  a_ctSwitchToHeaderView     = new TDEAction(i18n("Switch to Header View"), Key_H , this,
+                               TQ_SLOT(slotSwitchToHeaderView()), actionCollection(), "switch_to_header_view");
   a_ctSwitchToHeaderView->plugAccel(a_ccel);
-  a_ctSwitchToArticleViewer  = new TDEAction(i18n("Switch to Article Viewer"), Key_J , TQT_TQOBJECT(this),
-                               TQT_SLOT(slotSwitchToArticleViewer()), actionCollection(), "switch_to_article_viewer");
+  a_ctSwitchToArticleViewer  = new TDEAction(i18n("Switch to Article Viewer"), Key_J , this,
+                               TQ_SLOT(slotSwitchToArticleViewer()), actionCollection(), "switch_to_article_viewer");
   a_ctSwitchToArticleViewer->plugAccel(a_ccel);
 }
 
@@ -2054,7 +2054,7 @@ FetchArticleIdDlg::FetchArticleIdDlg(TQWidget *parent, const char */*name*/ )
   edit->setFocus();
   enableButtonOK( false );
   setButtonOK( i18n("&Fetch") );
-  connect( edit, TQT_SIGNAL(textChanged( const TQString & )), this, TQT_SLOT(slotTextChanged(const TQString & )));
+  connect( edit, TQ_SIGNAL(textChanged( const TQString & )), this, TQ_SLOT(slotTextChanged(const TQString & )));
   KNHelper::restoreWindowSize("fetchArticleWithID", this, TQSize(325,66));
 }
 
