@@ -60,104 +60,104 @@ PluginBabelFish::PluginBabelFish( TQObject* parent, const char* name,
     actionCollection(), "translatewebpage_nl" );
 
   m_en->insert( new TDEAction( i18n("&Chinese (Simplified)"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_zh") );
   m_en->insert( new TDEAction( i18n("Chinese (&Traditional)"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_zhTW") );
   m_en->insert( new TDEAction( i18n("&Dutch"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_nl") );
   m_en->insert( new TDEAction( i18n("&French"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_fr") );
   m_en->insert( new TDEAction( i18n("&German"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_de") );
   m_en->insert( new TDEAction( i18n("&Italian"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_it") );
   m_en->insert( new TDEAction( i18n("&Japanese"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_ja") );
   m_en->insert( new TDEAction( i18n("&Korean"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_ko") );
   m_en->insert( new TDEAction( i18n("&Norwegian"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_no") );
   m_en->insert( new TDEAction( i18n("&Portuguese"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_pt") );
   m_en->insert( new TDEAction( i18n("&Russian"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_ru") );
   m_en->insert( new TDEAction( i18n("&Spanish"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_es") );
   m_en->insert( new TDEAction( i18n("T&hai"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "en_th") );
 
   m_fr->insert( new TDEAction( i18n("&Dutch"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "fr_nl") );
   m_fr->insert( new TDEAction( i18n("&English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "fr_en") );
   m_fr->insert( new TDEAction( i18n("&German"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "fr_de") );
   m_fr->insert( new TDEAction( i18n("&Italian"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "fr_it") );
   m_fr->insert( new TDEAction( i18n("&Portuguese"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "fr_pt") );
   m_fr->insert( new TDEAction( i18n("&Spanish"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "fr_es") );
 
   m_de->insert( new TDEAction( i18n("&English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "de_en") );
   m_de->insert( new TDEAction( i18n("&French"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "de_fr") );
 
   m_es->insert( new TDEAction( i18n("&English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "es_en") );
   m_es->insert( new TDEAction( i18n("&French"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "es_fr") );
 
   m_pt->insert( new TDEAction( i18n("&English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "pt_en") );
   m_pt->insert( new TDEAction( i18n("&French"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "pt_fr") );
 
   m_it->insert( new TDEAction( i18n("&English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "it_en") );
   m_it->insert( new TDEAction( i18n("&French"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "it_fr") );
 
   m_nl->insert( new TDEAction( i18n("&English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "nl_en") );
   m_nl->insert( new TDEAction( i18n("&French"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "nl_fr") );
 
   m_menu->insert( new TDEAction( i18n("&Chinese (Simplified) to English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "zh_en") );
   m_menu->insert( new TDEAction( i18n("Chinese (&Traditional) to English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "zhTW_en") );
   m_menu->insert( m_nl );
   m_menu->insert( m_en );
@@ -165,14 +165,14 @@ PluginBabelFish::PluginBabelFish( TQObject* parent, const char* name,
   m_menu->insert( m_de );
   m_menu->insert( m_it );
   m_menu->insert( new TDEAction( i18n("&Japanese to English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "ja_en") );
   m_menu->insert( new TDEAction( i18n("&Korean to English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "ko_en") );
   m_menu->insert( m_pt );
   m_menu->insert( new TDEAction( i18n("&Russian to English"), 0,
-                             this, TQT_SLOT(translateURL()),
+                             this, TQ_SLOT(translateURL()),
                              actionCollection(), "ru_en") );
   m_menu->insert( m_es );
   m_menu->setEnabled( true );
@@ -181,8 +181,8 @@ PluginBabelFish::PluginBabelFish( TQObject* parent, const char* name,
   if ( parent && parent->inherits( "TDEHTMLPart" ) )
   {
     KParts::ReadOnlyPart* part = static_cast<KParts::ReadOnlyPart *>(parent);
-    connect( part, TQT_SIGNAL(started(TDEIO::Job*)), this,
-             TQT_SLOT(slotStarted(TDEIO::Job*)) );
+    connect( part, TQ_SIGNAL(started(TDEIO::Job*)), this,
+             TQ_SLOT(slotStarted(TDEIO::Job*)) );
   }
 }
 
