@@ -52,7 +52,7 @@ KImGalleryPlugin::KImGalleryPlugin( TQObject* parent, const char* name, const TQ
         : KParts::Plugin( parent, name ), m_commentMap(0)
 {
     new TDEAction( i18n( "&Create Image Gallery..." ), "imagegallery", CTRL+Key_I, this,
-                 TQT_SLOT( slotExecute() ), actionCollection(), "create_img_gallery" );
+                 TQ_SLOT( slotExecute() ), actionCollection(), "create_img_gallery" );
 }
 
 void KImGalleryPlugin::slotExecute()
@@ -82,7 +82,7 @@ void KImGalleryPlugin::slotExecute()
         KURL url(m_configDlg->getImageName());
         if ( !url.isEmpty() && url.isValid()) {
             m_progressDlg = new TQProgressDialog(m_part->widget(), "progressDlg", true );
-            TQObject::connect(m_progressDlg, TQT_SIGNAL( cancelled() ), this, TQT_SLOT( slotCancelled() ) );
+            TQObject::connect(m_progressDlg, TQ_SIGNAL( cancelled() ), this, TQ_SLOT( slotCancelled() ) );
 
             m_progressDlg->setLabelText( i18n("Creating thumbnails") );
             m_progressDlg->setCancelButton(new KPushButton(KStdGuiItem::cancel(),m_progressDlg));
