@@ -32,6 +32,7 @@
 #include <tdepopupmenu.h>
 
 #include "TECommon.h"
+#include "TEScreen.h"
 
 
 extern unsigned short vt100_graphics[32];
@@ -43,7 +44,7 @@ class TQTimer;
 class TEWidget : public TQFrame
 // a widget representing attributed text
 {
-   Q_OBJECT
+   TQ_OBJECT
    
 
   friend class Konsole;
@@ -52,7 +53,7 @@ public:
     TEWidget(TQWidget *parent=0, const char *name=0);
     virtual ~TEWidget();
 
-    void setBlendColor(const QRgb color) { blend_color = color; }
+    void setBlendColor(const TQRgb color) { blend_color = color; }
 
     void setDefaultBackColor(const TQColor& color);
     TQColor getDefaultBackColor();
@@ -146,6 +147,8 @@ public:
 
     void setRim(int rim) { rimX=rim; rimY=rim; }
 
+    void setScreen(int num, TEScreen *scr) { screen_num = num & 0x01; screen = scr; }
+
 public slots:
 
     void setSelectionEnd();
@@ -245,6 +248,10 @@ private:
     int bX;    // offset
     int bY;    // offset
 
+    // Required to handle mouse wheel events correctly in all cases
+		int screen_num;    // Screen number (0 or 1)
+		TEScreen *screen;  // Pointer to current screen. No ownership!!
+
     int lines;
     int columns;
     int contentHeight;
@@ -332,7 +339,7 @@ private:
     bool m_isIMEdit;
     bool m_isIMSel;
 
-    QRgb blend_color;
+    TQRgb blend_color;
  
 private slots:
     void drop_menu_activated(int item);
