@@ -36,7 +36,7 @@ class TDEProcess;
 class ZModemDialog;
 
 class TESession : public TQObject, virtual public SessionIface
-{ Q_OBJECT
+{ TQ_OBJECT
 
 public:
 
@@ -208,7 +208,7 @@ private:
   bool           xon_xoff;
   bool           fullScripting;
 
-  QString	 stateIconName;
+  TQString	 stateIconName;
 
   TQString        pgm;
   TQStrList       args;
