@@ -86,11 +86,11 @@ public:
   TQAsciiDict<int> ignoreTheseWidgets;
 
   void init(){
-    ignoreTheseWidgets.insert(TQLABEL_OBJECT_NAME_STRING, new int(1));
-    ignoreTheseWidgets.insert(TQFRAME_OBJECT_NAME_STRING, new int(2));
-    ignoreTheseWidgets.insert(TQGROUPBOX_OBJECT_NAME_STRING, new int(3));
-    ignoreTheseWidgets.insert(TQBUTTONGROUP_OBJECT_NAME_STRING, new int(4));
-    ignoreTheseWidgets.insert(TQWIDGET_OBJECT_NAME_STRING, new int(5));
+    ignoreTheseWidgets.insert("TQLabel", new int(1));
+    ignoreTheseWidgets.insert("TQFrame", new int(2));
+    ignoreTheseWidgets.insert("TQGroupBox", new int(3));
+    ignoreTheseWidgets.insert("TQButtonGroup", new int(4));
+    ignoreTheseWidgets.insert("TQWidget", new int(5));
     ignoreTheseWidgets.setAutoDelete(true);
 
     static bool defaultKDEPropertyMapInstalled = false;
@@ -141,46 +141,46 @@ bool KAutoConfig::retrieveSettings(bool trackChanges){
   
   if(trackChanges){
     // QT
-    changedMap.insert(TQString::fromLatin1(TQBUTTON_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1(TQCHECKBOX_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1(TQPUSHBUTTON_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1(TQRADIOBUTTON_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), TQT_SIGNAL(activated (int)));
+    changedMap.insert(TQString::fromLatin1("TQButton"), TQ_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::fromLatin1("TQCheckBox"), TQ_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::fromLatin1("TQPushButton"), TQ_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::fromLatin1("TQRadioButton"), TQ_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::fromLatin1("TQComboBox"), TQ_SIGNAL(activated (int)));
     //qsqlproperty map doesn't store the text, but the value!
-    //changedMap.insert(TQString::fromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert(TQString::fromLatin1(TQDATEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(const TQDate &)));
-    changedMap.insert(TQString::fromLatin1(TQDATETIMEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(const TQDateTime &)));
-    changedMap.insert(TQString::fromLatin1(TQDIAL_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged (int)));
-    changedMap.insert(TQString::fromLatin1(TQLINEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert(TQString::fromLatin1(TQSLIDER_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(int)));
-    changedMap.insert(TQString::fromLatin1(TQSPINBOX_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(int)));
-    changedMap.insert(TQString::fromLatin1(TQTIMEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(const TQTime &)));
-    changedMap.insert(TQString::fromLatin1(TQTEXTEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged()));
-    changedMap.insert(TQString::fromLatin1(TQTEXTBROWSER_OBJECT_NAME_STRING), TQT_SIGNAL(sourceChanged(const TQString &)));
-    changedMap.insert(TQString::fromLatin1(TQMULTILINEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged()));
-    changedMap.insert(TQString::fromLatin1(TQLISTBOX_OBJECT_NAME_STRING), TQT_SIGNAL(selectionChanged()));
-    changedMap.insert(TQString::fromLatin1(TQTABWIDGET_OBJECT_NAME_STRING), TQT_SIGNAL(currentChanged(TQWidget *)));
+    //changedMap.insert(TQString::fromLatin1("TQComboBox"), TQ_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert(TQString::fromLatin1("TQDateEdit"), TQ_SIGNAL(valueChanged(const TQDate &)));
+    changedMap.insert(TQString::fromLatin1("TQDateTimeEdit"), TQ_SIGNAL(valueChanged(const TQDateTime &)));
+    changedMap.insert(TQString::fromLatin1("TQDial"), TQ_SIGNAL(valueChanged (int)));
+    changedMap.insert(TQString::fromLatin1("TQLineEdit"), TQ_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert(TQString::fromLatin1("TQSlider"), TQ_SIGNAL(valueChanged(int)));
+    changedMap.insert(TQString::fromLatin1("TQSpinBox"), TQ_SIGNAL(valueChanged(int)));
+    changedMap.insert(TQString::fromLatin1("TQTimeEdit"), TQ_SIGNAL(valueChanged(const TQTime &)));
+    changedMap.insert(TQString::fromLatin1("TQTextEdit"), TQ_SIGNAL(textChanged()));
+    changedMap.insert(TQString::fromLatin1("TQTextBrowser"), TQ_SIGNAL(sourceChanged(const TQString &)));
+    changedMap.insert(TQString::fromLatin1("TQMultiLineEdit"), TQ_SIGNAL(textChanged()));
+    changedMap.insert(TQString::fromLatin1("TQListBox"), TQ_SIGNAL(selectionChanged()));
+    changedMap.insert(TQString::fromLatin1("TQTabWidget"), TQ_SIGNAL(currentChanged(TQWidget *)));
 
     // KDE
-    changedMap.insert( TQString::fromLatin1("KComboBox"), TQT_SIGNAL(activated (int)));
-    changedMap.insert( TQString::fromLatin1("TDEFontCombo"), TQT_SIGNAL(activated (int)));
-    changedMap.insert( TQString::fromLatin1("TDEFontRequester"), TQT_SIGNAL(fontSelected(const TQFont &)));
-    changedMap.insert( TQString::fromLatin1("TDEFontChooser"),  TQT_SIGNAL(fontSelected(const TQFont &)));
-    changedMap.insert( TQString::fromLatin1("KHistoryCombo"), TQT_SIGNAL(activated (int)));
+    changedMap.insert( TQString::fromLatin1("KComboBox"), TQ_SIGNAL(activated (int)));
+    changedMap.insert( TQString::fromLatin1("TDEFontCombo"), TQ_SIGNAL(activated (int)));
+    changedMap.insert( TQString::fromLatin1("TDEFontRequester"), TQ_SIGNAL(fontSelected(const TQFont &)));
+    changedMap.insert( TQString::fromLatin1("TDEFontChooser"),  TQ_SIGNAL(fontSelected(const TQFont &)));
+    changedMap.insert( TQString::fromLatin1("KHistoryCombo"), TQ_SIGNAL(activated (int)));
 
-    changedMap.insert( TQString::fromLatin1("KColorButton"), TQT_SIGNAL(changed(const TQColor &)));
-    changedMap.insert( TQString::fromLatin1("KDatePicker"), TQT_SIGNAL(dateSelected (TQDate)));
-    changedMap.insert( TQString::fromLatin1("KEditListBox"), TQT_SIGNAL(changed()));
-    changedMap.insert( TQString::fromLatin1("TDEListBox"), TQT_SIGNAL(selectionChanged()));
-    changedMap.insert( TQString::fromLatin1("KLineEdit"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KPasswordEdit"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KRestrictedLine"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KTextBrowser"), TQT_SIGNAL(sourceChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KTextEdit"), TQT_SIGNAL(textChanged()));
-    changedMap.insert( TQString::fromLatin1("KURLRequester"),  TQT_SIGNAL(textChanged (const TQString& )));
-    changedMap.insert( TQString::fromLatin1("KIntNumInput"), TQT_SIGNAL(valueChanged (int)));
-    changedMap.insert( TQString::fromLatin1("KIntSpinBox"), TQT_SIGNAL(valueChanged (int)));
-    changedMap.insert( TQString::fromLatin1("KDoubleNumInput"), TQT_SIGNAL(valueChanged (double)));
+    changedMap.insert( TQString::fromLatin1("KColorButton"), TQ_SIGNAL(changed(const TQColor &)));
+    changedMap.insert( TQString::fromLatin1("KDatePicker"), TQ_SIGNAL(dateSelected (TQDate)));
+    changedMap.insert( TQString::fromLatin1("KEditListBox"), TQ_SIGNAL(changed()));
+    changedMap.insert( TQString::fromLatin1("TDEListBox"), TQ_SIGNAL(selectionChanged()));
+    changedMap.insert( TQString::fromLatin1("KLineEdit"), TQ_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert( TQString::fromLatin1("KPasswordEdit"), TQ_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert( TQString::fromLatin1("KRestrictedLine"), TQ_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert( TQString::fromLatin1("KTextBrowser"), TQ_SIGNAL(sourceChanged(const TQString &)));
+    changedMap.insert( TQString::fromLatin1("KTextEdit"), TQ_SIGNAL(textChanged()));
+    changedMap.insert( TQString::fromLatin1("KURLRequester"),  TQ_SIGNAL(textChanged (const TQString& )));
+    changedMap.insert( TQString::fromLatin1("KIntNumInput"), TQ_SIGNAL(valueChanged (int)));
+    changedMap.insert( TQString::fromLatin1("KIntSpinBox"), TQ_SIGNAL(valueChanged (int)));
+    changedMap.insert( TQString::fromLatin1("KDoubleNumInput"), TQ_SIGNAL(valueChanged (double)));
   }
 
   // Go through all of the children of the widgets and find all known widgets
@@ -412,7 +412,7 @@ bool KAutoConfig::parseChildren(const TQWidget *widget,
             changedMap.end())
         {
           connect(childWidget, changedMap[TQString::fromLatin1(childWidget->className())],
-                  this, TQT_SIGNAL(widgetModified()));
+                  this, TQ_SIGNAL(widgetModified()));
         }
 #ifndef NDEBUG
         else if(trackChanges &&
