@@ -103,41 +103,41 @@ Kopete::CommandHandler::CommandHandler() : TQObject( tqApp )
 	mCommands.setAutoDelete( true );
 	p->pluginCommands.insert( this, mCommands );
 
-	registerCommand( this, TQString::fromLatin1("help"), TQT_SLOT( slotHelpCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("help"), TQ_SLOT( slotHelpCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /help [<command>] - Used to list available commands, or show help for a specified command." ), 0, 1 );
 
-	registerCommand( this, TQString::fromLatin1("close"), TQT_SLOT( slotCloseCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("close"), TQ_SLOT( slotCloseCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /close - Closes the current view." ) );
 
 	// FIXME: What's the difference with /close? The help doesn't explain it - Martijn
-	registerCommand( this, TQString::fromLatin1("part"), TQT_SLOT( slotPartCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("part"), TQ_SLOT( slotPartCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /part - Closes the current view." ) );
 
-	registerCommand( this, TQString::fromLatin1("clear"), TQT_SLOT( slotClearCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("clear"), TQ_SLOT( slotClearCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /clear - Clears the active view's chat buffer." ) );
 
-	//registerCommand( this, TQString::fromLatin1("me"), TQT_SLOT( slotMeCommand( const TQString &, Kopete::ChatSession * ) ),
+	//registerCommand( this, TQString::fromLatin1("me"), TQ_SLOT( slotMeCommand( const TQString &, Kopete::ChatSession * ) ),
 	//	i18n( "USAGE: /me <text> - Formats message as in '<nickname> went to the store'." ) );
 
-	registerCommand( this, TQString::fromLatin1("away"), TQT_SLOT( slotAwayCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("away"), TQ_SLOT( slotAwayCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /away [<reason>] - Marks you as away/back for the current account only." ) );
 
-	registerCommand( this, TQString::fromLatin1("awayall"), TQT_SLOT( slotAwayAllCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("awayall"), TQ_SLOT( slotAwayAllCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /awayall [<reason>] - Marks you as away/back for all accounts." ) );
 
-	registerCommand( this, TQString::fromLatin1("say"), TQT_SLOT( slotSayCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("say"), TQ_SLOT( slotSayCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /say <text> - Say text in this chat. This is the same as just typing a message, but is very "
 			"useful for scripts." ), 1 );
 
-	registerCommand( this, TQString::fromLatin1("exec"), TQT_SLOT( slotExecCommand( const TQString &, Kopete::ChatSession * ) ),
+	registerCommand( this, TQString::fromLatin1("exec"), TQ_SLOT( slotExecCommand( const TQString &, Kopete::ChatSession * ) ),
 		i18n( "USAGE: /exec [-o] <command> - Executes the specified command and displays the output in the chat buffer. "
 		"If -o is specified, the output is sent to all members of the chat."), 1 );
 
-	connect( Kopete::PluginManager::self(), TQT_SIGNAL( pluginLoaded( Kopete::Plugin*) ),
-		this, TQT_SLOT(slotPluginLoaded(Kopete::Plugin*) ) );
+	connect( Kopete::PluginManager::self(), TQ_SIGNAL( pluginLoaded( Kopete::Plugin*) ),
+		this, TQ_SLOT(slotPluginLoaded(Kopete::Plugin*) ) );
 
-	connect( Kopete::ChatSessionManager::self(), TQT_SIGNAL( viewCreated( KopeteView * ) ),
-		this, TQT_SLOT( slotViewCreated( KopeteView* ) ) );
+	connect( Kopete::ChatSessionManager::self(), TQ_SIGNAL( viewCreated( KopeteView * ) ),
+		this, TQ_SLOT( slotViewCreated( KopeteView* ) ) );
 }
 
 Kopete::CommandHandler::~CommandHandler()
@@ -294,8 +294,8 @@ void Kopete::CommandHandler::slotExecCommand( const TQString &args, Kopete::Chat
 				*proc << args;
 			}
 
-			connect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), this, TQT_SLOT(slotExecReturnedData(TDEProcess *, char *, int)));
-			connect(proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), this, TQT_SLOT(slotExecReturnedData(TDEProcess *, char *, int)));
+			connect(proc, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)), this, TQ_SLOT(slotExecReturnedData(TDEProcess *, char *, int)));
+			connect(proc, TQ_SIGNAL(receivedStderr(TDEProcess *, char *, int)), this, TQ_SLOT(slotExecReturnedData(TDEProcess *, char *, int)));
 			proc->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
 		}
 		else
@@ -469,7 +469,7 @@ void Kopete::CommandHandler::slotViewCreated( KopeteView *view )
 
 void Kopete::CommandHandler::slotPluginLoaded( Kopete::Plugin *plugin )
 {
-	connect( plugin, TQT_SIGNAL( destroyed( TQObject * ) ), this, TQT_SLOT( slotPluginDestroyed( TQObject * ) ) );
+	connect( plugin, TQ_SIGNAL( destroyed( TQObject * ) ), this, TQ_SLOT( slotPluginDestroyed( TQObject * ) ) );
 	if( !p->pluginCommands.contains( plugin ) )
 	{
 		//Create a TQDict optomized for a larger # of commands, and case insensitive
