@@ -93,13 +93,13 @@ ContactList::ContactList()
 
 	// automatically save on changes to the list
 	d->saveTimer = new TQTimer( this, "saveTimer" );
-	connect( d->saveTimer, TQT_SIGNAL( timeout() ), TQT_SLOT ( save() ) );
+	connect( d->saveTimer, TQ_SIGNAL( timeout() ), TQ_SLOT ( save() ) );
 
-	connect( this, TQT_SIGNAL( metaContactAdded( Kopete::MetaContact * ) ), TQT_SLOT( slotSaveLater() ) );
-	connect( this, TQT_SIGNAL( metaContactRemoved( Kopete::MetaContact * ) ), TQT_SLOT( slotSaveLater() ) );
-	connect( this, TQT_SIGNAL( groupAdded( Kopete::Group * ) ), TQT_SLOT( slotSaveLater() ) );
-	connect( this, TQT_SIGNAL( groupRemoved( Kopete::Group * ) ), TQT_SLOT( slotSaveLater() ) );
-	connect( this, TQT_SIGNAL( groupRenamed( Kopete::Group *, const TQString & ) ), TQT_SLOT( slotSaveLater() ) );
+	connect( this, TQ_SIGNAL( metaContactAdded( Kopete::MetaContact * ) ), TQ_SLOT( slotSaveLater() ) );
+	connect( this, TQ_SIGNAL( metaContactRemoved( Kopete::MetaContact * ) ), TQ_SLOT( slotSaveLater() ) );
+	connect( this, TQ_SIGNAL( groupAdded( Kopete::Group * ) ), TQ_SLOT( slotSaveLater() ) );
+	connect( this, TQ_SIGNAL( groupRemoved( Kopete::Group * ) ), TQ_SLOT( slotSaveLater() ) );
+	connect( this, TQ_SIGNAL( groupRenamed( Kopete::Group *, const TQString & ) ), TQ_SLOT( slotSaveLater() ) );
 }
 
 ContactList::~ContactList()
@@ -224,9 +224,9 @@ void ContactList::addMetaContact( MetaContact *mc )
 	d->contacts.append( mc );
 
 	emit metaContactAdded( mc );
-	connect( mc, TQT_SIGNAL( persistentDataChanged( ) ), TQT_SLOT( slotSaveLater() ) );
-	connect( mc, TQT_SIGNAL( addedToGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQT_SIGNAL( metaContactAddedToGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
-	connect( mc, TQT_SIGNAL( removedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQT_SIGNAL( metaContactRemovedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
+	connect( mc, TQ_SIGNAL( persistentDataChanged( ) ), TQ_SLOT( slotSaveLater() ) );
+	connect( mc, TQ_SIGNAL( addedToGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQ_SIGNAL( metaContactAddedToGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
+	connect( mc, TQ_SIGNAL( removedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQ_SIGNAL( metaContactRemovedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
 }
 
 
@@ -263,7 +263,7 @@ void ContactList::addGroup( Group * g )
 	{
 		d->groups.append( g );
 		emit groupAdded( g );
-		connect( g , TQT_SIGNAL ( displayNameChanged(Kopete::Group* , const TQString & )) , this , TQT_SIGNAL ( groupRenamed(Kopete::Group* , const TQString & )) ) ;
+		connect( g , TQ_SIGNAL ( displayNameChanged(Kopete::Group* , const TQString & )) , this , TQ_SIGNAL ( groupRenamed(Kopete::Group* , const TQString & )) ) ;
 	}
 }
 
@@ -304,11 +304,11 @@ void ContactList::loadGlobalIdentity()
 	if(Kopete::Config::enableGlobalIdentity())
  	{
 		// Disconnect to make sure it will not cause duplicate calls.
-		disconnect(myself(), TQT_SIGNAL(displayNameChanged(const TQString&, const TQString&)), this, TQT_SLOT(slotDisplayNameChanged()));
-		disconnect(myself(), TQT_SIGNAL(photoChanged()), this, TQT_SLOT(slotPhotoChanged()));
+		disconnect(myself(), TQ_SIGNAL(displayNameChanged(const TQString&, const TQString&)), this, TQ_SLOT(slotDisplayNameChanged()));
+		disconnect(myself(), TQ_SIGNAL(photoChanged()), this, TQ_SLOT(slotPhotoChanged()));
 
-		connect(myself(), TQT_SIGNAL(displayNameChanged(const TQString&, const TQString&)), this, TQT_SLOT(slotDisplayNameChanged()));
-		connect(myself(), TQT_SIGNAL(photoChanged()), this, TQT_SLOT(slotPhotoChanged()));
+		connect(myself(), TQ_SIGNAL(displayNameChanged(const TQString&, const TQString&)), this, TQ_SLOT(slotDisplayNameChanged()));
+		connect(myself(), TQ_SIGNAL(photoChanged()), this, TQ_SLOT(slotPhotoChanged()));
 
 		// Ensure that the myself metaContactId is always the KABC whoAmI
 		TDEABC::Addressee a = TDEABC::StdAddressBook::self()->whoAmI();
@@ -324,8 +324,8 @@ void ContactList::loadGlobalIdentity()
  	}
 	else
 	{
-		disconnect(myself(), TQT_SIGNAL(displayNameChanged(const TQString&, const TQString&)), this, TQT_SLOT(slotDisplayNameChanged()));
-		disconnect(myself(), TQT_SIGNAL(photoChanged()), this, TQT_SLOT(slotPhotoChanged()));
+		disconnect(myself(), TQ_SIGNAL(displayNameChanged(const TQString&, const TQString&)), this, TQ_SLOT(slotDisplayNameChanged()));
+		disconnect(myself(), TQ_SIGNAL(photoChanged()), this, TQ_SLOT(slotPhotoChanged()));
 	}
 }
 
@@ -370,7 +370,7 @@ void ContactList::load()
 {
 	loadXML();
 	// Apply the global identity when all the protocols plugins are loaded.
-	connect(PluginManager::self(), TQT_SIGNAL(allPluginsLoaded()), this, TQT_SLOT(loadGlobalIdentity()));
+	connect(PluginManager::self(), TQ_SIGNAL(allPluginsLoaded()), this, TQ_SLOT(loadGlobalIdentity()));
 }
 
 void ContactList::loadXML()
