@@ -31,7 +31,7 @@ class NowListeningConfig;
 
 class NowListeningPreferences : public TDECModule
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	NowListeningPreferences(TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList());
