@@ -47,7 +47,7 @@ class OnlineInquiry;
  * @author Chris Howells <howells@kde.org>, Heiko Sch&auml;fer <heiko@rangun.de>
  */
 class SMPPPDCSPlugin : public Kopete::Plugin, public IConnector, virtual public SMPPPDCSIFace {
-    Q_OBJECT
+    TQ_OBJECT
   
     SMPPPDCSPlugin(const SMPPPDCSPlugin&);
     SMPPPDCSPlugin& operator=(const SMPPPDCSPlugin&);
