@@ -183,15 +183,15 @@ void
 GaduAccount::initActions()
 {
 	p->searchAction		= new TDEAction( i18n( "&Search for Friends" ), "", 0,
-							this, TQT_SLOT( slotSearch() ), this, "actionSearch" );
+							this, TQ_SLOT( slotSearch() ), this, "actionSearch" );
 	p->listputAction		= new TDEAction( i18n( "Export Contacts to Server" ), "", 0,
-							this, TQT_SLOT( slotExportContactsList() ), this, "actionListput" );
+							this, TQ_SLOT( slotExportContactsList() ), this, "actionListput" );
 	p->listToFileAction	= new TDEAction( i18n( "Export Contacts to File..." ), "", 0,
-							this, TQT_SLOT( slotExportContactsListToFile() ), this, "actionListputFile" );
+							this, TQ_SLOT( slotExportContactsListToFile() ), this, "actionListputFile" );
 	p->listFromFileAction	= new TDEAction( i18n( "Import Contacts From File..." ), "", 0,
-							this, TQT_SLOT( slotImportContactsFromFile() ), this, "actionListgetFile" );
+							this, TQ_SLOT( slotImportContactsFromFile() ), this, "actionListgetFile" );
 	p->friendsModeAction	= new TDEToggleAction( i18n( "Only for Friends" ), "", 0,
-							this, TQT_SLOT( slotFriendsMode() ), this,
+							this, TQ_SLOT( slotFriendsMode() ), this,
 							"actionFriendsMode" );
 
 	static_cast<TDEToggleAction*>(p->friendsModeAction)->setChecked( p->forFriends );
@@ -200,34 +200,34 @@ GaduAccount::initActions()
 void
 GaduAccount::initConnections()
 {
-	TQObject::connect( p->session_, TQT_SIGNAL( error( const TQString&, const TQString& ) ),
-				TQT_SLOT( error( const TQString&, const TQString& ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( messageReceived( KGaduMessage* ) ),
-				TQT_SLOT( messageReceived( KGaduMessage* ) )  );
-	TQObject::connect( p->session_, TQT_SIGNAL( contactStatusChanged( KGaduNotify* ) ),
-				TQT_SLOT( contactStatusChanged( KGaduNotify* ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( connectionFailed( gg_failure_t )),
-				TQT_SLOT( connectionFailed( gg_failure_t ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( connectionSucceed( ) ),
-				TQT_SLOT( connectionSucceed( ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( disconnect( Kopete::Account::DisconnectReason ) ),
-				TQT_SLOT( slotSessionDisconnect( Kopete::Account::DisconnectReason ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( ackReceived( unsigned int ) ),
-				TQT_SLOT( ackReceived( unsigned int ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( pubDirSearchResult( const SearchResult&, unsigned int  ) ),
-				TQT_SLOT( slotSearchResult( const SearchResult&, unsigned int ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( userListExported() ),
-				TQT_SLOT( userListExportDone() ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( userListRecieved( const TQString& ) ),
-				TQT_SLOT( userlist( const TQString& ) ) );
-	TQObject::connect( p->session_, TQT_SIGNAL( incomingCtcp( unsigned int ) ),
-				TQT_SLOT( slotIncomingDcc( unsigned int ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( error( const TQString&, const TQString& ) ),
+				TQ_SLOT( error( const TQString&, const TQString& ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( messageReceived( KGaduMessage* ) ),
+				TQ_SLOT( messageReceived( KGaduMessage* ) )  );
+	TQObject::connect( p->session_, TQ_SIGNAL( contactStatusChanged( KGaduNotify* ) ),
+				TQ_SLOT( contactStatusChanged( KGaduNotify* ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( connectionFailed( gg_failure_t )),
+				TQ_SLOT( connectionFailed( gg_failure_t ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( connectionSucceed( ) ),
+				TQ_SLOT( connectionSucceed( ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( disconnect( Kopete::Account::DisconnectReason ) ),
+				TQ_SLOT( slotSessionDisconnect( Kopete::Account::DisconnectReason ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( ackReceived( unsigned int ) ),
+				TQ_SLOT( ackReceived( unsigned int ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( pubDirSearchResult( const SearchResult&, unsigned int  ) ),
+				TQ_SLOT( slotSearchResult( const SearchResult&, unsigned int ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( userListExported() ),
+				TQ_SLOT( userListExportDone() ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( userListRecieved( const TQString& ) ),
+				TQ_SLOT( userlist( const TQString& ) ) );
+	TQObject::connect( p->session_, TQ_SIGNAL( incomingCtcp( unsigned int ) ),
+				TQ_SLOT( slotIncomingDcc( unsigned int ) ) );
 
-	TQObject::connect( p->pingTimer_, TQT_SIGNAL( timeout() ),
-				TQT_SLOT( pingServer() ) );
+	TQObject::connect( p->pingTimer_, TQ_SIGNAL( timeout() ),
+				TQ_SLOT( pingServer() ) );
 
-	TQObject::connect( p->exportTimer_, TQT_SIGNAL( timeout() ),
-				TQT_SLOT( slotUserlistSynch() ) );
+	TQObject::connect( p->exportTimer_, TQ_SIGNAL( timeout() ),
+				TQ_SLOT( slotUserlistSynch() ) );
 }
 
 void
@@ -287,22 +287,22 @@ GaduAccount::actionMenu()
 	}
 	p->actionMenu_->insert( new TDEAction( i18n( "Go O&nline" ),
 				GaduProtocol::protocol()->convertStatus( GG_STATUS_AVAIL ).iconFor( this ),
-				0, this, TQT_SLOT( slotGoOnline() ), this, "actionGaduConnect" ) );
+				0, this, TQ_SLOT( slotGoOnline() ), this, "actionGaduConnect" ) );
 
 	p->actionMenu_->insert( new TDEAction( i18n( "Set &Busy" ),
 				GaduProtocol::protocol()->convertStatus( GG_STATUS_BUSY ).iconFor( this ),
-				0, this, TQT_SLOT( slotGoBusy() ), this, "actionGaduConnect" ) );
+				0, this, TQ_SLOT( slotGoBusy() ), this, "actionGaduConnect" ) );
 
 	p->actionMenu_->insert( new TDEAction( i18n( "Set &Invisible" ),
 				GaduProtocol::protocol()->convertStatus( GG_STATUS_INVISIBLE ).iconFor( this ),
-				0, this, TQT_SLOT( slotGoInvisible() ), this, "actionGaduConnect" ) );
+				0, this, TQ_SLOT( slotGoInvisible() ), this, "actionGaduConnect" ) );
 
 	p->actionMenu_->insert( new TDEAction( i18n( "Go &Offline" ),
 				GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ).iconFor( this ),
-				0, this, TQT_SLOT( slotGoOffline() ), this, "actionGaduConnect" ) );
+				0, this, TQ_SLOT( slotGoOffline() ), this, "actionGaduConnect" ) );
 
 	p->actionMenu_->insert( new TDEAction( i18n( "Set &Description..." ), "application-vnd.tde.info",
-			0, this, TQT_SLOT( slotDescription() ), this, "actionGaduDescription" ) );
+			0, this, TQ_SLOT( slotDescription() ), this, "actionGaduDescription" ) );
 
 	p->actionMenu_->insert( p->friendsModeAction );
 
