@@ -82,36 +82,36 @@ IRCAccount::IRCAccount(IRCProtocol *protocol, const TQString &accountId, const T
 	TQString version=i18n("Kopete IRC Plugin %1 [http://trinitydesktop.org]").arg(kapp->aboutData()->version());
 	m_engine->setVersionString( version  );
 
-	TQObject::connect(m_engine, TQT_SIGNAL(successfullyChangedNick(const TQString &, const TQString &)),
-			this, TQT_SLOT(successfullyChangedNick(const TQString &, const TQString &)));
+	TQObject::connect(m_engine, TQ_SIGNAL(successfullyChangedNick(const TQString &, const TQString &)),
+			this, TQ_SLOT(successfullyChangedNick(const TQString &, const TQString &)));
 
-	TQObject::connect(m_engine, TQT_SIGNAL(incomingFailedServerPassword()),
-			this, TQT_SLOT(slotFailedServerPassword()));
+	TQObject::connect(m_engine, TQ_SIGNAL(incomingFailedServerPassword()),
+			this, TQ_SLOT(slotFailedServerPassword()));
 
-	TQObject::connect(m_engine, TQT_SIGNAL(incomingNickInUse(const TQString &)),
-			this, TQT_SLOT(slotNickInUseAlert( const TQString &)) );
+	TQObject::connect(m_engine, TQ_SIGNAL(incomingNickInUse(const TQString &)),
+			this, TQ_SLOT(slotNickInUseAlert( const TQString &)) );
 
-	TQObject::connect(m_engine, TQT_SIGNAL(incomingFailedNickOnLogin(const TQString &)),
-			this, TQT_SLOT(slotNickInUse( const TQString &)) );
+	TQObject::connect(m_engine, TQ_SIGNAL(incomingFailedNickOnLogin(const TQString &)),
+			this, TQ_SLOT(slotNickInUse( const TQString &)) );
 
-	TQObject::connect(m_engine, TQT_SIGNAL(incomingJoinedChannel(const TQString &, const TQString &)),
-		this, TQT_SLOT(slotJoinedUnknownChannel(const TQString &, const TQString &)));
+	TQObject::connect(m_engine, TQ_SIGNAL(incomingJoinedChannel(const TQString &, const TQString &)),
+		this, TQ_SLOT(slotJoinedUnknownChannel(const TQString &, const TQString &)));
 
-	TQObject::connect(m_engine, TQT_SIGNAL(incomingCtcpReply(const TQString &, const TQString &, const TQString &)),
-			this, TQT_SLOT( slotNewCtcpReply(const TQString&, const TQString &, const TQString &)));
+	TQObject::connect(m_engine, TQ_SIGNAL(incomingCtcpReply(const TQString &, const TQString &, const TQString &)),
+			this, TQ_SLOT( slotNewCtcpReply(const TQString&, const TQString &, const TQString &)));
 
-	TQObject::connect(m_engine, TQT_SIGNAL(statusChanged(KIRC::Engine::Status)),
-			 this, TQT_SLOT(engineStatusChanged(KIRC::Engine::Status)));
+	TQObject::connect(m_engine, TQ_SIGNAL(statusChanged(KIRC::Engine::Status)),
+			 this, TQ_SLOT(engineStatusChanged(KIRC::Engine::Status)));
 
-	TQObject::connect(m_engine, TQT_SIGNAL(incomingServerLoadTooHigh()),
-		this, TQT_SLOT(slotServerBusy()));
+	TQObject::connect(m_engine, TQ_SIGNAL(incomingServerLoadTooHigh()),
+		this, TQ_SLOT(slotServerBusy()));
 
-	TQObject::connect(m_engine, TQT_SIGNAL(incomingNoSuchNickname(const TQString &)),
-			 this, TQT_SLOT(slotNoSuchNickname(const TQString &)));
+	TQObject::connect(m_engine, TQ_SIGNAL(incomingNoSuchNickname(const TQString &)),
+			 this, TQ_SLOT(slotNoSuchNickname(const TQString &)));
 
 	mAwayAction = new Kopete::AwayAction ( i18n("Set Away"),
 		m_protocol->m_UserStatusAway.iconFor( this ), 0, this,
-		TQT_SLOT(slotGoAway( const TQString & )), this );
+		TQ_SLOT(slotGoAway( const TQString & )), this );
 
 	currentHost = 0;
 
@@ -208,9 +208,9 @@ IRCAccount::IRCAccount(IRCProtocol *protocol, const TQString &accountId, const T
 	m_myServer = m_contactManager->myServer();
 
 	m_joinChannelAction = new TDEAction ( i18n("Join Channel..."), TQString(), 0, this,
-				TQT_SLOT(slotJoinChannel()), this);
+				TQ_SLOT(slotJoinChannel()), this);
 	m_searchChannelAction = new TDEAction ( i18n("Search Channels..."), TQString(), 0, this,
-				TQT_SLOT(slotSearchChannels()), this);
+				TQ_SLOT(slotSearchChannels()), this);
 }
 
 IRCAccount::~IRCAccount()
@@ -426,12 +426,12 @@ TDEActionMenu *IRCAccount::actionMenu()
 	mActionMenu->popupMenu()->insertSeparator();
 	mActionMenu->insert(m_joinChannelAction);
 	mActionMenu->insert(m_searchChannelAction);
-	mActionMenu->insert( new TDEAction ( i18n("Show Server Window"), TQString(), 0, this, TQT_SLOT(slotShowServerWindow()), mActionMenu ) );
+	mActionMenu->insert( new TDEAction ( i18n("Show Server Window"), TQString(), 0, this, TQ_SLOT(slotShowServerWindow()), mActionMenu ) );
 
 	if( m_engine->isConnected() && m_engine->useSSL() )
 	{
 		mActionMenu->insert( new TDEAction ( i18n("Show Security Information"), "", 0, m_engine,
-			TQT_SLOT(showInfoDialog()), mActionMenu ) );
+			TQ_SLOT(showInfoDialog()), mActionMenu ) );
 	}
 
 	return mActionMenu;
@@ -534,7 +534,7 @@ void IRCAccount::engineStatusChanged(KIRC::Engine::Status newStatus)
 			// after the 001 is sent, you need to wait until all the init junk is done.
 			// Unfortunatly, there is no way for us to know when it is done (it could be
 			// spewing out any number of replies), so just try delaying it
-			TQTimer::singleShot( 250, this, TQT_SLOT( slotPerformOnConnectCommands() ) );
+			TQTimer::singleShot( 250, this, TQ_SLOT( slotPerformOnConnectCommands() ) );
 		}
 		break;
 	case KIRC::Engine::Closing:
@@ -598,7 +598,7 @@ void IRCAccount::slotSearchChannels()
 	{
 		m_channelList = new ChannelListDialog( m_engine,
 			i18n("Channel List for %1").arg( m_engine->currentHost() ), this,
-			TQT_SLOT( slotJoinNamedChannel( const TQString & ) ) );
+			TQ_SLOT( slotJoinNamedChannel( const TQString & ) ) );
 	}
 	else
 		m_channelList->clear();
@@ -889,7 +889,7 @@ IRCContact *IRCAccount::getContact(KIRC::EntityPtr entity, Kopete::MetaContact *
 		m_contacts.append(contact);
 	}
 
-	TQObject::connect(contact, TQT_SIGNAL(destroyed(IRCContact *)), TQT_SLOT(destroyed(IRCContact *)));
+	TQObject::connect(contact, TQ_SIGNAL(destroyed(IRCContact *)), TQ_SLOT(destroyed(IRCContact *)));
 	return contact;
 }
 
@@ -899,6 +899,3 @@ void IRCAccount::destroyed(IRCContact *contact)
 }
 
 #include "ircaccount.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
-
