@@ -27,7 +27,7 @@ class IRCContact;
  */
 class IRCGUIClient : public TQObject , public KXMLGUIClient
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		IRCGUIClient( Kopete::ChatSession *parent = 0 );
