@@ -25,7 +25,7 @@
 class ChannelListDialog
 	: public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
