@@ -109,7 +109,7 @@ JabberAccount::JabberAccount (JabberProtocol * parent, const TQString & accountI
 	JabberContact *myContact = contactPool()->addContact ( XMPP::RosterItem ( accountId ), Kopete::ContactList::self()->myself(), false );
 	setMyself( myContact );
 
-	TQObject::connect(Kopete::ContactList::self(), TQT_SIGNAL( globalIdentityChanged(const TQString&, const TQVariant& ) ), TQT_SLOT( slotGlobalIdentityChanged(const TQString&, const TQVariant& ) ) );
+	TQObject::connect(Kopete::ContactList::self(), TQ_SIGNAL( globalIdentityChanged(const TQString&, const TQVariant& ) ), TQ_SLOT( slotGlobalIdentityChanged(const TQString&, const TQVariant& ) ) );
 
 	m_initialPresence = XMPP::Status ( "", "", 5, true );
 
@@ -178,7 +178,7 @@ TDEActionMenu *JabberAccount::actionMenu ()
 
 	TDEAction *action;
 	
-	action = new TDEAction (i18n ("Join Groupchat..."), "jabber_group", 0, this, TQT_SLOT (slotJoinNewChat ()), this, "actionJoinChat");
+	action = new TDEAction (i18n ("Join Groupchat..."), "jabber_group", 0, this, TQ_SLOT (slotJoinNewChat ()), this, "actionJoinChat");
 	m_actionMenu->insert(action);
 	action->setEnabled( isConnected() );
 	
@@ -190,17 +190,17 @@ TDEActionMenu *JabberAccount::actionMenu ()
 	m_actionMenu->popupMenu()->insertSeparator();
 	
 	action =  new TDEAction ( i18n ("Services..."), "jabber_serv_on", 0,
-							this, TQT_SLOT ( slotGetServices () ), this, "actionJabberServices");
+							this, TQ_SLOT ( slotGetServices () ), this, "actionJabberServices");
 	action->setEnabled( isConnected() );
 	m_actionMenu->insert ( action );
 
 	action = new TDEAction ( i18n ("Send Raw Packet to Server..."), "mail-message-new", 0,
-										 this, TQT_SLOT ( slotSendRaw () ), this, "actionJabberSendRaw") ;
+										 this, TQ_SLOT ( slotSendRaw () ), this, "actionJabberSendRaw") ;
 	action->setEnabled( isConnected() );
 	m_actionMenu->insert ( action );
 
 	action = new TDEAction ( i18n ("Edit User Info..."), "identity", 0,
-										 this, TQT_SLOT ( slotEditVCard () ), this, "actionEditVCard") ;
+										 this, TQ_SLOT ( slotEditVCard () ), this, "actionEditVCard") ;
 	action->setEnabled( isConnected() );
 	m_actionMenu->insert ( action );
 
@@ -295,40 +295,40 @@ void JabberAccount::connectWithPassword ( const TQString &password )
 	{
 		m_jabberClient = new JabberClient;
 	
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( csDisconnected () ), this, TQT_SLOT ( slotCSDisconnected () ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( csError ( int ) ), this, TQT_SLOT ( slotCSError ( int ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( tlsWarning ( int ) ), this, TQT_SLOT ( slotHandleTLSWarning ( int ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( connected () ), this, TQT_SLOT ( slotConnected () ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( error ( JabberClient::ErrorCode ) ), this, TQT_SLOT ( slotClientError ( JabberClient::ErrorCode ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( csDisconnected () ), this, TQ_SLOT ( slotCSDisconnected () ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( csError ( int ) ), this, TQ_SLOT ( slotCSError ( int ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( tlsWarning ( int ) ), this, TQ_SLOT ( slotHandleTLSWarning ( int ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( connected () ), this, TQ_SLOT ( slotConnected () ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( error ( JabberClient::ErrorCode ) ), this, TQ_SLOT ( slotClientError ( JabberClient::ErrorCode ) ) );
 
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( subscription ( const XMPP::Jid &, const TQString & ) ),
-				   this, TQT_SLOT ( slotSubscription ( const XMPP::Jid &, const TQString & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( rosterRequestFinished ( bool ) ),
-				   this, TQT_SLOT ( slotRosterRequestFinished ( bool ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( newContact ( const XMPP::RosterItem & ) ),
-				   this, TQT_SLOT ( slotContactUpdated ( const XMPP::RosterItem & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( contactUpdated ( const XMPP::RosterItem & ) ),
-				   this, TQT_SLOT ( slotContactUpdated ( const XMPP::RosterItem & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( contactDeleted ( const XMPP::RosterItem & ) ),
-				   this, TQT_SLOT ( slotContactDeleted ( const XMPP::RosterItem & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( resourceAvailable ( const XMPP::Jid &, const XMPP::Resource & ) ),
-				   this, TQT_SLOT ( slotResourceAvailable ( const XMPP::Jid &, const XMPP::Resource & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( resourceUnavailable ( const XMPP::Jid &, const XMPP::Resource & ) ),
-				   this, TQT_SLOT ( slotResourceUnavailable ( const XMPP::Jid &, const XMPP::Resource & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( messageReceived ( const XMPP::Message & ) ),
-				   this, TQT_SLOT ( slotReceivedMessage ( const XMPP::Message & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( incomingFileTransfer () ),
-				   this, TQT_SLOT ( slotIncomingFileTransfer () ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatJoined ( const XMPP::Jid & ) ),
-				   this, TQT_SLOT ( slotGroupChatJoined ( const XMPP::Jid & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatLeft ( const XMPP::Jid & ) ),
-				   this, TQT_SLOT ( slotGroupChatLeft ( const XMPP::Jid & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatPresence ( const XMPP::Jid &, const XMPP::Status & ) ),
-				   this, TQT_SLOT ( slotGroupChatPresence ( const XMPP::Jid &, const XMPP::Status & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatError ( const XMPP::Jid &, int, const TQString & ) ),
-				   this, TQT_SLOT ( slotGroupChatError ( const XMPP::Jid &, int, const TQString & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( debugMessage ( const TQString & ) ),
-				   this, TQT_SLOT ( slotClientDebugMessage ( const TQString & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( subscription ( const XMPP::Jid &, const TQString & ) ),
+				   this, TQ_SLOT ( slotSubscription ( const XMPP::Jid &, const TQString & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( rosterRequestFinished ( bool ) ),
+				   this, TQ_SLOT ( slotRosterRequestFinished ( bool ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( newContact ( const XMPP::RosterItem & ) ),
+				   this, TQ_SLOT ( slotContactUpdated ( const XMPP::RosterItem & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( contactUpdated ( const XMPP::RosterItem & ) ),
+				   this, TQ_SLOT ( slotContactUpdated ( const XMPP::RosterItem & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( contactDeleted ( const XMPP::RosterItem & ) ),
+				   this, TQ_SLOT ( slotContactDeleted ( const XMPP::RosterItem & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( resourceAvailable ( const XMPP::Jid &, const XMPP::Resource & ) ),
+				   this, TQ_SLOT ( slotResourceAvailable ( const XMPP::Jid &, const XMPP::Resource & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( resourceUnavailable ( const XMPP::Jid &, const XMPP::Resource & ) ),
+				   this, TQ_SLOT ( slotResourceUnavailable ( const XMPP::Jid &, const XMPP::Resource & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( messageReceived ( const XMPP::Message & ) ),
+				   this, TQ_SLOT ( slotReceivedMessage ( const XMPP::Message & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( incomingFileTransfer () ),
+				   this, TQ_SLOT ( slotIncomingFileTransfer () ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( groupChatJoined ( const XMPP::Jid & ) ),
+				   this, TQ_SLOT ( slotGroupChatJoined ( const XMPP::Jid & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( groupChatLeft ( const XMPP::Jid & ) ),
+				   this, TQ_SLOT ( slotGroupChatLeft ( const XMPP::Jid & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( groupChatPresence ( const XMPP::Jid &, const XMPP::Status & ) ),
+				   this, TQ_SLOT ( slotGroupChatPresence ( const XMPP::Jid &, const XMPP::Status & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( groupChatError ( const XMPP::Jid &, int, const TQString & ) ),
+				   this, TQ_SLOT ( slotGroupChatError ( const XMPP::Jid &, int, const TQString & ) ) );
+		TQObject::connect ( m_jabberClient, TQ_SIGNAL ( debugMessage ( const TQString & ) ),
+				   this, TQ_SLOT ( slotClientDebugMessage ( const TQString & ) ) );
 	}
 	else
 	{
@@ -560,7 +560,7 @@ void JabberAccount::slotConnected ()
 	{
 		kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Creating Jingle Voice caller..." << endl;
 		m_voiceCaller = new JingleVoiceCaller( this );
-		TQObject::connect(m_voiceCaller,TQT_SIGNAL(incoming(const Jid&)),this,TQT_SLOT(slotIncomingVoiceCall( const Jid& )));
+		TQObject::connect(m_voiceCaller,TQ_SIGNAL(incoming(const Jid&)),this,TQ_SLOT(slotIncomingVoiceCall( const Jid& )));
 		m_voiceCaller->initialize();
 	}
 	
@@ -571,7 +571,7 @@ void JabberAccount::slotConnected ()
 	{
 		kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Creating Jingle Session Manager..." << endl;
 		m_jingleSessionManager = new JingleSessionManager( this );
-		TQObject::connect(m_jingleSessionManager, TQT_SIGNAL(incomingSession(const TQString &, JingleSession *)), this, TQT_SLOT(slotIncomingJingleSession(const TQString &, JingleSession *)));
+		TQObject::connect(m_jingleSessionManager, TQ_SIGNAL(incomingSession(const TQString &, JingleSession *)), this, TQ_SLOT(slotIncomingJingleSession(const TQString &, JingleSession *)));
 	}
 #endif
 
@@ -1108,8 +1108,8 @@ void JabberAccount::slotSubscription (const XMPP::Jid & jid, const TQString & ty
 		
 		Kopete::UI::ContactAddedNotifyDialog *dialog=
 				new Kopete::UI::ContactAddedNotifyDialog( jid.full() ,TQString(),this, hideFlags );
-		TQObject::connect(dialog,TQT_SIGNAL(applyClicked(const TQString&)),
-						this,TQT_SLOT(slotContactAddedNotifyDialogClosed(const TQString& )));
+		TQObject::connect(dialog,TQ_SIGNAL(applyClicked(const TQString&)),
+						this,TQ_SLOT(slotContactAddedNotifyDialogClosed(const TQString& )));
 		dialog->show();
 	}
 	else if (type == "unsubscribed")
@@ -1709,13 +1709,13 @@ bool JabberAccount::removeAccount( )
 			}
 			
 			XMPP::JT_Register *task = new XMPP::JT_Register ( client()->rootTask () );
-			TQObject::connect ( task, TQT_SIGNAL ( finished () ), this, TQT_SLOT ( slotUnregisterFinished ) );
+			TQObject::connect ( task, TQ_SIGNAL ( finished () ), this, TQ_SLOT ( slotUnregisterFinished ) );
 			task->unreg ();
 			task->go ( true );
 			m_removing=true;
 			// from my experiment, not all server reply us with a response.   it simply dosconnect
 			// so after one seconde, we will force to remove the account
-			TQTimer::singleShot(1111, this, TQT_SLOT(slotUnregisterFinished())); 
+			TQTimer::singleShot(1111, this, TQ_SLOT(slotUnregisterFinished())); 
 			
 			return false; //the account will be removed when the task will be finished
 		}
