@@ -70,14 +70,14 @@ dlgJabberVCard::dlgJabberVCard (JabberAccount *account, JabberBaseContact *conta
 	m_mainWidget = new dlgVCard(this);
 	setMainWidget(m_mainWidget);
 
-	connect (this, TQT_SIGNAL (user1Clicked()), this, TQT_SLOT (slotSaveVCard ()));
-	connect (this, TQT_SIGNAL( user2Clicked()), this, TQT_SLOT (slotGetVCard ()));
+	connect (this, TQ_SIGNAL (user1Clicked()), this, TQ_SLOT (slotSaveVCard ()));
+	connect (this, TQ_SIGNAL( user2Clicked()), this, TQ_SLOT (slotGetVCard ()));
 
-	connect (m_mainWidget->btnSelectPhoto, TQT_SIGNAL (clicked()), this, TQT_SLOT (slotSelectPhoto()));
-	connect (m_mainWidget->btnClearPhoto, TQT_SIGNAL (clicked()), this, TQT_SLOT (slotClearPhoto()));
-	connect (m_mainWidget->urlHomeEmail, TQT_SIGNAL (leftClickedURL(const TQString &)), this, TQT_SLOT (slotOpenURL (const TQString &)));
-	connect (m_mainWidget->urlWorkEmail, TQT_SIGNAL (leftClickedURL(const TQString &)), this, TQT_SLOT (slotOpenURL (const TQString &)));
-	connect (m_mainWidget->urlHomepage, TQT_SIGNAL (leftClickedURL(const TQString &)), this, TQT_SLOT (slotOpenURL (const TQString &)));
+	connect (m_mainWidget->btnSelectPhoto, TQ_SIGNAL (clicked()), this, TQ_SLOT (slotSelectPhoto()));
+	connect (m_mainWidget->btnClearPhoto, TQ_SIGNAL (clicked()), this, TQ_SLOT (slotClearPhoto()));
+	connect (m_mainWidget->urlHomeEmail, TQ_SIGNAL (leftClickedURL(const TQString &)), this, TQ_SLOT (slotOpenURL (const TQString &)));
+	connect (m_mainWidget->urlWorkEmail, TQ_SIGNAL (leftClickedURL(const TQString &)), this, TQ_SLOT (slotOpenURL (const TQString &)));
+	connect (m_mainWidget->urlHomepage, TQ_SIGNAL (leftClickedURL(const TQString &)), this, TQ_SLOT (slotOpenURL (const TQString &)));
 
 	assignContactProperties();
 
@@ -407,7 +407,7 @@ void dlgJabberVCard::slotSaveVCard()
 
 	XMPP::JT_VCard *task = new XMPP::JT_VCard( m_account->client()->rootTask() );
 	// signal to ourselves when the vCard data arrived
-	TQObject::connect(task, TQT_SIGNAL(finished()), this, TQT_SLOT(slotVCardSaved()));
+	TQObject::connect(task, TQ_SIGNAL(finished()), this, TQ_SLOT(slotVCardSaved()));
 	task->set(vCard);
 	task->go(true);
 }
@@ -438,7 +438,7 @@ void dlgJabberVCard::slotGetVCard()
 
 	XMPP::JT_VCard *task = new XMPP::JT_VCard ( m_account->client()->rootTask() );
 	// signal to ourselves when the vCard data arrived
-	TQObject::connect( task, TQT_SIGNAL ( finished () ), this, TQT_SLOT ( slotGotVCard () ) );
+	TQObject::connect( task, TQ_SIGNAL ( finished () ), this, TQ_SLOT ( slotGotVCard () ) );
 	task->get ( m_contact->rosterItem().jid().full() );
 	task->go ( true );	
 }
