@@ -207,10 +207,10 @@ void MeanwhileSession::connect(TQString password)
     socket = sock;
     /* we want to receive signals when there is data to read */
     sock->enableRead(true);
-    TQObject::connect(sock, TQT_SIGNAL(readyRead()), this,
-                     TQT_SLOT(slotSocketDataAvailable()));
-    TQObject::connect(sock, TQT_SIGNAL(closed(int)), this,
-                     TQT_SLOT(slotSocketClosed(int)));
+    TQObject::connect(sock, TQ_SIGNAL(readyRead()), this,
+                     TQ_SLOT(slotSocketDataAvailable()));
+    TQObject::connect(sock, TQ_SIGNAL(closed(int)), this,
+                     TQ_SLOT(slotSocketClosed(int)));
 
     /* set login details */
     mwSession_setProperty(session, mwSession_AUTH_USER_ID,
@@ -694,8 +694,8 @@ void MeanwhileSession::handleSessionIOClose()
     if (socket == 0L)
         return;
 
-    TQObject::disconnect(socket, TQT_SIGNAL(closed(int)),
-                     this, TQT_SLOT(slotSocketClosed(int)));
+    TQObject::disconnect(socket, TQ_SIGNAL(closed(int)),
+                     this, TQ_SLOT(slotSocketClosed(int)));
     socket->flush();
     socket->closeNow();
 
