@@ -66,43 +66,43 @@ MSNChatSession::MSNChatSession( Kopete::Protocol *protocol, const Kopete::Contac
 
 	setInstance(protocol->instance());
 
-	connect( this, TQT_SIGNAL( messageSent( Kopete::Message&,
+	connect( this, TQ_SIGNAL( messageSent( Kopete::Message&,
 		Kopete::ChatSession* ) ),
-		this, TQT_SLOT( slotMessageSent( Kopete::Message&,
+		this, TQ_SLOT( slotMessageSent( Kopete::Message&,
 		Kopete::ChatSession* ) ) );
 
-	connect( this, TQT_SIGNAL( invitation(MSNInvitation*& ,  const TQString & , long unsigned int , MSNChatSession*  , MSNContact*  ) ) ,
-		protocol,  TQT_SIGNAL( invitation(MSNInvitation*& ,  const TQString & , long unsigned int , MSNChatSession*  , MSNContact*  ) ) );
+	connect( this, TQ_SIGNAL( invitation(MSNInvitation*& ,  const TQString & , long unsigned int , MSNChatSession*  , MSNContact*  ) ) ,
+		protocol,  TQ_SIGNAL( invitation(MSNInvitation*& ,  const TQString & , long unsigned int , MSNChatSession*  , MSNContact*  ) ) );
 
 
 	m_actionInvite = new TDEActionMenu( i18n( "&Invite" ), "kontact_contacts", actionCollection(), "msnInvite" );
-	connect ( m_actionInvite->popupMenu() , TQT_SIGNAL( aboutToShow() ) , this , TQT_SLOT(slotActionInviteAboutToShow() ) ) ;
+	connect ( m_actionInvite->popupMenu() , TQ_SIGNAL( aboutToShow() ) , this , TQ_SLOT(slotActionInviteAboutToShow() ) ) ;
 
 	#if !defined NDEBUG
-	new TDEAction( i18n( "Send Raw C&ommand..." ), 0, this, TQT_SLOT( slotDebugRawCommand() ), actionCollection(), "msnDebugRawCommand" ) ;
+	new TDEAction( i18n( "Send Raw C&ommand..." ), 0, this, TQ_SLOT( slotDebugRawCommand() ), actionCollection(), "msnDebugRawCommand" ) ;
 	#endif
 
 
-	m_actionNudge=new TDEAction( i18n( "Send Nudge" ), "bell", 0, this, TQT_SLOT(slotSendNudge() ), actionCollection(), "msnSendNudge" ) ;
+	m_actionNudge=new TDEAction( i18n( "Send Nudge" ), "bell", 0, this, TQ_SLOT(slotSendNudge() ), actionCollection(), "msnSendNudge" ) ;
 #if MSN_WEBCAM
 	// Invite to receive webcam action
-	m_actionWebcamReceive=new TDEAction( i18n( "View Contact's Webcam" ), "webcamreceive",  0, this, TQT_SLOT(slotWebcamReceive()), actionCollection(), "msnWebcamReceive" ) ;
+	m_actionWebcamReceive=new TDEAction( i18n( "View Contact's Webcam" ), "webcamreceive",  0, this, TQ_SLOT(slotWebcamReceive()), actionCollection(), "msnWebcamReceive" ) ;
 	
 	//Send webcam action
-	m_actionWebcamSend=new TDEAction( i18n( "Send Webcam" ), "webcamsend",  0, this, TQT_SLOT(slotWebcamSend()), actionCollection(), "msnWebcamSend" ) ;
+	m_actionWebcamSend=new TDEAction( i18n( "Send Webcam" ), "webcamsend",  0, this, TQ_SLOT(slotWebcamSend()), actionCollection(), "msnWebcamSend" ) ;
 #endif
 	
-	new TDEAction( i18n( "Send File" ),"attach", 0, this, TQT_SLOT( slotSendFile() ), actionCollection(), "msnSendFile" );
+	new TDEAction( i18n( "Send File" ),"attach", 0, this, TQ_SLOT( slotSendFile() ), actionCollection(), "msnSendFile" );
 
 	MSNContact *c = static_cast<MSNContact*>( others.first() );
-	(new TDEAction( i18n( "Request Display Picture" ), "image", 0,  this, TQT_SLOT( slotRequestPicture() ), actionCollection(), "msnRequestDisplayPicture" ))->setEnabled(!c->object().isEmpty());
+	(new TDEAction( i18n( "Request Display Picture" ), "image", 0,  this, TQ_SLOT( slotRequestPicture() ), actionCollection(), "msnRequestDisplayPicture" ))->setEnabled(!c->object().isEmpty());
 
 	if ( !c->object().isEmpty() )
 	{
 		
-		connect( c, TQT_SIGNAL( displayPictureChanged() ), this, TQT_SLOT( slotDisplayPictureChanged() ) );
+		connect( c, TQ_SIGNAL( displayPictureChanged() ), this, TQ_SLOT( slotDisplayPictureChanged() ) );
 		m_image = new TQLabel( 0L, "kde toolbar widget" );
-		new KWidgetAction( m_image, i18n( "MSN Display Picture" ), 0, this, TQT_SLOT( slotRequestPicture() ), actionCollection(), "msnDisplayPicture" );
+		new KWidgetAction( m_image, i18n( "MSN Display Picture" ), 0, this, TQ_SLOT( slotRequestPicture() ), actionCollection(), "msnDisplayPicture" );
 		if(c->hasProperty(Kopete::Global::Properties::self()->photo().key())  )
 		{
 			//if the view doesn't exist yet, we will be unable to get the size of the toolbar
@@ -110,7 +110,7 @@ MSNChatSession::MSNChatSession( Kopete::Protocol *protocol, const Kopete::Contac
 			//How to know when a our view is created?  We can't.
 			// but chances are the next created view will be for this KMM
 			// And if it is not?  never mind. the icon will just be sized 22x22
-			connect( Kopete::ChatSessionManager::self() , TQT_SIGNAL(viewActivated(KopeteView* )) , this, TQT_SLOT(slotDisplayPictureChanged()) );
+			connect( Kopete::ChatSessionManager::self() , TQ_SIGNAL(viewActivated(KopeteView* )) , this, TQ_SLOT(slotDisplayPictureChanged()) );
 			//it's viewActivated and not viewCreated because the view get his mainwindow only when it is shown.
 		}
 	}
@@ -163,35 +163,35 @@ void MSNChatSession::createChat( const TQString &handle,
 	m_chatService->setMsgHandle( handle );
 	m_chatService->connectToSwitchBoard( ID, address, auth );
 
-	connect( m_chatService, TQT_SIGNAL( userJoined(const TQString&,const TQString&,bool)),
-		this, TQT_SLOT( slotUserJoined(const TQString&,const TQString&,bool) ) );
-	connect( m_chatService, TQT_SIGNAL( userLeft(const TQString&,const TQString&)),
-		this, TQT_SLOT( slotUserLeft(const TQString&,const TQString&) ) );
-	connect( m_chatService, TQT_SIGNAL( msgReceived( Kopete::Message & ) ),
-		this, TQT_SLOT( slotMessageReceived( Kopete::Message & ) ) );
-	connect( m_chatService, TQT_SIGNAL( switchBoardClosed() ),
-		this, TQT_SLOT( slotSwitchBoardClosed() ) );
-	connect( m_chatService, TQT_SIGNAL( receivedTypingMsg( const TQString &, bool ) ),
-		this, TQT_SLOT( receivedTypingMsg( const TQString &, bool ) ) );
+	connect( m_chatService, TQ_SIGNAL( userJoined(const TQString&,const TQString&,bool)),
+		this, TQ_SLOT( slotUserJoined(const TQString&,const TQString&,bool) ) );
+	connect( m_chatService, TQ_SIGNAL( userLeft(const TQString&,const TQString&)),
+		this, TQ_SLOT( slotUserLeft(const TQString&,const TQString&) ) );
+	connect( m_chatService, TQ_SIGNAL( msgReceived( Kopete::Message & ) ),
+		this, TQ_SLOT( slotMessageReceived( Kopete::Message & ) ) );
+	connect( m_chatService, TQ_SIGNAL( switchBoardClosed() ),
+		this, TQ_SLOT( slotSwitchBoardClosed() ) );
+	connect( m_chatService, TQ_SIGNAL( receivedTypingMsg( const TQString &, bool ) ),
+		this, TQ_SLOT( receivedTypingMsg( const TQString &, bool ) ) );
 	TDEConfig *config = TDEGlobal::config();
 	config->setGroup( "MSN" );
 	if(config->readBoolEntry( "SendTypingNotification" , true) )
 	{
-		connect( this, TQT_SIGNAL( myselfTyping( bool ) ),
-			m_chatService, TQT_SLOT( sendTypingMsg( bool ) ) );
+		connect( this, TQ_SIGNAL( myselfTyping( bool ) ),
+			m_chatService, TQ_SLOT( sendTypingMsg( bool ) ) );
 	}
-	connect( m_chatService, TQT_SIGNAL( msgAcknowledgement(unsigned int, bool) ),
-		this, TQT_SLOT( slotAcknowledgement(unsigned int, bool) ) );
-	connect( m_chatService, TQT_SIGNAL( invitation( const TQString&, const TQString& ) ),
-		this, TQT_SLOT( slotInvitation( const TQString&, const TQString& ) ) );
-	connect( m_chatService, TQT_SIGNAL( nudgeReceived(const TQString&) ),
-		this, TQT_SLOT( slotNudgeReceived(const TQString&) ) );
-	connect( m_chatService, TQT_SIGNAL( errorMessage(int, const TQString& ) ), static_cast<MSNAccount *>(myself()->account()), TQT_SLOT( slotErrorMessageReceived(int, const TQString& ) ) );
+	connect( m_chatService, TQ_SIGNAL( msgAcknowledgement(unsigned int, bool) ),
+		this, TQ_SLOT( slotAcknowledgement(unsigned int, bool) ) );
+	connect( m_chatService, TQ_SIGNAL( invitation( const TQString&, const TQString& ) ),
+		this, TQ_SLOT( slotInvitation( const TQString&, const TQString& ) ) );
+	connect( m_chatService, TQ_SIGNAL( nudgeReceived(const TQString&) ),
+		this, TQ_SLOT( slotNudgeReceived(const TQString&) ) );
+	connect( m_chatService, TQ_SIGNAL( errorMessage(int, const TQString& ) ), static_cast<MSNAccount *>(myself()->account()), TQ_SLOT( slotErrorMessageReceived(int, const TQString& ) ) );
 	
 	if(!m_timeoutTimer)
 	{
 		m_timeoutTimer=new TQTimer(this);
-		connect( m_timeoutTimer , TQT_SIGNAL(timeout()), this , TQT_SLOT(slotConnectionTimeout() ) );
+		connect( m_timeoutTimer , TQ_SIGNAL(timeout()), this , TQ_SLOT(slotConnectionTimeout() ) );
 	}
 	m_timeoutTimer->start(20000,true);
 }
@@ -319,12 +319,12 @@ void MSNChatSession::slotActionInviteAboutToShow()
 		if( !members().contains( it.current() ) && it.current()->isOnline() && it.current() != myself() )
 		{
 			TDEAction *a=new KopeteContactAction( it.current(), this,
-				TQT_SLOT( slotInviteContact( Kopete::Contact * ) ), m_actionInvite );
+				TQ_SLOT( slotInviteContact( Kopete::Contact * ) ), m_actionInvite );
 			m_actionInvite->insert( a );
 			m_inviteactions.append( a ) ;
 		}
 	}
-	TDEAction *b=new TDEAction( i18n ("Other..."), 0, this, TQT_SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
+	TDEAction *b=new TDEAction( i18n ("Other..."), 0, this, TQ_SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
 	m_actionInvite->insert( b );
 	m_inviteactions.append( b ) ;
 }
@@ -443,7 +443,7 @@ void MSNChatSession::slotInvitation(const TQString &handle, const TQString &msg)
 		if( msg.contains(MSNFileTransferSocket::applicationID()) )
 		{
 			MSNFileTransferSocket *MFTS=new MSNFileTransferSocket(myself()->account()->accountId(),c,true,this);
-			connect(MFTS, TQT_SIGNAL( done(MSNInvitation*) ) , this , TQT_SLOT( invitationDone(MSNInvitation*) ));
+			connect(MFTS, TQ_SIGNAL( done(MSNInvitation*) ) , this , TQ_SLOT( invitationDone(MSNInvitation*) ));
 			m_invitations.insert( cookie  , MFTS);
 			MFTS->parseInvitation(msg);
 			setCanBeDeleted(false);
@@ -499,7 +499,7 @@ void MSNChatSession::sendFile(const TQString &fileLocation, const TQString &/*fi
 
 void MSNChatSession::initInvitation(MSNInvitation* invitation)
 {
-	connect(invitation->object(), TQT_SIGNAL( done(MSNInvitation*) ) , this , TQT_SLOT( invitationDone(MSNInvitation*) ));
+	connect(invitation->object(), TQ_SIGNAL( done(MSNInvitation*) ) , this , TQ_SLOT( invitationDone(MSNInvitation*) ));
 	m_invitations.insert( invitation->cookie() , invitation);
 
 	if(m_chatService)
@@ -552,7 +552,7 @@ void MSNChatSession::slotDisplayPictureChanged()
 			if(w)
 			{
 				//We connected that in the constructor.  we don't need to keep this slot active.
-				disconnect( Kopete::ChatSessionManager::self() , TQT_SIGNAL(viewActivated(KopeteView* )) , this, TQT_SLOT(slotDisplayPictureChanged()) );
+				disconnect( Kopete::ChatSessionManager::self() , TQ_SIGNAL(viewActivated(KopeteView* )) , this, TQ_SLOT(slotDisplayPictureChanged()) );
 			
 				TQPtrListIterator<TDEToolBar>  it=w->toolBarIterator() ;
 				TDEAction *imgAction=actionCollection()->action("msnDisplayPicture");
@@ -563,8 +563,8 @@ void MSNChatSession::slotDisplayPictureChanged()
 					{
 						sz=tb->iconSize();
 						//ipdate if the size of the toolbar change.
-						disconnect(tb, TQT_SIGNAL(modechange()), this, TQT_SLOT(slotDisplayPictureChanged()));
-						connect(tb, TQT_SIGNAL(modechange()), this, TQT_SLOT(slotDisplayPictureChanged()));
+						disconnect(tb, TQ_SIGNAL(modechange()), this, TQ_SLOT(slotDisplayPictureChanged()));
+						connect(tb, TQ_SIGNAL(modechange()), this, TQ_SLOT(slotDisplayPictureChanged()));
 						break;
 					}
 					++it;
@@ -693,7 +693,7 @@ void MSNChatSession::startChatSession()
 	if(!m_timeoutTimer)
 	{
 		m_timeoutTimer=new TQTimer(this);
-		connect( m_timeoutTimer , TQT_SIGNAL(timeout()), this , TQT_SLOT(slotConnectionTimeout() ) );
+		connect( m_timeoutTimer , TQ_SIGNAL(timeout()), this , TQ_SLOT(slotConnectionTimeout() ) );
 	}
 	m_timeoutTimer->start(20000, true);
 }
