@@ -66,28 +66,28 @@ ICQContact::ICQContact( ICQAccount *account, const TQString &name, Kopete::MetaC
 	else
 		setOnlineStatus( ICQ::Presence( ICQ::Presence::Offline, ICQ::Presence::Visible ).toOnlineStatus() );
 
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( loggedIn() ), this, TQT_SLOT( loggedIn() ) );
-	//TQObject::connect( mAccount->engine(), TQT_SIGNAL( userIsOnline( const TQString& ) ), this, TQT_SLOT( userOnline( const TQString&, UserDetails ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( userIsOffline( const TQString& ) ), this, TQT_SLOT( userOffline( const TQString& ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( authRequestReceived( const TQString&, const TQString& ) ),
-	                  this, TQT_SLOT( slotGotAuthRequest( const TQString&, const TQString& ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( authReplyReceived( const TQString&, const TQString&, bool ) ),
-	                  this, TQT_SLOT( slotGotAuthReply(const TQString&, const TQString&, bool ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( receivedIcqShortInfo( const TQString& ) ),
-	                  this, TQT_SLOT( receivedShortInfo( const TQString& ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( receivedIcqLongInfo( const TQString& ) ),
-	                  this, TQT_SLOT( receivedLongInfo( const TQString& ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( receivedUserInfo( const TQString&, const UserDetails& ) ),
-	                  this, TQT_SLOT( userInfoUpdated( const TQString&, const UserDetails& ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( receivedAwayMessage( const TQString&, const TQString& ) ),
-	                  this, TQT_SLOT( receivedStatusMessage( const TQString&, const TQString& ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( receivedAwayMessage( const Oscar::Message& ) ),
-	                  this, TQT_SLOT( receivedStatusMessage( const Oscar::Message& ) ) );
-	TQObject::connect( this, TQT_SIGNAL( featuresUpdated() ), this, TQT_SLOT( updateFeatures() ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( iconServerConnected() ),
-	                  this, TQT_SLOT( requestBuddyIcon() ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( haveIconForContact( const TQString&, TQByteArray ) ),
-	                  this, TQT_SLOT( haveIcon( const TQString&, TQByteArray ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( loggedIn() ), this, TQ_SLOT( loggedIn() ) );
+	//TQObject::connect( mAccount->engine(), TQ_SIGNAL( userIsOnline( const TQString& ) ), this, TQ_SLOT( userOnline( const TQString&, UserDetails ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( userIsOffline( const TQString& ) ), this, TQ_SLOT( userOffline( const TQString& ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( authRequestReceived( const TQString&, const TQString& ) ),
+	                  this, TQ_SLOT( slotGotAuthRequest( const TQString&, const TQString& ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( authReplyReceived( const TQString&, const TQString&, bool ) ),
+	                  this, TQ_SLOT( slotGotAuthReply(const TQString&, const TQString&, bool ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( receivedIcqShortInfo( const TQString& ) ),
+	                  this, TQ_SLOT( receivedShortInfo( const TQString& ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( receivedIcqLongInfo( const TQString& ) ),
+	                  this, TQ_SLOT( receivedLongInfo( const TQString& ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( receivedUserInfo( const TQString&, const UserDetails& ) ),
+	                  this, TQ_SLOT( userInfoUpdated( const TQString&, const UserDetails& ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( receivedAwayMessage( const TQString&, const TQString& ) ),
+	                  this, TQ_SLOT( receivedStatusMessage( const TQString&, const TQString& ) ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( receivedAwayMessage( const Oscar::Message& ) ),
+	                  this, TQ_SLOT( receivedStatusMessage( const Oscar::Message& ) ) );
+	TQObject::connect( this, TQ_SIGNAL( featuresUpdated() ), this, TQ_SLOT( updateFeatures() ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( iconServerConnected() ),
+	                  this, TQ_SLOT( requestBuddyIcon() ) );
+	TQObject::connect( mAccount->engine(), TQ_SIGNAL( haveIconForContact( const TQString&, TQByteArray ) ),
+	                  this, TQ_SLOT( haveIcon( const TQString&, TQByteArray ) ) );
 
 }
 
@@ -193,7 +193,7 @@ void ICQContact::userInfoUpdated( const TQString& contact, const UserDetails& de
 				int time = ( TDEApplication::random() % 10 ) * 1000;
 				kdDebug(OSCAR_ICQ_DEBUG) << k_funcinfo << "updating buddy icon in "
 				                         << time/1000 << " seconds" << endl;
-				TQTimer::singleShot( time, this, TQT_SLOT( requestBuddyIcon() ) );
+				TQTimer::singleShot( time, this, TQ_SLOT( requestBuddyIcon() ) );
 			}
 		}
 	}
@@ -237,7 +237,7 @@ void ICQContact::loggedIn()
 		m_requestingNickname = true;
 		int time = ( TDEApplication::random() % 20 ) * 1000;
 		kdDebug(OSCAR_ICQ_DEBUG) << k_funcinfo << "updating nickname in " << time/1000 << " seconds" << endl;
-		TQTimer::singleShot( time, this, TQT_SLOT( requestShortInfo() ) );
+		TQTimer::singleShot( time, this, TQ_SLOT( requestShortInfo() ) );
 	}
 
 }
@@ -298,7 +298,7 @@ void ICQContact::slotGotAuthRequest( const TQString& contact, const TQString& re
 
 	ICQAuthReplyDialog *replyDialog = new ICQAuthReplyDialog();
 
-	connect( replyDialog, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( slotAuthReplyDialogOkClicked() ) );
+	connect( replyDialog, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( slotAuthReplyDialogOkClicked() ) );
 	replyDialog->setUser( property( Kopete::Global::Properties::self()->nickName() ).value().toString() );
 	replyDialog->setRequestReason( reason );
 	replyDialog->setModal( TRUE );
@@ -503,7 +503,7 @@ bool ICQContact::cachedBuddyIcon( TQByteArray hash )
 		return false;
 	
 	KMD5 buddyIconHash;
-	buddyIconHash.update( *TQT_TQIODEVICE(&iconFile) );
+	buddyIconHash.update( iconFile );
 	iconFile.close();
 	
 	if ( memcmp( buddyIconHash.rawDigest(), hash.data(), 16 ) == 0 )
@@ -685,12 +685,12 @@ TQPtrList<TDEAction> *ICQContact::customContextMenuActions()
 	if(actionReadAwayMessage==0)
 	{
 		actionReadAwayMessage = new TDEAction(awTxt, awIcn, 0,
-			this, TQT_SLOT(slotReadAwayMessage()), this, "actionReadAwayMessage");
+			this, TQ_SLOT(slotReadAwayMessage()), this, "actionReadAwayMessage");
 		*/
 		actionRequestAuth = new TDEAction(i18n("&Request Authorization"), "mail-reply-sender", 0,
-			this, TQT_SLOT(slotRequestAuth()), this, "actionRequestAuth");
+			this, TQ_SLOT(slotRequestAuth()), this, "actionRequestAuth");
 		actionSendAuth = new TDEAction(i18n("&Grant Authorization"), "mail-forward", 0,
-			this, TQT_SLOT(slotSendAuth()), this, "actionSendAuth");
+			this, TQ_SLOT(slotSendAuth()), this, "actionSendAuth");
 		/*
 	}
 	else
@@ -701,11 +701,11 @@ TQPtrList<TDEAction> *ICQContact::customContextMenuActions()
 
 */
 	m_actionIgnore = new TDEToggleAction(i18n("&Ignore"), "", 0,
-	                                   this, TQT_SLOT(slotIgnore()), this, "actionIgnore");
+	                                   this, TQ_SLOT(slotIgnore()), this, "actionIgnore");
 	m_actionVisibleTo = new TDEToggleAction(i18n("Always &Visible To"), "", 0,
-	                                      this, TQT_SLOT(slotVisibleTo()), this, "actionVisibleTo");
+	                                      this, TQ_SLOT(slotVisibleTo()), this, "actionVisibleTo");
 	m_actionInvisibleTo = new TDEToggleAction(i18n("Always &Invisible To"), "", 0,
-	                                        this, TQT_SLOT(slotInvisibleTo()), this, "actionInvisibleTo");
+	                                        this, TQ_SLOT(slotInvisibleTo()), this, "actionInvisibleTo");
 
 	bool on = account()->isConnected();
 	if ( m_ssiItem.waitingAuth() )
@@ -717,7 +717,7 @@ TQPtrList<TDEAction> *ICQContact::customContextMenuActions()
 
 
     m_selectEncoding = new TDEAction( i18n( "Select Encoding..." ), "charset", 0,
-                                    this, TQT_SLOT( changeContactEncoding() ), this, "changeEncoding" );
+                                    this, TQ_SLOT( changeContactEncoding() ), this, "changeEncoding" );
 
 /*
 	actionReadAwayMessage->setEnabled(status != OSCAR_OFFLINE && status != OSCAR_ONLINE);
@@ -748,7 +748,7 @@ TQPtrList<TDEAction> *ICQContact::customContextMenuActions()
 void ICQContact::slotUserInfo()
 {
 	m_infoWidget = new ICQUserInfoWidget( Kopete::UI::Global::mainWidget(), "icq info" );
-	TQObject::connect( m_infoWidget, TQT_SIGNAL( finished() ), this, TQT_SLOT( closeUserInfoDialog() ) );
+	TQObject::connect( m_infoWidget, TQ_SIGNAL( finished() ), this, TQ_SLOT( closeUserInfoDialog() ) );
 	m_infoWidget->setContact( this );
 	m_infoWidget->show();
 	if ( account()->isConnected() )
@@ -768,8 +768,8 @@ void ICQContact::changeContactEncoding()
         return;
 
     m_oesd = new OscarEncodingSelectionDialog( Kopete::UI::Global::mainWidget(), property(mProtocol->contactEncoding).value().toInt() );
-    connect( m_oesd, TQT_SIGNAL( closing( int ) ),
-             this, TQT_SLOT( changeEncodingDialogClosed( int ) ) );
+    connect( m_oesd, TQ_SIGNAL( closing( int ) ),
+             this, TQ_SLOT( changeEncodingDialogClosed( int ) ) );
     m_oesd->show();
 }
 
@@ -827,7 +827,7 @@ void ICQContact::slotReadAwayMessage()
 		awayMessageDialog = new ICQReadAway(this, 0L, "awayMessageDialog");
 		if(!awayMessageDialog)
 			return;
-		TQObject::connect(awayMessageDialog, TQT_SIGNAL(closing()), this, TQT_SLOT(slotCloseAwayMessageDialog()));
+		TQObject::connect(awayMessageDialog, TQ_SIGNAL(closing()), this, TQ_SLOT(slotCloseAwayMessageDialog()));
 		awayMessageDialog->show();
 	}
 	else
