@@ -27,7 +27,7 @@ class YMSGTransfer;
 */
 class MessageReceiverTask : public Task
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	MessageReceiverTask(Task *parent);
