@@ -38,7 +38,7 @@ class KPushButton;
 class TQColor;
 class TQListView;
 
-class KDE_EXPORT KOPrefsDialogMain : public KPrefsModule
+class TDE_EXPORT KOPrefsDialogMain : public KPrefsModule
 {
     TQ_OBJECT
   
@@ -51,7 +51,7 @@ class KDE_EXPORT KOPrefsDialogMain : public KPrefsModule
     TQWidget *mUserEmailSettings;
 };
 
-class KDE_EXPORT KOPrefsDialogColors : public KPrefsModule
+class TDE_EXPORT KOPrefsDialogColors : public KPrefsModule
 {
     TQ_OBJECT
   
@@ -82,7 +82,7 @@ class KDE_EXPORT KOPrefsDialogColors : public KPrefsModule
     TQStringList mResourceIdentifier;
 };
 
-class KDE_EXPORT KOPrefsDialogGroupScheduling : public KPrefsModule
+class TDE_EXPORT KOPrefsDialogGroupScheduling : public KPrefsModule
 {
     TQ_OBJECT
   
@@ -106,7 +106,7 @@ class KDE_EXPORT KOPrefsDialogGroupScheduling : public KPrefsModule
 
 class KOGroupwarePrefsPage;
 
-class KDE_EXPORT KOPrefsDialogGroupwareScheduling : public KPrefsModule
+class TDE_EXPORT KOPrefsDialogGroupwareScheduling : public KPrefsModule
 {
     TQ_OBJECT
   
@@ -121,7 +121,7 @@ class KDE_EXPORT KOPrefsDialogGroupwareScheduling : public KPrefsModule
     KOGroupwarePrefsPage* mGroupwarePage;
 };
 
-class KDE_EXPORT KOPrefsDialogPlugins : public KPrefsModule
+class TDE_EXPORT KOPrefsDialogPlugins : public KPrefsModule
 {
     TQ_OBJECT
   
@@ -141,7 +141,7 @@ class KDE_EXPORT KOPrefsDialogPlugins : public KPrefsModule
     KPushButton *mConfigureButton;
 };
 
-class KDE_EXPORT KOPrefsDesignerFields : public KPIM::KCMDesignerFields
+class TDE_EXPORT KOPrefsDesignerFields : public KPIM::KCMDesignerFields
 {
   public:
     KOPrefsDesignerFields( TQWidget *parent = 0, const char *name = 0 );
