@@ -109,8 +109,8 @@ AlarmDialog::AlarmDialog( KCal::CalendarResources *calendar, TQWidget *parent, c
   // User3 => Dismiss Selected
   //    Ok => Suspend
 
-  connect( calendar, TQT_SIGNAL(calendarChanged()),
-           this, TQT_SLOT(slotCalendarChanged()) );
+  connect( calendar, TQ_SIGNAL(calendarChanged()),
+           this, TQ_SLOT(slotCalendarChanged()) );
 
   TDEGlobal::iconLoader()->addAppDir( "tdepim" );
   setButtonOK( i18n( "Suspend" ) );
@@ -122,7 +122,7 @@ AlarmDialog::AlarmDialog( KCal::CalendarResources *calendar, TQWidget *parent, c
   TQLabel *label = new TQLabel( i18n("The following items triggered reminders:"), topBox );
   topLayout->addWidget( label );
 
-  mSplitter = new TQSplitter( Qt::Vertical, topBox );
+  mSplitter = new TQSplitter( TQt::Vertical, topBox );
   mSplitter->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
   topLayout->addWidget( mSplitter );
 
@@ -135,10 +135,10 @@ AlarmDialog::AlarmDialog( KCal::CalendarResources *calendar, TQWidget *parent, c
   mIncidenceListView->setShowSortIndicator( true );
   mIncidenceListView->setAllColumnsShowFocus( true );
   mIncidenceListView->setSelectionMode( TQListView::Extended );
-  connect( mIncidenceListView, TQT_SIGNAL(selectionChanged()), TQT_SLOT(updateButtons()) );
-  connect( mIncidenceListView, TQT_SIGNAL(doubleClicked(TQListViewItem*)), TQT_SLOT(edit()) );
-  connect( mIncidenceListView, TQT_SIGNAL(currentChanged(TQListViewItem*)), TQT_SLOT(showDetails()) );
-  connect( mIncidenceListView, TQT_SIGNAL(selectionChanged()), TQT_SLOT(showDetails()) );
+  connect( mIncidenceListView, TQ_SIGNAL(selectionChanged()), TQ_SLOT(updateButtons()) );
+  connect( mIncidenceListView, TQ_SIGNAL(doubleClicked(TQListViewItem*)), TQ_SLOT(edit()) );
+  connect( mIncidenceListView, TQ_SIGNAL(currentChanged(TQListViewItem*)), TQ_SLOT(showDetails()) );
+  connect( mIncidenceListView, TQ_SIGNAL(selectionChanged()), TQ_SLOT(showDetails()) );
 
   mDetailView = new KOEventViewer( mCalendar, mSplitter );
   mDetailView->setFocus(); // set focus here to start with to make it harder
@@ -160,7 +160,7 @@ AlarmDialog::AlarmDialog( KCal::CalendarResources *calendar, TQWidget *parent, c
   mSuspendUnit->insertItem( i18n("week(s)") );
   mSuspendUnit->setCurrentItem( defSuspendUnit );
 
-  connect( &mSuspendTimer, TQT_SIGNAL(timeout()), TQT_SLOT(wakeUp()) );
+  connect( &mSuspendTimer, TQ_SIGNAL(timeout()), TQ_SLOT(wakeUp()) );
 
   setMainWidget( mIncidenceListView );
   mIncidenceListView->setMinimumSize( 500, 50 );
