@@ -255,7 +255,7 @@ void kpok::initWindow()
   // The draw button
   drawButton = new TQPushButton(this);
   drawButton->setText(i18n("&Deal"));
-  connect(drawButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(drawClick()));
+  connect(drawButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(drawClick()));
   inputLayout->addWidget(drawButton);
   inputLayout->addStretch(1);
 
@@ -291,20 +291,20 @@ void kpok::initWindow()
 
   // Timers
   blinkTimer = new TQTimer(this);
-  connect( blinkTimer, TQT_SIGNAL(timeout()), TQT_SLOT(bTimerEvent()) );
+  connect( blinkTimer, TQ_SIGNAL(timeout()), TQ_SLOT(bTimerEvent()) );
 
   waveTimer = new TQTimer(this);
-  connect( waveTimer, TQT_SIGNAL(timeout()), TQT_SLOT(waveTimerEvent()) );
+  connect( waveTimer, TQ_SIGNAL(timeout()), TQ_SLOT(waveTimerEvent()) );
 
   drawTimer = new TQTimer(this);
-  connect (drawTimer, TQT_SIGNAL(timeout()), TQT_SLOT(drawCardsEvent()) );
+  connect (drawTimer, TQ_SIGNAL(timeout()), TQ_SLOT(drawCardsEvent()) );
 
   // and now the betUp/Down Buttons
   betBox = new BetBox(this, 0);
   betLayout->addWidget(betBox);
-  connect(betBox, TQT_SIGNAL(betChanged(int)), this, TQT_SLOT(betChange(int)));
-  connect(betBox, TQT_SIGNAL(betAdjusted()),   this, TQT_SLOT(adjustBet()));
-  connect(betBox, TQT_SIGNAL(fold()),          this, TQT_SLOT(out()));
+  connect(betBox, TQ_SIGNAL(betChanged(int)), this, TQ_SLOT(betChange(int)));
+  connect(betBox, TQ_SIGNAL(betAdjusted()),   this, TQ_SLOT(adjustBet()));
+  connect(betBox, TQ_SIGNAL(fold()),          this, TQ_SLOT(out()));
 
   // some tips 
   TQToolTip::add(drawButton, i18n("Continue the round"));
@@ -438,7 +438,7 @@ void kpok::newRound()
 
   paintCash();
 
-  drawTimer->start(drawDelay, TRUE);
+  drawTimer->start(drawDelay, true);
 }
 
 
@@ -644,7 +644,7 @@ void kpok::initPoker(unsigned int numPlayers)
   //
   // FIXME: Make CardWidget::toggleHeld() work.
   playerBox[0]->activateToggleHeld(); 
-  connect(playerBox[0], TQT_SIGNAL(toggleHeld()), this, TQT_SLOT(toggleHeld()));
+  connect(playerBox[0], TQ_SIGNAL(toggleHeld()), this, TQ_SLOT(toggleHeld()));
 
   // hide some things
   playerBox[0]->showHelds(false);
@@ -763,9 +763,9 @@ void kpok::drawClick()
     }
 
     if (playerBox[0]->getHeld(0))
-      drawTimer->start(0, TRUE);
+      drawTimer->start(0, true);
     else
-      drawTimer->start(drawDelay, TRUE);
+      drawTimer->start(drawDelay, true);
   }
   else if (m_game.getState() == StateBet2) { // raise
     setBetButtonEnabled(false);
@@ -905,9 +905,9 @@ void kpok::drawCardsEvent()
     drawStat++;
     // look at next card and if it is held instantly call drawCardEvent again
     if (playerBox[0]->getHeld(drawStat))
-      drawTimer->start(0,TRUE);
+      drawTimer->start(0,true);
     else
-      drawTimer->start(drawDelay,TRUE);
+      drawTimer->start(drawDelay,true);
   }
 }
 
@@ -1028,7 +1028,7 @@ void kpok::stopWave()
 {
   waveTimer->stop();
   fCount = -1; /* clear image */
-  repaint ( FALSE );
+  repaint ( false );
   waveActive = false;
 }
 
@@ -1042,7 +1042,7 @@ void kpok::stopDrawing()
 void kpok::waveTimerEvent()
 {
   fCount = (fCount + 1) & 15;
-  repaint( FALSE );
+  repaint( false );
 }
 
 
