@@ -125,11 +125,11 @@ ConnectWidget::ConnectWidget(TQWidget *parent, const char *name, PPPStats *st)
 
   debug = new TQPushButton(i18n("&Log"), this);
   debug->setToggleButton(true);
-  connect(debug, TQT_SIGNAL(clicked()), TQT_SIGNAL(toggleDebugWindow()));
+  connect(debug, TQ_SIGNAL(clicked()), TQ_SIGNAL(toggleDebugWindow()));
 
   cancel = new KPushButton(KStdGuiItem::cancel(), this);
   cancel->setFocus();
-  connect(cancel, TQT_SIGNAL(clicked()), TQT_SLOT(cancelbutton()));
+  connect(cancel, TQ_SIGNAL(clicked()), TQ_SLOT(cancelbutton()));
 
   int maxw = TQMAX(cancel->sizeHint().width(),
 		 debug->sizeHint().width());
@@ -143,24 +143,24 @@ ConnectWidget::ConnectWidget(TQWidget *parent, const char *name, PPPStats *st)
   setFixedSize(sizeHint());
 
   pausetimer = new TQTimer(this);
-  connect(pausetimer, TQT_SIGNAL(timeout()), TQT_SLOT(pause()));
+  connect(pausetimer, TQ_SIGNAL(timeout()), TQ_SLOT(pause()));
 
   kapp->processEvents();
 
   timeout_timer = new TQTimer(this);
-  connect(timeout_timer, TQT_SIGNAL(timeout()), TQT_SLOT(script_timed_out()));
+  connect(timeout_timer, TQ_SIGNAL(timeout()), TQ_SLOT(script_timed_out()));
 
   inittimer = new TQTimer(this);
-  connect(inittimer, TQT_SIGNAL(timeout()), TQT_SLOT(init()));
+  connect(inittimer, TQ_SIGNAL(timeout()), TQ_SLOT(init()));
 
   if_timeout_timer = new TQTimer(this);
-  connect(if_timeout_timer, TQT_SIGNAL(timeout()), TQT_SLOT(if_waiting_timed_out()));
+  connect(if_timeout_timer, TQ_SIGNAL(timeout()), TQ_SLOT(if_waiting_timed_out()));
 
-  connect(this,TQT_SIGNAL(if_waiting_signal()),this,TQT_SLOT(if_waiting_slot()));
+  connect(this,TQ_SIGNAL(if_waiting_signal()),this,TQ_SLOT(if_waiting_slot()));
 
   prompt = new PWEntry( this, "pw" );
   if_timer = new TQTimer(this);
-  connect(if_timer,TQT_SIGNAL(timeout()), TQT_SLOT(if_waiting_slot()));
+  connect(if_timer,TQ_SIGNAL(timeout()), TQ_SLOT(if_waiting_slot()));
 }
 
 
@@ -259,7 +259,7 @@ void ConnectWidget::init() {
       semaphore = false;
 
       Modem::modem->stop();
-      Modem::modem->notify(TQT_TQOBJECT(this), TQT_SLOT(readChar(unsigned char)));
+      Modem::modem->notify(this, TQ_SLOT(readChar(unsigned char)));
 
       // if we are stuck anywhere we will time out
       timeout_timer->start(gpppdata.modemTimeout()*1000);
