@@ -94,8 +94,8 @@ KVncView::KVncView(TQWidget *parent,
 	setFocusPolicy(TQWidget::StrongFocus);
 
 	m_cb = TQApplication::clipboard();
-	connect(m_cb, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(selectionChanged()));
-	connect(m_cb, TQT_SIGNAL(dataChanged()), this, TQT_SLOT(clipboardChanged()));
+	connect(m_cb, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(selectionChanged()));
+	connect(m_cb, TQ_SIGNAL(dataChanged()), this, TQ_SLOT(clipboardChanged()));
 
 	TDEStandardDirs *dirs = TDEGlobal::dirs();
 	TQBitmap cursorBitmap(dirs->findResource("appdata",
@@ -290,7 +290,7 @@ bool KVncView::start() {
 	setStatus(REMOTE_VIEW_CONNECTING);
 
 	m_cthreadObject.moveToThread(&m_cthread);
-	TQTimer::singleShot(0, &m_cthreadObject, SLOT(run()));
+	TQTimer::singleShot(0, &m_cthreadObject, TQ_SLOT(run()));
 	m_cthread.start();
 
 	setBackgroundMode(TQt::NoBackground);
@@ -542,19 +542,19 @@ void KVncView::mouseEvent(TQMouseEvent *e) {
 	if ( e->type() != TQEvent::MouseMove ) {
 		if ( (e->type() == TQEvent::MouseButtonPress) ||
                      (e->type() == TQEvent::MouseButtonDblClick)) {
-			if ( e->button() & Qt::LeftButton )
+			if ( e->button() & TQt::LeftButton )
 				m_buttonMask |= 0x01;
-			if ( e->button() & Qt::MidButton )
+			if ( e->button() & TQt::MidButton )
 				m_buttonMask |= 0x02;
-			if ( e->button() & Qt::RightButton )
+			if ( e->button() & TQt::RightButton )
 				m_buttonMask |= 0x04;
 		}
 		else if ( e->type() == TQEvent::MouseButtonRelease ) {
-			if ( e->button() & Qt::LeftButton )
+			if ( e->button() & TQt::LeftButton )
 				m_buttonMask &= 0xfe;
-			if ( e->button() & Qt::MidButton )
+			if ( e->button() & TQt::MidButton )
 				m_buttonMask &= 0xfd;
-			if ( e->button() & Qt::RightButton )
+			if ( e->button() & TQt::RightButton )
 				m_buttonMask &= 0xfb;
 		}
 	}
