@@ -47,7 +47,7 @@ typedef KGenericFactory<KcmKRfb, TQWidget> KcmKRfbFactory;
 
 // Can't use K_EXPORT_COMPONENT_FACTORY, since insertCatalogue necessary
 extern "C" {
-  KDE_EXPORT void *init_kcm_krfb() {
+  TDE_EXPORT void *init_kcm_krfb() {
     TDEGlobal::locale()->insertCatalogue("krfb"); // For invitation translations
     return new KcmKRfbFactory("kcm_krfb"); 
   }
