@@ -26,7 +26,7 @@ class ConnectionWidget;
 
 class ConnectionDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
