@@ -9,7 +9,7 @@
 #undef KeyPress // X headers...
 
 class EnterCombo : public TQComboBox {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   EnterCombo ( TQWidget * parent=0, const char * name=0 )
