@@ -6,7 +6,7 @@
 
 class PageAutoConnect : public PageAutoConnectBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
