@@ -15,7 +15,7 @@
 
 class PageStartup : public PageStartupBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
