@@ -7,7 +7,7 @@
 
 class aHistLineEdit : public TQTextEdit
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     aHistLineEdit(TQWidget *parent = 0, const char *name = 0);
