@@ -18,14 +18,14 @@ extern DisplayMgr *displayMgr;
 dccTopLevel::dccTopLevel(TQWidget *parent, const char *name)
     : TDEMainWindow(parent, name, TQt::WDestructiveClose)
 {
-    m_mgr = new dccManager(this, TQCString(TQT_TQOBJECT(this)->name()) + "_dccManager");
+    m_mgr = new dccManager(this, TQCString(this->name()) + "_dccManager");
 //    m_mgr->show();
     setCentralWidget(m_mgr);
 
-    connect(m_mgr, TQT_SIGNAL(changed(bool, TQString)), this, TQT_SIGNAL(changed(bool, TQString)));
+    connect(m_mgr, TQ_SIGNAL(changed(bool, TQString)), this, TQ_SIGNAL(changed(bool, TQString)));
 
-    TQPopupMenu *win = new TQPopupMenu(this, TQCString(TQT_TQOBJECT(this)->name()) + "_popup_window");
-    TDEAction *act = KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection() );
+    TQPopupMenu *win = new TQPopupMenu(this, TQCString(this->name()) + "_popup_window");
+    TDEAction *act = KStdAction::close(this, TQ_SLOT( close() ), actionCollection() );
     act->plug(win);
 
     menuBar()->insertItem(i18n("&File"), win, DTL_WINDOW_ID, -1);
