@@ -8,7 +8,7 @@
 class KSircIONotify : public TQObject,
 		   public KSircMessageReceiver
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KSircIONotify(KSircProcess *_proc);
