@@ -215,22 +215,22 @@ KSircProcess::KSircProcess( TQString &server_id, KSircServer &kss, TQObject * pa
   KSircIODCC *dcc = new KSircIODCC(this);
   TopList.insert("!dcc", dcc);
   dcc = static_cast<KSircIODCC *>( TopList["!dcc"] ); // g++ bug
-  connect(dcc, TQT_SIGNAL(outputLine(TQCString)),
-	  iocontrol, TQT_SLOT(stdin_write(TQCString)));
+  connect(dcc, TQ_SIGNAL(outputLine(TQCString)),
+	  iocontrol, TQ_SLOT(stdin_write(TQCString)));
 
   KSircIOLAG *lag = new KSircIOLAG(this);
   TopList.insert("!lag", lag);
   lag = static_cast<KSircIOLAG*>( TopList["!lag"] ); // g++ bug!
-  connect(lag, TQT_SIGNAL(outputLine(TQCString)),
-	  iocontrol, TQT_SLOT(stdin_write(TQCString)));
+  connect(lag, TQ_SIGNAL(outputLine(TQCString)),
+	  iocontrol, TQ_SLOT(stdin_write(TQCString)));
 
   KSircIONotify *notify = new KSircIONotify(this);
   TopList.insert("!notify", notify);
   notify = static_cast<KSircIONotify *>( TopList["!notify"] ); // g++ bug
-  connect(notify, TQT_SIGNAL(notify_online(TQString)),
-	  this, TQT_SLOT(notify_forw_online(TQString)));
-  connect(notify, TQT_SIGNAL(notify_offline(TQString)),
-	  this, TQT_SLOT(notify_forw_offline(TQString)));
+  connect(notify, TQ_SIGNAL(notify_online(TQString)),
+	  this, TQ_SLOT(notify_forw_online(TQString)));
+  connect(notify, TQ_SIGNAL(notify_offline(TQString)),
+	  this, TQ_SLOT(notify_forw_offline(TQString)));
 
   TopList.insert("!base_rules", new KSMBaseRules(this));
 
@@ -383,20 +383,20 @@ void KSircProcess::new_toplevel(const KSircChannel &channelInfo, bool safe)
 
     // Connect needed signals.  For a message window we never want it
     // becomming the default so we ignore focusIn events into it.
-    connect(wm, TQT_SIGNAL(outputLine(TQCString)),
-	    iocontrol, TQT_SLOT(stdin_write(TQCString)));
-    connect(wm, TQT_SIGNAL(open_toplevel(const KSircChannel &)),
-	    this,TQT_SLOT(new_toplevel (const KSircChannel &)));
-    connect(wm, TQT_SIGNAL(closing(KSircTopLevel *, TQString)),
-	    this,TQT_SLOT(close_toplevel(KSircTopLevel *, TQString)));
-    connect(wm, TQT_SIGNAL(currentWindow(KSircTopLevel *)),
-	    this,TQT_SLOT(default_window(KSircTopLevel *)));
-    connect(wm, TQT_SIGNAL(changeChannel(const TQString &, const TQString &)),
-            this,TQT_SLOT(recvChangeChannel(const TQString &, const TQString &)));
-    connect(wm, TQT_SIGNAL(destroyed(TQObject *)),
-            this,TQT_SLOT(clean_toplevel(TQObject *)));
-    connect( wm, TQT_SIGNAL( requestQuit( const TQCString& ) ),
-            TQT_SLOT( request_quit( const TQCString& ) ) );
+    connect(wm, TQ_SIGNAL(outputLine(TQCString)),
+	    iocontrol, TQ_SLOT(stdin_write(TQCString)));
+    connect(wm, TQ_SIGNAL(open_toplevel(const KSircChannel &)),
+	    this,TQ_SLOT(new_toplevel (const KSircChannel &)));
+    connect(wm, TQ_SIGNAL(closing(KSircTopLevel *, TQString)),
+	    this,TQ_SLOT(close_toplevel(KSircTopLevel *, TQString)));
+    connect(wm, TQ_SIGNAL(currentWindow(KSircTopLevel *)),
+	    this,TQ_SLOT(default_window(KSircTopLevel *)));
+    connect(wm, TQ_SIGNAL(changeChannel(const TQString &, const TQString &)),
+            this,TQ_SLOT(recvChangeChannel(const TQString &, const TQString &)));
+    connect(wm, TQ_SIGNAL(destroyed(TQObject *)),
+            this,TQ_SLOT(clean_toplevel(TQObject *)));
+    connect( wm, TQ_SIGNAL( requestQuit( const TQCString& ) ),
+            TQ_SLOT( request_quit( const TQCString& ) ) );
 
     default_window(wm); // Set it to the default window.
     emit ProcMessage(serverID(), ProcCommand::addTopLevel, channelInfo.channel());
@@ -457,7 +457,7 @@ void KSircProcess::close_toplevel(KSircTopLevel *wm, TQString name)
   // Let's let em know she's deleted!
   if(ksopts->autoCreateWin == TRUE){
       emit ProcMessage(serverID(), ProcCommand::turnOffAutoCreate, TQString());
-      TQTimer::singleShot(5000, this, TQT_SLOT(turn_on_autocreate()));
+      TQTimer::singleShot(5000, this, TQ_SLOT(turn_on_autocreate()));
       auto_create_really = TRUE;
   }
   else{
@@ -496,7 +496,7 @@ void KSircProcess::request_quit( const TQCString& command )
     iocontrol->stdin_write( command );
     // Since removing the toplevels will delete the one that emitted this
     // signal as well, we need to defer this a little (malte)
-    TQTimer::singleShot( 0, this, TQT_SLOT( do_quit() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( do_quit() ) );
 }
 
 void KSircProcess::do_quit()
