@@ -103,11 +103,11 @@ PukeController::PukeController(TQString sock, TQObject *parent, const char *name
                                           // accept() never blocks.
 
   qsnListen = new TQSocketNotifier(iListenFd, TQSocketNotifier::Read, this, TQString(name) + "_iListen");
-  connect(qsnListen, TQT_SIGNAL(activated(int)),
-	  this, TQT_SLOT(NewConnect(int)));
+  connect(qsnListen, TQ_SIGNAL(activated(int)),
+	  this, TQ_SLOT(NewConnect(int)));
 
-  connect(objFind, TQT_SIGNAL(inserted(TQObject *)),
-          this, TQT_SLOT(slotInserted(TQObject *)));
+  connect(objFind, TQ_SIGNAL(inserted(TQObject *)),
+          this, TQ_SLOT(slotInserted(TQObject *)));
 
   qidConnectFd.setAutoDelete(TRUE);
 
@@ -124,8 +124,8 @@ PukeController::PukeController(TQString sock, TQObject *parent, const char *name
    * Connect outputMessage to the acutal write buffer function
    * outputMessage signals from pobjects are chained until they finally reach us.
    */
-  connect(this, TQT_SIGNAL(outputMessage(int, PukeMessage *)),
-	  this,  TQT_SLOT(writeBuffer(int, PukeMessage *)));
+  connect(this, TQ_SIGNAL(outputMessage(int, PukeMessage *)),
+	  this,  TQ_SLOT(writeBuffer(int, PukeMessage *)));
 
   initHdlr(); // Setup message command handlers.
 
@@ -176,10 +176,10 @@ void PukeController::NewConnect(int)
   fdStatus *fds = new fdStatus();
   fds->sr = new TQSocketNotifier(cfd, TQSocketNotifier::Read, this);
   fds->sw = new TQSocketNotifier(cfd, TQSocketNotifier::Write, this);
-  connect(fds->sr, TQT_SIGNAL(activated(int)),
-	  this, TQT_SLOT(Traffic(int)));
-  connect(fds->sw, TQT_SIGNAL(activated(int)),
-	  this, TQT_SLOT(Writeable(int)));
+  connect(fds->sr, TQ_SIGNAL(activated(int)),
+	  this, TQ_SLOT(Traffic(int)));
+  connect(fds->sw, TQ_SIGNAL(activated(int)),
+	  this, TQ_SLOT(Writeable(int)));
   qidConnectFd.insert(cfd, fds);
   qsnListen->setEnabled(TRUE);
 
@@ -609,8 +609,8 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm)
   }
   ws->type = iType;
 
-  connect(ws->pwidget, TQT_SIGNAL(outputMessage(int, PukeMessage*)),
-	  this, TQT_SIGNAL(outputMessage(int, PukeMessage*)));
+  connect(ws->pwidget, TQ_SIGNAL(outputMessage(int, PukeMessage*)),
+	  this, TQ_SIGNAL(outputMessage(int, PukeMessage*)));
 
   // insertPBoject(fd, uiBaseWinId, ws);
   // The widget list has to exist since we have ourselves in the list
@@ -796,8 +796,8 @@ void PukeController::insertPObject(int fd, int iWinId, WidgetS *obj){
 
   // Now connect to the destroyed signal so we can remove the object from the lists
   // Once it is deleted
-  connect(obj->pwidget, TQT_SIGNAL(destroyed()),
-          this, TQT_SLOT(pobjectDestroyed()));
+  connect(obj->pwidget, TQ_SIGNAL(destroyed()),
+          this, TQ_SLOT(pobjectDestroyed()));
 }
 
 void PukeController::pobjectDestroyed(){
@@ -959,8 +959,8 @@ widgetId PukeController::createWidget(widgetId wI, PukeMessage *pm)
   }
   ws->type = iType;
 
-  connect(ws->pwidget, TQT_SIGNAL(outputMessage(int, PukeMessage*)),
-	  this, TQT_SIGNAL(outputMessage(int, PukeMessage*)));
+  connect(ws->pwidget, TQ_SIGNAL(outputMessage(int, PukeMessage*)),
+	  this, TQ_SIGNAL(outputMessage(int, PukeMessage*)));
 
   // insertPBoject(fd, uiBaseWinId, ws);
   // The widget list has to exist since we have ourselves in the list
