@@ -12,7 +12,7 @@ class PButton;
 
 class PButton : public PWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   static PObject *createWidget(CreateArgs &ca);
