@@ -12,7 +12,7 @@ class PPopupMenu;
 
 class PPopupMenu : public PFrame
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   static PObject *createWidget(CreateArgs &ca);
