@@ -222,40 +222,13 @@ void KSMServer::shutdownInternal( TDEApplication::ShutdownConfirm confirm,
     if ( !logoutConfirmed ) {
         int selection;
         KSMShutdownFeedback::start(); // make the screen gray
-        logoutConfirmed =
-            KSMShutdownDlg::confirmShutdown( maysd, mayrb, sdtype, bopt, &selection );
+        logoutConfirmed = KSMShutdownDlg::confirmShutdown( maysd, mayrb, sdtype, bopt, &selection );
         // ###### We can't make the screen remain gray while talking to the apps,
         // because this prevents interaction ("do you want to save", etc.)
         // TODO: turn the feedback widget into a list of apps to be closed,
         // with an indicator of the current status for each.
         KSMShutdownFeedback::stop(); // make the screen become normal again
-        if (selection != 0) {
-		// respect lock on resume & disable suspend/hibernate settings
-		// from power-manager
-		TDEConfig config("power-managerrc");
-		bool lockOnResume = config.readBoolEntry("lockOnResume", true);
-		if (lockOnResume) {
-			TQCString replyType;
-			TQByteArray replyData;
-			// Block here until lock is complete
-			// If this is not done the desktop of the locked session will be shown after suspend/hibernate until the lock fully engages!
-			kapp->dcopClient()->call("kdesktop", "KScreensaverIface", "lock()", TQCString(""), replyType, replyData);
-		}
-#ifdef WITH_TDEHWLIB
-		TDERootSystemDevice* rootDevice = hwDevices->rootSystemDevice();
-		if (rootDevice) {
-			if (selection == 1) {	// Suspend
-				rootDevice->setPowerState(TDESystemPowerState::Suspend);
-			}
-			if (selection == 2) {	// Hibernate
-				rootDevice->setPowerState(TDESystemPowerState::Hibernate);
-			}
-			if (selection == 3) {	// Freeze
-				rootDevice->setPowerState(TDESystemPowerState::Freeze);
-			}
-		}
-#endif
-        }
+        suspend(selection);
     }
 
     if ( logoutConfirmed ) {
@@ -267,8 +240,8 @@ void KSMServer::shutdownInternal( TDEApplication::ShutdownConfirm confirm,
 	if (showLogoutStatusDlg) {
 		shutdownNotifierIPDlg = KSMShutdownIPDlg::showShutdownIP();
 		if (shutdownNotifierIPDlg) {
-			connect(shutdownNotifierIPDlg, SIGNAL(abortLogoutClicked()), this, SLOT(cancelShutdown()));
-			connect(shutdownNotifierIPDlg, SIGNAL(skipNotificationClicked()), this, SLOT(forceSkipSaveYourself()));
+			connect(shutdownNotifierIPDlg, TQ_SIGNAL(abortLogoutClicked()), this, TQ_SLOT(cancelShutdown()));
+			connect(shutdownNotifierIPDlg, TQ_SIGNAL(skipNotificationClicked()), this, TQ_SLOT(forceSkipSaveYourself()));
 			static_cast<KSMShutdownIPDlg*>(shutdownNotifierIPDlg)->setStatusMessage(i18n("Notifying applications of logout request..."));
 			notificationTimer.start( KSMSERVER_NOTIFICATION_MANUAL_OPTIONS_TIMEOUT, true );
 		}
@@ -284,7 +257,7 @@ void KSMServer::shutdownInternal( TDEApplication::ShutdownConfirm confirm,
         // Set the real desktop background to black so that exit looks
         // clean regardless of what was on "our" desktop.
         if (!showLogoutStatusDlg) {
-            TQT_TQWIDGET(kapp->desktop())->setBackgroundColor( Qt::black );
+            kapp->desktop()->setBackgroundColor( TQt::black );
         }
         state = Shutdown;
         wmPhase1WaitingCount = 0;
@@ -338,6 +311,70 @@ void KSMServer::shutdown( TDEApplication::ShutdownConfirm confirm,
     shutdownInternal( confirm, sdtype, sdmode );
 }
 
+void KSMServer::suspendInternal(int state)
+{
+    if (m_lockOnResume) {
+        TQCString replyType;
+        TQByteArray replyData;
+        // Block here until lock is complete
+        // If this is not done the desktop of the locked session will be shown after suspend/hibernate until the lock fully engages!
+        kapp->dcopClient()->call("kdesktop", "KScreensaverIface", "lock()", TQCString(""), replyType, replyData);
+    }
+
+#ifdef WITH_TDEHWLIB
+    TDERootSystemDevice* rootDevice = hwDevices->rootSystemDevice();
+    rootDevice->setPowerState((TDESystemPowerState::TDESystemPowerState)state);
+#endif
+}
+
+bool KSMServer::suspend(int stype)
+{
+    if (stype == SuspendType::NotSpecified)
+        return false;
+
+    reconfigure();
+
+#ifdef WITH_TDEHWLIB
+    TDERootSystemDevice* rootDevice = hwDevices->rootSystemDevice();
+    if (rootDevice) {
+        switch (stype) {
+            case SuspendType::Freeze:
+                if (rootDevice->canFreeze() && !m_disableSuspend)
+                {
+                    suspendInternal(TDESystemPowerState::Freeze);
+                    return true;
+                }
+                break;
+
+            case SuspendType::Suspend:
+                if (rootDevice->canSuspend() && !m_disableSuspend)
+                {
+                    suspendInternal(TDESystemPowerState::Suspend);
+                    return true;
+                }
+                break;
+
+            case SuspendType::Hibernate:
+                if (rootDevice->canHibernate() && !m_disableHibernate)
+                {
+                    suspendInternal(TDESystemPowerState::Hibernate);
+                    return true;
+                }
+                break;
+
+            case SuspendType::HybridSuspend:
+                if (rootDevice->canHybridSuspend() && !m_disableSuspend && !m_disableHibernate)
+                {
+                    suspendInternal(TDESystemPowerState::HybridSuspend);
+                    return true;
+                }
+                break;
+        }
+    }
+#endif
+    return false;
+}
+
 #include <tdemessagebox.h>
 
 void KSMServer::logoutTimed( int sdtype, int sdmode, TQString bootOption )
@@ -759,8 +796,8 @@ void KSMServer::completeShutdownOrCheckpoint()
         if (!shutdownNotifierIPDlg) {
             shutdownNotifierIPDlg = KSMShutdownIPDlg::showShutdownIP();
             if (shutdownNotifierIPDlg) {
-                connect(shutdownNotifierIPDlg, SIGNAL(abortLogoutClicked()), this, SLOT(cancelShutdown()));
-                connect(shutdownNotifierIPDlg, SIGNAL(skipNotificationClicked()), this, SLOT(forceSkipSaveYourself()));
+                connect(shutdownNotifierIPDlg, TQ_SIGNAL(abortLogoutClicked()), this, TQ_SLOT(cancelShutdown()));
+                connect(shutdownNotifierIPDlg, TQ_SIGNAL(skipNotificationClicked()), this, TQ_SLOT(forceSkipSaveYourself()));
             }
         }
         while (!KSMShutdownIPFeedback::ispainted()) {
@@ -958,7 +995,7 @@ void KSMServer::killWM()
     }
     if( iswm ) {
         completeKillingWM();
-        TQTimer::singleShot( 5000, this, TQT_SLOT( timeoutWMQuit() ) );
+        TQTimer::singleShot( 5000, this, TQ_SLOT( timeoutWMQuit() ) );
     }
     else {
         killingCompleted();
