@@ -93,23 +93,23 @@
 
 void KStars::slotViewToolBar() {
 
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_stars" ) ) {
+	if ( sender()->name() == TQString( "show_stars" ) ) {
 		Options::setShowStars( !Options::showStars() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_deepsky" ) ) {
+	} else if ( sender()->name() == TQString( "show_deepsky" ) ) {
 		Options::setShowDeepSky( ! Options::showDeepSky() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_planets" ) ) {
+	} else if ( sender()->name() == TQString( "show_planets" ) ) {
 		Options::setShowPlanets( ! Options::showPlanets() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_clines" ) ) {
+	} else if ( sender()->name() == TQString( "show_clines" ) ) {
 		Options::setShowCLines( !Options::showCLines() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_cnames" ) ) {
+	} else if ( sender()->name() == TQString( "show_cnames" ) ) {
 		Options::setShowCNames( !Options::showCNames() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_cbounds" ) ) {
+	} else if ( sender()->name() == TQString( "show_cbounds" ) ) {
 		Options::setShowCBounds( !Options::showCBounds() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_mw" ) ) {
+	} else if ( sender()->name() == TQString( "show_mw" ) ) {
 		Options::setShowMilkyWay( !Options::showMilkyWay() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_grid" ) ) {
+	} else if ( sender()->name() == TQString( "show_grid" ) ) {
 		Options::setShowGrid( !Options::showGrid() );
-	} else if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_horizon" ) ) {
+	} else if ( sender()->name() == TQString( "show_horizon" ) ) {
 		Options::setShowGround( !Options::showGround() );
 	}
 
@@ -198,7 +198,7 @@ void KStars::slotWUT() {
 
 //FIXME GLOSSARY
 // void KStars::slotGlossary(){
-// 	GlossaryDialog *dlg = new GlossaryDialog( true, TQT_TQOBJECT(this), "glossary" );
+// 	GlossaryDialog *dlg = new GlossaryDialog( true, this, "glossary" );
 // 	TQString glossaryfile =data()->stdDirs->findResource( "data", "kstars/glossary.xml" );
 // 	KURL u = glossaryfile;
 // 	Glossary *g = Glossary::readFromXML( u );
@@ -356,8 +356,8 @@ void KStars::slotViewOps() {
 	TDEConfigDialog* dialog = new TDEConfigDialog( this, "settings",
 					     Options::self() );
 
-	connect( dialog, TQT_SIGNAL( applyClicked() ), TQT_TQOBJECT(this), TQT_SLOT( slotApplySettings() ) );
-	connect( dialog, TQT_SIGNAL( okClicked() ), TQT_TQOBJECT(this), TQT_SLOT( slotApplySettings() ) );
+	connect( dialog, TQ_SIGNAL( applyClicked() ), this, TQ_SLOT( slotApplySettings() ) );
+	connect( dialog, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( slotApplySettings() ) );
 
 	OpsCatalog *opcatalog    = new OpsCatalog( this, "catalogs" );
 	OpsGuides  *opguides     = new OpsGuides( this, "guides" );
@@ -450,7 +450,7 @@ void KStars::slotExportImage() {
 	//Warn user if file exists!
 	if (TQFile::exists(fileURL.path()))
 	{
-		int r=KMessageBox::warningContinueCancel(TQT_TQWIDGET(parent()),
+		int r=KMessageBox::warningContinueCancel(static_cast<TQWidget*>(parent()),
 								i18n( "A file named \"%1\" already exists. "
 										"Overwrite it?" ).arg(fileURL.fileName()),
 								i18n( "Overwrite File?" ),
@@ -623,7 +623,7 @@ void KStars::slotToggleTimer() {
 
 //Focus
 void KStars::slotPointFocus() {
-	TQString sentFrom( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
+	TQString sentFrom( sender()->name() );
 
 	if ( sentFrom == "zenith" )
 		map()->invokeKey( KKey( "Z" ).keyCodeQt() );
@@ -813,12 +813,12 @@ void KStars::slotCoordSys() {
 //Settings Menu:
 void KStars::slotColorScheme() {
 	//use mid(3) to exclude the leading "cs_" prefix from the action name
-	TQString filename = TQString( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() ).mid(3) + ".colors";
+	TQString filename = TQString( sender()->name() ).mid(3) + ".colors";
 	loadColorScheme( filename );
 }
 
 void KStars::slotTargetSymbol() {
-	TQString symbolName( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
+	TQString symbolName( sender()->name() );
 	FOV f( symbolName ); //read data from fov.dat
 
 	Options::setFOVName( f.name() );
@@ -873,7 +873,7 @@ void KStars::slotFOVEdit() {
 
 				if ( fields.count() == 4 ) {
 					TQString nm = fields[0].stripWhiteSpace();
-					TDEToggleAction *kta = new TDEToggleAction( nm, 0, TQT_TQOBJECT(this), TQT_SLOT( slotTargetSymbol() ),
+					TDEToggleAction *kta = new TDEToggleAction( nm, 0, this, TQ_SLOT( slotTargetSymbol() ),
 							actionCollection(), nm.utf8() );
 					kta->setExclusiveGroup( "fovsymbol" );
 					fovActionMenu->insert( kta );
@@ -884,8 +884,8 @@ void KStars::slotFOVEdit() {
 		}
 
 		fovActionMenu->popupMenu()->insertSeparator();
-		fovActionMenu->insert( new TDEAction( i18n( "Edit FOV Symbols..." ), 0, TQT_TQOBJECT(this),
-				TQT_SLOT( slotFOVEdit() ), actionCollection(), "edit_fov" ) );
+		fovActionMenu->insert( new TDEAction( i18n( "Edit FOV Symbols..." ), 0, this,
+				TQ_SLOT( slotFOVEdit() ), actionCollection(), "edit_fov" ) );
 
 		//set FOV to whatever was highlighted in FOV dialog
 		if ( fovdlg.FOVList.count() > 0 ) {
@@ -955,24 +955,24 @@ void KStars::slotClearAllTrails() {
 //toggle display of GUI Items on/off
 void KStars::slotShowGUIItem( bool show ) {
 //Toolbars
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_mainToolBar" ) ) {
+	if ( sender()->name() == TQString( "show_mainToolBar" ) ) {
 		Options::setShowMainToolBar( show );
 		if ( show ) toolBar( "mainToolBar" )->show();
 		else toolBar( "mainToolBar" )->hide();
 	}
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_viewToolBar" ) ) {
+	if ( sender()->name() == TQString( "show_viewToolBar" ) ) {
 		Options::setShowViewToolBar( show );
 		if ( show ) toolBar( "viewToolBar" )->show();
 		else toolBar( "viewToolBar" )->hide();
 	}
 
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_statusBar" ) ) {
+	if ( sender()->name() == TQString( "show_statusBar" ) ) {
 		Options::setShowStatusBar( show );
 		if ( show ) statusBar()->show();
 		else  statusBar()->hide();
 	}
 
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_sbAzAlt" ) ) {
+	if ( sender()->name() == TQString( "show_sbAzAlt" ) ) {
 		Options::setShowAltAzField( show );
 		if ( show ) {
 			//To preserve the order (AzAlt before RADec), we have to remove
@@ -994,7 +994,7 @@ void KStars::slotShowGUIItem( bool show ) {
 		}
 	}
 
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_sbRADec" ) ) {
+	if ( sender()->name() == TQString( "show_sbRADec" ) ) {
 		Options::setShowRADecField( show );
 		if ( show ) {
 			TQString s = "000d 00m 00s,   +00d 00\' 00\""; //only need this to set the width
@@ -1008,19 +1008,19 @@ void KStars::slotShowGUIItem( bool show ) {
 
 //InfoBoxes: we only change options here; these are also connected to slots in
 //InfoBoxes that actually toggle the display.
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_boxes" ) )
+	if ( sender()->name() == TQString( "show_boxes" ) )
 		Options::setShowInfoBoxes( show );
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_time_box" ) )
+	if ( sender()->name() == TQString( "show_time_box" ) )
 		Options::setShowTimeBox( show );
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_location_box" ) )
+	if ( sender()->name() == TQString( "show_location_box" ) )
 		Options::setShowGeoBox( show );
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "show_focus_box" ) )
+	if ( sender()->name() == TQString( "show_focus_box" ) )
 		Options::setShowFocusBox( show );
 }
 
 void KStars::addColorMenuItem( TQString name, TQString actionName ) {
 	colorActionMenu->insert( new TDEAction( name, 0,
-			TQT_TQOBJECT(this), TQT_SLOT( slotColorScheme() ), actionCollection(), actionName.local8Bit() ) );
+			this, TQ_SLOT( slotColorScheme() ), actionCollection(), actionName.local8Bit() ) );
 }
 
 void KStars::removeColorMenuItem( TQString actionName ) {
