@@ -88,41 +88,41 @@ KStarsData::KStarsData() : stdDirs(0), locale(0),
 	//initialize FOV symbol
 	fovSymbol = FOV();
 
-	//set AutoDelete property for TQPtrLists.  Most are set TRUE,
-	//but some 'meta-lists' need to be FALSE.
-	starList.setAutoDelete( TRUE );
-	ADVtreeList.setAutoDelete( TRUE );
-	geoList.setAutoDelete( TRUE );
-	deepSkyList.setAutoDelete( TRUE );        // list of all deep space objects
+	//set AutoDelete property for TQPtrLists.  Most are set true,
+	//but some 'meta-lists' need to be false.
+	starList.setAutoDelete( true );
+	ADVtreeList.setAutoDelete( true );
+	geoList.setAutoDelete( true );
+	deepSkyList.setAutoDelete( true );        // list of all deep space objects
 
 	//separate lists for each deep-sky catalog.  The objects are duplicates of
 	//deepSkyList, so do not delete them twice!
-	deepSkyListMessier.setAutoDelete( FALSE );
-	deepSkyListNGC.setAutoDelete( FALSE );
-	deepSkyListIC.setAutoDelete( FALSE );
-	deepSkyListOther.setAutoDelete( FALSE );
+	deepSkyListMessier.setAutoDelete( false );
+	deepSkyListNGC.setAutoDelete( false );
+	deepSkyListIC.setAutoDelete( false );
+	deepSkyListOther.setAutoDelete( false );
 
 	//ObjLabelList does not construct new objects, so no autoDelete needed
-	ObjLabelList.setAutoDelete( FALSE );
+	ObjLabelList.setAutoDelete( false );
 
-	cometList.setAutoDelete( TRUE );
-	asteroidList.setAutoDelete( TRUE );
+	cometList.setAutoDelete( true );
+	asteroidList.setAutoDelete( true );
 
 	//Constellation lines are now pointers to existing StarObjects;
 	//these are already auto-deleted by starList.
-	clineList.setAutoDelete( FALSE );
-	clineModeList.setAutoDelete( TRUE );
-	cnameList.setAutoDelete( TRUE );
-	csegmentList.setAutoDelete( TRUE );
+	clineList.setAutoDelete( false );
+	clineModeList.setAutoDelete( true );
+	cnameList.setAutoDelete( true );
+	csegmentList.setAutoDelete( true );
 
-	Equator.setAutoDelete( TRUE );
-	Ecliptic.setAutoDelete( TRUE );
-	Horizon.setAutoDelete( TRUE );
-	for ( unsigned int i=0; i<11; ++i ) MilkyWay[i].setAutoDelete( TRUE );
+	Equator.setAutoDelete( true );
+	Ecliptic.setAutoDelete( true );
+	Horizon.setAutoDelete( true );
+	for ( unsigned int i=0; i<11; ++i ) MilkyWay[i].setAutoDelete( true );
 
-	VariableStarsList.setAutoDelete(TRUE);
-	INDIHostsList.setAutoDelete(TRUE);
-	INDITelescopeList.setAutoDelete(TRUE);
+	VariableStarsList.setAutoDelete(true);
+	INDIHostsList.setAutoDelete(true);
+	INDITelescopeList.setAutoDelete(true);
 
 	//Initialize object type strings
 	TypeName[0] = i18n( "star" );
