@@ -91,8 +91,8 @@ SkyMap::SkyMap(KStarsData *d, TQWidget *parent, const char *name )
 
 	//Initialize Transient label stuff
 	TransientTimeout = 100; //fade label color every 0.2 sec
-	connect( &HoverTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotTransientLabel() ) );
-	connect( &TransientTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotTransientTimeout() ) );
+	connect( &HoverTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotTransientLabel() ) );
+	connect( &TransientTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotTransientTimeout() ) );
 
 	IBoxes = new InfoBoxes( Options::windowWidth(), Options::windowHeight(),
 			Options::positionTimeBox(), Options::shadeTimeBox(),
@@ -111,14 +111,14 @@ SkyMap::SkyMap(KStarsData *d, TQWidget *parent, const char *name )
 
 	IBoxes->geoChanged( data->geo() );
 
-	connect( IBoxes->timeBox(),  TQT_SIGNAL( shaded(bool) ), data, TQT_SLOT( saveTimeBoxShaded(bool) ) );
-	connect( IBoxes->geoBox(),   TQT_SIGNAL( shaded(bool) ), data, TQT_SLOT( saveGeoBoxShaded(bool) ) );
-	connect( IBoxes->focusBox(), TQT_SIGNAL( shaded(bool) ), data, TQT_SLOT( saveFocusBoxShaded(bool) ) );
-	connect( IBoxes->timeBox(),  TQT_SIGNAL( moved(TQPoint) ), data, TQT_SLOT( saveTimeBoxPos(TQPoint) ) );
-	connect( IBoxes->geoBox(),   TQT_SIGNAL( moved(TQPoint) ), data, TQT_SLOT( saveGeoBoxPos(TQPoint) ) );
-	connect( IBoxes->focusBox(), TQT_SIGNAL( moved(TQPoint) ), data, TQT_SLOT( saveFocusBoxPos(TQPoint) ) );
+	connect( IBoxes->timeBox(),  TQ_SIGNAL( shaded(bool) ), data, TQ_SLOT( saveTimeBoxShaded(bool) ) );
+	connect( IBoxes->geoBox(),   TQ_SIGNAL( shaded(bool) ), data, TQ_SLOT( saveGeoBoxShaded(bool) ) );
+	connect( IBoxes->focusBox(), TQ_SIGNAL( shaded(bool) ), data, TQ_SLOT( saveFocusBoxShaded(bool) ) );
+	connect( IBoxes->timeBox(),  TQ_SIGNAL( moved(TQPoint) ), data, TQ_SLOT( saveTimeBoxPos(TQPoint) ) );
+	connect( IBoxes->geoBox(),   TQ_SIGNAL( moved(TQPoint) ), data, TQ_SLOT( saveGeoBoxPos(TQPoint) ) );
+	connect( IBoxes->focusBox(), TQ_SIGNAL( moved(TQPoint) ), data, TQ_SLOT( saveFocusBoxPos(TQPoint) ) );
 
-	connect( this, TQT_SIGNAL( destinationChanged() ), this, TQT_SLOT( slewFocus() ) );
+	connect( this, TQ_SIGNAL( destinationChanged() ), this, TQ_SLOT( slewFocus() ) );
 
 	//Initialize Refraction correction lookup table arrays.  RefractCorr1 is for calculating
 	//the apparent altitude from the true altitude, and RefractCorr2 is for the reverse.
