@@ -100,8 +100,8 @@ AltVsTime::AltVsTime( TQWidget* parent)  :
 	connect( avtUI->latBox,  TQ_SIGNAL( returnPressed() ), this, TQ_SLOT( slotAdvanceFocus() ) );
 	connect( avtUI->PlotList, TQ_SIGNAL( highlighted(int) ), this, TQ_SLOT( slotHighlight() ) );
 
-	pList.setAutoDelete(FALSE);
-	deleteList.setAutoDelete(TRUE); //needed for skypoints which may be created in this class
+	pList.setAutoDelete(false);
+	deleteList.setAutoDelete(true); //needed for skypoints which may be created in this class
 
 	//ther edit boxes should not pass on the return key!
 	avtUI->nameBox->setTrapReturnKey( true );
