@@ -1015,7 +1015,7 @@ void Executer::startWaiting(int msec)
 {
 	bStopWaiting = false;
 	// call a timer that sets stopWaiting to true when it runs 
-	TQTimer::singleShot( msec, this, TQT_SLOT( slotStopWaiting() ) );
+	TQTimer::singleShot( msec, this, TQ_SLOT( slotStopWaiting() ) );
 	while (bStopWaiting == false)
 	{
 		if (bAbort) return; // waits need to be interrupted by the stop action
