@@ -902,7 +902,7 @@ void kvoctrainApp::slotCleanVocabulary ()
 
 void kvoctrainApp::slotCreateRandom()
 {
-   bool ok = FALSE;
+   bool ok = false;
    int res = KInputDialog::getInteger(i18n( "Entries in Lesson" ),
                 i18n( "Enter number of entries in lesson:" ), Prefs::entriesPerLesson(), 1, 1000, 1, &ok, this );
    if (!ok)
