@@ -842,8 +842,8 @@ void KWordQuizView::doVocabSpecChar( )
   if (dlgSpecChar==0)
   {
     dlgSpecChar = new DlgSpecChar( this, "insert special char", f, c, false );
-    connect( dlgSpecChar, TQT_SIGNAL(insertChar(TQChar)), this, TQT_SLOT(slotSpecChar(TQChar)));
-    connect( dlgSpecChar, TQT_SIGNAL( finished() ), this, TQT_SLOT( slotDlgSpecCharClosed() ) );
+    connect( dlgSpecChar, TQ_SIGNAL(insertChar(TQChar)), this, TQ_SLOT(slotSpecChar(TQChar)));
+    connect( dlgSpecChar, TQ_SIGNAL( finished() ), this, TQ_SLOT( slotDlgSpecCharClosed() ) );
   }
   dlgSpecChar->show();
 }
@@ -852,8 +852,8 @@ void KWordQuizView::slotDlgSpecCharClosed( )
 {
   if ( dlgSpecChar )
   {
-    disconnect( dlgSpecChar, TQT_SIGNAL(insertChar(TQChar)), this, TQT_SLOT(slotSpecChar(TQChar)));
-    disconnect( dlgSpecChar, TQT_SIGNAL( finished() ), this, TQT_SLOT( slotDlgSpecCharClosed() ) );
+    disconnect( dlgSpecChar, TQ_SIGNAL(insertChar(TQChar)), this, TQ_SLOT(slotSpecChar(TQChar)));
+    disconnect( dlgSpecChar, TQ_SIGNAL( finished() ), this, TQ_SLOT( slotDlgSpecCharClosed() ) );
     dlgSpecChar->deleteLater();
     dlgSpecChar = 0L;
   }
@@ -1051,7 +1051,7 @@ void KWordQuizView::slotCheckedAnswer( int i )
 
 bool KWordQuizView::eventFilter( TQObject * o, TQEvent * e )
 {
-  if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(cellEditor))
+  if (o == cellEditor)
   {
     if ( e->type() == TQEvent::KeyPress )
     {
