@@ -3,14 +3,14 @@
 
 #include "kzoommainwindow.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class BaseInterface;
 class TDEToggleAction;
 class KKeyDialog;
 class TDEConfigDialog;
 
-class KDE_EXPORT BaseMainWindow : public KZoomMainWindow
+class TDE_EXPORT BaseMainWindow : public KZoomMainWindow
 {
     TQ_OBJECT
   
