@@ -4,9 +4,9 @@
 #include "mp_board.h"
 #include "mp_simple_types.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
-class KDE_EXPORT MPSimpleBoard : public MPBoard
+class TDE_EXPORT MPSimpleBoard : public MPBoard
 {
  TQ_OBJECT
   
