@@ -623,8 +623,8 @@ ExtDateTime::ExtDateTime( const ExtDate &date, const TQTime &time )
 /*!
     \fn bool ExtDateTime::isNull() const
 
-    Returns TRUE if both the date and the time are null; otherwise
-    returns FALSE. A null datetime is invalid.
+    Returns true if both the date and the time are null; otherwise
+    returns false. A null datetime is invalid.
 
     \sa ExtDate::isNull(), TQTime::isNull()
 */
@@ -632,8 +632,8 @@ ExtDateTime::ExtDateTime( const ExtDate &date, const TQTime &time )
 /*!
     \fn bool ExtDateTime::isValid() const
 
-    Returns TRUE if both the date and the time are valid; otherwise
-    returns FALSE.
+    Returns true if both the date and the time are valid; otherwise
+    returns false.
 
     \sa ExtDate::isValid(), TQTime::isValid()
 */
@@ -948,7 +948,7 @@ int ExtDateTime::secsTo( const ExtDateTime &dt ) const
 
 
 /*!
-    Returns TRUE if this datetime is equal to \a dt; otherwise returns FALSE.
+    Returns true if this datetime is equal to \a dt; otherwise returns false.
 
     \sa operator!=()
 */
@@ -959,8 +959,8 @@ bool ExtDateTime::operator==( const ExtDateTime &dt ) const
 }
 
 /*!
-    Returns TRUE if this datetime is different from \a dt; otherwise
-    returns FALSE.
+    Returns true if this datetime is different from \a dt; otherwise
+    returns false.
 
     \sa operator==()
 */
@@ -971,8 +971,8 @@ bool ExtDateTime::operator!=( const ExtDateTime &dt ) const
 }
 
 /*!
-    Returns TRUE if this datetime is earlier than \a dt; otherwise
-    returns FALSE.
+    Returns true if this datetime is earlier than \a dt; otherwise
+    returns false.
 */
 
 bool ExtDateTime::operator<( const ExtDateTime &dt ) const
@@ -983,8 +983,8 @@ bool ExtDateTime::operator<( const ExtDateTime &dt ) const
 }
 
 /*!
-    Returns TRUE if this datetime is earlier than or equal to \a dt;
-    otherwise returns FALSE.
+    Returns true if this datetime is earlier than or equal to \a dt;
+    otherwise returns false.
 */
 
 bool ExtDateTime::operator<=( const ExtDateTime &dt ) const
@@ -995,8 +995,8 @@ bool ExtDateTime::operator<=( const ExtDateTime &dt ) const
 }
 
 /*!
-    Returns TRUE if this datetime is later than \a dt; otherwise
-    returns FALSE.
+    Returns true if this datetime is later than \a dt; otherwise
+    returns false.
 */
 
 bool ExtDateTime::operator>( const ExtDateTime &dt ) const
@@ -1007,8 +1007,8 @@ bool ExtDateTime::operator>( const ExtDateTime &dt ) const
 }
 
 /*!
-    Returns TRUE if this datetime is later than or equal to \a dt;
-    otherwise returns FALSE.
+    Returns true if this datetime is later than or equal to \a dt;
+    otherwise returns false.
 */
 
 bool ExtDateTime::operator>=( const ExtDateTime &dt ) const
@@ -1121,12 +1121,12 @@ ExtDateTime ExtDateTime::fromString( const TQString& s, TQt::DateFormat f )
 
 
 #ifndef TQT_NO_DATASTREAM
-KDE_EXPORT TQDataStream &operator<<( TQDataStream & ostream, const ExtDate & date)
+TDE_EXPORT TQDataStream &operator<<( TQDataStream & ostream, const ExtDate & date)
 {
 	return ostream << (TQ_UINT32)(date.jd());
 }
 
-KDE_EXPORT TQDataStream &operator>>( TQDataStream & ostream, ExtDate & date)
+TDE_EXPORT TQDataStream &operator>>( TQDataStream & ostream, ExtDate & date)
 {
 	TQ_UINT32 julday;
 	ostream >> julday;
@@ -1134,14 +1134,14 @@ KDE_EXPORT TQDataStream &operator>>( TQDataStream & ostream, ExtDate & date)
 	return ostream;
 }
 
-KDE_EXPORT TQDataStream &operator<<( TQDataStream & ostream, const ExtDateTime & dt)
+TDE_EXPORT TQDataStream &operator<<( TQDataStream & ostream, const ExtDateTime & dt)
 {
 	ostream << dt.d;
 	ostream << dt.t;
 	return ostream;
 }
 
-KDE_EXPORT TQDataStream &operator>>( TQDataStream & ostream, ExtDateTime & dt)
+TDE_EXPORT TQDataStream &operator>>( TQDataStream & ostream, ExtDateTime & dt)
 {
 	ostream >> dt.d >> dt.t;
 	return ostream;
