@@ -35,9 +35,9 @@ TestWidget::TestWidget( TQWidget *p, const char *name ) : TDEMainWindow( p, name
 	kdp = new KDatePicker(w);
 	edp = new ExtDatePicker(w);
 	kdpEdit = new KLineEdit(w);
-	kdpEdit->setReadOnly( TRUE );
+	kdpEdit->setReadOnly( true );
 	edpEdit = new KLineEdit(w);
-	edpEdit->setReadOnly( TRUE );
+	edpEdit->setReadOnly( true );
 
 	kdw = new KDateWidget( TQDate::currentDate(), w );
 	edw = new ExtDateWidget( ExtDate::currentDate(), w );
@@ -53,8 +53,8 @@ TestWidget::TestWidget( TQWidget *p, const char *name ) : TDEMainWindow( p, name
 
 	setCentralWidget(w);
 
-	connect( kdp, TQT_SIGNAL( dateChanged(TQDate) ), this, TQT_SLOT( slotKDateChanged(TQDate) ) );
-	connect( edp, TQT_SIGNAL( dateChanged(const ExtDate&) ), this, TQT_SLOT( slotExtDateChanged(const ExtDate&) ) );
+	connect( kdp, TQ_SIGNAL( dateChanged(TQDate) ), this, TQ_SLOT( slotKDateChanged(TQDate) ) );
+	connect( edp, TQ_SIGNAL( dateChanged(const ExtDate&) ), this, TQ_SLOT( slotExtDateChanged(const ExtDate&) ) );
 }
 
 void TestWidget::slotKDateChanged(TQDate d) {
