@@ -70,7 +70,7 @@ void KGameProgress::initialize()
 	use_supplied_bar_color = false;
 	bar_pixmap = 0;
 	bar_style = Solid;
-	text_enabled = TRUE;
+	text_enabled = true;
 	setBackgroundMode( PaletteBackground );
 	connect(kapp, TQ_SIGNAL(appearanceChanged()), this, TQ_SLOT(paletteChange()));
 	paletteChange();
@@ -196,13 +196,13 @@ int KGameProgress::recalcValue(int range)
 
 void KGameProgress::valueChange()
 {
-	repaint(contentsRect(), FALSE);
+	repaint(contentsRect(), false);
 	emit percentageChanged(recalcValue(100));
 }
 
 void KGameProgress::rangeChange()
 {
-	repaint(contentsRect(), FALSE);
+	repaint(contentsRect(), false);
 	emit percentageChanged(recalcValue(100));
 }
 
