@@ -36,7 +36,7 @@
   *  tdeio_littleprogress_dlg (it looks similar)
   */
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class KMMainWidget;
 class KProgress;
@@ -51,9 +51,9 @@ class SSLLabel;
 class ProgressItem;
 class ProgressDialog;
 
-class KDE_EXPORT StatusbarProgressWidget : public TQFrame {
+class TDE_EXPORT StatusbarProgressWidget : public TQFrame {
 
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
