@@ -93,7 +93,7 @@ protected:
 typedef WId Window;
 #endif
 
-KDE_EXPORT int main(int argc, char *argv[])
+TDE_EXPORT int main(int argc, char *argv[])
 {
     TDELocale::setMainCatalogue("libtdescreensaver");
     TDECmdLineArgs::init(argc, argv, kss_applicationName, kss_description, kss_version);
