@@ -8,17 +8,17 @@
 
 extern "C"
 {
-Plugin *create_plugin()
-{
-	TDEGlobal::locale()->insertCatalogue("nexscope");
-	return new NexPlugin();
-}
+	TDE_EXPORT Plugin* create_plugin()
+	{
+		TDEGlobal::locale()->insertCatalogue("nexscope");
+		return new NexPlugin();
+	}
 }
 
 
 NexPlugin::NexPlugin()
 {
-	connect(&process, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(processExited(TDEProcess *)));
+	connect(&process, TQ_SIGNAL(processExited(TDEProcess *)), this, TQ_SLOT(processExited(TDEProcess *)));
 }
 
 NexPlugin::~NexPlugin()
