@@ -6,7 +6,7 @@
 
 class NexPlugin : public TQObject, public Plugin
 {
-Q_OBJECT
+TQ_OBJECT
   
 	
 public:
