@@ -219,7 +219,7 @@ WidgetView( TQWidget parent, String name )
     // put something in it
     TQPixmap openIcon = new TQPixmap( fileopen );
     TQToolButton  toolb = new TQToolButton( new TQIconSet(openIcon), "toolbutton 1",
-					   "", this, SLOT("open()"),
+					   "", this, TQ_SLOT("open()"),
 					   tools, "open file" );
     TQWhatsThis.add( toolb, "This is a <b>TQToolButton</b>. It lives in a "
 		     + "TQToolBar. This particular button doesn't do anything "
@@ -227,13 +227,13 @@ WidgetView( TQWidget parent, String name )
 
     TQPixmap saveIcon = new TQPixmap( filesave );
     toolb = new TQToolButton( new TQIconSet(saveIcon), "toolbutton 2", "",
-			     this, SLOT("dummy()"),
+			     this, TQ_SLOT("dummy()"),
 			     tools, "save file" );
     TQWhatsThis.add( toolb, "This is also a <b>TQToolButton</b>." );
 
     TQPixmap  printIcon = new TQPixmap( fileprint );
     toolb = new TQToolButton( new TQIconSet(printIcon), "toolbutton 3", "",
-			     this, SLOT("dummy()"),
+			     this, TQ_SLOT("dummy()"),
 			     tools, "print file" );
     TQWhatsThis.add( toolb, "This is the third <b>TQToolButton</b>.");
 
@@ -265,10 +265,10 @@ WidgetView( TQWidget parent, String name )
     int id;
     id = popup.insertItem( "&New" );
     popup.setItemEnabled( id, false );
-    id = popup.insertItem( new TQIconSet(openIcon), "&Open", this, SLOT(" open()") );
+    id = popup.insertItem( new TQIconSet(openIcon), "&Open", this, TQ_SLOT(" open()") );
 
     popup.insertSeparator();
-    popup.insertItem( "&Quit", tqApp(), SLOT("quit()"), new TQKeySequence(CTRL+Key_Q) );
+    popup.insertItem( "&Quit", tqApp(), TQ_SLOT("quit()"), new TQKeySequence(CTRL+Key_Q) );
 
 
     textStylePopup = popup = new TQPopupMenu( this );
@@ -294,8 +294,8 @@ WidgetView( TQWidget parent, String name )
     f = font();
     f.setStrikeOut( true );
     id = popup.insertItem( new MyMenuItem( "&Strike", f ) );
-    connect( textStylePopup, SIGNAL("activated(int)"),
-	     this, SLOT("popupSelected(int)") );
+    connect( textStylePopup, TQ_SIGNAL("activated(int)"),
+	     this, TQ_SLOT("popupSelected(int)") );
 */
     // Create an analog and a digital clock
     aclock = new AnalogClock( central );
@@ -317,7 +317,7 @@ WidgetView( TQWidget parent, String name )
     TQPushButton pb;
     pb = new TQPushButton( "&Push button 1", central, "button1" );
     grid.addWidget( pb, 0, 0, AlignVCenter );
-    connect( pb, SIGNAL("clicked()"), SLOT("button1Clicked()") );
+    connect( pb, TQ_SIGNAL("clicked()"), TQ_SLOT("button1Clicked()") );
     TQToolTip.add( pb, "push button 1" );
     TQWhatsThis.add( pb, "This is a <b>TQPushButton</b>.<br>"
 		     + "Click it and watch...<br>"
@@ -336,8 +336,8 @@ WidgetView( TQWidget parent, String name )
     // Create a label containing a TQMovie
     movie = new TQMovie( MOVIEFILENAME );
     movielabel = new TQLabel( central, "label0" );
-    movie.connectStatus(this, SLOT("movieStatus(int)"));
-    movie.connectUpdate(this, SLOT("movieUpdate(TQRect)"));
+    movie.connectStatus(this, TQ_SLOT("movieStatus(int)"));
+    movie.connectUpdate(this, TQ_SLOT("movieUpdate(TQRect)"));
     movielabel.setFrameStyle( TQFrame.Box | TQFrame.Plain );
     movielabel.setMovie( movie );
     movielabel.setFixedSize( 128+movielabel.frameWidth()*2,
@@ -367,7 +367,7 @@ WidgetView( TQWidget parent, String name )
     cb[2].setText( "&Execute" );
     vbox.addWidget( cb[2] );
 
-    connect( bg, SIGNAL("clicked(int)"), SLOT("checkBoxClicked(int)") );
+    connect( bg, TQ_SIGNAL("clicked(int)"), TQ_SLOT("checkBoxClicked(int)") );
 
     TQToolTip.add( cb[0], "check box 1" );
     TQToolTip.add( cb[1], "check box 2" );
@@ -397,7 +397,7 @@ WidgetView( TQWidget parent, String name )
     rb.setText( "&Short Wave" );
     vbox.addWidget(rb);
 
-    connect( bg, SIGNAL("clicked(int)"), SLOT("radioButtonClicked(int)") );
+    connect( bg, TQ_SIGNAL("clicked(int)"), TQ_SLOT("radioButtonClicked(int)") );
     TQToolTip.add( rb, "radio button 3" );
 
     // Create a list box
@@ -410,7 +410,7 @@ WidgetView( TQWidget parent, String name )
 	    lb.insertItem( str );
     }
     grid.addMultiCellWidget( lb, 2, 4, 0, 0 );
-    connect( lb, SIGNAL("selected(int)"), SLOT("listBoxItemSelected(int)") );
+    connect( lb, TQ_SIGNAL("selected(int)"), TQ_SLOT("listBoxItemSelected(int)") );
     TQToolTip.add( lb, "list box" );
 //    new MyWhatsThis( lb );
 
@@ -425,7 +425,7 @@ WidgetView( TQWidget parent, String name )
     sb.setFocusPolicy( TQWidget.TabFocus );
     vbox.addWidget( sb );
 
-    connect( sb, SIGNAL("valueChanged(int)"), SLOT("sliderValueChanged(int)") );
+    connect( sb, TQ_SIGNAL("valueChanged(int)"), TQ_SLOT("sliderValueChanged(int)") );
     TQToolTip.add( sb, "slider" );
     TQWhatsThis.add( sb, "This is a <b>TQSlider</b>. "
 		     + "The tick marks are optional."
@@ -438,8 +438,8 @@ WidgetView( TQWidget parent, String name )
     combo.insertItem( "blue" );
     combo.insertItem( "red" );
     vbox.addWidget( combo );
-    connect( combo, SIGNAL("activated(int)"),
-	     this, SLOT("comboBoxItemActivated(int)") );
+    connect( combo, TQ_SIGNAL("activated(int)"),
+	     this, TQ_SLOT("comboBoxItemActivated(int)") );
     TQToolTip.add( combo, "read-only combo box" );
 
     // Create an editable combo box
@@ -450,8 +450,8 @@ WidgetView( TQWidget parent, String name )
     edCombo.insertItem( "Alterable" );
     edCombo.insertItem( "Inconstant" );
     vbox.addWidget( edCombo );
-    connect( edCombo, SIGNAL("activated(String)"),
-	     this, SLOT("edComboBoxItemActivated(String)") );
+    connect( edCombo, TQ_SIGNAL("activated(String)"),
+	     this, TQ_SLOT("edComboBoxItemActivated(String)") );
     TQToolTip.add( edCombo, "editable combo box" );
 
     edCombo.setAutoCompletion( true );
@@ -463,8 +463,8 @@ WidgetView( TQWidget parent, String name )
     TQSpinBox spin = new TQSpinBox( 0, 10, 1, central, "spin" );
     spin.setSuffix(" mm");
     spin.setSpecialValueText( "Auto" );
-    connect( spin, SIGNAL(" valueChanged(String)"),
-	     SLOT(" spinBoxValueChanged(String)") );
+    connect( spin, TQ_SIGNAL(" valueChanged(String)"),
+	     TQ_SLOT(" spinBoxValueChanged(String)") );
     TQToolTip.add( spin, "spin box" );
     TQWhatsThis.add( spin, "This is a <b>TQSpinBox</b>. "
 		     + "You can chose values in a given range "
@@ -514,8 +514,8 @@ WidgetView( TQWidget parent, String name )
 
 
     grid.addMultiCellWidget( le, 4, 4, 1, 2 );
-    connect( le, SIGNAL("textChanged(String)"),
-	     SLOT("lineEditTextChanged(String)") );
+    connect( le, TQ_SIGNAL("textChanged(String)"),
+	     TQ_SLOT("lineEditTextChanged(String)") );
     TQToolTip.add( le, "single line editor" );
     TQWhatsThis.add( le, "This is a <b>TQLineEdit</b>, you can enter a "
 		     + "single line of text in it. "
@@ -536,14 +536,14 @@ WidgetView( TQWidget parent, String name )
     split.setOpaqueResize( true );
     topLayout.addWidget( split, 1 );
     TQListView lv = new MyListView( split );
-    connect(lv, SIGNAL("selectionChanged()"),
-	    this, SLOT(" selectionChanged()") );
-    connect(lv, SIGNAL("selectionChanged(TQListViewItem)"),
-	    this, SLOT(" selectionChanged(TQListViewItem)") );
-    connect(lv, SIGNAL("clicked(TQListViewItem)"),
-	    this, SLOT(" clicked(TQListViewItem)") );
-    connect(lv, SIGNAL("mySelectionChanged(TQListViewItem)"),
-	    this, SLOT(" mySelectionChanged(TQListViewItem)") );
+    connect(lv, TQ_SIGNAL("selectionChanged()"),
+	    this, TQ_SLOT(" selectionChanged()") );
+    connect(lv, TQ_SIGNAL("selectionChanged(TQListViewItem)"),
+	    this, TQ_SLOT(" selectionChanged(TQListViewItem)") );
+    connect(lv, TQ_SIGNAL("clicked(TQListViewItem)"),
+	    this, TQ_SLOT(" clicked(TQListViewItem)") );
+    connect(lv, TQ_SIGNAL("mySelectionChanged(TQListViewItem)"),
+	    this, TQ_SLOT(" mySelectionChanged(TQListViewItem)") );
     lv.addColumn( "One" );
     lv.addColumn( "Two" );
     lv.setAllColumnsShowFocus( true );
@@ -603,7 +603,7 @@ WidgetView( TQWidget parent, String name )
 
     TQAccel a = new TQAccel( this );
     a.connectItem(  a.insertItem( new TQKeySequence(Key_F9) ),
-		     this, SLOT(" showProperties()") );
+		     this, TQ_SLOT(" showProperties()") );
 
     prog = new TQProgressBar( statusBar(), "progress" );
     prog.setTotalSteps( 100 );
