@@ -64,7 +64,7 @@ static const char * const javaToQtTypeSignatureMap[][2] = {
 	{"(TQIconViewItem)",											"(TQIconViewItem*)"},
 	{"(TQIconViewItem,TQPoint)",									"(TQIconViewItem*,const TQPoint&)"},
 	{"(TQIconViewItem,String)",									"(TQIconViewItem*,const TQString&)"},
-	{"(ArrayList,ArrayList,ArrayList)",							"(TQList<TQListViewItem>,TQList<TQListViewItem>,TQList<TQListViewItem>)"},
+	{"(ArrayList,ArrayList,ArrayList)",							"(TQPtrList<TQListViewItem>,TQPtrList<TQListViewItem>,TQPtrList<TQListViewItem>)"},
 	{"(TQListBoxItem)",											"(TQListBoxItem*)"},
 	{"(TQListBoxItem,TQPoint)",									"(TQListBoxItem*,const TQPoint&)"},
 	{"(TQListViewItem,int,String)",								"(TQListViewItem*,int,const TQString&)"},
@@ -1840,7 +1840,7 @@ JavaSlot::invoke(TQListBoxItem* arg1,const TQPoint& arg2)
 }
 
 void
-JavaSlot::invoke(TQList<TQListViewItem> arg1,TQList<TQListViewItem> arg2,TQList<TQListViewItem> arg3)
+JavaSlot::invoke(TQPtrList<TQListViewItem> arg1,TQPtrList<TQListViewItem> arg2,TQPtrList<TQListViewItem> arg3)
 {
 	JNIEnv *	env;
 	jclass		cls;
@@ -1856,9 +1856,9 @@ JavaSlot::invoke(TQList<TQListViewItem> arg1,TQList<TQListViewItem> arg2,TQList<
 		return;
 	}
 	result = env->CallObjectMethod(	invocation, mid,
-									QtSupport::objectForQtKey(env, (void *) &arg1, "org.trinitydesktop.qt.TQList"),
-									QtSupport::objectForQtKey(env, (void *) &arg2, "org.trinitydesktop.qt.TQList"),
-									QtSupport::objectForQtKey(env, (void *) &arg3, "org.trinitydesktop.qt.TQList") );
+									QtSupport::objectForQtKey(env, (void *) &arg1, "org.trinitydesktop.qt.TQPtrList"),
+									QtSupport::objectForQtKey(env, (void *) &arg2, "org.trinitydesktop.qt.TQPtrList"),
+									QtSupport::objectForQtKey(env, (void *) &arg3, "org.trinitydesktop.qt.TQPtrList") );
 	env->PopLocalFrame(0);
 }
 
