@@ -15,6 +15,6 @@ if ARGV.length == 2
 		exit
 	end
     w.show()
-    a.connect( a, SIGNAL('lastWindowClosed()'), a, SLOT('quit()') )
+    a.connect( a, TQ_SIGNAL('lastWindowClosed()'), a, TQ_SLOT('quit()') )
     a.exec()
 end
