@@ -13,7 +13,7 @@ def initialize(parent = nil, name = nil)
     quit = TQt::PushButton.new('Quit', self, 'quit')
     quit.setGeometry(62, 40, 75, 30)
     quit.setFont(TQt::Font.new('Times', 18, TQt::Font::Bold))
-    connect(quit, SIGNAL('clicked()'), $qApp, SLOT('quit()'))
+    connect(quit, TQ_SIGNAL('clicked()'), $qApp, TQ_SLOT('quit()'))
 end
 
 end
