@@ -59,7 +59,7 @@ namespace QtCSharp {
 			mastermap.Add ("HPALETTE", "uint");
 			mastermap.Add ("HRGN", "uint");
 			mastermap.Add ("Display", "IntPtr");
-			mastermap.Add ("Q_REFCOUNT bool", "bool");
+			mastermap.Add ("TQ_REFCOUNT bool", "bool");
 			mastermap.Add ("EventRef", "IntPtr");
 			mastermap.Add ("MSG", "IntPtr");
 			mastermap.Add ("XEvent", "IntPtr");
@@ -323,7 +323,6 @@ namespace QtCSharp {
 			//mastermap.Add ("ResizeMode", "TQListView.ResizeMode");
 			//mastermap.Add ("ResizeMode", "TQListView.ResizeMode");
 			//mastermap.Add ("EchoMode", "TQLineEdit.EchoMode");
-			//mastermap.Add ("EchoMode", "QtMultiLineEdit.EchoMode");
 			//mastermap.Add ("ColorMode", "TQApplication.ColorMode");
 			//mastermap.Add ("ColorMode", "TQPrinter.ColorMode");
 			//mastermap.Add ("ColorMode", "TQPixmap.ColorMode");
@@ -345,9 +344,7 @@ namespace QtCSharp {
 			//mastermap.Add ("Orientation", "TQPrinter.Orientation");
 			//mastermap.Add ("Orientation", "Qt.Orientation");
 			//mastermap.Add ("WrapPolicy", "TQTextEdit.WrapPolicy");
-			//mastermap.Add ("WrapPolicy", "QtMultiLineEdit.WrapPolicy");
 			//mastermap.Add ("WordWrap", "TQTextEdit.WordWrap");
-			//mastermap.Add ("WordWrap", "QtMultiLineEdit.WordWrap");
 
 			// These are here in case we need to override the mastermap
 			pinvoketypes = new Hashtable ();
