@@ -45,7 +45,7 @@ ImageVisualizer::ImageVisualizer( TQWidget *parent, const char *name, const TQSt
     KURLLabel *label = new KURLLabel( this );
     label->setText(i18n("This picture isn't stored\non the local host.\nClick on this label to load it.\n" ) );
     label->setURL( url.prettyURL() );
-    connect(label, TQT_SIGNAL(leftClickedURL(const TQString&)), TQT_SLOT(downloadImage(const TQString&)));
+    connect(label, TQ_SIGNAL(leftClickedURL(const TQString&)), TQ_SLOT(downloadImage(const TQString&)));
     pic = label;
     description = new TQLabel(this);
     description->adjustSize( );
