@@ -35,7 +35,7 @@
 #include <kicontheme.h>
 #include "kiconeffect.h"
 
-#if defined(Q_WS_WIN) || defined(Q_WS_MACX)
+#if defined(TQ_WS_WIN) || defined(TQ_WS_MACX)
 static bool tqt_use_xrender=true;
 static bool tqt_has_xft=true;
 #else
@@ -287,7 +287,7 @@ void TDEIconEffect::toGray(TQImage &img, float value)
     int pixels = (img.depth() > 8) ? img.width()*img.height()
 	    : img.numColors();
     unsigned int *data = img.depth() > 8 ? (unsigned int *) img.bits()
-	    : (unsigned int *) img.tqcolorTable();
+	    : (unsigned int *) img.colorTable();
     int rval, gval, bval, val, alpha, i;
     for (i=0; i<pixels; i++)
     {
@@ -309,7 +309,7 @@ void TDEIconEffect::colorize(TQImage &img, const TQColor &col, float value)
     int pixels = (img.depth() > 8) ? img.width()*img.height()
 	    : img.numColors();
     unsigned int *data = img.depth() > 8 ? (unsigned int *) img.bits()
-	    : (unsigned int *) img.tqcolorTable();
+	    : (unsigned int *) img.colorTable();
     int rval, gval, bval, val, alpha, i;
     float rcol = col.red(), gcol = col.green(), bcol = col.blue();
     for (i=0; i<pixels; i++)
@@ -348,7 +348,7 @@ void TDEIconEffect::colorize(TQImage &img, const TQColor &col, float value)
 void TDEIconEffect::toMonochrome(TQImage &img, const TQColor &black, const TQColor &white, float value) {
    int pixels = (img.depth() > 8) ? img.width()*img.height() : img.numColors();
    unsigned int *data = img.depth() > 8 ? (unsigned int *) img.bits()
-         : (unsigned int *) img.tqcolorTable();
+         : (unsigned int *) img.colorTable();
    int rval, gval, bval, alpha, i;
    int rw = white.red(), gw = white.green(), bw = white.blue();
    int rb = black.red(), gb = black.green(), bb = black.blue();
@@ -400,7 +400,7 @@ void TDEIconEffect::deSaturate(TQImage &img, float value)
     int pixels = (img.depth() > 8) ? img.width()*img.height()
 	    : img.numColors();
     unsigned int *data = (img.depth() > 8) ? (unsigned int *) img.bits()
-	    : (unsigned int *) img.tqcolorTable();
+	    : (unsigned int *) img.colorTable();
     TQColor color;
     int h, s, v, i;
     for (i=0; i<pixels; i++)
@@ -418,7 +418,7 @@ void TDEIconEffect::toGamma(TQImage &img, float value)
     int pixels = (img.depth() > 8) ? img.width()*img.height()
 	    : img.numColors();
     unsigned int *data = (img.depth() > 8) ? (unsigned int *) img.bits()
-	    : (unsigned int *) img.tqcolorTable();
+	    : (unsigned int *) img.colorTable();
     TQColor color;
     int i, rval, gval, bval;
     float gamma;
@@ -743,7 +743,7 @@ TDEIconEffect::visualActivate(TQWidget * widget, TQRect rect)
     TQPainter p(widget);
 
     // Use NotROP to avoid having to repaint the pixmap each time.
-    p.setPen(TQPen(Qt::black, 2, Qt::DotLine));
+    p.setPen(TQPen(TQt::black, 2, TQt::DotLine));
     p.setRasterOp(TQt::NotROP);
 
     // The spacing between the rects we draw.
