@@ -171,7 +171,7 @@ bool TDESocketDevice::setSocketOptions(int opts)
   return true;			// all went well
 }
 
-bool TDESocketDevice::open(TQ_OpenMode)
+bool TDESocketDevice::open(int)
 {
   resetError();
   return false;
@@ -364,12 +364,7 @@ bool TDESocketDevice::disconnect()
   return true;			// all is well
 }
 
-#ifdef USE_QT3
 TQ_LONG TDESocketDevice::bytesAvailable() const
-#endif
-#ifdef USE_QT4
-qint64 TDESocketDevice::bytesAvailable() const
-#endif
 {
   if (m_sockfd == -1)
     return -1;			// there's nothing to read in a closed socket
@@ -419,7 +414,7 @@ static int do_read_common(int sockfd, char *data, TQ_ULONG maxlen, TDESocketAddr
   return 0;
 }
 
-TQT_TQIO_LONG TDESocketDevice::tqreadBlock(char *data, TQT_TQIO_ULONG maxlen)
+TQ_LONG TDESocketDevice::readBlock(char *data, TQ_ULONG maxlen)
 {
   resetError();
   if (m_sockfd == -1)
@@ -440,7 +435,7 @@ TQT_TQIO_LONG TDESocketDevice::tqreadBlock(char *data, TQT_TQIO_ULONG maxlen)
   return retval;
 }
 
-TQT_TQIO_LONG TDESocketDevice::tqreadBlock(char *data, TQT_TQIO_ULONG maxlen, TDESocketAddress &from)
+TQ_LONG TDESocketDevice::readBlock(char *data, TQ_ULONG maxlen, TDESocketAddress &from)
 {
   resetError();
   if (m_sockfd == -1)
@@ -503,12 +498,12 @@ TQ_LONG TDESocketDevice::peekBlock(char *data, TQ_ULONG maxlen, TDESocketAddress
   return retval;
 }
 
-TQT_TQIO_LONG TDESocketDevice::tqwriteBlock(const char *data, TQT_TQIO_ULONG len)
+TQ_LONG TDESocketDevice::writeBlock(const char *data, TQ_ULONG len)
 {
-  return tqwriteBlock(data, len, TDESocketAddress());
+  return writeBlock(data, len, TDESocketAddress());
 }
 
-TQT_TQIO_LONG TDESocketDevice::tqwriteBlock(const char *data, TQT_TQIO_ULONG len, const TDESocketAddress& to)
+TQ_LONG TDESocketDevice::writeBlock(const char *data, TQ_ULONG len, const TDESocketAddress& to)
 {
   resetError();
   if (m_sockfd == -1)
