@@ -45,7 +45,7 @@ class TDECORE_EXPORT KKey
 	 * @see ModFlag
 	 */
 	enum { MOD_FLAG_COUNT = 4 };
-	enum { QtWIN = (Qt::META) };
+	enum { QtWIN = (TQt::META) };
 	/**
 	 * Flags to represent the modifiers. You can combine modifiers
 	 * by ORing them.
@@ -68,7 +68,7 @@ class TDECORE_EXPORT KKey
 	/**
 	 * Creates a new key for the given Qt key code.
 	 * @param keyQt the qt keycode
-	 * @see Qt::Key
+	 * @see TQt::Key
 	 */
 	KKey( int keyQt );
 
@@ -115,7 +115,7 @@ class TDECORE_EXPORT KKey
 	 * Initializes the key with the given Qt key code.
 	 * @param keyQt the qt keycode
 	 * @return true if successful, false otherwise
-	 * @see Qt::Key
+	 * @see TQt::Key
 	 */
 	bool init( int keyQt );
 
@@ -217,7 +217,7 @@ class TDECORE_EXPORT KKey
 	/**
 	 * Returns the qt key code.
 	 * @return the qt key code or 0 if there is no key set.
-	 * @see Qt::Key
+	 * @see TQt::Key
 	 */
 	int keyCodeQt() const;
 
@@ -469,7 +469,7 @@ class TDECORE_EXPORT KKeySequence
 	 */
 	bool operator < ( const KKeySequence& seq ) const
 		{ return compare( seq ) < 0; }
-	// TODO: consider adding Qt::SequenceMatch matches(...) methods for TQKeySequence equivalence
+	// TODO: consider adding TQt::SequenceMatch matches(...) methods for TQKeySequence equivalence
 
 	/**
 	 * Converts this key sequence to a TQKeySequence.
@@ -480,7 +480,7 @@ class TDECORE_EXPORT KKeySequence
 	/**
 	 * Returns the qt key code of the first key.
 	 * @return the qt key code of the first key
-	 * @see Qt::Key
+	 * @see TQt::Key
 	 * @see KKey::keyCodeQt()
 	 */
 	int keyCodeQt() const;
@@ -528,7 +528,7 @@ class TDECORE_EXPORT KKeySequence
 * the below code binds the escape key to the close action.
 *
 * \code
-*  TDEAction *closeAction = KStdAction::close( this, TQT_SLOT( close() ), actionCollection() );
+*  TDEAction *closeAction = KStdAction::close( this, TQ_SLOT( close() ), actionCollection() );
 *  TDEShortcut closeShortcut = closeAction->shortcut();
 *  closeShortcut.append( KKey(Key_Escape));
 *  closeAction->setShortcut(closeShortcut);
@@ -561,7 +561,7 @@ class TDECORE_EXPORT TDEShortcut
 	 * Creates a new shortcut with the given Qt key code
 	 * as the only key sequence.
 	 * @param keyQt the qt keycode
-	 * @see Qt::Key
+	 * @see TQt::Key
 	 */
 	TDEShortcut( int keyQt );
 
@@ -622,7 +622,7 @@ class TDECORE_EXPORT TDEShortcut
 	 * Initializes the shortcut with the given Qt key code
 	 * as the only key sequence.
 	 * @param keyQt the qt keycode
-	 * @see Qt::Key
+	 * @see TQt::Key
 	 */
 	bool init( int keyQt );
 
@@ -686,7 +686,7 @@ class TDECORE_EXPORT TDEShortcut
 	 * Returns the key code of the first key sequence, or
 	 * null if there is no first key sequence.
 	 * @return the key code of the first sequence's first key
-	 * @see Qt::Key
+	 * @see TQt::Key
 	 * @see KKeySequence::keyCodeQt()
 	 */
 	int keyCodeQt() const;
