@@ -349,7 +349,7 @@ void ZeroConfProtocol::newService(DNSSD::RemoteService::Ptr srv)
 
 extern "C"
 {
-	int KDE_EXPORT kdemain( int argc, char **argv )
+	int TDE_EXPORT kdemain( int argc, char **argv )
 	{
 		// TDEApplication is necessary to use other ioslaves
 		putenv(strdup("SESSION_MANAGER="));
