@@ -42,7 +42,7 @@
 #include <tdeparts/browserinterface.h>
 #include <twin.h>
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
 #include <twinmodule.h> // schroder
 #endif
 
@@ -111,7 +111,7 @@ namespace KJS {
     TQGuardedPtr<TDEHTMLPart> part;
   };
 
-#ifdef Q_WS_QWS
+#ifdef TQ_WS_QWS
   class KonquerorFunc : public DOMFunction {
   public:
     KonquerorFunc(ExecState *exec, const Konqueror* k, const char* name)
@@ -160,7 +160,7 @@ Value Screen::get(ExecState *exec, const Identifier &p) const
 
 Value Screen::getValueProperty(ExecState *exec, int token) const
 {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
   KWinModule info(0, KWinModule::INFO_DESKTOP);
 #endif
   TQWidget *thisWidget = Window::retrieveActive(exec)->part()->widget();
@@ -177,7 +177,7 @@ Value Screen::getValueProperty(ExecState *exec, int token) const
     return Number(m.depth());
   }
   case AvailLeft: {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
     TQRect clipped = info.workArea().intersect(sg);
     return Number(clipped.x()-sg.x());
 #else
@@ -185,7 +185,7 @@ Value Screen::getValueProperty(ExecState *exec, int token) const
 #endif
   }
   case AvailTop: {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
     TQRect clipped = info.workArea().intersect(sg);
     return Number(clipped.y()-sg.y());
 #else
@@ -193,7 +193,7 @@ Value Screen::getValueProperty(ExecState *exec, int token) const
 #endif
   }
   case AvailHeight: {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
     TQRect clipped = info.workArea().intersect(sg);
     return Number(clipped.height());
 #else
@@ -201,7 +201,7 @@ Value Screen::getValueProperty(ExecState *exec, int token) const
 #endif
   }
   case AvailWidth: {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
     TQRect clipped = info.workArea().intersect(sg);
     return Number(clipped.width());
 #else
@@ -420,7 +420,7 @@ Window *Window::retrieveWindow(KParts::ReadOnlyPart *p)
   Object obj = Object::dynamicCast( retrieve( p ) );
 #ifndef NDEBUG
   // obj should never be null, except when javascript has been disabled in that part.
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(p);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(p);
   if ( part && part->jScriptEnabled() )
   {
     assert( obj.isValid() );
@@ -447,10 +447,10 @@ Window *Window::retrieveActive(ExecState *exec)
 Value Window::retrieve(KParts::ReadOnlyPart *p)
 {
   assert(p);
-  TDEHTMLPart * part = ::tqqt_cast<TDEHTMLPart *>(p);
+  TDEHTMLPart * part = ::tqt_cast<TDEHTMLPart *>(p);
   KJSProxy *proxy = 0L;
   if (!part) {
-    part = ::tqqt_cast<TDEHTMLPart *>(p->parent());
+    part = ::tqt_cast<TDEHTMLPart *>(p->parent());
     if (part)
       proxy = part->framejScript(p);
   } else
@@ -477,7 +477,7 @@ Location *Window::location() const
 
 ObjectImp* Window::frames( ExecState* exec ) const
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (part)
     return m_frames ? m_frames :
       (const_cast<Window*>(this)->m_frames = new FrameArray(exec, part));
@@ -515,7 +515,7 @@ bool Window::hasProperty(ExecState *exec, const Identifier &p) const
   if (Lookup::findEntry(&WindowTable, p))
     return true;
 
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (!part)
       return false;
 
@@ -584,7 +584,7 @@ Value Window::get(ExecState *exec, const Identifier &p) const
   }
 
   const HashEntry* entry = Lookup::findEntry(&WindowTable, p);
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
 
   // properties that work on all windows
   if (entry) {
@@ -848,7 +848,7 @@ Value Window::get(ExecState *exec, const Identifier &p) const
       const_cast<Window *>(this)->put(exec, "clientInformation", nav, DontDelete|ReadOnly|Internal);
       return nav;
     }
-#ifdef Q_WS_QWS
+#ifdef TQ_WS_QWS
     case _Konqueror: {
       Value k( new Konqueror(part) );
       const_cast<Window *>(this)->put(exec, "konqueror", k, DontDelete|ReadOnly|Internal);
@@ -860,7 +860,7 @@ Value Window::get(ExecState *exec, const Identifier &p) const
     case OuterHeight:
     case OuterWidth:
     {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
       if (!part->widget())
         return Number(0);
       KWin::WindowInfo inf = KWin::windowInfo(part->widget()->topLevelWidget()->winId());
@@ -1084,7 +1084,7 @@ void Window::put(ExecState* exec, const Identifier &propertyName, const Value &v
     default:
       break;
     }
-    TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+    TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
     if (part) {
     switch( entry->value ) {
     case Status: {
@@ -1221,7 +1221,7 @@ bool Window::toBoolean(ExecState *) const
 
 DOM::AbstractView Window::toAbstractView() const
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (!part)
     return DOM::AbstractView();
   return part->document().defaultView();
@@ -1231,7 +1231,7 @@ void Window::scheduleClose()
 {
   kdDebug(6070) << "Window::scheduleClose window.close() " << m_frame << endl;
   Q_ASSERT(winq);
-  TQTimer::singleShot( 0, winq, TQT_SLOT( timeoutClose() ) );
+  TQTimer::singleShot( 0, winq, TQ_SLOT( timeoutClose() ) );
 }
 
 void Window::closeNow()
@@ -1239,7 +1239,7 @@ void Window::closeNow()
   if (m_frame.isNull() || m_frame->m_part.isNull()) {
     kdDebug(6070) << k_funcinfo << "part is deleted already" << endl;
   } else {
-    TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+    TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
     if (!part) {
       kdDebug(6070) << "closeNow on non TDEHTML part" << endl;
     } else {
@@ -1287,7 +1287,7 @@ bool Window::checkIsSafeScript(KParts::ReadOnlyPart *activePart) const
    if ( activePart == m_frame->m_part ) // Not calling from another frame, no problem.
      return true;
 
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (!part)
     return true; // not a TDEHTMLPart
 
@@ -1300,7 +1300,7 @@ bool Window::checkIsSafeScript(KParts::ReadOnlyPart *activePart) const
     return false;
   }
 
-  TDEHTMLPart *activeTDEHTMLPart = ::tqqt_cast<TDEHTMLPart *>(activePart);
+  TDEHTMLPart *activeTDEHTMLPart = ::tqt_cast<TDEHTMLPart *>(activePart);
   if (!activeTDEHTMLPart)
     return true; // not a TDEHTMLPart
 
@@ -1326,7 +1326,7 @@ bool Window::checkIsSafeScript(KParts::ReadOnlyPart *activePart) const
 
 void Window::setListener(ExecState *exec, int eventId, Value func)
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (!part || !isSafeScript(exec))
     return;
   DOM::DocumentImpl *doc = static_cast<DOM::DocumentImpl*>(part->htmlDocument().handle());
@@ -1338,7 +1338,7 @@ void Window::setListener(ExecState *exec, int eventId, Value func)
 
 Value Window::getListener(ExecState *exec, int eventId) const
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (!part || !isSafeScript(exec))
     return Undefined();
   DOM::DocumentImpl *doc = static_cast<DOM::DocumentImpl*>(part->htmlDocument().handle());
@@ -1356,7 +1356,7 @@ Value Window::getListener(ExecState *exec, int eventId) const
 JSEventListener *Window::getJSEventListener(const Value& val, bool html)
 {
   // This function is so hot that it's worth coding it directly with imps.
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (!part || val.type() != ObjectType)
     return 0;
 
@@ -1432,8 +1432,8 @@ void Window::setCurrentEvent( DOM::Event *evt )
 void Window::goURL(ExecState* exec, const TQString& url, bool lockHistory)
 {
   Window* active = Window::retrieveActive(exec);
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
-  TDEHTMLPart *active_part = ::tqqt_cast<TDEHTMLPart *>(active->part());
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *active_part = ::tqt_cast<TDEHTMLPart *>(active->part());
   // Complete the URL using the "active part" (running interpreter)
   if (active_part && part) {
     if (url[0] == TQChar('#')) {
@@ -1469,7 +1469,7 @@ void Window::delayedGoHistory( int steps )
 
 void Window::goHistory( int steps )
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if(!part)
       // TODO history readonlypart
     return;
@@ -1487,7 +1487,7 @@ void Window::goHistory( int steps )
 
 void KJS::Window::resizeTo(TQWidget* tl, int width, int height)
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if(!part)
       // TODO resizeTo readonlypart
     return;
@@ -1530,7 +1530,7 @@ void KJS::Window::resizeTo(TQWidget* tl, int width, int height)
 
 Value Window::openWindow(ExecState *exec, const List& args)
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
   if (!part)
     return Undefined();
   TDEHTMLView *widget = part->view();
@@ -1543,7 +1543,7 @@ Value Window::openWindow(ExecState *exec, const List& args)
   KURL url;
   if (!str.isEmpty())
   {
-    TDEHTMLPart* p = ::tqqt_cast<TDEHTMLPart *>(Window::retrieveActive(exec)->m_frame->m_part);
+    TDEHTMLPart* p = ::tqt_cast<TDEHTMLPart *>(Window::retrieveActive(exec)->m_frame->m_part);
     if ( p )
       url = p->htmlDocument().completeURL(str).string();
     if ( !p ||
@@ -1601,7 +1601,7 @@ Value Window::openWindow(ExecState *exec, const List& args)
 
 Value Window::executeOpenWindow(ExecState *exec, const KURL& url, const TQString& frameName, const TQString& features)
 {
-    TDEHTMLPart *p = ::tqqt_cast<TDEHTMLPart *>(m_frame->m_part);
+    TDEHTMLPart *p = ::tqt_cast<TDEHTMLPart *>(m_frame->m_part);
     TDEHTMLView *widget = p->view();
     KParts::WindowArgs winargs;
 
@@ -1702,7 +1702,7 @@ Value Window::executeOpenWindow(ExecState *exec, const KURL& url, const TQString
     // request window (new or existing if framename is set)
     KParts::ReadOnlyPart *newPart = 0L;
     emit p->browserExtension()->createNewWindow(KURL(), uargs,winargs,newPart);
-    if (newPart && ::tqqt_cast<TDEHTMLPart*>(newPart)) {
+    if (newPart && ::tqt_cast<TDEHTMLPart*>(newPart)) {
       TDEHTMLPart *tdehtmlpart = static_cast<TDEHTMLPart*>(newPart);
       //tqDebug("opener set to %p (this Window's part) in new Window %p  (this Window=%p)",part,win,window);
       tdehtmlpart->setOpener(p);
@@ -1734,7 +1734,7 @@ void Window::forgetSuppressedWindows()
 
 void Window::showSuppressedWindows()
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>( m_frame->m_part );
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>( m_frame->m_part );
   KJS::Interpreter *interpreter = part->jScript()->interpreter();
   ExecState *exec = interpreter->globalExec();
 
@@ -1759,7 +1759,7 @@ Value WindowFunc::tryCall(ExecState *exec, Object &thisObj, const List &args)
   Window *window = static_cast<Window *>(thisObj.imp());
   TQString str, str2;
 
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(window->m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(window->m_frame->m_part);
   if (!part)
     return Undefined();
 
@@ -2113,7 +2113,7 @@ ScheduledAction::ScheduledAction(TQString _code, DateTimeMS _nextTime, int _inte
 
 bool ScheduledAction::execute(Window *window)
 {
-  TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart *>(window->m_frame->m_part);
+  TDEHTMLPart *part = ::tqt_cast<TDEHTMLPart *>(window->m_frame->m_part);
   if (!part || !part->jScriptEnabled())
     return false;
   ScriptInterpreter *interpreter = static_cast<ScriptInterpreter *>(part->jScript()->interpreter());
@@ -2169,8 +2169,8 @@ WindowQObject::WindowQObject(Window *w)
   if ( !parent->m_frame )
       kdDebug(6070) << "WARNING: null part in " << k_funcinfo << endl;
   else
-      connect( parent->m_frame, TQT_SIGNAL( destroyed() ),
-               this, TQT_SLOT( parentDestroyed() ) );
+      connect( parent->m_frame, TQ_SIGNAL( destroyed() ),
+               this, TQ_SLOT( parentDestroyed() ) );
   pausedTime = 0;
   lastTimerId = 0;
   currentlyDispatching = false;
@@ -2589,7 +2589,7 @@ void Location::put(ExecState *exec, const Identifier &p, const Value &v, int att
     TQString str = v.toString(exec).qstring();
     switch (entry->value) {
     case Href: {
-      TDEHTMLPart* p =::tqqt_cast<TDEHTMLPart*>(Window::retrieveActive(exec)->part());
+      TDEHTMLPart* p =::tqt_cast<TDEHTMLPart*>(Window::retrieveActive(exec)->part());
       if ( p )
         url = p->htmlDocument().completeURL( str ).string();
       else
@@ -2680,7 +2680,7 @@ Value LocationFunc::tryCall(ExecState *exec, Object &thisObj, const List &args)
             id == Location::Replace);
     break;
   case Location::Reload: {
-    TDEHTMLPart *tdehtmlpart = ::tqqt_cast<TDEHTMLPart *>(part);
+    TDEHTMLPart *tdehtmlpart = ::tqt_cast<TDEHTMLPart *>(part);
     if (tdehtmlpart)
       tdehtmlpart->scheduleRedirection(-1, part->url().url(), true/*lock history*/);
     else
@@ -2865,7 +2865,7 @@ Value HistoryFunc::tryCall(ExecState *exec, Object &thisObj, const List &args)
 
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef Q_WS_QWS
+#ifdef TQ_WS_QWS
 
 const ClassInfo Konqueror::info = { "Konqueror", 0, 0, 0 };
 
