@@ -27,7 +27,7 @@
 #include <tdediroperator.h> 
 #include <tdelistview.h>
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tdetempfile.h> 
 #include <netaccess.h>
 
