@@ -68,7 +68,7 @@
 #endif
 #endif
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
 #include <tdestartupinfo.h> // schroder
 #endif
 
@@ -77,8 +77,8 @@
 #include "ltdl.h"
 #include "tdelauncher_cmds.h"
 
-//#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#ifdef Q_WS_X11
+//#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+#ifdef TQ_WS_X11
 //#undef K_WS_QTONLY
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -107,8 +107,8 @@ extern "C" FcBool XftInitFtLibrary (void);
 extern char **environ;
 
 extern int lt_dlopen_flag;
-//#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#ifdef Q_WS_X11
+//#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+#ifdef TQ_WS_X11
 static int X11fd = -1;
 static Display *X11display = 0;
 static int X11_startup_notify_fd = -1;
@@ -119,12 +119,12 @@ static const TDEInstance *s_instance = 0;
 static char sock_file[MAX_SOCK_FILE];
 static char sock_file_old[MAX_SOCK_FILE];
 
-//#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#ifdef Q_WS_X11
+//#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+#ifdef TQ_WS_X11
 #define DISPLAY "DISPLAY"
-#elif defined(Q_WS_QWS)
+#elif defined(TQ_WS_QWS)
 #define DISPLAY "QWS_DISPLAY"
-#elif defined(Q_WS_MACX)
+#elif defined(TQ_WS_MACX)
 #define DISPLAY "MAC_DISPLAY"
 #elif defined(K_WS_QTONLY)
 #define DISPLAY "QT_DISPLAY"
@@ -159,8 +159,8 @@ static struct {
   bool suicide;
 } d;
 
-//#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#ifdef Q_WS_X11
+//#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+#ifdef TQ_WS_X11
 extern "C" {
 int tdeinit_xio_errhandler( Display * );
 int tdeinit_x_errhandler( Display *, XErrorEvent *err );
@@ -219,8 +219,8 @@ static void close_fds()
       close(d.wrapper_old);
       d.wrapper_old = 0;
    }
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11
    if (X11fd >= 0)
    {
       close(X11fd);
@@ -279,8 +279,8 @@ static void setup_tty( const char* tty )
 static int get_current_desktop( Display* disp )
 {
     int desktop = 0; // no desktop by default
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11 // Only X11 supports multiple desktops
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11 // Only X11 supports multiple desktops
     Atom net_current_desktop = XInternAtom( disp, "_NET_CURRENT_DESKTOP", False );
     Atom type_ret;
     int format_ret;
@@ -317,8 +317,8 @@ const char* get_env_var( const char* var, int envc, const char* envs )
     return NULL;
 }
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11 // FIXME(E): Implement for Qt/Embedded
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11 // FIXME(E): Implement for Qt/Embedded
 static void init_startup_info( TDEStartupInfoId& id, const char* bin,
     int envc, const char* envs )
 {
@@ -481,8 +481,8 @@ static pid_t launch(int argc, const char *_name, const char *args,
      return d.fork;
   }
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11
   TDEStartupInfoId startup_id;
   startup_id.initId( startup_id_str );
   if( !startup_id.none())
@@ -549,8 +549,8 @@ static pid_t launch(int argc, const char *_name, const char *args,
         envs++;
      }
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11
       if( startup_id.none())
           TDEStartupInfo::resetStartupEnv();
       else
@@ -744,8 +744,8 @@ static pid_t launch(int argc, const char *_name, const char *args,
         d.launcher_pid = d.fork;
      }
   }
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11
   if( !startup_id.none())
   {
      if( d.fork && d.result == 0 ) // launched successfully
@@ -1290,7 +1290,7 @@ static void handle_launcher_request(int sock = -1)
 #ifndef NDEBUG
        fprintf(stderr,"[tdeinit] Terminating Trinity.\n");
 #endif
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
        tdeinit_xio_errhandler( 0L );
 #endif
    }
@@ -1322,7 +1322,7 @@ static void handle_requests(pid_t waitForPid)
       max_sock = d.wrapper_old;
    if (d.launcher_pid && (d.launcher[0] > max_sock))
       max_sock = d.launcher[0];
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
 //#ifdef _WS_X11
    if (X11fd > max_sock)
       max_sock = X11fd;
@@ -1383,8 +1383,8 @@ static void handle_requests(pid_t waitForPid)
          FD_SET(d.wrapper_old, &rd_set);
       }
       FD_SET(d.deadpipe[0], &rd_set);
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11
       if(X11fd >= 0) FD_SET(X11fd, &rd_set);
 #endif
 
@@ -1442,8 +1442,8 @@ static void handle_requests(pid_t waitForPid)
             return;
       }
 
-//#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#ifdef Q_WS_X11
+//#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+#ifdef TQ_WS_X11
       /* Look for incoming X11 events */
       if((result > 0) && (X11fd >= 0))
       {
@@ -1586,7 +1586,7 @@ int tdeinit_xio_errhandler( Display *disp )
     return 0;
 }
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 int tdeinit_x_errhandler( Display *dpy, XErrorEvent *err )
 {
 #ifndef NDEBUG
@@ -1606,8 +1606,8 @@ int tdeinit_x_errhandler( Display *dpy, XErrorEvent *err )
 }
 #endif
 
-//#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#ifdef Q_WS_X11
+//#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+#ifdef TQ_WS_X11
 // needs to be done sooner than initXconnection() because of also opening
 // another X connection for startup notification purposes
 static void setupX()
@@ -1772,7 +1772,7 @@ int main(int argc, char **argv, char **envp)
    d.lt_dlopen_flag = lt_dlopen_flag;
    lt_dlopen_flag |= LTDL_GLOBAL;
    init_signals();
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
    setupX();
 #endif
 
@@ -1821,8 +1821,8 @@ int main(int argc, char **argv, char **envp)
       handle_requests(pid); // Wait for tdelauncher to be ready
    }
    
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifdef Q_WS_X11
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
+//#ifdef TQ_WS_X11
    X11fd = initXconnection();
 #endif
 
@@ -1837,7 +1837,7 @@ int main(int argc, char **argv, char **envp)
       TQFont::initialize();
       setlocale (LC_ALL, "");
       setlocale (LC_NUMERIC, "C");
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
       if (XSupportsLocale ())
       {
          // Similar to TQApplication::create_xim()
