@@ -107,12 +107,12 @@ KSSLInfoDlg::KSSLInfoDlg(bool secureConnection, TQWidget *parent, const char *na
 
         if (KSSL::doesSSLWork()) {
             button = new KPushButton(KGuiItem(i18n("C&ryptography Configuration..."),"configure"), this);
-            connect(button, TQT_SIGNAL(clicked()), TQT_SLOT(launchConfig()));
+            connect(button, TQ_SIGNAL(clicked()), TQ_SLOT(launchConfig()));
             buttonLayout->addWidget( button );
         }
 
         button = new KPushButton(KStdGuiItem::close(), this);
-        connect(button, TQT_SIGNAL(clicked()), TQT_SLOT(close()));
+        connect(button, TQ_SIGNAL(clicked()), TQ_SLOT(close()));
         buttonLayout->addWidget( button );
 
         button->setFocus();
@@ -188,7 +188,7 @@ void KSSLInfoDlg::setup(KSSLCertificate *cert,
     layout->addWidget(new TQLabel(i18n("Chain:"), this), 0, 0);
     d->_chain = new KComboBox(this);
     layout->addMultiCellWidget(d->_chain, 1, 1, 0, 1);
-    connect(d->_chain, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotChain(int)));
+    connect(d->_chain, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotChain(int)));
 
     d->_chain->clear();
 
@@ -285,14 +285,14 @@ void KSSLInfoDlg::displayCert(KSSLCertificate *x) {
     d->_serialNum->setText(x->getSerialNumber());
 
     cspl = d->_validFrom->palette();
-    if (x->getQDTNotBefore() > TQDateTime::currentDateTime(Qt::UTC))
+    if (x->getQDTNotBefore() > TQDateTime::currentDateTime(TQt::UTC))
         cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
     else cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
     d->_validFrom->setPalette(cspl);
     d->_validFrom->setText(x->getNotBefore());
 
     cspl = d->_validUntil->palette();
-    if (x->getQDTNotAfter() < TQDateTime::currentDateTime(Qt::UTC))
+    if (x->getQDTNotAfter() < TQDateTime::currentDateTime(TQt::UTC))
         cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
     else cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
     d->_validUntil->setPalette(cspl);
@@ -317,8 +317,8 @@ void KSSLInfoDlg::displayCert(KSSLCertificate *x) {
         ksv = ksvl.first();
 
         if (ksv == KSSLCertificate::SelfSigned) {
-            if (x->getQDTNotAfter() > TQDateTime::currentDateTime(Qt::UTC) &&
-                    x->getQDTNotBefore() < TQDateTime::currentDateTime(Qt::UTC)) {
+            if (x->getQDTNotAfter() > TQDateTime::currentDateTime(TQt::UTC) &&
+                    x->getQDTNotBefore() < TQDateTime::currentDateTime(TQt::UTC)) {
                 if (KSSLSigners().useForSSL(*x))
                     ksv = KSSLCertificate::Ok;
             } else {
@@ -411,40 +411,40 @@ void KSSLCertBox::setValues(TQString certName, TQWidget *mailCatcher) {
     TQLabel *label = 0L;
     if (!(tmp = cert.getValue("O")).isEmpty()) {
         label = new TQLabel(i18n("Organization:"), _frame);
-        label->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+        label->setAlignment(TQt::AlignLeft | TQt::AlignTop);
         (new TQLabel(tmp, _frame))->setTextFormat(TQt::PlainText);
     }
     if (!(tmp = cert.getValue("OU")).isEmpty()) {
         label = new TQLabel(i18n("Organizational unit:"), _frame);
-        label->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+        label->setAlignment(TQt::AlignLeft | TQt::AlignTop);
         (new TQLabel(tmp, _frame))->setTextFormat(TQt::PlainText);
     }
     if (!(tmp = cert.getValue("L")).isEmpty()) {
         label = new TQLabel(i18n("Locality:"), _frame);
-        label->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+        label->setAlignment(TQt::AlignLeft | TQt::AlignTop);
         (new TQLabel(tmp, _frame))->setTextFormat(TQt::PlainText);
     }
     if (!(tmp = cert.getValue("ST")).isEmpty()) {
         label = new TQLabel(i18n("Federal State","State:"), _frame);
-        label->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+        label->setAlignment(TQt::AlignLeft | TQt::AlignTop);
         (new TQLabel(tmp, _frame))->setTextFormat(TQt::PlainText);
     }
     if (!(tmp = cert.getValue("C")).isEmpty()) {
         label = new TQLabel(i18n("Country:"), _frame);
-        label->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+        label->setAlignment(TQt::AlignLeft | TQt::AlignTop);
         (new TQLabel(tmp, _frame))->setTextFormat(TQt::PlainText);
     }
     if (!(tmp = cert.getValue("CN")).isEmpty()) {
         label = new TQLabel(i18n("Common name:"), _frame);
-        label->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+        label->setAlignment(TQt::AlignLeft | TQt::AlignTop);
         (new TQLabel(tmp, _frame))->setTextFormat(TQt::PlainText);
     }
     if (!(tmp = cert.getValue("Email")).isEmpty()) {
         label = new TQLabel(i18n("Email:"), _frame);
-        label->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+        label->setAlignment(TQt::AlignLeft | TQt::AlignTop);
         if (mailCatcher) {
             KURLLabel *mail = new KURLLabel(tmp, tmp, _frame);
-            connect(mail, TQT_SIGNAL(leftClickedURL(const TQString &)), mailCatcher, TQT_SLOT(mailClicked(const TQString &)));
+            connect(mail, TQ_SIGNAL(leftClickedURL(const TQString &)), mailCatcher, TQ_SLOT(mailClicked(const TQString &)));
         } else {
             label = new TQLabel(tmp, _frame);
             label->setTextFormat(TQt::PlainText);
