@@ -57,7 +57,7 @@ namespace TDEIO {
  */
 class TDEIO_EXPORT KRun : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   /**
    * Create a KRun object to run the preferred application for a file/URL.
@@ -477,12 +477,12 @@ public:
  */
 class TDEIO_EXPORT TDEProcessRunner : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
 
     static pid_t run(TDEProcess *, const TQString & binName);
-#ifdef Q_WS_X11 // We don't have TDEStartupInfo in Qt/Embedded
+#ifdef TQ_WS_X11 // We don't have TDEStartupInfo in Qt/Embedded
     static pid_t run(TDEProcess *, const TQString & binName, const TDEStartupInfoId& id );
 #endif
 
@@ -497,14 +497,14 @@ class TDEIO_EXPORT TDEProcessRunner : public TQObject
   private:
 
     TDEProcessRunner(TDEProcess *, const TQString & binName);
-#ifdef Q_WS_X11 // We don't have TDEStartupInfo in Qt/Embedded
+#ifdef TQ_WS_X11 // We don't have TDEStartupInfo in Qt/Embedded
     TDEProcessRunner(TDEProcess *, const TQString & binName, const TDEStartupInfoId& id );
 #endif
     TDEProcessRunner();
 
     TDEProcess * process_;
     TQString binName;
-#ifdef Q_WS_X11 // We don't have TDEStartupInfo in Qt/Embedded
+#ifdef TQ_WS_X11 // We don't have TDEStartupInfo in Qt/Embedded
     TDEStartupInfoId id_;
 #endif
 };
