@@ -34,7 +34,7 @@ namespace TDEIO {
      */
     class TDEIO_EXPORT PreviewJob : public TDEIO::Job
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
 	/**
 	 * Creates a new PreviewJob.
