@@ -134,7 +134,7 @@ TDEIO::filesize_t Ftp::UnknownSize = (TDEIO::filesize_t)-1;
 
 using namespace TDEIO;
 
-extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
+extern "C" { TDE_EXPORT int kdemain(int argc, char **argv); }
 
 int kdemain( int argc, char **argv )
 {
@@ -640,7 +640,7 @@ bool Ftp::ftpLogin()
 
     if( needPass )
     {
-      tempbuf = "pass ";
+      tempbuf = "PASS ";
       tempbuf += pass.latin1();
       kdDebug(7102) << "Sending Login password: " << "[protected]" << endl;
       loggedIn = ( ftpSendCmd(tempbuf) && (m_iRespCode == 230) );
