@@ -70,7 +70,7 @@ TabWidget::TabWidget(TQWidget* parent, const char* name)
 
   setHoverCloseButton(true);
 
-  connect(this, TQT_SIGNAL(closeRequest(TQWidget*)), this, TQT_SLOT(closeTab(TQWidget*)));
+  connect(this, TQ_SIGNAL(closeRequest(TQWidget*)), this, TQ_SLOT(closeTab(TQWidget*)));
 }
 
 TabWidget::~TabWidget()
@@ -89,7 +89,7 @@ bool TabWidget::eventFilter(TQObject *obj, TQEvent *e )
   {
     // if we lost a child we uninstall ourself as event filter for the lost
     // child and its children
-    TQObject* pLostChild = TQT_TQOBJECT(((TQChildEvent*)e)->child());
+    TQObject* pLostChild = ((TQChildEvent*)e)->child();
     if ((pLostChild != 0L) && (pLostChild->isWidgetType())) {
        TQObjectList *list = pLostChild->queryList( "TQWidget" );
        list->insert(0, pLostChild);        // add the lost child to the list too, just to save code
@@ -108,7 +108,7 @@ bool TabWidget::eventFilter(TQObject *obj, TQEvent *e )
     // if we got a new child and we are attached to the MDI system we
     // install ourself as event filter for the new child and its children
     // (as we did when we were added to the MDI system).
-    TQObject* pNewChild = TQT_TQOBJECT(((TQChildEvent*)e)->child());
+    TQObject* pNewChild = ((TQChildEvent*)e)->child();
     if ((pNewChild != 0L) && (pNewChild->isWidgetType()))
     {
        TQWidget* pNewWidget = (TQWidget*)pNewChild;
@@ -122,7 +122,7 @@ bool TabWidget::eventFilter(TQObject *obj, TQEvent *e )
           TQWidget* widg = (TQWidget*)o;
           ++it;
           widg->installEventFilter(this);
-          connect(widg, TQT_SIGNAL(destroyed()), this, TQT_SLOT(childDestroyed()));
+          connect(widg, TQ_SIGNAL(destroyed()), this, TQ_SLOT(childDestroyed()));
        }
        delete list;                        // delete the list, not the objects
     }
