@@ -122,7 +122,7 @@ void KDisplayText::ClearEv(bool totally)
   RemoveLinkedList();
   if (totally)
   {
-    TQT_TQOBJECT(this)->killTimers();
+    this->killTimers();
     autoscrollv=0;
     resizeContents(0,0);
     viewport()->repaint(TRUE);
@@ -425,7 +425,7 @@ void KDisplayText::PaintIn(int type)
 	autoscrollv+=qfmetr->lineSpacing();
 	if (b) startTimer(100);
 	else {
-	   TQT_TQOBJECT(this)->killTimers();
+	   this->killTimers();
 	   startTimer(100/(autoscrollv/qfmetr->lineSpacing()+1));
 	}
 	}
@@ -484,7 +484,7 @@ void KDisplayText::gotomsec(ulong i)
             
         }
         
-	TQT_TQOBJECT(this)->killTimers();
+	this->killTimers();
 	autoscrollv=0;
         setContentsPos(0,first_line->ypos);
         viewport()->repaint();
