@@ -146,8 +146,8 @@ Part::~Part()
   if ( m_widget )
   {
     // We need to disconnect first, to avoid calling it !
-    disconnect( m_widget, TQT_SIGNAL( destroyed() ),
-                this, TQT_SLOT( slotWidgetDestroyed() ) );
+    disconnect( m_widget, TQ_SIGNAL( destroyed() ),
+                this, TQ_SLOT( slotWidgetDestroyed() ) );
   }
 
   if ( m_manager )
@@ -195,8 +195,8 @@ void Part::setWidget( TQWidget *widget )
 {
   assert ( !m_widget ); // otherwise we get two connects
   m_widget = widget;
-  connect( m_widget, TQT_SIGNAL( destroyed() ),
-           this, TQT_SLOT( slotWidgetDestroyed() ) );
+  connect( m_widget, TQ_SIGNAL( destroyed() ),
+           this, TQ_SLOT( slotWidgetDestroyed() ) );
 
   // Tell the actionCollection() which widget its
   //  action shortcuts should be connected to.
@@ -367,7 +367,7 @@ bool ReadOnlyPart::openURL( const KURL &url )
     d->m_job = TDEIO::file_copy( m_url, destURL, 0600, true, false, d->m_showProgressInfo );
     d->m_job->setWindow( widget() ? widget()->topLevelWidget() : 0 );
     emit started( d->m_job );
-    connect( d->m_job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotJobFinished ( TDEIO::Job * ) ) );
+    connect( d->m_job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotJobFinished ( TDEIO::Job * ) ) );
     return true;
   }
 }
@@ -639,7 +639,7 @@ bool ReadWritePart::saveToURL()
     }
     d->m_uploadJob = TDEIO::file_move( uploadUrl, m_url, -1, true /*overwrite*/ );
     d->m_uploadJob->setWindow( widget() ? widget()->topLevelWidget() : 0 );
-    connect( d->m_uploadJob, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotUploadFinished (TDEIO::Job *) ) );
+    connect( d->m_uploadJob, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotUploadFinished (TDEIO::Job *) ) );
     return true;
   }
 }
