@@ -28,7 +28,7 @@ class TQSocketNotifier;
 
 class PrintWrapper : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	PrintWrapper();
 
