@@ -27,7 +27,7 @@ class TDEListView;
 
 class ConfFilters : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	ConfFilters(TQWidget *parent = 0, const char *name = 0);
 
