@@ -31,6 +31,8 @@
 #include <tdemessagebox.h>
 #include <tdeapplication.h>
 
+#include <kdebug.h>
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <cmath>
@@ -1095,7 +1097,6 @@ void KRandrSimpleAPI::applyHotplugRules(TQString kde_confdir) {
 }
 
 void KRandrSimpleAPI::applyDisplayGamma(TQPtrList<SingleScreenData> screenInfoArray) {
-	int i;
 	Display *randr_display;
 	XRROutputInfo *output_info;
 	ScreenInfo *randr_screen_info;
@@ -1106,37 +1107,35 @@ void KRandrSimpleAPI::applyDisplayGamma(TQPtrList<SingleScreenData> screenInfoAr
 	if (isValid() == true) {
 		randr_display = tqt_xdisplay();
 		randr_screen_info = read_screen_info(randr_display);
-		for (i = 0; i < screenInfoArray.count(); i++) {
+		for (int i = 0; i < screenInfoArray.count(); i++) {
 			screendata = screenInfoArray.at(i);
 			output_info = randr_screen_info->outputs[i]->info;
 			CrtcInfo *current_crtc = randr_screen_info->outputs[i]->cur_crtc;
 			if (!current_crtc) {
 				continue;
 			}
-			// vvvvvvvvv This chunk of code is borrowed from xrandr vvvvvvvvvv
+			// vvvvvvvvv This chunk of code is based on code from the function set_gamma() of xrandr vvvvvvvvvv
 			int size = XRRGetCrtcGammaSize(randr_display, current_crtc->id);
-			if (!size) {
+			if (size <= 0 || size > 65536) {
+				kdWarning() << "Gamma correction table has wrong size." << endl;
 				continue;
 			}
 			gamma = XRRAllocGamma(size);
 			if (!gamma) {
+				kdWarning() << "Gamma allocation failed." << endl;
 				continue;
 			}
-			for (i = 0; i < size; i++) {
-				if (screendata->gamma_red == 1.0)
-					gamma->red[i] = i << 8;
-				else
-					gamma->red[i] = (pow((double)i/(double)(size-1), (double)screendata->gamma_red) * (double)(size-1)*256);
-
-				if (screendata->gamma_green == 1.0)
-					gamma->green[i] = i << 8;
-				else
-					gamma->green[i] = (pow((double)i/(double)(size-1), (double)screendata->gamma_green) * (double)(size-1)*256);
-
-				if (screendata->gamma_blue == 1.0)
-					gamma->blue[i] = i << 8;
-				else
-					gamma->blue[i] = (pow((double)i/(double)(size-1), (double)screendata->gamma_blue) * (double)(size-1)*256);
+			for (int j = 0; j < size; j++) {
+				if (size == 1) {
+					gamma->red[j] = 0.0;
+					gamma->green[j] = 0.0;
+					gamma->blue[j] = 0.0;
+				}
+				else {
+					gamma->red[j] = fmin(pow((double)j / (double)(size - 1), screendata->gamma_red), 1.0) * 65535.0;
+					gamma->green[j] = fmin(pow((double)j / (double)(size - 1), screendata->gamma_green), 1.0) * 65535.0;
+					gamma->blue[j] = fmin(pow((double)j / (double)(size - 1), screendata->gamma_blue), 1.0) * 65535.0;
+				}
 			}
 			XRRSetCrtcGamma(randr_display, current_crtc->id, gamma);
 			free(gamma);
@@ -1380,8 +1379,13 @@ TQPtrList<SingleScreenData> KRandrSimpleAPI::readCurrentDisplayConfiguration() {
 					//int slot = 127;
 					int slot = 7;
 					int size = XRRGetCrtcGammaSize(randr_display, current_crtc->id);
-					if(size>0) {
-						XRRCrtcGamma *gammastruct = XRRGetCrtcGamma (randr_display, current_crtc->id);
+					XRRCrtcGamma *gammastruct = XRRGetCrtcGamma (randr_display, current_crtc->id);
+					if (size == 1) {
+						screendata->gamma_red = 0.0;
+						screendata->gamma_green = 0.0;
+						screendata->gamma_blue = 0.0;
+					}
+					else if (size > 1) {
 						screendata->gamma_red = log(gammastruct->red[slot]/((size-1.0)*256.0))/log(slot/(size-1.0));
 						screendata->gamma_green = log(gammastruct->green[slot]/((size-1.0)*256.0))/log(slot/(size-1.0));
 						screendata->gamma_blue = log(gammastruct->blue[slot]/((size-1.0)*256.0))/log(slot/(size-1.0));
