@@ -26,7 +26,7 @@
 
 class TDERESOURCES_EXPORT KCMTDEResources : public TDECModule
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KCMTDEResources( TQWidget *parent, const char *name, const TQStringList& );
