@@ -54,21 +54,21 @@
 extern "C"
 {
    /** application name for the libtdescreensaver interface */
-   KDE_EXPORT const char *kss_applicationName = "krotation.kss";
+   TDE_EXPORT const char *kss_applicationName = "krotation.kss";
    /** application description for the libtdescreensaver interface */
-   KDE_EXPORT const char *kss_description =
+   TDE_EXPORT const char *kss_description =
    I18N_NOOP("Simulation of a force free rotating asymmetric body");
    /** application version for the libtdescreensaver interface */
-   KDE_EXPORT const char *kss_version = KROTATION_VERSION;
+   TDE_EXPORT const char *kss_version = KROTATION_VERSION;
 
    /** function to create screen saver object */
-   KDE_EXPORT  KScreenSaver* kss_create(WId id)
+   TDE_EXPORT  KScreenSaver* kss_create(WId id)
    {
       return new KRotationSaver(id);
    }
 
    /** function to create setup dialog for screen saver */
-   KDE_EXPORT TQDialog* kss_setup()
+   TDE_EXPORT TQDialog* kss_setup()
    {
       return new KRotationSetup();
    }
@@ -490,7 +490,7 @@ KRotationSaver::KRotationSaver(WId id)
    glArea->show();              // show gl widget
 
    timer = new TQTimer(this);
-   timer->start(deltaT, TRUE);
+   timer->start(deltaT, true);
    connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(doTimeStep()));
 }
 
@@ -675,7 +675,7 @@ void KRotationSaver::doTimeStep()
    }
 
    glArea->updateGL();
-   timer->start(deltaT, TRUE); // restart timer
+   timer->start(deltaT, true); // restart timer
 }
 
 // public slot of KRotationSaver, forward resize event to public slot of glArea
@@ -696,7 +696,7 @@ KRotationSetup::KRotationSetup(TQWidget* parent, const char* name)
 {
    // the dialog should block, no other control center input should be possible
    // until the dialog is closed
-   setModal(TRUE);
+   setModal(true);
 
    lengthEdit->setValidator(
       new TQDoubleValidator(
