@@ -28,7 +28,7 @@
 class KDETrayModule
     : public KDEDModule
     {
-    Q_OBJECT
+    TQ_OBJECT
     K_DCOP
     public:
         KDETrayModule( const TQCString& obj );
