@@ -104,12 +104,12 @@ KDialogBase::KDialogBase( TQWidget *parent, const char *name, bool modal,
   :KDialog( parent, name, modal, (WFlags)WStyle_DialogBorder ),
    mTopLayout(0), mMainWidget(0), mUrlHelp(0), mJanus(0), mActionSep(0),
    mIsActivated(false), mShowTile(false), mMessageBoxMode(false),
-   mButtonOrientation(Qt::Horizontal), d(new KDialogBasePrivate)
+   mButtonOrientation(TQt::Horizontal), d(new KDialogBasePrivate)
 {
   setCaption( caption );
 
   makeRelay();
-  connect( this, TQT_SIGNAL(layoutHintChanged()), TQT_SLOT(updateGeometry()) );
+  connect( this, TQ_SIGNAL(layoutHintChanged()), TQ_SLOT(updateGeometry()) );
 
   enableButtonSeparator( separator );
   makeButtonBox( buttonMask, defaultButton, user1, user2, user3 );
@@ -126,16 +126,16 @@ KDialogBase::KDialogBase( int dialogFace, const TQString &caption,
   :KDialog( parent, name, modal, (WFlags)WStyle_DialogBorder ),
    mTopLayout(0), mMainWidget(0), mUrlHelp(0), mJanus(0), mActionSep(0),
    mIsActivated(false), mShowTile(false), mMessageBoxMode(false),
-   mButtonOrientation(Qt::Horizontal), d(new KDialogBasePrivate)
+   mButtonOrientation(TQt::Horizontal), d(new KDialogBasePrivate)
 {
   setCaption( caption );
 
   makeRelay();
-  connect( this, TQT_SIGNAL(layoutHintChanged()), TQT_SLOT(updateGeometry()) );
+  connect( this, TQ_SIGNAL(layoutHintChanged()), TQ_SLOT(updateGeometry()) );
 
   mJanus = new KJanusWidget( this, "janus", dialogFace );
-  connect(mJanus, TQT_SIGNAL(aboutToShowPage(TQWidget *)),
-          this, TQT_SIGNAL(aboutToShowPage(TQWidget *)));
+  connect(mJanus, TQ_SIGNAL(aboutToShowPage(TQWidget *)),
+          this, TQ_SIGNAL(aboutToShowPage(TQWidget *)));
 
   if( !mJanus || !mJanus->isValid() ) { return; }
 
@@ -155,16 +155,16 @@ KDialogBase::KDialogBase(  KDialogBase::DialogType dialogFace, WFlags f, TQWidge
   :KDialog( parent, name, modal, f ),
    mTopLayout(0), mMainWidget(0), mUrlHelp(0), mJanus(0), mActionSep(0),
    mIsActivated(false), mShowTile(false), mMessageBoxMode(false),
-   mButtonOrientation(Qt::Horizontal), d(new KDialogBasePrivate)
+   mButtonOrientation(TQt::Horizontal), d(new KDialogBasePrivate)
 {
   setCaption( caption );
 
   makeRelay();
-  connect( this, TQT_SIGNAL(layoutHintChanged()), TQT_SLOT(updateGeometry()) );
+  connect( this, TQ_SIGNAL(layoutHintChanged()), TQ_SLOT(updateGeometry()) );
 
   mJanus = new KJanusWidget( this, "janus", dialogFace );
-  connect(mJanus, TQT_SIGNAL(aboutToShowPage(TQWidget *)),
-          this, TQT_SIGNAL(aboutToShowPage(TQWidget *)));
+  connect(mJanus, TQ_SIGNAL(aboutToShowPage(TQWidget *)),
+          this, TQ_SIGNAL(aboutToShowPage(TQWidget *)));
 
   if( !mJanus || !mJanus->isValid() ) { return; }
 
@@ -183,13 +183,13 @@ KDialogBase::KDialogBase( const TQString &caption, int buttonMask,
   :KDialog( parent, name, modal, (WFlags)WStyle_DialogBorder ),
    mTopLayout(0), mMainWidget(0), mUrlHelp(0), mJanus(0), mActionSep(0),
    mIsActivated(false), mShowTile(false), mMessageBoxMode(true),
-   mButtonOrientation(Qt::Horizontal),mEscapeButton(escapeButton),
+   mButtonOrientation(TQt::Horizontal),mEscapeButton(escapeButton),
    d(new KDialogBasePrivate)
 {
   setCaption( caption );
 
   makeRelay();
-  connect( this, TQT_SIGNAL(layoutHintChanged()), TQT_SLOT(updateGeometry()) );
+  connect( this, TQ_SIGNAL(layoutHintChanged()), TQ_SLOT(updateGeometry()) );
 
   enableButtonSeparator( separator );
 
@@ -235,7 +235,7 @@ void SButton::resize( bool sameWidth, int margin,
     if( s.width() > w ) { w = s.width(); }
   }
 
-  if( orientation == Qt::Horizontal )
+  if( orientation == TQt::Horizontal )
   {
     for( p = list.first(); p; p =  list.next() )
     {
@@ -281,7 +281,7 @@ KDialogBase::delayedDestruct()
 {
    if (isVisible())
       hide();
-   TQTimer::singleShot( 0, this, TQT_SLOT(slotDelayedDestruct()));
+   TQTimer::singleShot( 0, this, TQ_SLOT(slotDelayedDestruct()));
 }
 
 void
@@ -299,7 +299,7 @@ void KDialogBase::setupLayout()
   // mTopLayout = new TQVBoxLayout( this, marginHint(), spacingHint() );
 
 
-  if( mButtonOrientation == Qt::Horizontal )
+  if( mButtonOrientation == TQt::Horizontal )
   {
     mTopLayout = new TQBoxLayout( this, TQBoxLayout::TopToBottom,
 				 marginHint(), spacingHint() );
@@ -349,10 +349,10 @@ void KDialogBase::setButtonBoxOrientation( int orientation )
     mButtonOrientation = orientation;
     if( mActionSep )
     {
-      mActionSep->setOrientation( mButtonOrientation == Qt::Horizontal ?
+      mActionSep->setOrientation( mButtonOrientation == TQt::Horizontal ?
 				  TQFrame::HLine : TQFrame::VLine );
     }
-    if( mButtonOrientation == Qt::Vertical )
+    if( mButtonOrientation == TQt::Vertical )
     {
       enableLinkedHelp(false); // 2000-06-18 Espen: No support for this yet.
     }
@@ -373,15 +373,15 @@ void KDialogBase::makeRelay()
 {
   if( mTile )
   {
-    connect( mTile, TQT_SIGNAL(pixmapChanged()), TQT_SLOT(updateBackground()) );
+    connect( mTile, TQ_SIGNAL(pixmapChanged()), TQ_SLOT(updateBackground()) );
     return;
   }
 
   mTile = new KDialogBaseTile;
   if( mTile )
   {
-    connect( mTile, TQT_SIGNAL(pixmapChanged()), TQT_SLOT(updateBackground()) );
-    connect( tqApp, TQT_SIGNAL(aboutToQuit()), mTile, TQT_SLOT(cleanup()) );
+    connect( mTile, TQ_SIGNAL(pixmapChanged()), TQ_SLOT(updateBackground()) );
+    connect( tqApp, TQ_SIGNAL(aboutToQuit()), mTile, TQ_SLOT(cleanup()) );
   }
 }
 
@@ -396,7 +396,7 @@ void KDialogBase::enableButtonSeparator( bool state )
     }
     mActionSep = new KSeparator( this );
     mActionSep->setFocusPolicy(TQWidget::NoFocus);
-    mActionSep->setOrientation( mButtonOrientation == Qt::Horizontal ?
+    mActionSep->setOrientation( mButtonOrientation == TQt::Horizontal ?
 				TQFrame::HLine : TQFrame::VLine );
     mActionSep->show();
   }
@@ -506,7 +506,7 @@ TQSize KDialogBase::minimumSizeHint() const
   if( d->mButton.box )
   {
     s2 = d->mButton.box->minimumSize();
-    if( mButtonOrientation == Qt::Horizontal )
+    if( mButtonOrientation == TQt::Horizontal )
     {
       s1.rwidth()   = TQMAX( s1.rwidth(), s2.rwidth() );
       s1.rheight() += s2.rheight();
@@ -576,35 +576,35 @@ void KDialogBase::makeButtonBox( int buttonMask, ButtonCode defaultButton,
   {
     KPushButton *pb = d->mButton.append( Help, KStdGuiItem::help() );
 
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotHelp()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotHelp()) );
   }
   if( d->mButton.mask & Default )
   {
     KPushButton *pb = d->mButton.append( Default, KStdGuiItem::defaults() );
 
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotDefault()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotDefault()) );
   }
   if( d->mButton.mask & Details )
   {
     KPushButton *pb = d->mButton.append( Details, TQString() );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotDetails()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotDetails()) );
     setDetails(false);
   }
   if( d->mButton.mask & User3 )
   {
     KPushButton *pb = d->mButton.append( User3, user3 );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotUser3()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotUser3()) );
   }
   if( d->mButton.mask & User2 )
   {
     KPushButton *pb = d->mButton.append( User2, user2 );
     if( mMessageBoxMode )
     {
-      connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotYes()) );
+      connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotYes()) );
     }
     else
     {
-      connect( pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotUser2()) );
+      connect( pb, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotUser2()) );
     }
   }
   if( d->mButton.mask & User1 )
@@ -612,39 +612,39 @@ void KDialogBase::makeButtonBox( int buttonMask, ButtonCode defaultButton,
     KPushButton *pb = d->mButton.append( User1, user1 );
     if( mMessageBoxMode )
     {
-      connect( pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNo()) );
+      connect( pb, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNo()) );
     }
     else
     {
-      connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotUser1()) );
+      connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotUser1()) );
     }
   }
   if( d->mButton.mask & Ok )
   {
     KPushButton *pb = d->mButton.append( Ok, KStdGuiItem::ok() );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotOk()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotOk()) );
   }
   if( d->mButton.mask & Apply )
   {
     KPushButton *pb = d->mButton.append( Apply, KStdGuiItem::apply() );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotApply()) );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(applyPressed()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotApply()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(applyPressed()) );
   }
   if( d->mButton.mask & Try )
   {
     KPushButton *pb = d->mButton.append( Try,
                            i18n( "&Try" ) );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotTry()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotTry()) );
   }
   if( d->mButton.mask & Cancel )
   {
     KPushButton *pb = d->mButton.append( Cancel, KStdGuiItem::cancel() );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotCancel()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotCancel()) );
   }
   if( d->mButton.mask & Close )
   {
     KPushButton *pb = d->mButton.append( Close, KStdGuiItem::close() );
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(slotClose()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(slotClose()) );
   }
 
   if( defaultButton != NoDefault )
@@ -686,7 +686,7 @@ void KDialogBase::setButtonStyle( int style )
     layoutMax = 6;
     layout = layoutRule[ d->mButton.style ];
   }
-  else if (mButtonOrientation == Qt::Horizontal)
+  else if (mButtonOrientation == TQt::Horizontal)
   {
     static const unsigned int layoutRule[5][10] =
     {
@@ -720,7 +720,7 @@ void KDialogBase::setButtonStyle( int style )
   }
 
   TQBoxLayout *lay;
-  if( mButtonOrientation == Qt::Horizontal )
+  if( mButtonOrientation == TQt::Horizontal )
   {
     lay = new TQBoxLayout( d->mButton.box, TQBoxLayout::LeftToRight, 0,
 			  spacingHint());
@@ -1256,8 +1256,8 @@ void KDialogBase::enableLinkedHelp( bool state )
       mUrlHelp->setBackgroundPixmap(*mTile->get());
     }
     mUrlHelp->setMinimumHeight( fontMetrics().height() + marginHint() );
-    connect(mUrlHelp,TQT_SIGNAL(leftClickedURL(const TQString &)),
-	    TQT_SLOT(helpClickedSlot(const TQString &)));
+    connect(mUrlHelp,TQ_SIGNAL(leftClickedURL(const TQString &)),
+	    TQ_SLOT(helpClickedSlot(const TQString &)));
     mUrlHelp->show();
   }
   else
