@@ -422,8 +422,8 @@ void KEditToolbar::init()
 
     setMainWidget(m_widget);
 
-    connect(m_widget, TQT_SIGNAL(enableOk(bool)), TQT_SLOT(acceptOK(bool)));
-    connect(m_widget, TQT_SIGNAL(enableOk(bool)), TQT_SLOT(enableButtonApply(bool)));
+    connect(m_widget, TQ_SIGNAL(enableOk(bool)), TQ_SLOT(acceptOK(bool)));
+    connect(m_widget, TQ_SIGNAL(enableOk(bool)), TQ_SLOT(enableButtonApply(bool)));
     enableButtonApply(false);
 
     setMinimumSize(sizeHint());
@@ -499,8 +499,8 @@ void KEditToolbar::slotDefault()
     setMainWidget(m_widget);
     m_widget->show();
 
-    connect(m_widget, TQT_SIGNAL(enableOk(bool)), TQT_SLOT(acceptOK(bool)));
-    connect(m_widget, TQT_SIGNAL(enableOk(bool)), TQT_SLOT(enableButtonApply(bool)));
+    connect(m_widget, TQ_SIGNAL(enableOk(bool)), TQ_SLOT(acceptOK(bool)));
+    connect(m_widget, TQ_SIGNAL(enableOk(bool)), TQ_SLOT(enableButtonApply(bool)));
 
     enableButtonApply(false);
     emit newToolbarConfig();
@@ -762,8 +762,8 @@ void KEditToolbarWidget::setupLayout()
   m_toolbarCombo->setEnabled(false);
   d->m_comboLabel->setBuddy(m_toolbarCombo);
   d->m_comboSeparator = new KSeparator(this);
-  connect(m_toolbarCombo, TQT_SIGNAL(activated(const TQString&)),
-          this,           TQT_SLOT(slotToolbarSelected(const TQString&)));
+  connect(m_toolbarCombo, TQ_SIGNAL(activated(const TQString&)),
+          this,           TQ_SLOT(slotToolbarSelected(const TQString&)));
 
 //  TQPushButton *new_toolbar = new TQPushButton(i18n("&New"), this);
 //  new_toolbar->setPixmap(BarIcon("document-new", TDEIcon::SizeSmall));
@@ -785,10 +785,10 @@ void KEditToolbarWidget::setupLayout()
   int column2 = m_inactiveList->addColumn(""); // text
   m_inactiveList->setSorting( column2 );
   inactive_label->setBuddy(m_inactiveList);
-  connect(m_inactiveList, TQT_SIGNAL(selectionChanged(TQListViewItem *)),
-          this,           TQT_SLOT(slotInactiveSelected(TQListViewItem *)));
-  connect(m_inactiveList, TQT_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int  )),
-          this,           TQT_SLOT(slotInsertButton()));
+  connect(m_inactiveList, TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+          this,           TQ_SLOT(slotInactiveSelected(TQListViewItem *)));
+  connect(m_inactiveList, TQ_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int  )),
+          this,           TQ_SLOT(slotInsertButton()));
 
   // our list of active actions
   TQLabel *active_label = new TQLabel(i18n("Curr&ent actions:"), this);
@@ -804,14 +804,14 @@ void KEditToolbarWidget::setupLayout()
   m_activeList->setSorting(-1);
   active_label->setBuddy(m_activeList);
 
-  connect(m_inactiveList, TQT_SIGNAL(dropped(TDEListView*,TQDropEvent*,TQListViewItem*)),
-          this,              TQT_SLOT(slotDropped(TDEListView*,TQDropEvent*,TQListViewItem*)));
-  connect(m_activeList, TQT_SIGNAL(dropped(TDEListView*,TQDropEvent*,TQListViewItem*)),
-          this,            TQT_SLOT(slotDropped(TDEListView*,TQDropEvent*,TQListViewItem*)));
-  connect(m_activeList, TQT_SIGNAL(selectionChanged(TQListViewItem *)),
-          this,         TQT_SLOT(slotActiveSelected(TQListViewItem *)));
-  connect(m_activeList, TQT_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int  )),
-          this,           TQT_SLOT(slotRemoveButton()));
+  connect(m_inactiveList, TQ_SIGNAL(dropped(TDEListView*,TQDropEvent*,TQListViewItem*)),
+          this,              TQ_SLOT(slotDropped(TDEListView*,TQDropEvent*,TQListViewItem*)));
+  connect(m_activeList, TQ_SIGNAL(dropped(TDEListView*,TQDropEvent*,TQListViewItem*)),
+          this,            TQ_SLOT(slotDropped(TDEListView*,TQDropEvent*,TQListViewItem*)));
+  connect(m_activeList, TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+          this,         TQ_SLOT(slotActiveSelected(TQListViewItem *)));
+  connect(m_activeList, TQ_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int  )),
+          this,           TQ_SLOT(slotRemoveButton()));
 
   // "change icon" button
   d->m_changeIcon = new KPushButton( i18n( "Change &Icon..." ), this );
@@ -819,8 +819,8 @@ void KEditToolbarWidget::setupLayout()
   d->m_hasKDialog = !kdialogExe.isEmpty();
   d->m_changeIcon->setEnabled( d->m_hasKDialog );
 
-  connect( d->m_changeIcon, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotChangeIcon() ) );
+  connect( d->m_changeIcon, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotChangeIcon() ) );
 
   // The buttons in the middle
   TQIconSet iconSet;
@@ -830,26 +830,26 @@ void KEditToolbarWidget::setupLayout()
   m_upAction->setIconSet( iconSet );
   m_upAction->setEnabled(false);
   m_upAction->setAutoRepeat(true);
-  connect(m_upAction, TQT_SIGNAL(clicked()), TQT_SLOT(slotUpButton()));
+  connect(m_upAction, TQ_SIGNAL(clicked()), TQ_SLOT(slotUpButton()));
 
   m_insertAction = new TQToolButton(this);
   iconSet = TQApplication::reverseLayout() ? SmallIconSet( "back" ) : SmallIconSet( "forward" );
   m_insertAction->setIconSet( iconSet );
   m_insertAction->setEnabled(false);
-  connect(m_insertAction, TQT_SIGNAL(clicked()), TQT_SLOT(slotInsertButton()));
+  connect(m_insertAction, TQ_SIGNAL(clicked()), TQ_SLOT(slotInsertButton()));
 
   m_removeAction = new TQToolButton(this);
   iconSet = TQApplication::reverseLayout() ? SmallIconSet( "forward" ) : SmallIconSet( "back" );
   m_removeAction->setIconSet( iconSet );
   m_removeAction->setEnabled(false);
-  connect(m_removeAction, TQT_SIGNAL(clicked()), TQT_SLOT(slotRemoveButton()));
+  connect(m_removeAction, TQ_SIGNAL(clicked()), TQ_SLOT(slotRemoveButton()));
 
   m_downAction   = new TQToolButton(this);
   iconSet = SmallIconSet( "go-down" );
   m_downAction->setIconSet( iconSet );
   m_downAction->setEnabled(false);
   m_downAction->setAutoRepeat(true);
-  connect(m_downAction, TQT_SIGNAL(clicked()), TQT_SLOT(slotDownButton()));
+  connect(m_downAction, TQ_SIGNAL(clicked()), TQ_SLOT(slotDownButton()));
 
   d->m_helpArea = new TQLabel(this);
   d->m_helpArea->setAlignment( TQt::WordBreak );
@@ -890,7 +890,7 @@ void KEditToolbarWidget::setupLayout()
   changeIcon_layout->addStretch( 1 );
 
   list_layout->addLayout(inactive_layout);
-  list_layout->addLayout(TQT_TQLAYOUT(button_layout));
+  list_layout->addLayout(button_layout);
   list_layout->addLayout(active_layout);
 
   top_layout->addLayout(name_layout);
@@ -1405,8 +1405,8 @@ void KEditToolbarWidget::slotChangeIcon()
   m_activeList->setEnabled( false ); // don't change the current item
   m_toolbarCombo->setEnabled( false ); // don't change the current toolbar
 
-  connect( d->m_kdialogProcess, TQT_SIGNAL( processExited( TDEProcess* ) ),
-           this, TQT_SLOT( slotProcessExited( TDEProcess* ) ) );
+  connect( d->m_kdialogProcess, TQ_SIGNAL( processExited( TDEProcess* ) ),
+           this, TQ_SLOT( slotProcessExited( TDEProcess* ) ) );
 }
 
 void KEditToolbarWidget::slotProcessExited( TDEProcess* )
