@@ -45,7 +45,7 @@
 
 extern "C"
 {
-	KDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
+	TDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
 	{
 		return(new GlowConfigDialog(conf, parent));
 	}
