@@ -463,7 +463,7 @@ void NextClient::initializeButtonsAndTitlebar(TQBoxLayout* titleLayout)
     // Finally, activate all live buttons
     for ( int i = 0; i < MAX_NUM_BUTTONS; i++) {
         if (button[i]) {
-            button[i]->setMouseTracking( TRUE );
+            button[i]->setMouseTracking( true );
         }
     }
 }
