@@ -30,7 +30,7 @@ namespace RiscOS
 
 class StickyButton : public Button
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 
    public:
