@@ -45,7 +45,7 @@ class Bridge;
 
 class Client : public TQObject, public KDecorationDefines
     {
-    Q_OBJECT
+    TQ_OBJECT
     public:
         Client( Workspace *ws );
         Window window() const;
@@ -232,6 +232,15 @@ class Client : public TQObject, public KDecorationDefines
         void resizeWithChecks( int w, int h, ForceGeometry_t force = NormalGeometrySet );
         void resizeWithChecks( const TQSize& s, ForceGeometry_t force = NormalGeometrySet );
         void keepInArea( TQRect area, bool partial = false );
+        void setActiveBorderMode( ActiveMaximizingMode mode );
+        void setActiveBorder( ActiveBorder border);
+        ActiveMaximizingMode activeBorderMode() const;
+        ActiveBorder activeBorder() const;
+        void setActiveBorderMaximizing(bool maximizing);
+        void cancelActiveBorderMaximizing();
+        bool isActiveBorderMaximizing() const;
+        TQRect activeBorderMaximizeGeometry();
+        void tileToBorder(ActiveBorder border);
 
         void growHorizontal();
         void shrinkHorizontal();
@@ -331,6 +340,7 @@ class Client : public TQObject, public KDecorationDefines
     private slots:
         void autoRaise();
         void shadeHover();
+        void configureRequestTimeout();
         void shortcutActivated();
 	void updateOpacityCache();
 
@@ -448,7 +458,7 @@ class Client : public TQObject, public KDecorationDefines
         static void sendClientMessage( Window w, Atom a, Atom protocol,
             long data1 = 0, long data2 = 0, long data3 = 0 );
 
-        void embedClient( Window w, const XWindowAttributes &attr );    
+        void embedClient( Window w, const XWindowAttributes &attr );
         void detectNoBorder();
         void detectShapable();
         void destroyDecoration();
@@ -472,14 +482,15 @@ class Client : public TQObject, public KDecorationDefines
         int desk;
         bool buttonDown;
         bool moveResizeMode;
+        bool inhibitConfigureRequests;
         bool move_faked_activity;
         Window move_resize_grab_window;
         bool unrestrictedMoveResize;
-        bool isMove() const 
+        bool isMove() const
             {
             return moveResizeMode && mode == PositionCenter;
             }
-        bool isResize() const 
+        bool isResize() const
             {
             return moveResizeMode && mode != PositionCenter;
             }
@@ -550,6 +561,7 @@ class Client : public TQObject, public KDecorationDefines
         WinInfo* info;
         TQTimer* autoRaiseTimer;
         TQTimer* shadeHoverTimer;
+        TQTimer* configureRequestTimer;
         Colormap cmap;
         TQCString resource_name;
         TQCString resource_class;
@@ -600,6 +612,12 @@ class Client : public TQObject, public KDecorationDefines
         bool isBMP_;
         TQTimer* demandAttentionKNotifyTimer;
 
+        bool activeMaximizing;
+        bool activeTiled;
+        TQRect activeTiledOrigGeom;
+        ActiveMaximizingMode activeMode;
+        ActiveBorder currentActiveBorder;
+
         friend bool performTransiencyCheck();
         bool minimized_before_suspend;
     };
@@ -946,7 +964,7 @@ inline bool Client::hasUserTimeSupport() const
     {
     return info->userTime() != -1U;
     }
-    
+
 inline bool Client::ignoreFocusStealing() const
     {
     return ignore_focus_stealing;
