@@ -606,7 +606,7 @@ void ButtonDropSite::drawContents( TQPainter* p )
 
 	TQColor c1( 0x0A, 0x5F, 0x89 );		// KDE 2 titlebar default colour
 	p->fillRect( r, c1 );
-	p->setPen( Qt::white );
+	p->setPen( TQt::white );
 	p->setFont( TQFont( TDEGlobalSettings::generalFont().family(), 12, TQFont::Bold) );
 	p->drawText( r, AlignLeft | AlignVCenter, i18n("TDE") );
 
@@ -689,11 +689,11 @@ ButtonPositionWidget::ButtonPositionWidget(TQWidget *parent, const char* name)
 	layout->addWidget(m_dropSite);
 	layout->addWidget(m_buttonSource);
 
-	connect( m_dropSite, TQT_SIGNAL(buttonAdded(TQChar)), m_buttonSource, TQT_SLOT(hideButton(TQChar)) );
-	connect( m_dropSite, TQT_SIGNAL(buttonRemoved(TQChar)), m_buttonSource, TQT_SLOT(showButton(TQChar)) );
-	connect( m_buttonSource, TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), m_dropSite, TQT_SLOT(removeSelectedButton()) );
+	connect( m_dropSite, TQ_SIGNAL(buttonAdded(TQChar)), m_buttonSource, TQ_SLOT(hideButton(TQChar)) );
+	connect( m_dropSite, TQ_SIGNAL(buttonRemoved(TQChar)), m_buttonSource, TQ_SLOT(showButton(TQChar)) );
+	connect( m_buttonSource, TQ_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), m_dropSite, TQ_SLOT(removeSelectedButton()) );
 
-	connect( m_dropSite, TQT_SIGNAL(changed()), TQT_SIGNAL(changed()) );
+	connect( m_dropSite, TQ_SIGNAL(changed()), TQ_SIGNAL(changed()) );
 
 	// insert all possible buttons into the source (backwards to keep the preferred order...)
 	bool dummy;
