@@ -22,7 +22,7 @@ public:
 
         setCentralWidget( m_host->widget() );
 
-        connect(m_host, TQT_SIGNAL( actionsInitialized() ), this, TQT_SLOT( mergeGUI() ) );
+        connect(m_host, TQ_SIGNAL( actionsInitialized() ), this, TQ_SLOT( mergeGUI() ) );
 
 #if 1
         m_partProcess = new TDEProcess;
@@ -31,10 +31,10 @@ public:
         m_partProcess->start();
 #endif
 
-        KStdAction::quit( this, TQT_SLOT( close() ), actionCollection() );
+        KStdAction::quit( this, TQ_SLOT( close() ), actionCollection() );
         TDESelectAction *s = new TDESelectAction( "http://www.kde.org" , 0,
                            actionCollection(), "location" );
-        connect( s, TQT_SIGNAL(activated( const TQString& ) ), this, TQT_SLOT( slotOpenUrl( const TQString & ) ) );
+        connect( s, TQ_SIGNAL(activated( const TQString& ) ), this, TQ_SLOT( slotOpenUrl( const TQString & ) ) );
         s->setEditable(true);
     }
     virtual ~ShellWindow()
